(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    510285,      10825]*)
(*NotebookOutlinePosition[    510970,      10849]*)
(*  CellTagsIndexPosition[    510926,      10845]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Question:\n\nHow can a CustomMirror[] system be \
optimized?  I have a design with an asymmetric conic mirror and need to \
optimize the system.  A simple example is shown below.  Can you show how to \
optimize the curvature and conic constants (shown in red) below?\n",
  FontFamily->"Arial",
  FontSize->16]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Rayica`Rayica`\>"]\)], "Input"],

Cell["+++++++++++++++++++++++++", "Print"],

Cell[BoxData[
    \("Rayica 2.0 was loaded in 11 s and needs 7359 kilobytes of memory on \
top of 4075 kilobytes already used"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(AsymmetricConicMirror[curvx_, \ kx_, \ curvy_, \ ky_, diam_, \ 
          thickness_]\  := \ 
        CustomMirror[\[IndentingNewLine]Function[{x, 
              y}, \ \(curvx\ x\^2\  + \ curvy\ y\^2\)\/\(1\  + \ \@\(1\  - \ \
curvx\^2\ \((1 + kx)\)\ x\^2\  - \ \(\(curvy\^2\)\(\ \)\((1 + ky)\)\(\ \
\)\(y\^2\)\(\ \ \)\)\)\)], \[IndentingNewLine]diam, \
\[IndentingNewLine]thickness, \[IndentingNewLine]CustomMirror, \
\[IndentingNewLine]SurfacePoints \[Rule] 
            21, \[IndentingNewLine]SurfaceRayIntersections \[Rule] \ 
            FindRoot\  (*\ 
            FindMinimum\ or\ FindRoot\ *) , \
\[IndentingNewLine]SurfaceNormalCalculations \[Rule] Automatic, \  (*\ 
            Numeric\ or\ Automatic\ *) \[IndentingNewLine]GraphicDesign \
\[Rule] Automatic\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AsymmetricConicMirror[{symcurvx_, \ curvx_}, {symkx_, 
            kx_}, \ {symcurvy_, \ curvy_}, \ {symky_, \ ky_}, diam_, \ 
          thickness_]\  := \ 
        CustomMirror[\[IndentingNewLine]Function[{x, 
              y}, \ \(curvx\ x\^2\  + \ curvy\ y\^2\)\/\(1\  + \ \@\(1\  - \ \
curvx\^2\ \((1 + kx)\)\ x\^2\  - \ \(\(curvy\^2\)\(\ \)\((1 + ky)\)\(\ \
\)\(y\^2\)\(\ \ \)\)\)\)], \[IndentingNewLine]diam, \[IndentingNewLine] \
(*\(thickness\)\(,\)*) \[IndentingNewLine]CustomMirror, \
\[IndentingNewLine]SurfacePoints \[Rule] 
            21, \[IndentingNewLine]SymbolicValues \[Rule] {symcurvx -> curvx, 
              symkx \[Rule] kx, symcurvy -> curvy, \ 
              symky -> 
                ky}, \[IndentingNewLine]SymbolicSurfaceApproximation \[Rule] \
{SphericalShape \[Rule] 
                1/symcurvx}, \[IndentingNewLine]SurfaceApproximation \[Rule] \
{SphericalShape \[Rule] 
                1/curvx}, \[IndentingNewLine]SymbolicSurfaceFunction\  \
\[Rule] \ Function[{x, 
                y}, \ \(symcurvx\ x\^2\  + \ symcurvy\ y\^2\)\/\(1\  + \ \
\@\(1\  - \ symcurvx\^2\ \((1 + symkx)\)\ x\^2\  - \ \(\(symcurvy\^2\)\(\ \
\)\((1 + symky)\)\(\ \)\(y\^2\)\(\ \ \)\)\)\)], \
\[IndentingNewLine]SurfaceRayIntersections \[Rule] \ 
            Numeric, \[IndentingNewLine]SurfaceNormalCalculations \[Rule] 
            Automatic, \  (*\ 
            Numeric\ or\ Automatic\ *) \[IndentingNewLine]GraphicDesign \
\[Rule] Automatic\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"sys", " ", "=", " ", 
        RowBox[{"{", "\[IndentingNewLine]", 
          
          RowBox[{\(Move[WedgeOfRays[30, \ NumberOfRays \[Rule] 9], 50]\), 
            ",", "\[IndentingNewLine]", \(Move[
              WedgeOfRays[30, \ NumberOfRays \[Rule] 9], \ 100, 
              TwistAngle \[Rule] 90]\), ",", "\[IndentingNewLine]", 
            RowBox[{"Move", "[", 
              RowBox[{
                RowBox[{"AsymmetricConicMirror", "[", 
                  RowBox[{
                    StyleBox[\(\(-1\)\/175\),
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[",",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[" ",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[\(-1.5\),
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[",",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[" ",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[\(\(-1\)\/150\),
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[",",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[\(-1.5\),
                      FontColor->RGBColor[1, 0, 0]], ",", " ", "100", ",", 
                    " ", "10"}], "]"}], ",", " ", "200"}], "]"}], ",", 
            "\[IndentingNewLine]", \(Baffle[50]\)}], "\[IndentingNewLine]", 
          "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Options[CustomMirror]", "Input"],

Cell[BoxData[
    \({Labels \[Rule] "M", LabelPositions \[Rule] Automatic, 
      ComponentDescription \[Rule] Automatic, Reflectance \[Rule] 100, 
      ComponentMedium \[Rule] BK7, CoatingMedium \[Rule] Automatic, 
      Transmittance \[Rule] Transmittance, 
      SwitchDirectionOnReflection \[Rule] False, FrontSurface \[Rule] True, 
      OffAxis \[Rule] {0, 0}, Hole \[Rule] {}, HoleOffset \[Rule] {0, 0}, 
      FlatSubstrate \[Rule] True, Centered \[Rule] Automatic, 
      InputEdgeThickness \[Rule] False, Temperature \[Rule] Temperature, 
      Tension \[Rule] Tension, GraphicDesign \[Rule] Automatic, 
      SurfaceLabel \[Rule] OtherShape, Simplify \[Rule] True, 
      SymbolicSurfaceIntersectionFunction \[Rule] True, 
      SymbolicSurfaceNormalFunction \[Rule] True, 
      SymbolicValues \[Rule] Automatic, 
      SurfaceRayIntersections \[Rule] Automatic, AccuracyGoal \[Rule] 10, 
      SurfaceNormalCalculations \[Rule] Automatic, 
      ExtrapolateSurfaceFunction \[Rule] Automatic, 
      SurfaceApproximation \[Rule] Automatic, BoundaryFactor \[Rule] 1, 
      BoundingBox \[Rule] False, SurfacePoints \[Rule] 7, 
      Interpolation \[Rule] True, 
      Automatic \[Rule] {SurfaceRendering \[Rule] {Fill, Trace}, 
          EdgeRendering \[Rule] Mesh, CrossRendering \[Rule] Trace}, 
      Sketch \[Rule] {SurfaceRendering \[Rule] Trace, 
          EdgeRendering \[Rule] Trace, CrossRendering \[Rule] Trace}, 
      Wire \[Rule] {SurfaceRendering \[Rule] Mesh, 
          EdgeRendering \[Rule] Mesh, CrossRendering \[Rule] Empty}, 
      Solid \[Rule] {SurfaceRendering \[Rule] {Fill, Trace}, 
          EdgeRendering \[Rule] Fill, 
          CrossRendering \[Rule] Empty}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnalyzeSystem[{\[IndentingNewLine]sys, \
\[IndentingNewLine]Boundary[{\(-1\), \ \(-55\), \ \(-55\)}, {220, \ 55, \ 
              55}]\[IndentingNewLine]}, SequentialTrace \[Rule] True, \ 
        PlotType \[Rule] Full3D, ShowRange \[Rule] All, \ 
        Axes \[Rule] True, \ ImageSize \[Rule] \ 600, \ 
        ColorView \[Rule] SourceID];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81031 
%%ImageSize: 600 486.189 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10  scalefont  setfont
% Scaling calculations
-0.00481315 1.00481 -0.0707267 1.00481 [
[.05109 .26124 -9 -11.7529 ]
[.05109 .26124 0 .24706 ]
[.20008 .20604 -13.6853 -12 ]
[.20008 .20604 .31465 0 ]
[.35642 .14814 -17.738 -12 ]
[.35642 .14814 1.26203 0 ]
[.52068 .08732 -16.903 -12 ]
[.52068 .08732 2.09704 0 ]
[.69347 .02338 -16.0679 -12 ]
[.69347 .02338 2.93205 0 ]
[.81608 .01469 0 -8.19273 ]
[.81608 .01469 20.9375 3.80727 ]
[.85454 .07423 0 -8.12958 ]
[.85454 .07423 20.9375 3.87042 ]
[.89124 .13104 0 -8.06997 ]
[.89124 .13104 9 3.93003 ]
[.92629 .18531 0 -8.01361 ]
[.92629 .18531 14 3.98639 ]
[.95981 .2372 0 -7.96023 ]
[.95981 .2372 14 4.03977 ]
[.97251 .27422 0 -7.9255 ]
[.97251 .27422 20.9375 4.0745 ]
[.98114 .34489 0 -7.8636 ]
[.98114 .34489 20.9375 4.1364 ]
[.99009 .41825 0 -7.79951 ]
[.99009 .41825 9 4.20049 ]
[.99938 .49442 0 -7.73313 ]
[.99938 .49442 14 4.26687 ]
[1.00904 .5736 0 -7.66432 ]
[1.00904 .5736 14 4.33568 ]
[ 0 0 0 0 ]
[ 1 .81031 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04128 .2769 m
.792 0 L
s
.06016 .26994 m
.06469 .27428 L
s
gsave
.05109 .26124 -70 -15.7529 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20875 .21513 m
.21309 .21967 L
s
gsave
.20008 .20604 -74.6853 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.36465 .15762 m
.36877 .16237 L
s
gsave
.35642 .14814 -78.738 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5284 .09723 m
.53226 .10218 L
s
gsave
.52068 .08732 -77.903 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.70061 .03371 m
.70418 .03887 L
s
gsave
.69347 .02338 -77.0679 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.08932 .25918 m
.09202 .26181 L
s
.11875 .24832 m
.12143 .25098 L
s
.14847 .23736 m
.15112 .24004 L
s
.17847 .2263 m
.1811 .229 L
s
.23933 .20385 m
.24191 .2066 L
s
.27021 .19246 m
.27276 .19523 L
s
.30138 .18096 m
.30391 .18376 L
s
.33286 .16935 m
.33536 .17217 L
s
.39676 .14578 m
.3992 .14866 L
s
.42918 .13383 m
.43159 .13672 L
s
.46192 .12175 m
.4643 .12467 L
s
.495 .10955 m
.49734 .1125 L
s
.56215 .08478 m
.56443 .08778 L
s
.59623 .07221 m
.59848 .07523 L
s
.63067 .05951 m
.63289 .06255 L
s
.66546 .04667 m
.66764 .04975 L
s
.73613 .02061 m
.73823 .02373 L
s
.77201 .00737 m
.77408 .01052 L
s
.25 Mabswid
.792 0 m
.95795 .2567 L
s
.80429 .019 m
.79839 .02116 L
s
gsave
.81608 .01469 -61 -12.1927 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.8427 .07843 m
.83679 .08053 L
s
gsave
.85454 .07423 -61 -12.1296 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.87936 .13513 m
.87343 .13718 L
s
gsave
.89124 .13104 -61 -12.07 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.91438 .1893 m
.90843 .1913 L
s
gsave
.92629 .18531 -61 -12.0136 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.94787 .2411 m
.9419 .24305 L
s
gsave
.95981 .2372 -61 -11.9602 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.81212 .03112 m
.80858 .0324 L
s
.81987 .04311 m
.81633 .04439 L
s
.82756 .055 m
.82401 .05627 L
s
.83517 .06677 m
.83162 .06804 L
s
.85017 .08998 m
.84662 .09124 L
s
.85757 .10143 m
.85402 .10268 L
s
.8649 .11277 m
.86135 .11401 L
s
.87217 .124 m
.86861 .12524 L
s
.8865 .14617 m
.88293 .14739 L
s
.89356 .1571 m
.89 .15831 L
s
.90057 .16793 m
.897 .16914 L
s
.90751 .17866 m
.90394 .17987 L
s
.9212 .19985 m
.91763 .20104 L
s
.92796 .2103 m
.92438 .21148 L
s
.93465 .22065 m
.93107 .22184 L
s
.94129 .23092 m
.93771 .2321 L
s
.79638 .00678 m
.79284 .00808 L
s
.95439 .25119 m
.95081 .25235 L
s
.25 Mabswid
.95795 .2567 m
1 .60209 L
s
.96055 .27806 m
.95457 .27997 L
s
gsave
.97251 .27422 -61 -11.9255 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.96914 .34862 m
.96315 .35048 L
s
gsave
.98114 .34489 -61 -11.8636 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.97806 .42185 m
.97204 .42366 L
s
gsave
.99009 .41825 -61 -11.7995 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.98732 .49791 m
.98128 .49965 L
s
gsave
.99938 .49442 -61 -11.7331 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.99694 .57695 m
.99089 .57863 L
s
gsave
1.00904 .5736 -61 -11.6643 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.96225 .29196 m
.95866 .29311 L
s
.96395 .30597 m
.96036 .30711 L
s
.96567 .32008 m
.96208 .32121 L
s
.9674 .3343 m
.9638 .33542 L
s
.9709 .36305 m
.9673 .36416 L
s
.97267 .37759 m
.96907 .37869 L
s
.97445 .39223 m
.97085 .39333 L
s
.97625 .40699 m
.97264 .40808 L
s
.97988 .43683 m
.97627 .43791 L
s
.98172 .45193 m
.97811 .453 L
s
.98357 .46714 m
.97996 .4682 L
s
.98544 .48247 m
.98182 .48352 L
s
.98921 .51347 m
.98559 .51451 L
s
.99112 .52916 m
.9875 .53019 L
s
.99305 .54497 m
.98942 .54599 L
s
.99499 .5609 m
.99136 .56191 L
s
.95887 .26425 m
.95529 .26541 L
s
.99891 .59314 m
.99528 .59414 L
s
0 0 m
1 0 L
1 .81031 L
0 .81031 L
closepath
clip
newpath
.5 Mabswid
.93681 .26473 m
.26877 .4811 L
s
.25094 .79334 m
.26877 .4811 L
s
.938 .685 .527 r
.18561 .52611 m .19799 .51949 L .20436 .54081 L F
.17962 .51267 m .19799 .51949 L .18561 .52611 L F
.17962 .51267 m .1891 .4995 L .19799 .51949 L F
.18989 .54045 m .20436 .54081 L .20781 .5621 L F
.18561 .52611 m .20436 .54081 L .18989 .54045 L F
0 g
.19799 .51949 m
.20436 .54081 L
s
.938 .685 .527 r
.17231 .501 m .1891 .4995 L .17962 .51267 L F
.17231 .501 m .17824 .48208 L .1891 .4995 L F
0 g
.1891 .4995 m
.19799 .51949 L
s
.938 .685 .527 r
.19219 .55476 m .20781 .5621 L .2081 .58202 L F
.18989 .54045 m .20781 .5621 L .19219 .55476 L F
0 g
.20436 .54081 m
.20781 .5621 L
s
.938 .685 .527 r
.16413 .49188 m .17824 .48208 L .17231 .501 L F
.16413 .49188 m .16608 .46838 L .17824 .48208 L F
0 g
.17824 .48208 m
.1891 .4995 L
s
.938 .685 .527 r
.19219 .55476 m .2081 .58202 L .19234 .56812 L F
.19234 .56812 m .2081 .58202 L .20517 .59929 L F
0 g
.20781 .5621 m
.2081 .58202 L
s
.938 .685 .527 r
.173 .53285 m .18561 .52611 L .18989 .54045 L F
.16998 .52607 m .18561 .52611 L .173 .53285 L F
.16998 .52607 m .17962 .51267 L .18561 .52611 L F
.17516 .54008 m .18989 .54045 L .19219 .55476 L F
.173 .53285 m .18989 .54045 L .17516 .54008 L F
.15563 .48592 m .16608 .46838 L .16413 .49188 L F
.15563 .48592 m .15339 .45934 L .16608 .46838 L F
0 g
.16608 .46838 m
.17824 .48208 L
s
.938 .685 .527 r
.16628 .52021 m .17962 .51267 L .16998 .52607 L F
.16628 .52021 m .17231 .501 L .17962 .51267 L F
.17631 .5473 m .19219 .55476 L .19234 .56812 L F
.17516 .54008 m .19219 .55476 L .17631 .5473 L F
.19033 .57964 m .20517 .59929 L .19918 .61274 L F
.19234 .56812 m .20517 .59929 L .19033 .57964 L F
0 g
.20517 .59929 m
.2081 .58202 L
s
.938 .685 .527 r
.16216 .51565 m .17231 .501 L .16628 .52021 L F
.16216 .51565 m .16413 .49188 L .17231 .501 L F
.17631 .5473 m .19234 .56812 L .17637 .55401 L F
.17637 .55401 m .19234 .56812 L .19033 .57964 L F
.15789 .51271 m .16413 .49188 L .16216 .51565 L F
.15789 .51271 m .15563 .48592 L .16413 .49188 L F
.14736 .48356 m .15339 .45934 L .15563 .48592 L F
.14736 .48356 m .14099 .45562 L .15339 .45934 L F
0 g
.15339 .45934 m
.16608 .46838 L
s
.938 .685 .527 r
.19033 .57964 m .19918 .61274 L .18625 .58855 L F
.17533 .55978 m .19033 .57964 L .18625 .58855 L F
.17637 .55401 m .19033 .57964 L .17533 .55978 L F
.18625 .58855 m .19918 .61274 L .19045 .6214 L F
0 g
.19918 .61274 m
.20517 .59929 L
s
.938 .685 .527 r
.16016 .53971 m .173 .53285 L .17516 .54008 L F
.16016 .53971 m .16998 .52607 L .173 .53285 L F
.16016 .53971 m .17516 .54008 L .17631 .5473 L F
.16016 .53971 m .16628 .52021 L .16998 .52607 L F
.16016 .53971 m .17631 .5473 L .17637 .55401 L F
0 g
.25094 .79334 m
.97493 .59359 L
s
.938 .685 .527 r
.15375 .51159 m .15563 .48592 L .15789 .51271 L F
.15375 .51159 m .14736 .48356 L .15563 .48592 L F
.16016 .53971 m .16216 .51565 L .16628 .52021 L F
0 0 0 r
2 Mabswid
.16257 .51066 Mdot
.938 .685 .527 r
.16016 .53971 m .17637 .55401 L .17533 .55978 L F
.18625 .58855 m .19045 .6214 L .18037 .59422 L F
.17325 .56421 m .18625 .58855 L .18037 .59422 L F
.17533 .55978 m .18625 .58855 L .17325 .56421 L F
.16016 .53971 m .15789 .51271 L .16216 .51565 L F
.16016 .53971 m .17533 .55978 L .17325 .56421 L F
0 0 0 r
.16187 .51913 Mdot
.938 .685 .527 r
.13989 .48502 m .14099 .45562 L .14736 .48356 L F
.13989 .48502 m .12973 .4576 L .14099 .45562 L F
0 g
.5 Mabswid
.14099 .45562 m
.15339 .45934 L
s
0 0 0 r
2 Mabswid
.17003 .54842 Mdot
.938 .685 .527 r
.16016 .53971 m .15375 .51159 L .15789 .51271 L F
0 0 0 r
.16125 .52658 Mdot
.938 .685 .527 r
.17325 .56421 m .18037 .59422 L .17027 .56699 L F
.16016 .53971 m .17325 .56421 L .17027 .56699 L F
.15003 .51239 m .14736 .48356 L .15375 .51159 L F
.15003 .51239 m .13989 .48502 L .14736 .48356 L F
.18037 .59422 m .19045 .6214 L .17952 .6246 L F
0 g
.5 Mabswid
.19045 .6214 m
.19918 .61274 L
s
0 0 0 r
2 Mabswid
.16559 .5445 Mdot
.938 .685 .527 r
.18037 .59422 m .17952 .6246 L .17304 .59621 L F
.17027 .56699 m .18037 .59422 L .17304 .59621 L F
.16016 .53971 m .15003 .51239 L .15375 .51159 L F
0 0 0 r
.16069 .53332 Mdot
.1628 .54204 Mdot
.938 .685 .527 r
.17027 .56699 m .17304 .59621 L .16659 .56792 L F
.16016 .53971 m .17027 .56699 L .16659 .56792 L F
0 0 0 r
.16118 .54061 Mdot
.938 .685 .527 r
.16016 .53971 m .14699 .51505 L .15003 .51239 L F
.16016 .53971 m .14484 .51942 L .14699 .51505 L F
.16016 .53971 m .14372 .5252 L .14484 .51942 L F
.16016 .53971 m .14374 .53199 L .14372 .5252 L F
.16016 .53971 m .14488 .53933 L .14374 .53199 L F
.16016 .53971 m .14708 .5467 L .14488 .53933 L F
.16016 .53971 m .15017 .55359 L .14708 .5467 L F
.16016 .53971 m .15395 .55951 L .15017 .55359 L F
.16016 .53971 m .15814 .56406 L .15395 .55951 L F
.16016 .53971 m .16245 .56692 L .15814 .56406 L F
.16016 .53971 m .16659 .56792 L .16245 .56692 L F
0 0 0 r
.16016 .53971 Mdot
.16016 .53971 Mdot
.15914 .53881 Mdot
.938 .685 .527 r
.14699 .51505 m .13989 .48502 L .15003 .51239 L F
0 0 0 r
.15752 .53738 Mdot
.15963 .54612 Mdot
.938 .685 .527 r
.16659 .56792 m .16477 .59435 L .16245 .56692 L F
.16659 .56792 m .17304 .59621 L .16477 .59435 L F
.13373 .49024 m .12973 .4576 L .13989 .48502 L F
.14699 .51505 m .13373 .49024 L .13989 .48502 L F
0 0 0 r
.15471 .5349 Mdot
.938 .685 .527 r
.13373 .49024 m .12039 .46526 L .12973 .4576 L F
0 g
.5 Mabswid
.12973 .4576 m
.14099 .45562 L
s
.938 .685 .527 r
.17304 .59621 m .16709 .62199 L .16477 .59435 L F
.17304 .59621 m .17952 .6246 L .16709 .62199 L F
0 g
.17952 .6246 m
.19045 .6214 L
s
.938 .685 .527 r
.14484 .51942 m .13373 .49024 L .14699 .51505 L F
0 0 0 r
2 Mabswid
.15906 .55293 Mdot
.938 .685 .527 r
.16245 .56692 m .1561 .58869 L .15814 .56406 L F
.16245 .56692 m .16477 .59435 L .1561 .58869 L F
0 0 0 r
.15021 .53093 Mdot
.15844 .5605 Mdot
.938 .685 .527 r
.14484 .51942 m .12934 .49891 L .13373 .49024 L F
.14372 .5252 m .12934 .49891 L .14484 .51942 L F
.15814 .56406 m .14764 .57961 L .15395 .55951 L F
.15814 .56406 m .1561 .58869 L .14764 .57961 L F
.12934 .49891 m .12039 .46526 L .13373 .49024 L F
0 g
.5 Mabswid
.06205 .28395 m
.26877 .4811 L
s
.938 .685 .527 r
.14372 .5252 m .12705 .51048 L .12934 .49891 L F
.14374 .53199 m .12705 .51048 L .14372 .5252 L F
0 0 0 r
2 Mabswid
.15772 .56918 Mdot
0 g
.5 Mabswid
.02461 .61146 m
.06205 .28395 L
s
.938 .685 .527 r
.15395 .55951 m .14001 .56771 L .15017 .55359 L F
.15395 .55951 m .14764 .57961 L .14001 .56771 L F
.16477 .59435 m .15403 .61363 L .1561 .58869 L F
.16477 .59435 m .16709 .62199 L .15403 .61363 L F
0 g
.16709 .62199 m
.17952 .6246 L
s
.938 .685 .527 r
.14374 .53199 m .12703 .52414 L .12705 .51048 L F
.14488 .53933 m .12703 .52414 L .14374 .53199 L F
.15017 .55359 m .13375 .55382 L .14708 .5467 L F
.15017 .55359 m .14001 .56771 L .13375 .55382 L F
.14488 .53933 m .12932 .53894 L .12703 .52414 L F
.14708 .5467 m .12932 .53894 L .14488 .53933 L F
.14708 .5467 m .13375 .55382 L .12932 .53894 L F
.12934 .49891 m .11368 .47818 L .12039 .46526 L F
0 g
.12039 .46526 m
.12973 .4576 L
s
.938 .685 .527 r
.12705 .51048 m .11368 .47818 L .12934 .49891 L F
.1561 .58869 m .14124 .60003 L .14764 .57961 L F
.1561 .58869 m .15403 .61363 L .14124 .60003 L F
0 g
.15403 .61363 m
.16709 .62199 L
s
.02461 .61146 m
.25094 .79334 L
s
.938 .685 .527 r
.12705 .51048 m .11013 .49554 L .11368 .47818 L F
0 g
.11368 .47818 m
.12039 .46526 L
s
.938 .685 .527 r
.12703 .52414 m .11013 .49554 L .12705 .51048 L F
.14764 .57961 m .12966 .58209 L .14001 .56771 L F
.14764 .57961 m .14124 .60003 L .12966 .58209 L F
0 g
.93681 .26473 m
.97493 .59359 L
s
.938 .685 .527 r
.12703 .52414 m .11004 .51616 L .11013 .49554 L F
0 g
.11013 .49554 m
.11368 .47818 L
s
.938 .685 .527 r
.12932 .53894 m .11004 .51616 L .12703 .52414 L F
.14001 .56771 m .12017 .56108 L .13375 .55382 L F
.14001 .56771 m .12966 .58209 L .12017 .56108 L F
0 g
.14124 .60003 m
.15403 .61363 L
s
.938 .685 .527 r
.12932 .53894 m .11346 .53855 L .11004 .51616 L F
.13375 .55382 m .11346 .53855 L .12932 .53894 L F
.13375 .55382 m .12017 .56108 L .11346 .53855 L F
0 g
.11004 .51616 m
.11013 .49554 L
s
.12966 .58209 m
.14124 .60003 L
s
.11004 .51616 m
.11346 .53855 L
s
.12017 .56108 m
.12966 .58209 L
s
.11346 .53855 m
.12017 .56108 L
s
.734 .418 0 r
.82292 .31578 m .82291 .31029 L .8378 .35521 L F
.722 .373 0 r
.811 .28647 m .82291 .31029 L .82292 .31578 L F
.811 .28647 m .80508 .26729 L .82291 .31029 L F
0 g
.82291 .31029 m
.88245 .29108 L
s
.778 .492 0 r
.83286 .34644 m .8378 .35521 L .84872 .39958 L F
.734 .418 0 r
.82292 .31578 m .8378 .35521 L .83286 .34644 L F
0 g
.82291 .31029 m
.8378 .35521 L
s
.741 .359 0 r
.79789 .26027 m .80508 .26729 L .811 .28647 L F
.79789 .26027 m .7855 .22864 L .80508 .26729 L F
0 g
.80508 .26729 m
.82291 .31029 L
s
.80508 .26729 m
.86564 .24733 L
s
.844 .585 .042 r
.84011 .37663 m .84872 .39958 L .85484 .44087 L F
.778 .492 0 r
.83286 .34644 m .84872 .39958 L .84011 .37663 L F
0 g
.8378 .35521 m
.84872 .39958 L
s
.83803 .35514 m
.89654 .33668 L
s
.8378 .35521 m
.83803 .35514 L
s
.88245 .29108 m
.89654 .33668 L
s
.86564 .24733 m
.88245 .29108 L
s
.89654 .33668 m
.9071 .38156 L
s
.782 .372 0 r
.78445 .2388 m .7855 .22864 L .79789 .26027 L F
.78445 .2388 m .76543 .19662 L .7855 .22864 L F
0 g
.7855 .22864 m
.80508 .26729 L
s
.7855 .22864 m
.84704 .20795 L
s
.67769 .05833 m
.77705 .02192 L
s
.06205 .28395 m
.67769 .05833 L
s
.84704 .20795 m
.86564 .24733 L
s
.844 .585 .042 r
.84011 .37663 m .85484 .44087 L .84415 .40452 L F
0 g
.84881 .39956 m
.9071 .38156 L
s
.84872 .39958 m
.84881 .39956 L
s
.914 .677 .178 r
.84415 .40452 m .85484 .44087 L .85561 .47657 L F
.2 0 1 r
.30988 .49178 m
.84617 .41722 L
s
.84782 .41699 m
.84786 .41699 L
s
.17003 .54842 m
.84619 .41734 L
s
.84783 .41703 m
.84787 .41702 L
s
0 g
.84872 .39958 m
.85484 .44087 L
s
.85484 .44087 m
.91348 .42313 L
s
.9071 .38156 m
.91348 .42313 L
s
.82769 .17534 m
.84704 .20795 L
s
.831 .405 0 r
.77154 .22353 m .76543 .19662 L .78445 .2388 L F
.77154 .22353 m .7461 .17336 L .76543 .19662 L F
0 g
.76543 .19662 m
.7855 .22864 L
s
.76543 .19662 m
.82769 .17534 L
s
.896 .566 .076 r
.81713 .32338 m .82292 .31578 L .83286 .34644 L F
.889 .539 .054 r
.81116 .3084 m .82292 .31578 L .81713 .32338 L F
.81116 .3084 m .811 .28647 L .82292 .31578 L F
0 g
.91348 .42313 m
.9152 .45885 L
s
.91348 .42313 m
.88998 .39039 L
s
.914 .604 .122 r
.82209 .33907 m .83286 .34644 L .84011 .37663 L F
.896 .566 .076 r
.81713 .32338 m .83286 .34644 L .82209 .33907 L F
.892 .526 .056 r
.80457 .29509 m .811 .28647 L .81116 .3084 L F
.80457 .29509 m .79789 .26027 L .811 .28647 L F
.967 .748 .31 r
.84465 .42835 m .85561 .47657 L .85087 .50429 L F
.914 .677 .178 r
.84415 .40452 m .85561 .47657 L .84465 .42835 L F
0 g
.85484 .44087 m
.85561 .47657 L
s
.85561 .47657 m
.9152 .45885 L
s
.2 0 1 r
.84787 .41702 m
.84844 .41691 L
s
.84786 .41699 m
.84844 .41691 L
s
0 0 0 r
2 Mabswid
.84844 .41691 Mdot
.939 .648 .186 r
.82569 .35447 m .84011 .37663 L .84415 .40452 L F
.914 .604 .122 r
.82209 .33907 m .84011 .37663 L .82569 .35447 L F
.902 .526 .078 r
.79781 .28432 m .79789 .26027 L .80457 .29509 L F
.79781 .28432 m .78445 .2388 L .79789 .26027 L F
0 g
.5 Mabswid
.80875 .15168 m
.82769 .17534 L
s
.83193 .22291 m
.82769 .17534 L
s
.939 .648 .186 r
.82569 .35447 m .84415 .40452 L .82767 .3686 L F
.963 .691 .259 r
.82767 .3686 m .84415 .40452 L .84465 .42835 L F
0 g
.84415 .40452 m
.85484 .44087 L
s
.2 0 1 r
.84024 .39598 m
.84075 .39589 L
s
.30988 .49178 m
.83569 .3968 L
s
.84023 .39598 m
.84024 .39598 L
s
.84025 .396 m
.84075 .39589 L
s
.16559 .5445 m
.83574 .39699 L
s
.84024 .396 m
.84025 .396 L
s
0 g
.9152 .45885 m
.912 .48635 L
s
.875 .449 .037 r
.75999 .21559 m .7461 .17336 L .77154 .22353 L F
.75999 .21559 m .72871 .16068 L .7461 .17336 L F
0 g
.7461 .17336 m
.76543 .19662 L
s
.7461 .17336 m
.80875 .15168 L
s
0 0 0 r
2 Mabswid
.84075 .39589 Mdot
.916 .535 .118 r
.79132 .27682 m .78445 .2388 L .79781 .28432 L F
1 0 0 r
.5 Mabswid
.16187 .51913 m
.79189 .27749 L
s
.79541 .27614 m
.79586 .27596 L
s
.46689 .44151 m
.79218 .27782 L
s
.79542 .27619 m
.79586 .27596 L
s
.916 .535 .118 r
.79132 .27682 m .77154 .22353 L .78445 .2388 L F
1 0 0 r
.79018 .25832 m
.7909 .25791 L
s
.46689 .44151 m
.78545 .26101 L
s
.79015 .25822 m
.7909 .25791 L
s
.16257 .51066 m
.78516 .26022 L
s
0 g
.76543 .19662 m
.78445 .2388 L
s
.88998 .39039 m
.86575 .35664 L
s
.967 .748 .31 r
.84465 .42835 m .85087 .50429 L .84152 .4465 L F
.982 .725 .331 r
.82789 .38052 m .84465 .42835 L .84152 .4465 L F
.963 .691 .259 r
.82767 .3686 m .84465 .42835 L .82789 .38052 L F
.2 0 1 r
.30988 .49178 m
.8278 .37561 L
s
.1628 .54204 m
.8278 .37569 L
s
.83063 .37499 m
.83101 .37489 L
s
.8306 .37499 m
.83063 .37499 L
s
.83063 .37498 m
.83101 .37489 L
s
.8306 .37498 m
.83063 .37498 L
s
.994 .789 .417 r
.84152 .4465 m .85087 .50429 L .84085 .52188 L F
0 g
.85087 .50429 m
.912 .48635 L
s
.85087 .50429 m
.85561 .47657 L
s
0 0 0 r
2 Mabswid
.7909 .25791 Mdot
0 g
.5 Mabswid
.83629 .27172 m
.83193 .22291 L
s
.966 .649 .268 r
.80503 .33325 m .81713 .32338 L .82209 .33907 L F
.964 .641 .263 r
.80503 .33325 m .81116 .3084 L .81713 .32338 L F
0 g
.79142 .13881 m
.80875 .15168 L
s
.97 .659 .281 r
.80503 .33325 m .82209 .33907 L .82569 .35447 L F
.963 .636 .263 r
.80503 .33325 m .80457 .29509 L .81116 .3084 L F
0 0 0 r
2 Mabswid
.83101 .37489 Mdot
.929 .55 .169 r
.78553 .27314 m .77154 .22353 L .79132 .27682 L F
.78553 .27314 m .75999 .21559 L .77154 .22353 L F
.974 .671 .299 r
.80503 .33325 m .82569 .35447 L .82767 .3686 L F
.963 .634 .267 r
.80503 .33325 m .79781 .28432 L .80457 .29509 L F
.978 .682 .321 r
.80503 .33325 m .82767 .3686 L .82789 .38052 L F
0 g
.5 Mabswid
.82767 .3686 m
.84415 .40452 L
s
0 0 0 r
2 Mabswid
.79586 .27596 Mdot
0 g
.5 Mabswid
.912 .48635 m
.90387 .50351 L
s
.994 .789 .417 r
.84152 .4465 m .84085 .52188 L .83494 .45761 L F
.993 .747 .394 r
.82632 .38942 m .84152 .4465 L .83494 .45761 L F
.982 .725 .331 r
.82789 .38052 m .84152 .4465 L .82632 .38942 L F
.905 .494 .145 r
.75053 .21577 m .72871 .16068 L .75999 .21559 L F
.75053 .21577 m .71435 .15995 L .72871 .16068 L F
0 g
.72871 .16068 m
.7461 .17336 L
s
.72871 .16068 m
.79142 .13881 L
s
.963 .633 .275 r
.80503 .33325 m .79132 .27682 L .79781 .28432 L F
1 0 0 r
.16125 .52658 m
.79597 .29596 L
s
.79934 .29473 m
.79989 .29453 L
s
.46689 .44151 m
.79603 .29623 L
s
.79935 .29477 m
.79989 .29453 L
s
0 g
.78445 .2388 m
.79781 .28432 L
s
.982 .692 .344 r
.80503 .33325 m .82789 .38052 L .82632 .38942 L F
.2 0 1 r
.81844 .35418 m
.81858 .35414 L
s
.16118 .54061 m
.81349 .35558 L
s
.81858 .35414 m
.81913 .35399 L
s
.81843 .35418 m
.81858 .35414 L
s
.30988 .49178 m
.81347 .35552 L
s
.81858 .35414 m
.81913 .35399 L
s
0 g
.86575 .35664 m
.84076 .32181 L
s
0 0 0 r
2 Mabswid
.79989 .29453 Mdot
.999 .802 .494 r
.83494 .45761 m .84085 .52188 L .82619 .52764 L F
0 g
.5 Mabswid
.84085 .52188 m
.90387 .50351 L
s
.84085 .52188 m
.85087 .50429 L
s
0 0 0 r
2 Mabswid
.81913 .35399 Mdot
.964 .635 .287 r
.80503 .33325 m .78553 .27314 L .79132 .27682 L F
1 0 0 r
.5 Mabswid
.80224 .3139 m
.80295 .31363 L
s
.80218 .31392 m
.80224 .3139 L
s
.46689 .44151 m
.79913 .31508 L
s
.80224 .31387 m
.80295 .31363 L
s
.80217 .31389 m
.80224 .31387 L
s
.16069 .53332 m
.79909 .31495 L
s
.939 .569 .226 r
.78083 .27357 m .75999 .21559 L .78553 .27314 L F
.78083 .27357 m .75053 .21577 L .75999 .21559 L F
0 g
.84076 .32181 m
.83629 .27172 L
s
.993 .747 .394 r
.82632 .38942 m .83494 .45761 L .82305 .39466 L F
.984 .699 .365 r
.80503 .33325 m .82632 .38942 L .82305 .39466 L F
.999 .802 .494 r
.83494 .45761 m .82619 .52764 L .82533 .46069 L F
.995 .756 .442 r
.82305 .39466 m .83494 .45761 L .82533 .46069 L F
0 g
.77693 .13807 m
.79142 .13881 L
s
0 0 0 r
2 Mabswid
.80295 .31363 Mdot
.966 .638 .302 r
.80503 .33325 m .78083 .27357 L .78553 .27314 L F
.995 .756 .442 r
.82305 .39466 m .82533 .46069 L .81831 .39583 L F
.984 .703 .381 r
.80503 .33325 m .82305 .39466 L .81831 .39583 L F
0 g
.5 Mabswid
.90387 .50351 m
.89114 .50872 L
s
.967 .643 .321 r
.80503 .33325 m .77753 .27818 L .78083 .27357 L F
.968 .651 .341 r
.80503 .33325 m .77586 .2867 L .77753 .27818 L F
.97 .659 .361 r
.80503 .33325 m .77594 .29861 L .77586 .2867 L F
.972 .668 .38 r
.80503 .33325 m .77778 .31308 L .77594 .29861 L F
.2 0 1 r
.78817 .31295 m
.78843 .31286 L
s
.78803 .313 m
.78817 .31295 L
s
.78843 .31286 m
.7887 .31276 L
s
.78817 .31296 m
.78843 .31286 L
s
.78803 .31301 m
.78817 .31296 L
s
.78843 .31286 m
.7887 .31276 L
s
.974 .677 .394 r
.80503 .33325 m .78128 .32911 L .77778 .31308 L F
.2 0 1 r
.30988 .49178 m
.77854 .31656 L
s
.15914 .53881 m
.77851 .31642 L
s
.976 .685 .404 r
.80503 .33325 m .78619 .34553 L .78128 .32911 L F
1 0 0 r
.46689 .44151 m
.78449 .33983 L
s
.2 0 1 r
.30988 .49178 m
.78449 .33983 L
s
1 0 0 r
.16016 .53971 m
.78449 .33983 L
s
.978 .692 .409 r
.80503 .33325 m .7922 .36115 L .78619 .34553 L F
1 0 0 r
.46689 .44151 m
.79076 .35739 L
s
.15963 .54612 m
.79096 .35792 L
s
.98 .697 .41 r
.80503 .33325 m .79889 .37483 L .7922 .36115 L F
0 g
.02461 .61146 m
.71096 .39488 L
s
.981 .701 .408 r
.80503 .33325 m .80579 .38561 L .79889 .37483 L F
0 g
.71096 .39488 m
.7126 .39436 L
s
1 0 0 r
.15906 .55293 m
.79958 .37591 L
s
.46689 .44151 m
.79929 .37546 L
s
.983 .703 .403 r
.80503 .33325 m .81242 .39276 L .80579 .38561 L F
.984 .704 .394 r
.80503 .33325 m .81831 .39583 L .81242 .39276 L F
1 0 0 r
.80604 .37413 m
.80618 .37409 L
s
.80604 .37412 m
.80618 .37409 L
s
.80606 .35342 m
.80611 .35341 L
s
.80606 .35342 m
.80611 .35341 L
s
.80562 .37424 m
.80576 .37421 L
s
.80576 .37421 m
.80604 .37413 L
s
.80562 .3742 m
.80576 .37417 L
s
.80576 .37417 m
.80604 .37412 L
s
0 0 0 r
2 Mabswid
.80503 .33325 Mdot
.80503 .33325 Mdot
0 g
.5 Mabswid
.79781 .28432 m
.80503 .33325 L
s
.80503 .33325 m
.82767 .3686 L
s
1 0 0 r
.80532 .35361 m
.80539 .35359 L
s
.80539 .35359 m
.80553 .35356 L
s
.80533 .35364 m
.80539 .35362 L
s
.80539 .35362 m
.80553 .35358 L
s
.80576 .3535 m
.80606 .35342 L
s
.80553 .35356 m
.80576 .3535 L
s
.80576 .35351 m
.80606 .35342 L
s
.80553 .35358 m
.80576 .35351 L
s
.946 .59 .285 r
.77753 .27818 m .75053 .21577 L .78083 .27357 L F
.921 .536 .247 r
.7438 .22434 m .71435 .15995 L .75053 .21577 L F
.7438 .22434 m .70396 .17187 L .71435 .15995 L F
0 g
.71435 .15995 m
.72871 .16068 L
s
.71435 .15995 m
.77693 .13807 L
s
.946 .59 .285 r
.77753 .27818 m .7438 .22434 L .75053 .21577 L F
.992 .757 .476 r
.81831 .39583 m .81336 .45524 L .81242 .39276 L F
.81831 .39583 m .82533 .46069 L .81336 .45524 L F
0 0 0 r
2 Mabswid
.80611 .35341 Mdot
0 g
.5 Mabswid
.84535 .37325 m
.84076 .32181 L
s
.84076 .32181 m
.81496 .28587 L
s
.992 .798 .543 r
.82533 .46069 m .80789 .52053 L .81336 .45524 L F
.82533 .46069 m .82619 .52764 L .80789 .52053 L F
0 g
.82619 .52764 m
.84085 .52188 L
s
.82619 .52764 m
.89114 .50872 L
s
.949 .611 .341 r
.77586 .2867 m .7438 .22434 L .77753 .27818 L F
0 g
.77705 .02192 m
.93681 .26473 L
s
.985 .751 .498 r
.81242 .39276 m .79989 .44137 L .80579 .38561 L F
.81242 .39276 m .81336 .45524 L .79989 .44137 L F
0 0 0 r
2 Mabswid
.7887 .31276 Mdot
.80618 .37409 Mdot
0 g
.5 Mabswid
.76641 .1501 m
.77693 .13807 L
s
.949 .611 .341 r
.77586 .2867 m .74027 .241 L .7438 .22434 L F
.951 .632 .39 r
.77594 .29861 m .74027 .241 L .77586 .2867 L F
.927 .572 .336 r
.74027 .241 m .70396 .17187 L .7438 .22434 L F
.978 .74 .509 r
.80579 .38561 m .78589 .41986 L .79889 .37483 L F
1 0 0 r
.46689 .44151 m
.79248 .39704 L
s
.978 .74 .509 r
.80579 .38561 m .79989 .44137 L .78589 .41986 L F
0 g
.80503 .33325 m
.80579 .38561 L
s
1 0 0 r
.15772 .56918 m
.78661 .42097 L
s
.80244 .41723 m
.80248 .41723 L
s
.80248 .41723 m
.80324 .41705 L
s
.46689 .44151 m
.78635 .41827 L
s
.80246 .4171 m
.80249 .4171 L
s
.80249 .4171 m
.80324 .41705 L
s
.15844 .5605 m
.79201 .39868 L
s
.80475 .39542 m
.80476 .39542 L
s
.80476 .39542 m
.80523 .3953 L
s
.80476 .39537 m
.80477 .39537 L
s
.80477 .39537 m
.80523 .3953 L
s
0 0 0 r
2 Mabswid
.80523 .3953 Mdot
.979 .783 .57 r
.81336 .45524 m .78729 .50043 L .79989 .44137 L F
.81336 .45524 m .80789 .52053 L .78729 .50043 L F
0 g
.5 Mabswid
.80412 .36548 m
.97493 .59359 L
s
.80789 .52053 m
.82619 .52764 L
s
.951 .632 .39 r
.77594 .29861 m .74021 .26477 L .74027 .241 L F
.952 .653 .432 r
.77778 .31308 m .74021 .26477 L .77594 .29861 L F
0 g
.77594 .29861 m
.80503 .33325 L
s
.2 0 1 r
.76975 .29275 m
.77013 .29258 L
s
.30988 .49178 m
.76393 .29527 L
s
.76974 .29274 m
.77013 .29258 L
s
.15752 .53738 m
.76381 .29511 L
s
0 g
.89114 .50872 m
.87447 .50101 L
s
.97 .726 .511 r
.79889 .37483 m .77237 .39216 L .7922 .36115 L F
.79889 .37483 m .78589 .41986 L .77237 .39216 L F
.927 .572 .336 r
.74027 .241 m .69826 .19624 L .70396 .17187 L F
0 g
.70396 .17187 m
.76641 .1501 L
s
.70396 .17187 m
.71435 .15995 L
s
0 0 0 r
2 Mabswid
.77013 .29258 Mdot
.952 .653 .432 r
.77778 .31308 m .74369 .29407 L .74021 .26477 L F
.2 0 1 r
.5 Mabswid
.30988 .49178 m
.74162 .27664 L
s
.74891 .27301 m
.74936 .27278 L
s
.74891 .27301 m
.74891 .27301 L
s
.15471 .5349 m
.74157 .27622 L
s
.74889 .27299 m
.74936 .27278 L
s
.74889 .27299 m
.74889 .27299 L
s
.954 .673 .465 r
.78128 .32911 m .74369 .29407 L .77778 .31308 L F
0 g
.85006 .42608 m
.84535 .37325 L
s
.963 .71 .504 r
.7922 .36115 m .76031 .36031 L .78619 .34553 L F
.7922 .36115 m .77237 .39216 L .76031 .36031 L F
0 0 0 r
2 Mabswid
.80324 .41705 Mdot
.954 .673 .465 r
.78128 .32911 m .75053 .32675 L .74369 .29407 L F
.958 .692 .489 r
.78619 .34553 m .75053 .32675 L .78128 .32911 L F
.78619 .34553 m .76031 .36031 L .75053 .32675 L F
0 g
.5 Mabswid
.77705 .02192 m
.80412 .36548 L
s
.81496 .28587 m
.78831 .24875 L
s
.80789 .52053 m
.87447 .50101 L
s
.927 .604 .409 r
.74021 .26477 m .69826 .19624 L .74027 .241 L F
.965 .762 .581 r
.79989 .44137 m .76592 .46832 L .78589 .41986 L F
.79989 .44137 m .78729 .50043 L .76592 .46832 L F
0 g
.79989 .44137 m
.80579 .38561 L
s
.78729 .50043 m
.79989 .44137 L
s
.78729 .50043 m
.80789 .52053 L
s
.76081 .17465 m
.76641 .1501 L
s
0 0 0 r
2 Mabswid
.74936 .27278 Mdot
.927 .604 .409 r
.74021 .26477 m .69774 .23183 L .69826 .19624 L F
0 g
.5 Mabswid
.69826 .19624 m
.70396 .17187 L
s
.927 .634 .466 r
.74369 .29407 m .69774 .23183 L .74021 .26477 L F
0 g
.74021 .26477 m
.77594 .29861 L
s
.2 0 1 r
.72593 .2537 m
.72644 .2534 L
s
.30988 .49178 m
.71746 .25854 L
s
.72589 .25367 m
.72644 .2534 L
s
.15021 .53093 m
.71702 .25794 L
s
0 g
.87447 .50101 m
.8549 .48036 L
s
.8549 .48036 m
.85006 .42608 L
s
.951 .738 .579 r
.78589 .41986 m .74537 .42634 L .77237 .39216 L F
.78589 .41986 m .76592 .46832 L .74537 .42634 L F
0 g
.69826 .19624 m
.76081 .17465 L
s
0 0 0 r
2 Mabswid
.72644 .2534 Mdot
0 g
.5 Mabswid
.78729 .50043 m
.8549 .48036 L
s
.76592 .46832 m
.78729 .50043 L
s
.927 .634 .466 r
.74369 .29407 m .70257 .27628 L .69774 .23183 L F
0 g
.69774 .23183 m
.69826 .19624 L
s
.69774 .23183 m
.74021 .26477 L
s
.929 .661 .511 r
.75053 .32675 m .70257 .27628 L .74369 .29407 L F
0 g
.78831 .24875 m
.76078 .21039 L
s
.941 .713 .566 r
.77237 .39216 m .72716 .37766 L .76031 .36031 L F
.77237 .39216 m .74537 .42634 L .72716 .37766 L F
.929 .661 .511 r
.75053 .32675 m .71257 .32623 L .70257 .27628 L F
.933 .688 .544 r
.76031 .36031 m .71257 .32623 L .75053 .32675 L F
.76031 .36031 m .72716 .37766 L .71257 .32623 L F
0 g
.7126 .39436 m
.80412 .36548 L
s
.76078 .21039 m
.76081 .17465 L
s
.69774 .23183 m
.76078 .21039 L
s
.69774 .23183 m
.70257 .27628 L
s
.8549 .48036 m
.83381 .44779 L
s
.74537 .42634 m
.76592 .46832 L
s
.76592 .46832 m
.83381 .44779 L
s
.70257 .27628 m
.76652 .25496 L
s
.70257 .27628 m
.71257 .32623 L
s
.76652 .25496 m
.76078 .21039 L
s
.72716 .37766 m
.74537 .42634 L
s
.74537 .42634 m
.81281 .40548 L
s
.83381 .44779 m
.81281 .40548 L
s
.71257 .32623 m
.77774 .30502 L
s
.71257 .32623 m
.72716 .37766 L
s
.72716 .37766 m
.79359 .35658 L
s
.77774 .30502 m
.76652 .25496 L
s
.81281 .40548 m
.79359 .35658 L
s
.79359 .35658 m
.77774 .30502 L
s
.25 Mabswid
.04128 .2769 m
.792 0 L
s
.06016 .26994 m
.06469 .27428 L
s
gsave
.05109 .26124 -70 -15.7529 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20875 .21513 m
.21309 .21967 L
s
gsave
.20008 .20604 -74.6853 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.36465 .15762 m
.36877 .16237 L
s
gsave
.35642 .14814 -78.738 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5284 .09723 m
.53226 .10218 L
s
gsave
.52068 .08732 -77.903 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.70061 .03371 m
.70418 .03887 L
s
gsave
.69347 .02338 -77.0679 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
.08932 .25918 m
.09202 .26181 L
s
.11875 .24832 m
.12143 .25098 L
s
.14847 .23736 m
.15112 .24004 L
s
.17847 .2263 m
.1811 .229 L
s
.23933 .20385 m
.24191 .2066 L
s
.27021 .19246 m
.27276 .19523 L
s
.30138 .18096 m
.30391 .18376 L
s
.33286 .16935 m
.33536 .17217 L
s
.39676 .14578 m
.3992 .14866 L
s
.42918 .13383 m
.43159 .13672 L
s
.46192 .12175 m
.4643 .12467 L
s
.495 .10955 m
.49734 .1125 L
s
.56215 .08478 m
.56443 .08778 L
s
.59623 .07221 m
.59848 .07523 L
s
.63067 .05951 m
.63289 .06255 L
s
.66546 .04667 m
.66764 .04975 L
s
.73613 .02061 m
.73823 .02373 L
s
.77201 .00737 m
.77408 .01052 L
s
.25 Mabswid
.95795 .2567 m
1 .60209 L
s
.96055 .27806 m
.95457 .27997 L
s
gsave
.97251 .27422 -61 -11.9255 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.96914 .34862 m
.96315 .35048 L
s
gsave
.98114 .34489 -61 -11.8636 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.938 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.97806 .42185 m
.97204 .42366 L
s
gsave
.99009 .41825 -61 -11.7995 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.98732 .49791 m
.98128 .49965 L
s
gsave
.99938 .49442 -61 -11.7331 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.99694 .57695 m
.99089 .57863 L
s
gsave
1.00904 .5736 -61 -11.6643 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
.96225 .29196 m
.95866 .29311 L
s
.96395 .30597 m
.96036 .30711 L
s
.96567 .32008 m
.96208 .32121 L
s
.9674 .3343 m
.9638 .33542 L
s
.9709 .36305 m
.9673 .36416 L
s
.97267 .37759 m
.96907 .37869 L
s
.97445 .39223 m
.97085 .39333 L
s
.97625 .40699 m
.97264 .40808 L
s
.97988 .43683 m
.97627 .43791 L
s
.98172 .45193 m
.97811 .453 L
s
.98357 .46714 m
.97996 .4682 L
s
.98544 .48247 m
.98182 .48352 L
s
.98921 .51347 m
.98559 .51451 L
s
.99112 .52916 m
.9875 .53019 L
s
.99305 .54497 m
.98942 .54599 L
s
.99499 .5609 m
.99136 .56191 L
s
.95887 .26425 m
.95529 .26541 L
s
.99891 .59314 m
.99528 .59414 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 486.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001iR000`400?l00000o`00003ooooooooo
oooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo
003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003ooooooooo
ooooF_ooool00?ooooooboooool2o`0008cooooo003oooooolSooooo0ol000000ooooooo0000oooo
o`2;ooooo`00ooooooo5ooooo`?o00001Oooool00ol0003oooooooooo`29ooooo`00ooooooo3oooo
o`;o00002Oooool00ol0003oooooooooo`28ooooo`00ooooooo0ooooo`?o00002_ooool2o`0001Co
oooo0ol00003ooooo`;o0000K_ooool00?oooooo_Oooool4o`0000_ooooo00Co0000oooooooooooo
00005_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo06_ooooo003oooooohCooooo
0ol00003ooooo`;o00000oooool2o`0002Wooooo0ol00004ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02_ooool4o`0000Gooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`1[ooooo`00oooooon4ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo02Cooooo0_l0000Fooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`1[ooooo`00oooooon5ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo027o
oooo0ol0000Iooooo`03o`000?oooooooooo00oooooo0ol00002ooooo`04o`000?ooooooooooo`00
06gooooo003oooooohGooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool07_ooool3o`0001cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0006gooooo003oooooohKooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01cooooo0_l0000P
ooooo`03o`000?oooooooooo00oooooo0ol00002ooooo`;o0000K_ooool00?ooooooQ?ooool00ol0
003oooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooooooo
o`0Iooooo`?o00008Oooool3o`0008Gooooo003oooooohGooooo00?o0000ooooooooool00_ooool2
o`0000?ooooo0_l0000Iooooo`?o00008_ooool2o`0000;ooooo00?o0000ooooooooool0Poooool0
0?ooooooYoooool3o`000003ooooool0003ooooo01Gooooo0_l0000@ooooo`03o`000?oooooooooo
08;ooooo003oooooojGooooo0_l00005ooooo`03o`000?oooooooooo013ooooo0ol000000ooooooo
0000ooooo`0@ooooo`03o`000?oooooooooo087ooooo003ooooooj;ooooo0ol0000Gooooo`?o0000
1?ooool2o`00013ooooo00?o0000ooooooooool0POooool00?ooooooWoooool3o`0001Oooooo0ol0
0007ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0P?ooool00?ooooooWOooool2
o`0001Sooooo0_l0000:ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0Ooooool0
0?ooooooV_ooool3o`0001Oooooo0ol0000<ooooo`04o`000?ooooooooooo`0000oooooo0_l00021
ooooo`00oooooonGooooo`?o00005oooool3o`0000oooooo00Go0000ooooooooooooooooo`00000=
ooooo`04o`000?ooooooooooo`00083ooooo003ooooooiCooooo1?l0000Fooooo`?o00004oooool0
1?l0003oooooooooool0000Aooooo`03o`000?oooooooooo07gooooo003ooooooi;ooooo0_l00003
ooooo`03o`000?oooooooooo01;ooooo0_l0000Fooooo`05o`000?ooooooooooooooool000004?oo
ool00ol0003oooooooooo`1mooooo`00oooooon?ooooo`?o00001_ooool00ol0003oooooooooo`0>
ooooo`?o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0O?ooool00?ooooooS?ooool3o`0000[ooooo00?o0000ooooooooool02_ooool3o`00
01_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07cooooo003ooooooh[ooooo0_l0000Gooooo`?o00007_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Noooool00?ooooooQoooool3o`0001Kooooo
0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool2o`0007cooooo
003oooooohCooooo0ol0000Gooooo`;o00009?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooool00000O?ooool00?ooooooP_ooool2o`0001Oooooo0ol0000V
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1i
ooooo`00oooooomoooooo`?o000000?oooooo`000?ooool04oooool3o`0002Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07Sooooo003oooooogco
oooo0ol00005ooooo`03o`000?oooooooooo00kooooo0ol0000/ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1hooooo`00oooooomiooooo`?o0000
5oooool2o`0002oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo07Oooooo003oooooogOooooo0_l0000Gooooo`?o0000<Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0M_ooool00?ooooooM?ooool3
o`0001Kooooo0ol0000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool2
o`0007Sooooo003oooooog7ooooo0ol0000Fooooo`?o0000>?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000Moooool00?ooooooKoooool2o`00
01Oooooo0_l0000kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`1dooooo`00oooooom/ooooo`?o00005_ooool3o`0003gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07Cooooo003oooooofWooooo
0ol00003ooooo`03o`000?oooooooooo013ooooo0ol00010ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1cooooo`00oooooomVooooo`?o00005_oo
ool3o`0004?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo07;ooooo003oooooofCooooo0_l0000Gooooo`;o0000A_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0L_ooool00?ooooooHOooool3o`00
01Kooooo0ol00018ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`00
01?ooooo0ol00002ooooo`?o0000F?ooool00?ooooooG_ooool3o`0001Kooooo0ol0001;ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0EOooool00?ooooooG?ooool2o`0001Oo
oooo0_l0001>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`Co00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Go
oooo003ooooooeWooooo0ol0000Fooooo`?o0000D?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05Gooooo003oooooob3ooooo0ol000001?oooooo0000o`000?l00003ooooo`;o0000
:_ooool3o`000003ooooool0003ooooo01?ooooo0ol0001Cooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?o0000
F?ooool00?oooooo8Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool09?ooool3o`0000Gooooo00?o0000ooooooooool03_ooool3o`0005Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`1Hooooo`00oooooolQooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Rooooo`;o00005oooool2
o`0005[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`;o00004?ooool0
0ol0003oooooooooo`02ooooo`?o0000Eoooool00?oooooo8Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool07oooool3o`0001Kooooo0ol0001Loooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001_oooo
o`00oooooolQooooo`03o`000?oooooooooo00?o00000_ooool01?l0003oooooooooool0000Noooo
o`?o00005_ooool3o`0005oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool00000K_ooool00?oooooo8Oooool01?l0003oooooooooool00004
ooooo`04o`000?ooooooooooo`0001cooooo0_l0000Fooooo`?o0000H_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Joooool00?oooooo8?ooool2
o`0000?ooooo0ol00002ooooo`;o00006_ooool3o`0001Kooooo0_l0001Uooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1[ooooo`00oooooom3oooo
o`?o000000?oooooo`000?ooool04oooool3o`0006Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo06[ooooo003ooooood7ooooo0_l00005ooooo`03
o`000?oooooooooo00kooooo0ol0001Zooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Yooooo`00oooooolnooooo`?o00005_ooool2o`0006gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`;o0000Joooool00?oooooo>ooo
ool3o`0001Kooooo0ol0001_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02ooo
ool01?l0003oooooooooool0001Zooooo`00oooooolhooooo`?o00005_ooool3o`0007;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Sooooo003o
ooooocKooooo0_l0000Fooooo`?o0000MOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0Ioooool00?oooooo<oooool3o`0001Kooooo0_l0001hoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Voooo
o`00ooooool`ooooo`Co00005Oooool3o`0007[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo06Kooooo003oooooobkooooo0_l00004ooooo`03o`00
0?oooooooooo00oooooo0ol0001nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Uooooo`00ooooool[ooooo`?o00001oooool00ol0003ooooooooo
o`0<ooooo`;o0000POooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo0_l0
001Vooooo`00oooooolXooooo`?o00005_ooool3o`0008?ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000006Kooooo003oooooobGooooo0ol0000Foooo
o`?o0000Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0Hoooool00?oooooo8oooool2o`0001Kooooo0ol00029ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Rooooo`00oooooolPooooo`?o0000
5_ooool2o`0008cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo06;ooooo003ooooooagooooo1?l0000Eooooo`?o0000S_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0HOooool00?oooooo6oooool2
o`0000Cooooo00?o0000ooooooooool03oooool3o`00097ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0=ooooo`;o0000H_ooool00?oooooo6?ooool3o`0001Gooooo0ol0002Doooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001Roooo
o`00oooooolEooooo`?o00005_ooool2o`0009Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05oooooo003ooooooa;ooooo0ol0000Fooooo`?o0000
VOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Goooool00?oooooo4?ooool2o`0001Kooooo0ol0002Looooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Nooooo`00ooooool=ooooo`?o00005_ooool2
o`000:3ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo05gooooo003oooooo`[ooooo1?l0000Eooooo`?o0000X_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0GOooool00?oooooo2?ooool2o`0000Co
oooo00?o0000ooooooooool03oooool3o`000:Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0<ooooo`;o00003Oooool2o`0004oooooo003oooooo`Gooooo0ol0000Eooooo`?o0000
Z?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00002oooool01?l0003oooooooooool0001>ooooo`00ooooool2ooooo`?o00005_ooool2o`000:_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo0000C_ooool00?oooooo0_l0000Fooooo`?o0000[Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool0001>ooooo`00o?ooool3o`0001Gooooo0ol0002`ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
04kooooo003iooooo`?o00005Oooool3o`000;?ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000C_ooool00;oo
oooo0ol00002ooooo`;o00000oooool2o`0002_ooooo1?l0000Eooooo`;o0000]_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00cooooo0_l00009ooooo`;o0000Coooool00<3ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo02Ko
oooo0_l00004ooooo`03o`000?oooooooooo00oooooo0ol0002hooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0001Iooooo`00`?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool08oooool3o`00
01Gooooo0ol0002eooooo`_o00008_ooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool00000FOooool00<3ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo023ooooo0ol0000Fooooo`;o0000]Oooool3o`000003ooooool0003o
oooo00;ooooo0ol00003ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Fooooo`00`?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool07_ooool2o`0001Kooooo0ol0002dooooo`?o00000oooool0
0ol0003oooooo`000002o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0EOooool00<3ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo01_ooooo0ol0000E
ooooo`?o0000]?ooool3o`0000Gooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Gooooo002ooooo
o`;o00000oooool2o`0000?ooooo0_l0000Kooooo`?o00005Oooool3o`000;Gooooo0_l00006oooo
o`;o00002?ooool00ol0003oooooooooo`04ooooo`;o00008?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo05Cooooo003Sooooo`Co00005Oooool2o`000;Gooooo0ol00005ooooo`Co
00002Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02oooool3o`0005Kooooo003Qooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`?o0000
]?ooool3o`0000Gooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Doooool00=kooooo0ol0000Eooooo`?o0000]?ooool3o`0000Gooooo0ol00003ooooo`;o00002ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`1Booooo`00foooool3o`0001Gooooo0ol0002dooooo`?o00001Oooool3
o`0000?ooooo0ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l0000N
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D_ooool00=Wooooo0_l0000Foooo
o`;o0000]Oooool2o`0000Kooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo0ol000000ooooooo0000ooooo`0Nooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0DOooool00=Kooooo0ol0000Eooooo`?o0000]?ooool3o`0000Go
oooo0ol00002ooooo`?o00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1@ooooo`00doooool3o`0001Gooooo0ol0002dooooo`?o00001Oooool3o`0000?ooooo
0_l00009ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000000_l00009ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool03Oooool2o`00057ooooo003Aooooo`?o00005Ooo
ool2o`000;Cooooo0ol00005ooooo`?o00000oooool3o`0000_ooooo00?o0000ooooooooool02_oo
ool2o`0000gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`;o000000?o
ooooo`000?ooool0D?ooool00<kooooo0ol00003ooooo`03o`000?oooooooooo00oooooo0ol0002e
ooooo`[o00000_ooool3o`0000kooooo00?o0000ooooooooool01oooool4o`0000oooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo003;oooo
o`?o00001oooool00ol0003oooooooooo`0;ooooo`?o0000^?ooool00ol0003oighUonMn9@05onMn
9@04ommb2Ol0003o0000o`00017ooooo00?o0000ooooooooool01?ooool3o`0000?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0C_ooool00<Sooooo0ol0000Eooooo`?o0000^_ooool00ol0003ojhToonMn9@04onMn
9@?o00000_oOLPT00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo0ol00007oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04gooooo0036ooooo`;o00005_ooool2o`000;cooooo00Co0000on^9?oo[
RCoojhTo0_oWORD2o`0000?oighU0ooOLPT00ol0003oooooooooo`0=ooooo`03o`000?oooooo0000
00;o00002_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1<ooooo`00`oooool3o`0001Gooooo0ol0002mooooo`04
o`000?o[RCoojhToon^9?`?o00001_oWORD3ommb2@;o00003Oooool2o`0000gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo0_l0001=oooo
o`00`?ooool3o`0001Gooooo0ol0002oooooo`03o`000?o[RCoo000000;o00000_o[RCl8onMn9@Co
gg8900?o0000ooooooooool01oooool4o`0000kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000COooool00;kooooo
0_l000000ooooooo0000ooooo`0Booooo`?o0000`Oooool3o`0000KojhTo1ooWORD5ommb2@03o`00
0?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
Boooool00;_ooooo0ol00004ooooo`03o`000?oooooooooo00kooooo0_l00033ooooo`03o`000?o[
RCoojhTo00OojhTo2?oWORD5ommb2@03o`000?oooooo000000;o00001Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo04[ooooo002hooooo`?o00005Oooool3o`000<Gooooo00?o0000
on^9?oo[RCl02?o[RCl7onMn9@Kogg8900?o0000ooooooooool01Oooool2o`0000oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0BOooool00;Gooooo0ol0000Eooooo`?o0000b?ooool00ol0003ojhToon^9?`09on^9
?`OoighU1OoOLPT00ol0003oooooooooo`02ooooo`?o000000?oooooo`000?ooool03_ooool00ol0
003oooooooooo`0Booooo`;o00007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
04Wooooo002cooooo`;o00005_ooool2o`000<[ooooo00?o0000onfBE_o]TUH02_o[RCl7onMn9@Ko
gg891?l00004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool3o`000003
ooooool0003ooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o
00000_ooool3o`0003Gooooo002`ooooo`?o00005Oooool3o`000<cooooo00Co0000onfBE_o]TUKo
kI9F2_o[RCl7onMn9@?ogg891?l00006ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool3o`0000Cooooo0_l0000Mooooo`03o`000?oooooooooo00_ooooo0ol0000<ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<_ooool00:gooooo0ol0000Eooooo`?o
0000coooool01?l0003okI9FonfBE_o]TUH;on^9?`KoighU0ol00003ommb2@03omAW0?l0003ooooo
00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`?o00001oooool00ol0
003oooooo`00000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03;ooooo002[ooooo`;o00000_ooool00ol0003o
ooooooooo`0@ooooo`?o0000dOooool00ol0003okI9FonfBEP03onfBEP[ojhTo0ooWORD3o`000003
onMn9OoOLPWogg8900?ogg890_oDI`000ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool3o`0000[ooooo00?o0000ooooool000007Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0booooo`00Z?ooool3o`0000Gooooo00?o0000ooooooooool03Oooool2o`000=Cooooo
00?o0000onfBE_o]TUH01?o]TUH9on^9?`?o00001OoWORD5ommb2@;oe6L000Go0000oooooooooooo
ooooo`00000@ooooo`03o`000?oooooooooo00;ooooo0ol0000>ooooo`03o`000?oooooo000001go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?o
0000=Oooool00:Gooooo0ol0000Eooooo`?o0000e_ooool00ol0003okI9FonfBEP05onfBEPKojhTo
0_l00002on^9?`KoighU1OoOLPT3omAW0004o`000?ooooooooooo`00013ooooo00?o0000ooooool0
00000_l0000Aooooo`03o`000?oooooo000001kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0=Oooool00:;ooooo
0ol0000Eooooo`?o0000fOooool00ol0003okI9FonfBEP06onfBEP;ojhTo0ol00004on^9?`OoighU
1OoOLPT2omAW0004o`000?ooooooooooo`0000oooooo0ol0000Dooooo`04o`000?ooooooooooo`00
01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo0ol0000dooooo`00X?ooool2o`0001Kooooo0_l0003Kooooo`03o`000?o]TUKokI9F00Ko
kI9F0ol00008on^9?`KoighU1OoOLPT3omAW0003o`000?oooooo000000cooooo0ol000000ooooooo
0000ooooo`0Dooooo`05o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`0;oooo
o`?o0000AOooool006Sooooo0ol00003ooooo`;o0000;Oooool3o`0001Gooooo0ol0003Mooooo`03
o`000?o]TUKokI9F00?okI9F0ol00002onfBEPWojhTo1ooWORD5ommb2@?oe6L00_l00009ooooo`?o
00001?ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000007_ooool00ol0
003oooooooooo`08ooooo`;o00000_ooool00ol0003oooooooooo`13ooooo`00Joooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo02Oooooo1?l0000Dooooo`?o0000h?ooool00ol0003o
kI9FonfBEP03o`0000KokI9F2Oo[RCl6onMn9@Gogg891?oDI`000ol0003oooooooooo`04ooooo`?o
00001oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04;ooooo001[ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool09Oooool2o`0000Cooooo00?o0000ooooooooool0
3_ooool3o`000>;ooooo1?l0000:onfBEPWojhTo1_oWORD5ommb2@?oe6L00_l00002ooooo`?o0000
2_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo001[ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool08_ooool3o`0001Gooooo0_l0003Uooooo`03o`000?o]
TUKokI9F00_okI9F2Oo[RCl7onMn9@Cogg890ooDI`001?l0003oe6L0o`000?l0000=ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0@Oooool006Sooooo0ol00002ooooo`04o`000?oo
ooooooooo`00027ooooo0ol0000Eooooo`?o0000ioooool00ol0003okI9FonfBEP0<onfBEPWojhTo
1_oWORD5ommb2@;oe6L000?o0000omAW0?l000003_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo043ooooo001Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
7oooool2o`0001Gooooo0ol0003Zooooo`03o`000?o]TUKokI9F00gokI9F2Oo[RCl6onMn9@Gogg89
00Goe6L0o`000?oDI`3oe6L0o`00000=ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo0_l00011ooooo`00
JOooool3o`0000;ooooo0_l0000Mooooo`?o00005?ooool3o`000>gooooo00?o0000onfJJ?o]TUH0
3_o]TUH8on^9?`KoighU1OoOLPT01?oDI`3o0000omAW0?oDI`02o`0000cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooo`000011ooooo`00R_ooool3o`0001Gooooo0_l0003`ooooo`03o`00
0?o]VVSokIYX00kokI9F2Oo[RCl6onMn9@Gogg8900Go0000omAW0?oDI`3oe6L0o`00000<ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0?_ooool008Oooooo0ol000000ooooooo0000
ooooo`0Booooo`?o0000l_ooool01?l0003okIYXonfJJ?o]VVP>onfBEPWojhTo1OoWORD5ommb2@04
o`000?oDI`3oe6L0omAW00;o00002oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03kooooo0025ooooo`;o00001Oooool00ol0003oooooooooo`0=ooooo`?o0000mOooool00ol0003o
kIYXonfJJ002onfJJ0kokI9F2?o[RCl6onMn9@Cogg8900?o0000omAW0?oDI`000_oDI`000ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0?Oooool008;ooooo
0ol0000Eooooo`;o0000n?ooool00ol0003okIYXonfJJ003onfJJ0kokI9F2?o[RCl5onMn9@Cogg89
00?o0000omAW0?oDI`000_oDI`02o`0000_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`06ooooo`;o00007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03cooooo
001oooooo`?o00005Oooool3o`000?[ooooo00?o0000onfJJ?o]VVP01?o]VVP=onfBEPWojhTo1OoW
ORD01OoOLPWo0000o`000?l0003ogg8900?oe6L000?o0000olQO0?l000002_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00?ooooo0ol000000ooooooo0000ooooo`0Mooooo`03o`00
0?oooooooooo00_ooooo0_l0000nooooo`00OOooool2o`0001Gooooo0ol0003mooooo`03o`000?o]
VVSokIYX00GokIYX3Oo]TUH8on^9?`?oighU0ol00002ommb2@03o`000?oOLPWoe6L000?oe6L00_l0
000:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ol00005ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000mooooo`00N_oo
ool3o`0001Cooooo0ol0003oooooo`7ooooo00?o0000onfJJ?o]VVP01_o]VVP=onfBEPOojhTo0ol0
0003onMn9@;ogg890_l000001ooOLPWoe6L0omAW0?oDI`3o0000olQO0?l000002Oooool00ol0003o
ooooooooo`0Cooooo`?o00002?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0>_ooool007Oooooo0ol0000Eooooo`;o0000ooooool4ooooo`03o`00
0?o]VVSokIYX00OokIYX3Oo]TUH3on^9?`?o00000_o[RCl5onMn9@04ommb2Ol0003ogg89o`0000Co
e6L000?o0000olQO0?l000002?ooool00ol0003oooooooooo`0@ooooo`?o000000?oooooo`000?oo
ool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0>_ooool007Cooooo0ol00003ooooo`03o`000?oooooooooo00oooooo0ol0003oooooo`Kooooo
00?o0000onfJJ?o]VVP02?o]VVP<onfBEP?o00001Oo[RCl5oo2A>@05onf<:ol0003ogg89ommb2Ol0
00000ooDI`000ol0003ob5l0o`000008ooooo`03o`000?oooooooooo00gooooo0ol00004ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Wooooo001booooo`;o00001oooool00ol0003oooooooooo`0;ooooo`?o0000
ooooool9ooooo`03o`000?o]VVSokIYX00WokIYX2?o]TUH3o`000003onfBE_o[RCoojhTo00GojhTo
00?olYM8oo2A>Oo`TCT00oo`TCT01?o]S2_o0000ommb2Ol00004omAW0003o`000?o8G`3o000000Oo
oooo00?o0000ooooooooool02_ooool3o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>?ooool006oooooo
0ol0000Dooooo`?o0000ooooool<ooooo`03o`000?o]VVSokIYX00[okIYX1?o]TUH3o`0000GokI9F
1Oo[RCl2oo:GB0Gol94i00GokH`[o`000?o]S2_okH`[o`000003omAW0004o`000?o8G`3ob5l0o`00
00Kooooo00?o0000ooooooooool01oooool3o`0000[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo0_l0000jooooo`00K?ooool3o`0001Go
oooo0_l0003oooooo`oooooo00?o0000onfJJ?o]VVP02oo]VVP3o`0000WokI9F0oo[RCl4oo:GB0Go
l94i00Go0000onf<:oo]S2_okH`[o`000003omAW0003o`000?o8G`3o000000Kooooo00?o0000oooo
ooooool01?ooool3o`0000gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000>Oooool006[ooooo0_l0000Eoooo
o`?o0000oooooolAooooo`03o`000?o]VVSokIYX00SokIYX0ol000000oo]VVSokI9FonfBEP0:onfB
EP03on^9?oobUdSolYM800?olYM81Oo`TCT01Ol0003okH`[onf<:oo]S2_o000000?oe6L000Co0000
olQO0?o8G`3o00001Oooool01?l0003oooooooooooooool3o`00013ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
=oooool006Oooooo0ol0000Dooooo`?o0000oooooolDooooo`03o`000?o]VVSokIYX00GokIYX0ol0
0005onfJJ0_okI9F1oobUdP4oo2A>@03o`000?o]S2_okH`[00;okH`[00Oo0000omAW0?oDI`3oe6L0
o`000?o8G`3o000000Gooooo1?l0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo001Tooooo`Co0000
5?ooool2o`000?oooooo5oooool00ol0003okIYXonfJJ002onfJJ0?o00002Oo]VVP:onfBEP03oo:L
EoobUdSolYM800ColYM81?o`TCT00ol0003okH`[onf<:`03onf<:`04o`000?oDI`3oe6L0o`0000;o
b5l000?o0000ooooooooool01?l0000Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo001Qooooo`?o0000
1?ooool00ol0003oooooooooo`0>ooooo`?o0000oooooolIooooo`03o`000?o]VVSo000000;o0000
3Oo]VVP9onfBEP;olYaG1_obUdP3oo2A>@03o`000?o]S2_okH`[00?okH`[00CojXPNo`000?oDI`3o
00000oo8G`02o`0000?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0eooooo`00
Goooool2o`0001Gooooo0ol0003ooooooacooooo0_l0000AonfJJ0OokI9F0oobW5L6oo:GB0?ol94i
00?o0000oo2A>Oo]S2/00oo]S2/01OoZR1ko0000omAW0?oDI`3o000000;ob5l000?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`;o00003?ooool3o`0000?ooooo0_l0000Rooooo`00
G?ooool3o`0001Cooooo0ol0003ooooooaoooooo00?o0000onfRMol000004Oo]VVP6onfBEPColYaG
1_obUdP2oo2A>@03o`000?o`TCWokH`[00CokH`[00CojXPNo`000?oDI`3o00000oo8G`001Ol0003o
oooooooooooooooo000001Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo01oooooo001Iooooo`?o00005Oooool2o`000?oooooo8_ooool01?l0
003okJ9gonfRMol0000AonfJJ0GokI9F1?obW5L6oo:GB0?ol94i00?o0000oo2A>Oo]S2/00oo]S2/2
onZ87P03o`000?oDI`3o000000;ob5l000Go0000ooooooooooooooooo`00000Eooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Oooooo`00Eoooool2
o`0001Gooooo0ol0003oooooobCooooo00Go0000onfRMoo]XWOokJ9go`00000AonfJJ0CokI9F1Oob
W5L6oo:GB0;ol94i00?o0000oo2A>Oo]S2/00oo]S2/3onZ87P;o00000_o8G`001OnmF`3o0000oooo
oooooooo000001Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo01oooooo001Dooooo`?o00005?ooool3o`000?oooooo9oooool00ol0003okJ9gonfR
M`02onfRM`;o00004?o]VVP3onfBEPKolYaG1OobUdP2oo2A>@03o`000?o`TCWol94i00CokH`[0_oZ
R1h00ol0003ojXPNo`000002olQO0004o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1oooool3o`0000;ooooo00Co0000oooooooooooo00008Oooool0057ooooo0ol00003ooooo`03o`00
0?oooooooooo00kooooo0ol0003oooooob_ooooo00?o0000onfRMoo]XWL00oo]XWL00ol0003okIYX
onfJJ00>onfJJ003onfBE_obW5OolYaG00GolYaG1_obUdP01?o`TCWo0000oo2A>Oo`TCT4onf<:`?o
jXPN0_l00002olQO0004okeK0?l0003oooooo`0001Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`00027ooooo001?ooooo`;o00005Oooool2o`00
0?oooooo;_ooool00ol0003okJ9gonfRM`04onfRM`03o`000?o]VVSokIYX00kokIYX2?obW5L5oo:G
B003oo2A>Ol0003ol94i00;ol94i0oo]S2/4onZ87P07o`000?o8G`3ob5l0olQO0?l0003oooooo`00
000Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0;ooooo`;o00002Oooool3o`0000;ooooo0_l0000Rooooo`00C?ooool3o`0001Cooooo0ol0003o
oooooc3ooooo00?o0000onfRMoo]XWL01Oo]XWL00ol0003okIYXonfJJ00=onfJJ0SolYaG1_obUdP0
1?l0003ol94ioo2A>Oo`TCT4onf<:`?ojXPN0_l00002olQO0003okeK0?l0003o000001Kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo0_l0
0002ooooo`03o`000?oooooooooo02oooooo0019ooooo`?o00005?ooool3o`000?oooooo<oooool0
0ol0003okJ9gonfRM`06onfRM`;o00003Oo]VVP00oocXF?olYaGoo:LE`06oo:LE`GolYM800?o0000
oo2A>Oo`TCT00_o`TCT3onf<:`CojXPN00Co0000olQO0?o8G`3o_E/00_l0000Fooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02oooooo0016ooooo`?o00005Oooool2o`000?oooooo=_ooool00ol0003okJ9gonfRM`08
onfRM`03o`000?o]VVSokIYX00[okIYX0_ocXF<8oo:LE`ColYM800?o0000oo2A>Oo`TCT00_o`TCT3
onf<:`CojXPN0_l00002olQO0003okeK0?l0003ooooo01Gooooo00?o0000ooooooooool03_ooool2
o`0002;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`005oooool2o`00
02_ooooo0_l0000Eooooo`?o0000oooooolhooooo`03o`000?o]XWOokJ9g00WokJ9g00?o0000onfJ
J?o]VVP02Oo]VVP3oo>QH`OolYaG1?obUdP00ol0003ol94ioo2A>@02oo2A>@CokH`[1?oZR1h2o`00
0003olQO0?nmF`3o000001Kooooo00?o0000ooooooooool02oooool3o`000003ooooool0003ooooo
02;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0^ooooo`005_ooool01?l0003o
ooooooooool0000Wooooo`?o000000?oooooo`000?ooool04Oooool3o`000?oooooo>oooool00ol0
003okJ9gonfRM`0:onfRM`03o`000?o]VVSokIYX00SokIYX0oocXF<8oo:LE`ColYM800?o0000oo2A
>Oo`TCT00_o`TCT3onf<:`CojXPN0_l000001?o8G`3o_E/0okeK0?l0000Eooooo`03o`000?oooooo
oooo00Sooooo0ol00005ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0]ooooo`005_ooool01?l0003oooooooooool0000Tooooo`?o00001Oooool0
0ol0003oooooooooo`0<ooooo`?o0000oooooolnooooo`03o`000?o]XWOokJ9g00_okJ9g0ol00007
onfJJ0Colj5S2?obW5L3oo:GB003o`000?o`TCWol94i00;ol94i1?o]S2/3onZ87P06o`000?oVQQ?o
0000olQO0?nmF`3o00005Oooool00ol0003oooooooooo`05ooooo`?o00002?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00[ooooo0ol0000^ooooo`005_ooool01?l0003ooooooooo
ool0000Rooooo`;o00005Oooool2o`000?oooooo@Oooool00ol0003okJ9gonfRM`0<onfRM`;o0000
1oo]VVP5oo>QH`OolYaG0oobUdP00ol0003olYM8oo2A>@03oo2A>@?okH`[1?oZR1h01?l0003oiXHC
o`000?nmF`02o`0001Cooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02cooooo000Fooooo`04o`00
0?ooooooooooo`0001oooooo0ol0000Dooooo`?o0000oooooom4ooooo`03o`000?o]XWOokJ9g00go
kJ9g00?o0000onfJJ?o]VVP01?o]VVP6oo>QH`OolYaG0ol000000oobUdSol94ioo2A>@02oo2A>@?o
kH`[1?oZR1h01?l0003oiXHCo`000?o8G`02o`0001Cooooo00?o0000ooooool000000_l0000?oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[oooo
o`005_ooool01?l0003oooooooooool0000Looooo`?o00005?ooool3o`000?ooooooAoooool00ol0
003okJ9gonfRM`0>onfRM`03o`000?o]VVSokIYX00?okIYX1oocXF<3oo:LE`?o00000_obUdP00ol0
003olYM8oo:GB004oo2A>@?okH`[0ooZR1h5o`000003okeK0?l0003ooooo017ooooo0ol0000Boooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zoooo
o`005oooool2o`0001[ooooo0ol0000Eooooo`;o0000oooooom:ooooo`03o`000?o]XWOokJ9g00Ko
kJ9g00?o<`3oonfRMoo]XWL01_o]XWL2o`0000?okIYX1oocXF<3o`0000ColYaG00ColYM8o`000?ob
UdSolYM81?o`TCT3onf<:`?ojXPN0ol000001?oVQQ?o0000okeK0?l0000?ooooo`?o000000?ooooo
o`000?ooool04oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:_ooool0037ooooo0_l000000ooooooo0000ooooo`0Booooo`?o0000oooooom<oooo
o`03o`000?o]XWOokJ9g017okJ9g00?o0000onfJJ?o]VVP01?ocXF<3o`000003oo>QHoobW5OolYaG
00GolYaG00ColYM8o`000?obUdSolYM81?o`TCT2onf<:`;oo`000_oZR1h01?l0003oiXHConJ64ol0
0002okeK0003o`000?oooooooooo00Wooooo0ol00004ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo000^
ooooo`?o00001?ooool00ol0003oooooooooo`0=ooooo`?o0000oooooom?ooooo`03o`000?o]XWOo
kJ9g01;okJ9g00?o0000onfJJ?ocXF<00ol00005oo>QH`KolYaG00ColYM8o`000?obUdSolYM81?o`
TCT3onf<:`?ojXPN00?o0000onJ64ooVQQ<00_l000000onmF`3o0000ooooo`07ooooo`?o00002?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Zooooo`00:oooool3o`0001Cooooo0ol0003ooooooe;ooooo00?o0000
onfRMoo]XWL04_o]XWL3o`0000Wolj5S1_obW5L01?l0003olYM8oo:GB?obUdP4oo2A>@;okH`[0ooZ
R1h02?l0003oiXHConJ64ol0003oi8H>o`000?nmF`3o00001?ooool3o`0000_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Qooooo`?o00002_ooool2o`0002cooooo000Yooooo`;o
00005Oooool2o`000?ooooooEOooool00ol0003okJ9gonfRM`0?onfRM`?o00000_o]XWL2o`0000So
lj5S1_obW5L01?l0003olYM8oo:GB?obUdP4oo2A>@;okH`[1?oZR1h02?l0003oiXHCo`000?oVQQ?o
0000okeK0?l0003ooooo0ol0000>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
7_ooool3o`0000;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000[ooooo`00
9_ooool3o`0001Cooooo0ol0003ooooooeGooooo0_lc0?l00ol0003okJ9gonfRM`0<onfRM`?o0000
1Oo]XWL2oo>WKP03o`000?ocXF?olj5S00Kolj5S1OobW5L00ol0003olYM8oo:GB002oo:GB0?ol94i
0oo]S2/3onZ87P08o`000?oVQQ?o0000onJ64ooTQPko0000okeK0?l0000Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool06oooool3o`0000Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0=ooooo`?o00000oooool2o`0001Cooooo000Sooooo`?o00005?ooool3o`00
0?ooooooE_ooool3oc<0o`03ooooool0003okJ9g00[okJ9g0ol00008onfRM`?oljM^00?o0000oo>Q
HoocXF<01_ocXF<5oo:LE`04o`000?obUdSolYM8oo:GB0Col94i0_o]S2/3onZ87P06o`000?oVQQ?o
0000onJ64ooTQPko_E/00_l0000Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
5oooool3o`0000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool04Oooool0023ooooo1?l0000Cooooo`?o0000oooo
oomFooooo`Go<`3o0oooool00ol0003okJ9gonfRM`05onfRM`?o00002oo]XWL4oo>WKP03o`000?oc
XF?olj5S00Kolj5S1?obW5L00ol0003olYM8oo:GB002oo:GB0?ol94i0_o]S2/3onZ87P04o`000?oV
QQ?oiXHCo`0000;oi8H>00?o_E/0o`000?l000004?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Cooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool4o`0000Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Aooooo`007_oo
ool2o`0000Cooooo00?o0000ooooooooool03_ooool2o`000?ooooooEoooool2oc<0o`03oooooolc
0?oo<`3o00Gooooo00?o0000onfRMoo]XWL00_o]XWL3o`0000kokJ9g1?ocYfh2o`0000Oolj5S1?ob
W5L00ol0003olYaGoo:GB002oo:GB0Col94i0_o]S2/3onZ87P03o`000?oVQQ?o000000;oi8H>00?o
_E/0o`000?l000004?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo0ol0
000?ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooooooo017ooooo000Kooooo`?o00001oooool00ol0003oooooooooo`0:
ooooo`?o0000oooooomGooooo`;o<`3o00?ooooooc<0oolc0?l01oooool00ol0003okJ9go`000002
o`0001;okJ9g0oocYfh3o`0000Oolj5S0oobW5L00ol0003olYaGoo:GB003oo:GB0;ol94i00?omj==
ooJRBOo]S2/00ooZR1h01?l0003oiXHCo`000?oVQQ<2onB63P03okeK0?l0003o000000oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`?o00004_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00gooooo0ol00002ooooo`04o`000?ooooooooooo`0001?ooooo
000Hooooo`?o00005?ooool3o`000?ooooooF?ooool2oc<0o`;ooooo00?o<`3oooooooooool01ooo
ool2o`0001GokJ9g1_ocYfh00ol0003olj5Soo>QH`05oo>QH`;olYaG00?o0000oo:LEoobW5L00oob
UdP3ooNSC@;omZ990ooZR1h3o`000006onJ64ooTQPkoi8H>onB63_nmF`3o00003oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo0ol0000Eooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
01?ooooo000Gooooo`03o`000?oooooooooo01?ooooo0_l0003ooooooeWooooo0_lc0?l2ooooo`;o
<`3o2_ooool00ol0003okJV2onfRM`0DonfRM`OoljM^00?o0000oo>QHoocXF<01OocXF<2oo:LE`04
o`000?obW5OolYaGoo:GB0;omjAB0oogXdd2ooJRB@;oo`000ol000001_oVQQ?oi8H>onB63_oTQPko
_E/0o`0000oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06ooooo`?o00006?oo
ool00ol0003oooooooooo`08ooooo`;o00004?ooool3o`0000;ooooo0_l0000Dooooo`00:_ooool3
o`000?ooooooFOooool2oc<0o`;ooooo0_lc0?l<ooooo`04o`000?o]ZH;okJV2onfYPQ?okJ9g2?oc
Yfh00ol0003olj5Soo>QH`05oo>QH`04oo:LEol0003olYaGoo:LE`?omjAB0oogXdd2ooJRB@03ooJR
A_oZR1kojXPN00;o000000?oiXHConB63_oTQPh00_oTQPh00onhG`3o0000ooooo`0=ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00oooool3o`0001_ooooo00?o0000ooooooooool0
1_ooool2o`0000;ooooo00?o0000ooooooooool0:?ooool002Oooooo0ol0003ooooooe[ooooo0_lc
0?l2ooooo`;o<`3o3oooool00ol0003okJV2onfYPP02onfYPQ7okJ9g2OocYfh00ol0003olj5Soo>Q
H`04oo>QH`05oo:LEol0003olYaGoo:LEoogYUL00_ogY583ooNSC@;omZ990_ofXTH01?oZR1ko0000
o`000?oVQQ<4onB63P03okeK0?l0003o000000gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooo`000002o`0001kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`00
9?ooool3o`000?ooooooFoooool2oc<0o`?ooooo00?o<`3oooooooooool03oooool00ol0003okJV2
onfYPP05onfYPPkokJ9g2_ocYfh00ol0003olj5Soo>QH`04oo>QH`04o`000?obW5OolYaGooNVE`?o
mjAB0oogXdd2ooJRB@;omZ9600CojXPNo`000?oVQQ?oiXHC1?oTQPh00onhG`3o0000ooooo`0=oooo
o`03o`000?oooooooooo01Cooooo0ol0000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:?ooool002?ooooo0_l0003ooooooe_ooooo0_lc0?l3ooooo`;o<`3o4_ooool00ol0003o
kJV2onfYPP07onfYPPcokJ9g2oocYfh00ol0003olj5Soo>QH`03oo>QH`03o`000?obW5OomjIG00;o
mjIG0_ogY583ooNSC@;omZ990oofXTH00ol0003oiXHConJ64`04onB63P03okQO0?l0003o000000go
oooo00?o0000ooooooooool04Oooool3o`000003ooooool0003ooooo027ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Xooooo`008oooool00ol0003oooooo`00003ooooooeSooooo
0_lc0?l3ooooo`;o<`3o5?ooool00ol0003okJV2onfYPP09onfYPP[okJ9g3?ocYfh00ol0003olj5S
oo>QH`03oo>QH`04o`000?ogYUOomjIGooNVE`?omjAB0_ogXdd2ooJRB@?omZ9600?o0000onJ64ooV
QQ<01OoTQPh00onhG`3o0000o`00000<ooooo`03o`000?oooooooooo00gooooo1?l00005ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`00
8oooool01?l0003oooooooooool0003ooooooeGooooo0_lc0?l3ooooo`;o<`3o5_ooool00ol0003o
kJV2onfYPP0;onfYPPSokJ9g3OocYfh00ol0003olj5Soo>QH`02oo>QH`03o`000?ogYUOomjIG00;o
mjIG0_ogY583ooNSC@05ooJRBOofXTKomZ96ooJRA_l000000_oVQQ<5onB63P03okQO0?l0003o0000
00cooooo00?o0000ooooooooool02_ooool3o`0000Wooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo000Sooooo`05o`000?oooooooooooooo
ool00000oooooomBooooo`;o<`3o1?ooool00olc0?ooooooooooo`0Gooooo`03o`000?o]ZH;okJV2
00cokJV21oo]XWL=oo>WKP06o`000?ocXF?olj5Soo>QHol0003on:QL0oogYUL3ooNTDP;omj==0_of
XTT2ooJRAP03o`000?ofXTCoiXHC00Goi8H>00CohhT=okQO0?l0003o00002oooool00ol0003ooooo
ooooo`07ooooo`?o00003?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:?ooool002?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3oooooodgooooo0_lc0?l4ooooo`;o<`3o6?ooool2oc<0o`03o`000?o]ZH;okJV200ookJV21?o]
XWL>oo>WKP;o000000Colj5So`000?ohZ5con:QL0oogYUL2ooNTDP;omj==0_ofXTT3ooJRAP03o`00
0?oVQQ?oiXHC00Coi8H>00GohhT=okQO0?l0003oooooo`00000:ooooo`03o`000?oooooooooo00Co
oooo0ol0000>ooooo`?o00008Oooool00ol0003oooooooooo`08ooooo`;o0000:_ooool002?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodWooooo0olc0?l4ooooo`;o<`3o
6?ooool2oc<0o`03ool00?lc0?oo000001?okJV20_o]XWL>oo>WKP;o000000Colj5So`000?ohZ5co
n:QL0oogYUL2ooNTDP?omj==00ComZ99ooJRA_ofXTKomZ960_l000000ooVQQ?oi8H>onB63P02onB6
3P03on>93OnhG`3o000000;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool3
o`0000kooooo0ol00002ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool0
0ol0003oooooo`00000Zooooo`008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?ooooooA_ooool2oc<0o`Gooooo0_lc0?lHooooo`;o<`3o00Goo`00oc<0oolc0?ooooooo`00000E
onfYPP[oljM^0_lc0?l4oo>WKP03o`000?ocXF?o000000;on:QL0oogYUL2ooNTDP;omj==00ComZ99
ooJRA_ofXTKomZ960_l000000oofXTCoi8H>onB63P02onB63P;ohhT=00Co^5l0o`000?oooooo0000
2Oooool4o`0000kooooo0ol00005ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Wooooo`008_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo@oooool2oc<0o`Kooooo00?o<`3oooooooooool05_ooool2oc<0o`03ool00?lc
0?oo<`3o00?ooooo00?o0000onfYP_o]ZH804oo]ZH82ooB/M`ooljM^0_l00002ooRXG0?omjIG0_og
Y582ooNSC@;omZ9900?oo`00ooJRA_l000000_ofXT@4onB63P;ohhT=00Go^5l0o`000?oooooooooo
o`000006ooooo`?o00003_ooool3o`0000Wooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Oooooo000Rooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0oooooom0ooooo`;o<`3o1_ooool2oc<0oaKooooo0olc0?l00ooooooo<`3ooc<0
o`06ooooo`03o`000?o]ZH;okJV201;okJV21?od[7L>oo>WKP04o`000?ohZ5con:QLooRXG0?omjIG
0_ogY582ooNSC@04ooJRBOofXTKomZ96o`0000;omZ9400ComZ93onB63_oTQPkoi8H>0ooSR@d01Onh
G`3o0000oooooooooooo000000;ooooo0ol00003ooooo`03o`000?oooooooooo00Sooooo0ol0000<
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0W
ooooo`008_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo?Oooool2oc<0
o`Kooooo0_lc0?lFooooo`;o<`3o00Coo`00oooooolc0?oo<`3o2?ooool00ol0003okJV2onfYPP0C
onfYPPCom:ag3OocYfh00ol0003on:QLooRXG002ooRXG0;omjIG0_ogY582ooNSC@04ooJRBOofXTKo
mZ96o`0000;omZ9400ComZ93onB63_oTQPkoi8H>0ooSR@d01?nhG`3o0000ooooooooool3o`0000Ko
oooo00?o0000ooooooooool01Oooool3o`0000oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo000Rooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0ooooooljooooo`;o<`3o1_ooool2oc<0oaKooooo0_lc0?l2ooooo`;o<`3o
2_ooool00ol0003okJV2onfYPP0ConfYPPKom:ag2oocYfh2o`0000?on:QL0oogYUL01?ogY5;omj==
ooNSCOofXTT2ooJRAP03o`000?ofXTComZ9400;omZ930_oTQPh4on>93@05okQO0?l0003o0000oooo
ool000001oooool00ol0003oooooooooo`02ooooo`?o00004oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool002;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`3oooooocOooooo0_lc0?l7ooooo`03oc<0oooooooooooo01Co
oooo0_lc0?l2ooooo`;o<`3o3?ooool00ol0003okJV2onfYPP0ConfYPPSom:ag2OocYfh00oohZf7o
0000o`000003ooRXG0;omjIG0_ogY582ooNSC@05ooJRBOofXTKo0000o`000?ofXT@00_ofXT<2onB6
3PCohhT=00?o^5l0o`000?ooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00;o00005_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool09oooool002;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3oooooocCo
oooo0_lc0?l7ooooo`;o<`3o5?ooool3oc<0o`;ooooo0_lc0?l<ooooo`;oo`0000?o0000onfYP_o]
ZH804oo]ZH8:ooB/M`KoljM^0ol000000oohZf7o0000ooRXG002ooRXG0;omjIG00GomjABooNSCOog
XdgomZ99ooJRAP02o`000005ooJRA?ofXT?omZ93ooJR@ooTQPh01?oSR@d00onhG`3o0000ooooo`03
ooooo`03o`000?oooooooooo00;ooooo0ol0000Iooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool02?ooool2o`0002Wooooo000Rooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0oooooolaooooo`;o<`3o1oooool2oc<0oaCooooo0_lc0?l3ooooo`;o<`3o3Oooool01Ooo
003ooooooooooooooooo000001CokJV22ood[7L2oo>WKP?o00000_ocYfh01?l0003on:]QooR[HOl0
0002ooRXG0;omjIG0_ogY5800oogXdgomZ99ooJRAP02o`000005ooJRA?ofXT?omZ93ooJR@ooTQPh0
1OoSR@d00onhG`3o0000ooooo`02ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool0
6_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
:Oooool002;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3oooooobkooooo0_lc
0?l7ooooo`;o<`3o4oooool00ooo003o<`3ooc<0o`03ooooo`;o<`3o3Oooool2ool000Cooooo00?o
0000onfYP_o]ZH804oo]ZH89ooB/M`?o00001OocYfh01OohZf7o0000ooR[HOohZf7o000000;on:QL
0_ogYUL01?ogY5;omj==ooJRBOofXTH2o`000003ooJRA?ofXT?omZ9300;omZ931OoSR@d01?nhG`3o
0000ooooooooool3o`0000Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`3oooooob_ooooo0_lc0?l8ooooo`03oc<0oooooooooooo017o
oooo00?oo`00oc<0oolc0?l00oooool2oc<0o`gooooo0_oo0003ooooo`?oo`0000?o0000onfYP_o]
ZH804oo]ZH86ooB/M`?o00001Ood[7L3oo>WKP03ooR[HOl0003on:]Q00;on:]Q00Go0000ooRXG?oh
Z5comjIGooNTDP02ooNSC@04ooJRBOl0003o0000ooJRA0ComZ931_oSR@d00onhG`3o0000o`000003
ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3oooooobSooooo0_lc0?l8ooooo`;o<`3o4Oooool01?oo003o<`3ooc<0oolc
0?l3ooooo`;o<`3o3Oooool2ool000;ooooo0ooo0003ooooo`03o`000?o]ZH;okJV201?okJV20ood
[7L3o`0000Wom:ag0_ocYfh00oohZf7o0000ooR[H@02ooR[H@?o00000_ogYUL00oogY5;omj==ooJR
B@04o`0000?omZ9300?omZA3on>93OoSR@d00ooSR@d00onhG`3o0000ooooo`03ooooo`05o`000?oo
ooooooooooooool000007?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`3oooooobGooooo0_lc0?l8ooooo`;o<`3o4Oooool00ooo003o<`3ooc<0o`04ooooo`;o<`3o3Ooo
ool2ool000;ooooo0_oo0006ooooo`03o`000?o]ZH;okJV201?okJV20ol0000>ooB/M`;on:]Q00Co
0000ooR[HOohZf7on:]Q0_l000001_ohZ5comjIGooNTD_ogXdgomZ99ooJRAP?o00000oofXT<00oof
Y4?ohhT=on>93@03on>93@03okQO0?l0003ooooo00Cooooo00Co0000oooooooooooo00007?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3oooooob7ooooo0olc0?l8oooo
o`;o<`3o4?ooool2ool000;o<`3o1?ooool2oc<0o`kooooo00?oo`00oooooooo00000_oo0008oooo
o`03oc<0ool0003okJV2013okJV20ol000000oo]ZH;om:agooB/M`0>ooB/M`;o<`3o00?o0000ooR[
HOohZf400_ohZf401ol0003on:QLooNVEoogYUOomjABooNSCOoo00000_l00003ooJR@`;omZA31_oS
R@d00onkJ`3o0000ooooo`04ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oo
oooooooo01?ooooo0_l0003ooooooaoooooo0_lc0?l:ooooo`03oc<0oooooooooooo00kooooo00Co
o`00oc<0oolc0?oo<`3o1?ooool2oc<0o`kooooo1?oo0008ooooo`Co<`3o00?o0000onfYP_o]ZH80
3?o]ZH83o`0000CokJV24?od[7L2oc<0o`03o`000?ohZf7on:]Q00?on:]Q00Ko0000ooRXG?ogYUOo
mjABooNSCOofXTT2o`0000?omZ930oofY4<5on>93@03ok][0?l0003ooooo00Gooooo00?o0000oooo
ool000006oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool09_ooool0027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooa[o
oooo0_lc0?l:ooooo`;o<`3o3_ooool2ool000;o<`3o1Oooool2oc<0o`kooooo1?oo0008ooooo`;o
<`3o00Gooooooc<0oolc0?ooo`00o`00000;onfYPP?o00001oo]ZH8AooB/M`;onJeT00?o0000ooV]
I?ohZf400oohZf401Ol0003on:QLooNVEoogY5;omZ9900;o00000oofXT<3ooJT@`CohhT=00?oiI0C
ok][0?l000001_ooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo0?oooooo5oooool2oc<0o`[ooooo0_lc0?l>ooooo`;oo`000_lc0?l5oooo
o`;o<`3o3_ooool3ool000Sooooo1_lc0?l01?oo003oooooooooool00008onfYPP?o00002_o]ZH8A
ooB/M`;onJeT00?o0000ooV]I?oi[F@01?ohZf401?l0003omjIGooNTD_ogXdd2o`0000;omZ931?of
Y4<3on>93@?oiI0C00?o^f/0o`000?ooool01Oooool2o`0001cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`07ooooo`?o0000:?ooool0027ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`3ooooooaCooooo0_lc0?l:ooooo`;o<`3o3Oooool3ool000;o<`3o1Oooool2
oc<0o`kooooo0_oo0009ooooo`;o<`3o00?ooooooc<0oolc0?l00_oo0004ooooo`03o`000?o]ZH;o
kJV200?okJV20ol0000=onfYPQ7om:ag0_oi[F@00ol0003onJeTooV]I002ooV]I0;on:]Q00Co0000
ooRXG?ogYUOomj==0_l00002ooJR@`GomZA300?ohhT=onF@4ooUT1<00_oUT1<00onkJ`3o0000oooo
o`06ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0oooooolAooooo`;o<`3o2oooool00olc0?ooooooooooo`0;ooooo`;oo`000olc0?l5
ooooo`;o<`3o3Oooool4ool000Oooooo0olc0?l00ooooooo<`3ooc<0o`02ool000Oooooo00?o0000
onfYP_l000000_l0000AonfYPQ3om:ag0ooi[F@00ol0003onJeTooV]I002ooV]I0;on:]Q00?o0000
ooRXG?ogY5800_l00002ooJR@`ComZA300?omjI4onF@4ooUT1<00ooUT1<00onkJ`3o0000ooooo`06
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Gooooo000Pooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0ooooool>ooooo`;o<`3o2oooool2oc<0o`_ooooo0ooo0002oc<0o`Kooooo0_lc0?l<oooo
o`Goo`001oooool2oc<0o`04oooooolc0?oo<`3ooc<0o`;oo`002Oooool2o`0001CokJV24?od[7L3
ooV]I003o`000?oi[FConJeT00?onJeT0_ohZf401?l0003omjIGo`000?l00002ooJR@`?omZA30_og
YT@6onF@4`03ok][0?l0003ooooo00Gooooo0_l0000Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`008?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo0?oooooo2oooool2oc<0o`_ooooo0_lc0?l;ooooo`;oo`0000?ooooo
oc<0oolc0?l01_ooool2oc<0o`cooooo0_oo00000oooooooo`00ool00006ooooo`?o<`3o00Cooooo
oc<0oolc0?oooooo0_oo0008ooooo`?oo`0000?o0000onj`Roo^/8/04oo^/8/5ooFaO@com:ag0_oi
[F@00ol0003onJeTooV]I005ooV]I005ooR[HOl0003o0000ooJRA_l000000oofY4<4ooNVA0GoiI0C
00?o^f/0o`000?ooool01Oooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`008?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0?oooooo2?ooool2oc<0o`_ooooo0_lc0?l:ooooo`?oo`0000?o
oooooc<0oolc0?l01_ooool2oc<0o`_ooooo0ooo0002ooooo`03ool00?oooooooooo00Cooooo0_lc
0?l2ooooo`;o<`3o00?oooooool00?oo00001oooool3ool000?ooooo00?o0000onj`Roo^/8/04oo^
/8/>ooFaO@?om:ag0ooi[F@00ol0003onJeTooV]I005ooV]I004ooR[HOl0003omZ96o`0000;omZA3
1OogYT@5onF@4`03ok][0?l0003ooooo00Gooooo00?o0000ooooool000007?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool0023ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`3oooooo`Gooooo0_lc0?l<ooooo`03oc<0oooo
oooooooo00Sooooo0_oo00001?oooooo<`3ooc<0oolc0?l6ooooo`;o<`3o2oooool2ool000?ooooo
0_oo0004ooooo`?o<`3o00Gooooooc<0oolc0?oo<`3oooooo`02ool000Kooooo0ooo0007ooooo`03
o`000?o^/8_ok[2;01?ok[2;4?oe/Gd3ooV_I`03o`000?oi[fOonJeT00KonJeT0ol000000oofY4?o
mjI4ooNVA004ooNVA0GoiI0C0_nkJ`000ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo000Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0ooooool2ooooo`;o
<`3o3?ooool2oc<0o`Sooooo0ooo00000ooooooo<`3ooc<0o`07ooooo`;o<`3o2_ooool3ool000?o
oooo0_oo0004ooooo`;o<`3o0_ooool2oc<0o`;ooooo0_oo0006ooooo`;oo`002?ooool2ool00003
o`000?o^/8_ok[2;01?ok[2;4Ooe/Gd2ooV_I`03o`000?oi[fOonJmW00KonJmW00Co0000ooV]I?l0
003o00001oogYT@5onF@4`03ok][0?l0003ooooo00Gooooo00Co0000oooooooooooo00006_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool0
023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3nooooo`;o<`3o3?ooool2oc<0
o`Sooooo0_oo0002ooooo`;o<`3o1oooool2oc<0o`Wooooo0ooo0004ooooo`;oo`000oooool3oc<0
o`;ooooo0_lc0?l2ooooo`;oo`001Oooool3ool000Sooooo0_oo0002ooooo`03o`000?o^/8_ok[2;
01?ok[2;4Ooe/Gd3ooV_I`03o`000?oi[fOonJmW00KonJmW0ol00007ooNVA0GoiI0C00?o^f/0o`00
0?ooool01Oooool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`07ooooo`?o00009oooool0023ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`3kooooo`;o<`3o3?ooool2oc<0o`Oooooo0ooo0002ooooo`;o<`3o1oooool2oc<0
o`Wooooo0_oo0006ooooo`04ool00?ooooooooooooooo`;o<`3o0_ooool3oc<0o`;ooooo0_oo0004
ooooo`?oo`002Oooool2ool000;ooooo0ol0000Eonj`Ra7omK5m0ooi[fL00ol0003onJmWooV_I`05
ooV_I`04ooZaJ?l0003o0000o`0000?on:Q71?ogYT@5onF@4`03ok][0?l0003ooooo00Gooooo00Go
0000ooooooooooooooooo`00000Hooooo`?o00007?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Gooooo000Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0mooo
ool3oc<0o`gooooo00?o<`3oooooooooool01Oooool2ool000;ooooo0olc0?l7ooooo`;o<`3o2?oo
ool3ool000Kooooo0_oo0002ooooo`;o<`3o0_ooool2oc<0o`?ooooo0_oo0003ooooo`?oo`002Ooo
ool3ool00005ooooool0003o0000o`000?ooool00_lc0?l00ol0003ok[2;onj`R`0Conj`Ra7omK5m
0_oi[fL00ol0003onJmWooV_I`03ooV_I`?on[5X0_l000000ooj[U;o0000ooRXA`03ooRXA`?omjI4
1?oUT1<2ok][0003o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Booooo`?o00000_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03Oooool3o`0000;ooooo0ol0000?ooooo`008?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo0?Cooooo0_lc0?l>ooooo`;o<`3o1Oooool3ool000;ooooo0_lc
0?l8ooooo`;o<`3o2?ooool2ool000Oooooo0_oo00001?oooooo<`3ooc<0oolc0?l2ooooo`;o<`3o
0oooool2ool000;ooooo0ooo000:ooooo`;oo`0000Coooooo`000?l0003o00000_ooool2oc<0o`;o
oooo00?o0000onj`Roo^/8/04oo^/8/AooFaO@04ool00?oi[fOonJmWo`0000;onJmW1Ooj/FP2o`00
0003oo^aF?l0003on:Q700Kon:Q71OoUT1<00onkJ`3o0000ooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03_ooool3o`0000Gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0<ooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
0?7ooooo0_lc0?l>ooooo`;o<`3o1Oooool2ool000?ooooo0_lc0?l8ooooo`;o<`3o1oooool3ool0
00Oooooo0_oo00000ooooooo<`3ooc<0o`03ooooo`;o<`3o0oooool2ool000;ooooo0_oo000;oooo
o`;oo`000ol00002ooooo`?o<`3o00Gooooooc<0oolc0?oo<`3oo`00000Eonj`Ra7omK5m0ooi[fL0
0ol0003onJmWooZaJ004ooZaJ006ooZbJ?l0003o0000oo^bGOoj[U;o00001_ohZ4L2onVJ7`?oiI0C
00?o^f/0o`000?ooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
0ol00009ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`Co00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
000Oooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0k_ooool2oc<0o`kooooo0_lc
0?l4ooooo`?oo`000_ooool3oc<0o`Sooooo0_lc0?l6ooooo`?oo`002Oooool01?oo003o<`3ooc<0
oolc0?l2ooooo`?o<`3o0oooool2ool00004oooooooo003oo`00ool000[ooooo0ooo0002o`0000;o
oooo0olc0?l01?oooooo<`3ooc<0oolc0?l3ooooo`03ool00?l0003ok[2;01?ok[2;4_oe/Gd2ooV_
I`03o`000?oj/FSon[5X00Con[5X00Oon[9Xo`000?l0003onk=Qoo^aF?l0003onJ]<00Gon:Q70ooY
VQl2onF@4`;o^f/000?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo0ol0000<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?oo
ool001oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`3[ooooo`;o<`3o3oooool0
0olc0?ooooooooooo`02ooooo`;oo`000oooool2oc<0o`Wooooo0_lc0?l6ooooo`;oo`002_ooool0
0ooo003o<`3ooc<0o`03ooooo`;o<`3o1?ooool5ool000_ooooo0_oo0002o`0000;ooooo0olc0?l2
ooooo`;o<`3o0oooool3ool00003ooooool0003ok[2;01Cok[2;4Ooe/Gd01?oi[fOon[5XooZaJ?l0
0005ooZaJ008ooZbJ?l0003o0000oo^cHOok/UgonZiBo`000?oiZd`5ooRXA`CojIXO00?oiI0Cok][
0?l000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0ol0000?oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?o00003oooool001oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`3Xooooo`;o<`3o3oooool2oc<0o`;ooooo0ooo0003ooooo`;o<`3o2Oooool2oc<0o`Go
oooo0ooo000:ooooo`?o<`3o0oooool2oc<0o`Cooooo1?oo000<ooooo`;oo`0000Co0000oooooooo
oooooooo0_lc0?l2ooooo`?o<`3o0_ooool3ool000;ooooo0_oo00000ol0003ok[2;onj`R`0Conj`
Ra3omK5m00Gom[F1ooZaJ?oj/FSon[5Xo`000004ooZaJ0;on[9X0_l000001_ok]6Conk9MooZ^D_oj
[U;o0000ooV[C0Con:Q71OoYVQl00onkJ`3o0000ooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00ol0000Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
3oooool001oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3Uooooo`;o<`3o3ooo
ool2oc<0o`;ooooo0_oo0004ooooo`;o<`3o2Oooool2oc<0o`Gooooo0_oo000;ooooo`;o<`3o0ooo
ool3oc<0o`Cooooo0ooo000<ooooo`03o`000?oo003oo`0000?ooooo0olc0?l01?oooooo<`3ooc<0
oolc0?l2ooooo`?oo`000_ooool3ool000;ooooo00?o0000onj`Roo^/8/04oo^/8/>ooFaO@Com[F1
0_oj/FP00ol0003on[5XooZaJ002ooZaJ0;on[9X0_l000001Ook]6Conk=Qoo^aF?oj[U;o000000;o
nJ]<0oohZ4L5onVJ7`;o^f/000?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o
00005_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0_l0000@ooooo`03
o`000?oooooooooo00;ooooo0ol0000>ooooo`007oooool00ol0003oooooooooo`0Yooooo`;o0000
hoooool2oc<0o`oooooo0_lc0?l01?ooooooo`00ool00?oo0003ooooo`?o<`3o2Oooool2oc<0o`Co
oooo0ooo000:ooooo`?o<`3o0oooool2oc<0o`Gooooo0ooo000:ooooo`;o00000ooo0002ooooo`?o
<`3o00Cooooooc<0oolc0?oo<`3o0_ooool3ool000?ooooo0_oo0006ooooo`03o`000?o^/8_ok[2;
01;ok[2;3Ooe/Gd5ooJeP@?on[5X00?o0000ooZaJ?oj/FP00ooj/VP2o`000003oo^dI?ok/f7onk9M
00;onZiB00?o0000ooV[C?oiZd`00_ohZ4L5onVJ7`03olMm0?nkJ`3o000000Cooooo00Co0000oooo
oooooooooooo0ol00002ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`06ooooo`;o000000?oooooo`000?ooool09Oooool001oooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`3Nooooo`;o<`3o4?ooool01?lc0?ooooooool00?oo0004
ooooo`;o<`3o2_ooool2oc<0o`?ooooo0ooo000;ooooo`;o<`3o00Coo`00oooooooooooooooo0_lc
0?l4ooooo`?oo`002_ooool3o`0000;oo`000_ooool3oc<0o`;ooooo0_lc0?l2ooooo`?oo`000ooo
ool3ool000Sooooo00?o0000onj`Roo^/8/04oo^/8/:ooFaO@Som[F10_oj/FP00ol0003on[5XooZa
J003ooZbJ0?o000000?onk=Qoo^bGOok/EP00_oj[U801?l0003onJ]<ooV[C?ohZ4L6onVJ7`03olMm
0?l0003ooooo00?ooooo1?l00006ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0foooool2oc<0oa3ooooo0_lc0?l2ool000Cooooo0_lc
0?l:ooooo`;o<`3o0oooool2ool000_ooooo0olc0?l2ool00004oooooolc0?oo<`3ooc<0o`?ooooo
1?oo0009ooooo`?o000000Coooooool00?oo003ooooo0olc0?l2ooooo`?o<`3o00Coooooool00?oo
003oo`001?ooool2ool000_ooooo00?o0000onj`Roo^/8/04oo^/8/8ooFaO@[om[F10_oj/FP00ol0
003on[5XooZbJ003ooZbJ0?o000000?onkAToo^cHOok/Ud00_oj[U83o`000003ooV[C?ohZ4OojIXO
00CojIXO00Coagd0ok][0?l0003ooooo0ol00009ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo000Ooooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0f?ooool2oc<0oa3ooooo0_lc0?l00ooo
003oooooooooo`03ooooo`;o<`3o2_ooool2oc<0o`;ooooo0ooo000;ooooo`;o<`3o00Coooooool0
0?oo003ooooo0_lc0?l4ooooo`Coo`002?ooool3o`0000;ooooo0_oo00000ooooooo<`3ooc<0o`02
ooooo`?o<`3o00Coooooool00?oo003oo`001?ooool3ool000gooooo00?o0000onj`Roo^/8/04oo^
/8/7ooFaO@_om[F10ooj/FP00ol0003on[9XooZbJ002ooZbJ0;o000000Gonk=Woo^dI?ok/f7onk9M
oc<0o`02ooZ^DP;o00000_oiZd`5onVJ7`;oagd00_l00002ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`3Eooooo`;o<`3o4?ooool2oc<0o`03ool00?oooooooooo00;ooooo0olc0?l:ooooo`;o<`3o00Co
ooooool00?oo003oo`002oooool3oc<0o`04oooooooo003oo`00ooooo`;o<`3o0oooool5ool000Oo
oooo0ol00002ooooo`?oo`000olc0?l2ooooo`;o<`3o00Coooooool00?oo003oo`001?ooool3ool0
017ooooo00?o0000onj`Roo^/8/04_o^/8/5ooFaO@kom[F10ol00003ooZbJ0;onk=X00Ko0000oo^c
Iook]6Conk=Qoo^bGOok/EP2ooZ^DP04o`000?oiZdconJ]<ooV[C0KojIXO00?oagd0o`000?ooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0d_ooool2oc<0oa3ooooo00?oo`00oc<0ooooool01?oo
ool2oc<0o`_ooooo0_lc0?l00oooooooo`00ool0000<ooooo`;o<`3o0oooool01?oo003o<`3ooc<0
oolc0?l2ooooo`?oo`0000?oooooool00?oo00001_ooool3o`0000?ooooo0_oo0003oc<0o`;ooooo
0olc0?l3ool000Gooooo0_oo000Dooooo`03o`000?o^/8_ok[2;01?ok[2;0_oe/Gd=ooJeP@?o0000
00?oo`00ooZaJ?l000000ooj/VP2oo^cJ004o`000?ok/fOonkAToo^cH@;onk9M00Conk5HooZ^D_oj
[U;o00000_oiZd`00oo`YBoojIXOonVJ7`03onVJ7`03olMm0?l0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo0<kooooo0olc0?l?ooooo`;oo`000_lc0?l4ooooo`;o<`3o2oooool2oc<0o`?o
o`002oooool3oc<0o`?ooooo00?oo`00oc<0oolc0?l00_ooool3ool000?ooooo00?oo`00oooooooo
ool00oooool3o`0000Cooooo00Coo`00oc<0oolc0?oo<`3o0_ooool3oc<0o`?oo`001Oooool3ool0
01?ooooo0ooo00000ol0003ok[2;onj`R`0Conj`R`03ooFaOOof]H7om[F100Wom[F10ol00004ooJe
P@03ooZaJ?oj/VSo000000;on[9X0_ok/fP2o`000005oo^dI?ok/f7onk=Qoo^bGOok/EP00ooj[U80
1?l0003onJ]<oo2U;oo`YBl4onVJ7`;oagd000Co0000oooooooooooo00003?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Sooooo`007_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0<_ooooo0_lc
0?l@ooooo`;oo`000_lc0?l4ooooo`;o<`3o2oooool2oc<0o`;oo`003?ooool2oc<0o`Cooooo00Co
o`00oc<0oolc0?oooooo0ooo0004ooooo`;oo`000oooool3o`0000Cooooo00Coo`00oc<0oolc0?oo
<`3o0oooool2oc<0o`?oo`001Oooool3ool001?ooooo0ooo0003ooooo`03o`000?o^/8_ok[2;01;o
k[2;00?ol;J@ooJePOof]H401oof]H43o`0000Oom[F10_oj/VP00ol0003on[9XooZbJ002oo^cJ0;o
00000_ok]6@01?ok/f7onk9Moo^bGOok/EP2ooZ^DP03o`000?oiZdcol:D_00;ol:D_1?oYVQl01Oo7
O@3o0000oooooooooooo000000gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Sooooo0_l0000Uooooo`007_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo0<Sooooo0_lc0?l?ooooo`?oo`000_lc0?l3ooooo`?o<`3o2oooool2oc<0
o`;oo`002oooool3oc<0o`Cooooo00Coo`00oc<0oolc0?oooooo0_oo0005ooooo`;oo`000_ooool3
o`0000Gooooo00?oo`00oc<0oolc0?l00oooool3oc<0o`;oo`001_ooool2ool001?ooooo0ooo0007
ooooo`03o`000?o^/8_ok[2;00ook[2;1?o`]Y04ooJeP@Co00002_of]H400ooh^H;on[9Xo`000002
ooZbJ0;onk=X0_l000000ook/fOonkAToo^cH@02oo^bG@06oo^aF?oj[U;onZiBooZ^D_l0003onJ]<
0_o`YBl4onVJ7`05olMm0?l0003oooooooooool000003_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000Uooooo`00
7_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0<Gooooo0_lc0?l?ooooo`;oo`00
0_ooool01?lc0?ooooooooooooooool2oc<0o`cooooo0_lc0?l00ooo003oooooooooo`0:ooooo`;o
<`3o1Oooool3oc<0o`?oo`001Oooool2ool00004ooooool0003o0000o`0000Kooooo0olc0?l2oooo
o`?o<`3o0_oo0006ooooo`?oo`004_ooool3ool000[ooooo00?o0000onj`Roo^/8/03Oo^/8/6oo2f
T004ooJePOl0003o0000o`0000gom[F10_oh^H82ooZbJ003o`000?oj/VSo000000?o000000Gonk=W
oo^dI?ok/f7onk=Qoo^bG@02oo^aF0;onZiB00?o0000ooV[C?o`YBl00_o`YBl3onVJ7`03olMm0?l0
003ooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`007_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo0<;ooooo0_lc0?l>ooooo`?oo`000_ooool2
oc<0o`;ooooo0_lc0?l<ooooo`;o<`3o3?ooool3oc<0o`Gooooo0_lc0?l3ool000Kooooo0_oo0003
o`0000Kooooo0olc0?l3ooooo`;o<`3o0_oo0006ooooo`?oo`004Oooool01?lc0?ooo`00ool00?oo
000=ooooo`03o`000?o^/8_ok[2;00_ok[2;1_o`]Y03o`0000oom[F11?oh^H83o`0000;onk=X0_l0
00001?ok/fOonkAToo^cHOok/f42oo^bG@05oo^aF?oj[U;onZiBooZ^D_l000001?o`YBl2onVJ7`;o
agd000Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo0;oooooo0_lc0?l>ooooo`;oo`000oooool2oc<0o`04
oooooolc0?oo<`3ooc<0o`_ooooo00?oo`00oc<0oolc0?l03?ooool2oc<0o`Kooooo0_lc0?l2ool0
00Oooooo0_oo0002o`0000Kooooo0olc0?l00ooo003oooooooooo`03oc<0o`03ool00?oooooooooo
00Gooooo0_oo000Aooooo`Coo`004Oooool00ol0003ok[2;onj`R`08onj`R`Gol;J@0ol00003oo2f
T0oom[F100Con;V2o`000?l0003o00000_oj/VP01_l0003onk=Xoo^cJ?ok/fSo0000oo^cI`;onkAT
00?onk=Qoo^bGOok/Ud00_ok/EP3ooZ^DP03o`000?o`YBool:D_00;ol:D_0_oYVQl01Oo7O@3o0000
oooooooooooo000000oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool001kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`2looooo`;o<`3o3Oooool3ool000?ooooo0_lc0?l00ooooooo<`3o
oc<0o`0<ooooo`03ool00?lc0?oo<`3o00_ooooo0olc0?l5ooooo`?o<`3o00?oo`00ooooooooool0
1_ooool2ool00003o`000?oooooooooo00Gooooo0_lc0?l00ooo003oooooooooo`03oc<0o`03ool0
0?oooooooooo00Gooooo0ooo000@ooooo`?oo`005Oooool00ol0003ok[2;onj`R`07onj`R`;ol;J@
1?l00006oo2fT0gom[F10ol00004ooRiPP03ooZbJ?l0003onk=X00;onk=X0_l00002oo^dI0;onk=Q
00?onk9Moo^aF?ok/EP00ooj[U800ol0003ol:D_oo2U;`02oo2U;`;ojIXO00Goagd0o`000?oooooo
ooooo`00000@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0^Oooool2oc<0o`gooooo0_oo0005ooooo`04oc<0oooooooo<`3ooc<0o`_o
oooo0_oo0002oc<0o`_ooooo0_lc0?l6ooooo`;o<`3o0_oo0006ooooo`;o00000_oo0007ooooo`?o
<`3o00?oo`00oooooolc0?l00_lc0?l2ool000Kooooo0ooo000@ooooo`?oo`006?ooool00ol0003o
k[2;onj`R`05onj`R`04oo2fT?l0003o0000o`0000_ol;J@2Oof]H43o`0000Oon;V200Con[9Xo`00
0?ok/fSonk=X0_l000000ook/fOo0000oo^dI002oo^cH@;onk9M00Konk5HooZ^D_oj[U;onZiBooJ`
@_l00004oo2U;`06onVJ7oo7O@3oagd0o`000?oooooo00004?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Roooo
o`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0;Kooooo0_lc0?l<ooooo`?o
o`001Oooool4oc<0o`[ooooo0ooo0002oc<0o`[ooooo0olc0?l6ooooo`;o<`3o0ooo0004ooooo`?o
00000_oo0006ooooo`?o<`3o0_oo00000ooooooo<`3ooc<0o`02ool000Oooooo0_oo000@ooooo`?o
o`006Oooool2ool00003o`000?o^/8_ok[2;00?ok[2;0ol0000>oo2fT0Kom[F10ol00003ooJeP@So
n;V200?onk=Xo`000?ok/fP00_l000000ook/fOo0000oo^dI002oo^cH@;onk9M0_ok/EP2ooZ^DP04
ooJ`@_l0003o0000o`0000?ol:D_00GojIXOolMm0?l0003oooooo`00000Aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02;ooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0/oooool2oc<0
o`cooooo0_oo0006ooooo`Co<`3o2_ooool2ool00003oooooolc0?oo<`3o00[ooooo0_lc0?l6oooo
o`?o<`3o00?oooooool00?oo00000oooool3o`000003oooooooo003oo`0000Gooooo0olc0?l3ool0
00?o<`3o00?oo`00ooooooooool01Oooool3ool000oooooo0ooo000Hooooo`Coo`000oooool00ol0
003ok[2;o`000002o`00017ol;J@0oof]H43o`0000Gom[F12Ooh^H801Ooo003o0000oo^cJ?ok/fSo
000000;onk=W00?o0000oo^cHOok/f400ook/Ud01Ook/ESonZiBooZ^D_lc0?oom[1200;o00001?o`
YBl01?o7O@3o0000ooooool0000Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0/?ooool2oc<0o`_ooooo0ooo0007ooooo`;o<`3o2_oo
ool3ool00003oooooolc0?oo<`3o00Wooooo0olc0?l6ooooo`;o<`3o0_ooool2ool000;ooooo0ol0
0002ooooo`;oo`001?ooool3oc<0o`03oooooooo003oo`0000?o<`3o00?oo`00ooooooooool01Ooo
ool3ool000oooooo0ooo000Gooooo`Coo`001Oooool2ool000;o00005?o`]Y03o`0000Oom[F12_oh
^H801Ooj_H;onk=Xo`000?ok/fSo000000;onk=W00ConkATo`000?ok/f7onk=Q0_ok/Ud2oo^aF004
ooZ^D_of/4;om[12o`0000Gol:D_00Coagd0o`000?oooooo00004_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool2o`0002Cooooo000Moooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0[Oooool2oc<0o`_ooooo0_oo0008oooo
o`;o<`3o2Oooool3ool000;ooooo0_lc0?l9ooooo`;o<`3o1_ooool00ooo003o<`3ooc<0o`03oooo
o`03ool00?oooooo000000;o00000oooool2ool000Cooooo0_lc0?l2ooooo`;oo`000_lc0?l00ooo
003oooooooooo`06ooooo`;oo`003oooool3ool001Kooooo1?oo0006ooooo`?oo`000_lc0?l00ol0
003ol;J@oo2fT00?oo2fT0Co000000?ol;J@ooJePOof]H401oof]H4:ooRiPP05ooZmP_ok/fSo0000
oo^cJ?l000000_ok/fL2oo^dI004o`000?ok/f7onk9Moo^bG@;onk5H00GonZiBooJ`@_of/4;om[12
o`000004oo2U;`04omRE2_o7O@3o0000o`0001?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000009?ooool001gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2Zooooo`;o<`3o2_ooool3ool000Sooooo
0_lc0?l9ooooo`;oo`000oooool2oc<0o`Sooooo0olc0?l5ooooo`04ool00?lc0?oo<`3ooc<0o`?o
oooo0_oo0002o`0000Cooooo0_oo0003ooooo`?o<`3o00?oooooool00?oo00000olc0?l8ooooo`?o
o`003Oooool01?lc0?ooo`00ool00?oo000Eooooo`Coo`001oooool3ool000Co<`3o0_ooool00ol0
003ol;J@oo2fT00;oo2fT0?o00001Oo`]Y08ooJeP@[on;V20ooj_H800ol0003onk=Xo`000002oo^c
I`;onkAT00?o0000oo^cHOok/Ud00_ok/Ud2oo^aF0?om[1200?o0000oo2U;oo`YBl00_o`YBl01?oH
U@[oagd0o`000?l0000Dooooo`03o`000?oooooooooo00[ooooo0_l0000Iooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08Oooool001gooooo00?o0000ooooooooool0?oooool2o`00
0:Oooooo0olc0?l:ooooo`;oo`002?ooool3oc<0o`Sooooo0ooo0003ooooo`;o<`3o2?ooool2oc<0
o`Gooooo0_oo0002oc<0o`Cooooo0_oo00000ol0003oooooooooo`03ooooo`;oo`000_ooool3oc<0
o`;ooooo00Coo`00oc<0oolc0?oo<`3o2Oooool2ool000gooooo1?oo000Eooooo`?oo`001oooool4
ool000?o<`3o1_ooool00ol0003ol;J@oo2fT008oo2fT0?o00002Oo`]Y06ooJeP@_on;V21?oj_H82
o`0000;onk=W0_ok]6@00ook/f7o0000oo^cH@02oo^bG@;onk5H1?of/4801_l0003ol:D_oo2U;oo`
YBoof9D:olMm00;o00005Oooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?ooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027ooooo000Mooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool0X_ooool2oc<0o`[ooooo0ooo0008ooooo`?o<`3o2?oo
ool2ool000Cooooo0_lc0?l7ooooo`?o<`3o1Oooool2ool000;o<`3o0oooool00ol0003oo`00ool0
0006ooooo`;oo`0000Cooooooc<0oolc0?oo<`3o0oooool00ooo003o<`3ooc<0o`09ooooo`?oo`00
3?ooool3ool001Gooooo1?oo0007ooooo`?oo`001?lc0?l9ooooo`03o`000?o`]Y3ol;J@00Gol;J@
0ol0000<oo2fT0Kom[F12ooh^H84ooZmPP;o00000_ok/fL3oo^dI003oo^cHOl0003onk9M00;onk9M
00?onk5Hoo^iE?of/4800_of/4800ol0003ol:D_oo2U;`02oo2U;`03omRE2_l0003o000001Gooooo
00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo027ooooo000Mooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0Woooool2oc<0o`[ooooo0_oo0009ooooo`Co<`3o1_ooool3ool000Cooooo0_lc
0?l7ooooo`;o<`3o1Oooool3ool000;o<`3o0_ooool2o`0000;oo`001_ooool2ool00003oooooolc
0?oo<`3o00?ooooo00Coo`00oc<0oolc0?oo<`3o2?ooool3ool000cooooo0ooo000Dooooo`Coo`00
2?ooool3ool000?o<`3o3_ooool01?l0003ol;J@oo2fT?o`]Y03o`00013ol;J@1?of]H4;ooRiPPGo
n[f20_l00002oo^cI`?onkAT0_ok/f401Ol0003onk9Moo^bGOok/ESonkUD00Com[1200Oo0000oo2U
;oo`YBool:D_omRE2_o7O@3o000001Kooooo00?o0000ooooool000000_l00007ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`007?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo09cooooo0_lc0?l:ooooo`;oo`002Oooool4
oc<0o`Gooooo0ooo0005ooooo`;o<`3o1_ooool3oc<0o`Cooooo0ooo0003oc<0o`06ooooool0003o
0000o`000?ooooooo`001_ooool2ool000?o<`3o0_ooool01?oo003o<`3ooc<0oolc0?l9ooooo`;o
o`003?ooool3ool001?ooooo1?oo0008ooooo`Coo`000olc0?lAooooo`Co00004oo`]Y03ooJeP@co
n;V21_oj_H801?l0003onk=Woo^cIook/fL2oo^dI0;onk=Q00Go0000oo^bGOok/Ugonk5Hoo^iE004
ooJ`@P06o`000?o`YBool:D_oo2U;ooHU@[oagd00_l0000Dooooo`?o00002oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool001cooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`2Iooooo`;o<`3o2Oooool3ool000Sooooo1Olc
0?l5ooooo`;oo`001_ooool2oc<0o`Kooooo0_lc0?l4ooooo`?oo`0000Cooooooc<0oolc0?oooooo
0ol00002ooooo`;oo`001Oooool01?oo003o<`3ooc<0oolc0?l2ooooo`;oo`000_lc0?l9ooooo`?o
o`002oooool3ool001;ooooo1?oo0008ooooo`04oc<0oooo003oo`00ool000?o<`3o4_ooool00ooo
003o0000o`000002o`0001Gol;J@0oof]H4<ooRiPPKon[f200Co0000ooc0Oook/fOonk=W0_ok]6@3
oo^cH@03o`000?ok/Ugonk9M00;onkUD0oof/4801?l0003ol:D_oo2U;oo`YBl2omRE2P;o00004Ooo
ool3o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08Oooool001cooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`2Fooooo`;o<`3o2Oooool2ool000Wooooo0_lc0?l2ooooo`03oc<0oooooooo
oooo00;ooooo0ooo0006ooooo`;o<`3o1Oooool3oc<0o`?ooooo0ooo0002ooooo`;o<`3o0ol00003
ooooo`;oo`001Oooool3oc<0o`;ooooo0_oo0003oc<0o`Sooooo0ooo000;ooooo`?oo`004Oooool4
ool000Wooooo00Co<`3oool00?oo003oo`000olc0?l@ooooo`?oo`000ol00003ooooo`03o`000?o`
]Y3ol;J@01Col;J@00?om[F1ooRiP_oh^H802_oh^H87ooZmPP;o000000Coo<1ooo^cIook]6ConkAT
0ook/f400ook/Ugo0000oo^bG@02oo^iE0Com[1200?o0000oo2U;oo`YBl00_oHU@X00oo7O@3o0000
ooooo`0=ooooo`?o00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02Oooool2o`0002?ooooo000Looooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0Toooool2oc<0o`Sooooo0ooo0009ooooo`;o<`3o0_ooool2oc<0o`?ooooo0_oo
0007ooooo`;o<`3o1Oooool2oc<0o`Cooooo0_oo0002ooooo`?o<`3o0_l00004ooooo`;oo`001?oo
ool3oc<0o`;ooooo0_oo0003oc<0o`03ool00?oooooooooo00Kooooo0_oo000;ooooo`?oo`004Ooo
ool3ool000Wooooo00?o<`3oool00?oo00000_oo0002oc<0o`oooooo1Ooo0003o`0000Kooooo00?o
0000oo2fT?o`]Y005?o`]Y0=ooRiPPOon[f20_l00002ooc0O`?onkAT0ook/f401?ok/Ugo0000oo^i
E?ok^E@4ooJ`@P03o`000?o`YBool:D_00;of9D:00?oagd0o`000?ooool02_ooool3o`0000[ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000008oooool001cooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`2@ooooo`;o<`3o2?ooool2ool000Wooooo0olc0?l2ooooo`;o<`3o0_ooool3ool000Oooooo0_lc
0?l4ooooo`?o<`3o0oooool3ool000;ooooo0_lc0?l2o`0000Kooooo00?oo`00ooooooooool00_oo
ool2oc<0o`04ool00?ooooooo`00ool000?o<`3o0_oo0007ooooo`?oo`002Oooool01?lc0?ooo`00
ool00?oo000@ooooo`Coo`002?ooool2oc<0o`?oo`000olc0?l=ooooo`Goo`001Ol00007ooooo`?o
o`0000?o0000oo2fT?o`]Y004oo`]Y000ooc_9Con;V2ooRiPP0:ooRiPPKon[f20ol00002ooc0O`?o
oL5i0ook/f400ook/Ugo0000oojoI002oo^iE0Com[120_l00003omRE2P03o`000?oooooooooo00Ko
oooo0ol0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo023ooooo000Looooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool0SOooool2oc<0o`Oooooo0ooo0009ooooo`;o<`3o0oooool2oc<0o`04oooo
oooo003oo`00ool000Sooooo0_lc0?l4ooooo`;o<`3o0oooool3ool000;ooooo00?o0000oc<0oolc
0?l02?ooool2ool000;ooooo0olc0?l01?oo003oooooool00?oo0002oc<0o`;oo`001oooool3ool0
00Wooooo1?oo000?ooooo`Coo`002?ooool2oc<0o`Coo`000_lc0?l<ooooo`Goo`000_ooool3o`00
00Sooooo1?oo00001?oooooo<`3ooc<0ool0000Doo2fT0;olkbD2ooh^H800ooo003on[f2ooZmPP04
ooZmPP;o000000?oo<1oo`000?ol`7l00oom`GT3ook1L@;oo[mT00?o0000oo^iE?ok^E@00_of/480
1?lc0?oom[12o`000?l00003omRE2P03o`000?oooooooooo00?ooooo0ol0000Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo023ooooo000Looooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0R_ooool2
oc<0o`Oooooo0_oo000:ooooo`;o<`3o1?ooool01?lc0?ooooooool00?oo0009ooooo`;o<`3o0ooo
ool3oc<0o`;ooooo0ooo0002ooooo`04o`000?lc0?oo<`3ooc<0o`Sooooo0_oo00001?oooooo<`3o
oc<0oolc0?l4ool000?o<`3o0_oo0007ooooo`;oo`002Oooool4ool000kooooo1?oo0009ooooo`;o
<`3o0ooo0002oc<0o`[ooooo1_oo0004ooooo`?o00001oooool4ool00003oooooolc0?oo<`3o00;o
<`3o0_ooool00olc0?oo0000oo2fT00Aoo2fT0ColkbD2_oh^H800ooo003on[f2ooZmPP04ooZmPP05
o`000?ol`7ooo<1oo`000?ol`7l00oom`GT3ook1L@?oo[mT00?o0000oo^iE?ok^E@01?of/4801?l0
003of9D:omRE2_oHU@X2o`000004ooooool0003o0000o`0001Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool001cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`27ooooo`;o<`3o1_ooool3
ool000[ooooo0_lc0?l4ooooo`;o<`3o0_oo0009ooooo`;o<`3o0oooool2oc<0o`?ooooo0_oo0002
ooooo`;o00000_lc0?l9ooooo`;oo`000olc0?l01?ooooooo`00ool00?oo0003oc<0o`?oo`001_oo
ool3ool000Sooooo0ooo000>ooooo`Coo`002Oooool3oc<0o`?oo`000_lc0?l8ooooo`Goo`001ooo
ool3o`0000Oooooo0ooo0005oc<0o`;ooooo1?lc0?l00ooooooo0000oo2fT00@oo2fT0GolkbD2_oh
^H87ooZmPP05o`000?ol`7ooo<1oooc0Ool000000oom`GT3ook1L@?oo[mT00?onkUDo`000?ok^E@0
1?of/4801?l0003ol:D_omRE2_oHU@X3o`0001Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool001cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`24ooooo`;o<`3o1_ooool2ool000[ooooo
0olc0?l4ooooo`;o<`3o00?oo`00ooooooooool02?ooool2oc<0o`;ooooo0olc0?l2ooooo`?oo`00
00Coooooo`000?l0003o00000_lc0?l:ooooo`?o<`3o0_ooool3ool000;o<`3o00?oooooool00?oo
00001_ooool3ool000Sooooo0ooo000=ooooo`Coo`002Oooool3oc<0o`Coo`0000?o<`3ooooooooo
ool01Oooool5ool000Wooooo0ol00006ooooo`Coo`000olc0?l3ooooo`Co<`3o1Oooool00ol0003o
l;J@oo2fT00?oo2fT0KolkbD2Ooh^H87ooZmPP05o`000?ol`7ooo<1oooc0Ool000000oom`GT4ook1
L@?oo[mT00?o0000oo^iE?of/4801?of/4800ol0003of9D:omRE2P02o`0001_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08?ooool001_ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`21ooooo`;o
<`3o1Oooool3ool000[ooooo0_lc0?l5ooooo`;o<`3o2oooool2oc<0o`;ooooo0_lc0?l2ooooo`?o
o`0000Goooooo`000?l0003o0000ooooo`02oc<0o`[ooooo0_lc0?l2ooooo`?oo`000olc0?l00ooo
ooooo`00ool00006ooooo`;oo`002?ooool3ool000cooooo1?oo000:ooooo`?o<`3o0ooo0002oc<0
o`Gooooo1Ooo000;ooooo`?o00001_ooool3ool000?o<`3o0oooool4oc<0o`Wooooo00?oo`00o`00
0?o`]Y003_o`]Y07oo>lU0Son;V22?oj_H801Ol0003oo<1oooc0Oool`7oo000000?ooL5i1?on`G43
oojoI003oo^iE?l0003onkUD00Com[1200?o0000omRE2_oHU@X00_l0000Looooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo023ooooo000Kooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0O_ooool2oc<0
o`Gooooo0_oo000;ooooo`;o<`3o1?ooool2ool00003oc<0oooooooooooo00Wooooo0_lc0?l01Ooo
oooo<`3ooc<0oolc0?oooooo00?oo`0000Goooooo`000?l0003o0000ooooo`03oc<0o`Wooooo0olc
0?l01?ooooooo`00ool00?oo0003oc<0o`;ooooo0_oo0005ooooo`?oo`001oooool3ool000cooooo
0ooo000:ooooo`Co<`3o0ooo00000olc0?ooooooooooo`02ooooo`Goo`003?ooool4o`0000Gooooo
1?oo00000olc0?ooooooooooo`02ooooo`Co<`3o1_ooool7ool00003ooooool0003ol;J@00gol;J@
2Ooc_9@7ooRiPPSon[f200?o0000ooc0Oool`7l00ol00003oog1N@?oo/5a0oon_f@2oo^iE003o`00
0?of/4;om[1200?om[1200Co0000omRE2_l0003o00007?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`00
6oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo07[ooooo0olc0?l4ooooo`?oo`00
2oooool2oc<0o`Cooooo0_oo0002oc<0o`[ooooo0_lc0?l00ooooooo<`3ooc<0o`02ooooo`;oo`00
00Coooooo`000?l0003o00000_ooool2oc<0o`Wooooo0olc0?l5ool000;o<`3o0_ooool3ool000Go
oooo0_oo0007ooooo`?oo`002oooool4ool000Wooooo1?lc0?l4ool00003oc<0oooooooooooo00Go
o`003_ooool3o`0000Gooooo1?oo00000olc0?ooooooooooo`02ooooo`Co<`3o0oooool7ool000So
oooo00?o0000oo2fT?o`]Y002oo`]Y0:oo>lU0Oon;V22?oj_H83o`0000;oo<1o00Co0000oog1NOom
`GWooL5i0oon`G43oojoI0?onkUD00?o0000ooJ`@_of/4800_of/4801?l0003of9D:o`000?l0000M
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08
ooooo`;o00008_ooool001_ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`1goooo
o`;o<`3o1Oooool2ool000_ooooo0olc0?l3ooooo`?oo`000_lc0?l:ooooo`Go<`3o00Coooooool0
0?oo003oo`000ol00003ooooo`;o<`3o2?ooool3oc<0o`05oooooooo003oo`00ool00?ooool00olc
0?l2ooooo`;oo`001Oooool3ool000Gooooo00Co<`3oool00?oo003oo`002_ooool4ool000[ooooo
0olc0?l01_ooooooo`00ool00?oo003o<`3oooooo`Goo`004?ooool3o`0000Cooooo00Co<`3oool0
0?oo003oo`001Oooool3oc<0o`Soo`004?ooool00ol0003ol;J@oo2fT00:oo2fT0_olkbD1Ooh^H86
ooZmPP?o00001Ool`7l01?om`GWo0000oog1NOom`GT3ook1L@Coo[mT0_ok^E@00ol0003om[12ooJ`
@P02ooJ`@P05o`000?oHU@[o0000omRE2_l000007Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000Qooooo`00
6oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo07Cooooo0_lc0?l4ooooo`?oo`00
2oooool2oc<0o`?ooooo0ooo00000ooooooo<`3ooc<0o`0:ooooo`Co<`3o00Coooooool00?oo003o
o`000ol00003ooooo`?o<`3o2?ooool2oc<0o`05oooooooo003oo`00ool00?ooool00olc0?l3oooo
o`;oo`001?ooool3ool000Gooooo1?oo0009ooooo`Coo`002_ooool4oc<0o`03oooooooo003oo`00
00Koo`004_ooool3o`0000;ooooo0_lc0?l4ool000Cooooo1ooo000Hooooo`03o`000?o`]Y3ol;J@
00Wol;J@3?oc_9@5ooRiPP?on[f20ol00002ooZmPP03o`000?ol`7ooo<1o00?oo<1o00CooL5io`00
0?om`GWooL5i1?on`G43oojoI0?onkUD00Go0000ooJ`@_of/4;om[12onV];@02o`000003omRE2_l0
003ooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07oooool001_ooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`1aooooo`;o<`3o1?ooool2ool000cooooo0_lc0?l3ooooo`;oo`000oooool0
0olc0?ooooooooooo`08ooooo`Co<`3o0ooo0003o`0000Cooooo0_lc0?l8ooooo`?o<`3o1?oo0000
1?oooooo<`3ooc<0oooo0003ooooo`;oo`001?ooool2ool000Gooooo1?oo0008ooooo`Coo`002_oo
ool4oc<0o`03oooooooo003oo`0000Goo`005?ooool3o`000004oooooolc0?oo<`3ooc<0o`?oo`00
00?oooooool00?oo00001Ooo000Mooooo`?oo`0000?o0000oo2fT?o`]Y001oo`]Y0>oo>lU0?on;V2
1?l00005ooZmPP03o`000?ol`7ooo<1o00?oo<1o0_om`GT00ol0003ooL5iook1L@03ook1L@?oo[mT
0ook^E@01Oof/4;o0000ooJ`@_of/4;ojJd]00;o000000?of9D:o`000?ooool07Oooool01Ol0003o
oooooooooooooooo000001Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`;o00005Oooool001_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1^ooooo`;o
<`3o0oooool3ool000cooooo0_lc0?l2ooooo`?oo`000oooool2oc<0o`Wooooo0olc0?l3ool000?o
00001Oooool2oc<0o`Oooooo0olc0?l5ool000?o<`3o00?oo`00ooooooooool00ooo0003ooooo`?o
o`001?ooool3ool000Sooooo1?oo000:ooooo`Co<`3o0_ooool5ool001Kooooo0ol00003oc<0o`So
o`000olc0?lMooooo`Coo`000olc0?l00ol0003ol;J@oo2fT006oo2fT0oolkbD0ol00009ooZmPP03
o`000?ol`7ooo<1o00?oo<1o0_om`GT00ol0003ooL5iook1L@03ook1L@?oo[mT1?ok^E@01_of/4;o
0000ooJ`@_oY[Bgo0000omRE2P;o00007oooool01?l0003oooooooooool0000Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0000Dooooo`006ooo
ool00ol0003oooooooooo`1Eooooo`;o0000K?ooool2oc<0o`?ooooo0_oo000<ooooo`?o<`3o0_oo
ool2ool000Cooooo0_lc0?l9ooooo`?o<`3o0_oo0003o`0000Gooooo0olc0?l6ooooo`?o<`3o0ooo
0002ooooo`?o<`3o0_oo0002ooooo`;oo`000oooool3ool000Cooooo0ooo0008ooooo`?oo`002ooo
ool3oc<0o`03oooooooo003oo`0000?oo`006?ooool2o`0000Soo`000_ooool4oc<0oagooooo1?oo
0004oc<0o`?ooooo00?o0000oo2fT?o`]Y001_o`]Y0<oo>lU0?o000000?olkbDooRiP_oh^H802Ooj
_H82o`0000Coo<1o0oom`GT00ol0003oo/5aook1L@02ook1L@Coo[mT0ook^E@00oof/4;o0000ooJ`
@P02onV];@?o00008?ooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool01?l0003oooooooooool0000Dooooo`006oooool00ol0003ooooooooo
o`1Gooooo`03o`000?oooooooooo06Oooooo0_lc0?l2ooooo`?oo`003?ooool2oc<0o`;ooooo0ooo
0004ooooo`;o<`3o2Oooool2oc<0o`?oo`0000?o0000ooooooooool01Oooool2oc<0o`Kooooo0olc
0?l3ool000;ooooo0olc0?l00oooooooo`00ool00002ooooo`;oo`000oooool2ool000Cooooo0ooo
0007ooooo`Coo`002_ooool3oc<0o`Ooo`005_ooool:ool000?ooooo1?lc0?lMooooo`Coo`000_lc
0?l8ooooo`;o<`3o00?o0000oo2fT?o`]Y001?o`]Y0:oo>lU0?o00001?oc_9@2ooRiPPWon[f20_l0
0004ooc0O`?ooL5i00?o0000ook1LOon`G400_on`G44oojoI0ConkUD00Com[12o`000?oY[Bgo<`3o
0ol0000Pooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`0001Cooooo000Jooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0I?ooool2oc<0o`;ooooo0_oo000=ooooo`;o<`3o00Coooooool00?oo003o
o`001_ooool00olc0?ooooooooooo`07ooooo`;o<`3o0_oo00000ol0003oooooooooo`06ooooo`;o
<`3o1_ooool2oc<0o`?oo`000oooool2oc<0o`05ool00?ooooooo`00ool00?ooool00ooo0002oooo
o`?oo`000oooool3ool000Kooooo1?oo000:ooooo`03oc<0oooo003oo`0000Ooo`004oooool7ool0
0003o`000?oooooooooo00Coo`000_ooool4oc<0oacooooo00?o<`3oool00?oo00000_oo00000olc
0?ooooooooooo`06ooooo`Go<`3o0_ooool00ol0003ol;J@oo2fT003oo2fT0OolkbD1?l00008oo>l
U003ool00?oj_H;on[f200Oon[f200?o0000ooc0Oool`7l00ool`7l4oog1N@03o`000?on`G7oo/5a
00;oo/5a0oon_f@4oo^iE0;om[1200?o0000onV];Ol000000_l0000Qooooo`03o`000?oooooo0000
01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0001Cooooo000Jooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0HOooool2oc<0
o`04oooooooo003oo`00ool000cooooo0olc0?l00oooooooo`00ool00007ooooo`;o<`3o1oooool3
oc<0o`03ool00?l0003ooooo00Oooooo0olc0?l5ooooo`?o<`3o0_oo0003ooooo`?o<`3o00Goo`00
oooooooo003oo`00ooooo`02ool000;ooooo0ooo0003ooooo`?oo`001Oooool4ool000[ooooo1Ooo
0002ooooo`Coo`003oooool7ool000;o<`3o0ol00002ooooo`?oo`000_ooool4oc<0oa_ooooo0_lc
0?l4ool000Wooooo1?lc0?l8ooooo`04o`000?o`]Y3ol;J@oo2fT0GolkbD0ol0000<oo>lU0;oo`00
2?oj_H800ol0003oo<1oooc0O`03ooc0O`CooL5i00?o0000ook1LOon`G400_on`G43oojoI0ConkUD
0_of/4800ooY[Bgo0000o`000002o`0002;ooooo0_l0000Gooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool0000Dooooo`006_ooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo05kooooo0_lc0?l00oooooooo`00ool0000=ooooo`;o<`3o
00Coooooool00?oo003oo`001oooool2oc<0o`Oooooo0olc0?l00ol0003oooooooooo`07ooooo`;o
<`3o1Oooool3oc<0o`;oo`000oooool3oc<0o`;oo`0000Coooooool00?oo003ooooo0_oo0002oooo
o`;oo`000_ooool01?lc0?ooo`00ool00?oo0004ooooo`Coo`002Oooool5ool00004oc<0oooooooo
oooooc<0o`?oo`002oooool8ool000;ooooo1?lc0?l3o`000003oooooooo003oo`0000;oo`0000?o
oooooc<0oolc0?l00_lc0?lIooooo`Co<`3o1?oo0008ooooo`Go<`3o3?oo00001?l0003ol;J@oo2f
T?o`]Y02oo>lU0?o00003ooc_9@00oog`iCon[f2ooZmPP06ooZmPP03o`000?ol`7ooo<1o00Coo<1o
1Oom`GT01?l0003oo/5aook1LOon`G43oojoI0GonkUD00Oom[12onV];Ol0003ojJd]o`000?oHU@[o
0000023ooooo0ol0000Hooooo`03o`000?oooooooooo00Sooooo0ol00009ooooo`;o00005Oooool0
01[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`1Kooooo`;o<`3o0ooo000=oooo
o`;o<`3o0ooo0008ooooo`;o<`3o1_ooool4oc<0o`[ooooo0_lc0?l4ooooo`?o<`3o0_oo0004oooo
o`;o<`3o0_ooool01Ooo003oooooool00?oo003ooooo00;oo`0000Koooooool00?oo003oo`00oooo
oolc0?l3ool000?ooooo1?oo0008ooooo`Goo`000_lc0?l3ooooo`04oc<0oooo003oo`00ool000Oo
oooo1ooo0005ooooo`Go<`3o00Coooooo`000?l0003o00001?oo00000ooooooo<`3ooc<0o`02oc<0
oaOooooo1_lc0?l4ool000?ooooo3_oo000<ooooo`03o`000?o`]Y3ol;J@00?o00004Ooc_9@3ooO3
U0Oon[f200?o0000ooc0Oool`7l01?ol`7l5oog1N@04o`000?on`G7oo/5aook1L@Coo[mT1?ok^E@0
0oof/4;ojJd]onV];@02o`000003omRE2_l0003ooooo01cooooo0ol00002ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo00?o0000ooooooooool07_ooool0
01[ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Hooooo`;o<`3o0_oo000>oooo
o`;o<`3o0_oo000:ooooo`03oc<0oooooooooooo00Cooooo1?lc0?l:ooooo`;o<`3o0oooool3oc<0
o`?oo`000oooool3oc<0o`;ooooo2_oo00000oooooooo`00ool00002ool000?ooooo0ooo0007oooo
o`Goo`000olc0?l3ooooo`03oc<0oooo003oo`0000;oo`000oooool7ool000Sooooo1?lc0?l3oooo
o`?o00000ooo00000ooooooo<`3ooc<0o`02oc<0oaKooooo1?lc0?l>ool000Go<`3o5_ooool2o`00
01ColkbD0oog`i@7ooZmPP03o`000?ol`7ooo<1o00Coo<1o1Oom`GT01?on`G7o0000ook1LOon`G44
oojoI0ConkUD00Oom[12onV];OoY[BgojJd]o`000?oHU@[o000001[ooooo0ol00005ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`006_oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo05Gooooo0_lc0?l2ool000gooooo0olc
0?l2ool000[ooooo0_lc0?l4ooooo`Go<`3o2Oooool3oc<0o`?ooooo0_lc0?l3ool000?ooooo0olc
0?l3ooooo`Koo`0000Coooooool00?oo003ooooo1?oo0002ooooo`Coo`001Oooool5ool00003oooo
oolc0?oo<`3o00;o<`3o0oooool00olc0?ooo`00ool00008ool000[ooooo1Olc0?l3ooooo`?o0000
1?oo0004oc<0oa3ooooo4Ooo0007ooooo`Co<`3o6oooool00ol0003olkbDoo>lU00Coo>lU0Coml>D
1_oj_H800ol0003oo<1oooc0O`04ooc0O`GooL5i00?oo/5ao`000?on`G400_on`G43oojoI0GonkUD
0ooY[Bd3o`0001Oooooo0ol00008ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Nooooo`006_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo057ooooo0olc0?l00ooo003oooooooooo`0<ooooo`;o<`3o0_oo000;ooooo`;o<`3o0ooo
ool01?l0003o<`3ooc<0ooooool2oc<0o`Wooooo0_lc0?l3ooooo`?o<`3o0_oo0004ooooo`;o<`3o
1?ooool<ool000;ooooo1?oo0004ooooo`Goo`000_ooool4oc<0o`?ooooo2?oo000=ooooo`Co<`3o
1Oooool3o`0000?oo`001?lc0?l5ooooo`ooo`001?lc0?l6ooooo`?oo`001_ooool5oc<0ob3ooooo
00?o0000oo>lU?oc_9@04Ooc_9@5ooO3U0Kon[f200?o0000ooc0Oool`7l01?ol`7l5oog1N@03ook1
LOl0003oo/5a00;oo/5a0oon_f@5oo^iE0?ojJd]0ol0000Dooooo`?o00002oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool001[ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooooooo`1>ooooo`;o<`3o0_oo000>ooooo`;o<`3o0_oo
000;ooooo`;o<`3o0_ooool01Ol0003o<`3ooc<0oolc0?oooooo00;o<`3o2Oooool2oc<0o`;ooooo
0olc0?l2ool000Cooooo0olc0?l5ooooo`[oo`0000?oooooool00?oo00000_oo0003ooooo`Goo`00
1?ooool3oc<0o`Woo`003_ooool5oc<0o`Kooooo0_l0000@ool000Sooooo1_lc0?l7ooooo`Coo`00
1Oooool4oc<0ob3ooooo1Ooo00000ol0003olkbDoo>lU00Aoo>lU0Koml>D1Ooj_H800ol0003oo<1o
ooc0O`04ooc0O`GooL5i0_on`G400ol0003oo/5aook1L@04oojoI0ConkUD0ooY[Bd3o`00017ooooo
0ol0000>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Nooooo`006_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04_ooooo0_lc
0?l00ooo003oooooooooo`0=ooooo`;o<`3o00?oo`00ooooooooool02oooool01?lc0?ooooooo`00
0?oo0002oc<0o`;ooooo0_lc0?l8ooooo`?o<`3o00Cooooooc<0oolc0?oo<`3o0_oo0004ooooo`?o
<`3o1_ooool=ool000;ooooo1Ooo0005ooooo`Ooo`000_lc0?l3ool000kooooo1?lc0?l00ooooooo
o`00ool0000<ool00003oc<0oooooooooooo00kooooo1Olc0?l9ooooo`Coo`001?ooool5oc<0oago
oooo0olc0?l4ool00003oc<0oooooooooooo00?ooooo00?o0000oo>lU?oc_9@04?oc_9@7ooO3U0Co
n[f200?o0000ooc0Oool`7l01?ol`7l5oog1N@;oo/5a00?o0000ook1LOon`G401?on_f@4oo^iE003
ooNoCooY[BgojJd]00Co00003Oooool3o`00017ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01kooooo000Iooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0B?ooool2oc<0o`03ool00?oooooooooo00cooooo0olc0?l>ooooo`;o<`3o
00Coo`00oc<0oolc0?oo<`3o0_ooool2oc<0o`Sooooo0_lc0?l2ooooo`;o<`3o0_oo0005ooooo`;o
<`3o1oooool;ool00003oooooooo003oo`0000?oo`000_ooool8ool000Cooooo0_lc0?l3ool000So
oooo3_oo0004ooooo`04o`000?oo003oo`00ool000?o<`3o3_ooool6oc<0o`[ooooo1?oo0003oooo
o`Go<`3o6oooool6oc<0o`Coo`002_ooool00ol0003olkbDoo>lU00?oo>lU0Soml>D1?oj_H800ol0
003oo<1oooc0O`04ooc0O`GooL5i0oon`G400ol0003oo/5aoojoI003oojoI0ConkUD00Somkm?onV]
;OoY[Bgo0000onV];Ol0003oooooo`0000Wooooo0ol0000Dooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Nooooo`006Oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo04Gooooo0_lc0?l?ooooo`;o<`3o00?oo`00ooooooooool03?oo
ool2oc<0o`03ool00?lc0?oo<`3o00?ooooo0_lc0?l8ooooo`;o<`3o00Gooooooc<0oolc0?oo<`3o
ool00005ooooo`?o<`3o1oooool3ool00003oc<0oooo003oo`0000ooo`001?lc0?l4ooooo`;o<`3o
3ooo0005oc<0o`[ooooo1?oo0002oc<0o`gooooo1Olc0?l<ooooo`Coo`000oooool4oc<0oaWooooo
1olc0?l2ooooo`Coo`002oooool4oc<0o`03o`000?oc_9ColkbD00kolkbD2Oog`i@2ooZmPP03o`00
0?ol`7ooo<1o00Goo<1o1Oom`GT3ook1L@03o`000?on`G7oo/5a00?oo[mT0ook^E@2ooNoC`?ojJd]
1?l00006ooooo`?o00005oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo
0_l0000Oooooo`006Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo047ooooo00?o
o`00oc<0oolc0?l03oooool2oc<0o`gooooo0_l00005oc<0o`?ooooo0_lc0?l7ooooo`Ko<`3o00?o
o`00ooooooooool00oooool3oc<0o`Wooooo00?oo`00oc<0oooo00003?oo0003ooooo`ooo`002_oo
ool4oc<0o`_ooooo00Co0000ool00?oo003oo`000_lc0?l;ooooo`Ko<`3o3Oooool4ool000;ooooo
1Olc0?lFooooo`Oo<`3o1?ooool5ool000[ooooo1Olc0?l4ooooo`03o`000?oc_9ColkbD00golkbD
2_og`i@2ooZmPP03o`000?ol`7ooo<1o00Goo<1o1_om`GT3ook1L@03o`000?on`G7oo[mT00?oo[mT
0_ok^E@2ooNoC`?ojJd]0ol000001?oooooo0000ooooooooool3o`0001[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000001oooooo000Iooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool0?_ooool00ooo003o<`3ooc<0o`0>ooooo`03ool0
0?lc0?oo<`3o00cooooo0ol000001?oo003o<`3ooc<0oolc0?l4ooooo`;o<`3o1oooool5oc<0o`03
ool00?oooooooooo00?ooooo0olc0?l:oooooaCoo`0000?o<`3oooooooooool00_ooool3oc<0o`?o
o`002Oooool5oc<0o`cooooo1?oo00000olc0?ooooooooooo`08ooooo`Go<`3o3oooool4ool000;o
oooo1?lc0?lCooooo`So<`3o1oooool4ool000Wooooo1_lc0?l:ooooo`03o`000?oc_9ColkbD00co
lkbD2oog`i@00ooj_H;o0000ooc0O`06ooc0O`KooL5i0oon`G400ol0003oo/5aoojoI003oojoI0;o
nkUD0oog_dl2onV];@04o`000?oY[Bgo0000ooooo`?o00007Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool001Wooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`0jooooo`;oo`000_lc0?l=ooooo`04ool00?lc0?oo<`3ooc<0
o`_ooooo0ol00002ool000?o<`3o1?ooool2oc<0o`Oooooo1?lc0?l00ooo003oooooooooo`04oooo
o`;o<`3o2_ooool9ool000Oooooo1?lc0?l5ooooo`;o<`3o1?oo0008ooooo`Co<`3o3Oooool4ool0
0003oc<0oooooooooooo00Kooooo1_lc0?l@ooooo`Coo`0000?ooooooc<0oolc0?l00olc0?l@oooo
o`Oo<`3o2oooool4ool000Sooooo1Olc0?l@ooooo`03o`000?oc_9ColkbD00colkbD3?og`i@00ol0
003oo<1oooc0O`05ooc0O`KooL5i1?on`G400ol0003oo[mToojoI002oojoI0;onkUD0oog_dl2onV]
;@04o`000?oY[Bgo0000o`0000;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool001Wooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0gooooo`;oo`000_lc0?l=ooooo`03ool00?lc0?oo<`3o
00_ooooo0ol00003ool000;o<`3o1Oooool2oc<0o`Kooooo1?lc0?l00ooo003oooooooooo`04oooo
o`?o<`3o2Oooool3ool000gooooo0olc0?l5ooooo`?o<`3o0ooo0007ooooo`Go<`3o3_ooool3ool0
0003o`000?oooooooooo00Cooooo1_lc0?lBooooo`Coo`0000?ooooooc<0oolc0?l00_lc0?l>oooo
o`Oo<`3o3_ooool4ool000Oooooo1Olc0?lFooooo`03o`000?oc_9ColkbD00[olkbD3Oog`i@00ol0
003oo<1oooc0O`05ooc0O`KooL5i1?on`G400ol0003oo[mToojoI002oojoI0;onkUD0oog_dl2onV]
;@03o`000?oY[Bgo000000?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool001Wooooo00?o0000oooooooo
ool0JOooool00ol0003oooooooooo`0cooooo`?oo`000_lc0?l<ooooo`;oo`000_lc0?l:ooooo`?o
000000?oooooool00?oo00000olc0?l5ooooo`;o<`3o1_ooool4oc<0o`Kooooo0olc0?l9ooooo`?o
o`003?ooool4oc<0o`Gooooo0_lc0?l4ool000Kooooo1?lc0?l?ooooo`Coo`0000?o0000oooooooo
ool00_ooool5oc<0oaCooooo1?oo0005oc<0o`_ooooo1olc0?l@ooooo`Goo`001_ooool5oc<0oa_o
oooo00?o0000oo>lU?oc_9@02_oc_9@=ooO3U003o`000?ojb97oo<1o00Goo<1o1_om`GT5ook1L@03
o`000?on_fCoo[mT00;oo[mT1?og_dl2onV];@03o`000?oY[Bgo000000Cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool07Oooool001Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0`ooooo`;oo`00
00?ooooooc<0oolc0?l02oooool2ool000?o<`3o2Oooool3o`000004oooooooo003oo`00ool000?o
<`3o1Oooool2oc<0o`Kooooo0olc0?l7ooooo`;o<`3o2Oooool3ool000_ooooo1?lc0?l5ooooo`?o
<`3o0ooo0005ooooo`Go<`3o3oooool01?lc0?ooo`00ool00?oo0002o`000003oooooolc0?oo<`3o
00Co<`3o5Oooool4ool000Co<`3o2?ooool8oc<0oa?ooooo1?oo0006ooooo`Go<`3o8Oooool00ol0
003olkbDoo>lU008oo>lU0goml>D00Co0000oo[8TOojb97on/RA1Ool`7l6oog1N@Goo/5a00?o0000
oojoI?on_f@00_on_f@5ooNoC`04onV];Ol0003ojJd]o`0000Gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Ooo
ool001Wooooo00?o0000ooooooooool0Joooool2o`0002gooooo0ooo00000ooooooo<`3ooc<0o`0;
ooooo`;oo`000_lc0?l9ooooo`?o000000Coooooool00?oo003oo`001Olc0?l4ooooo`;o<`3o1Ooo
ool3oc<0o`Oooooo0olc0?l8ooooo`?oo`002oooool3oc<0o`Gooooo1?lc0?l3ool000Cooooo1?lc
0?l@ooooo`03oc<0oooo003oo`0000;oo`000_l00004oc<0oaSooooo0ooo0004oc<0o`Gooooo1olc
0?lGooooo`Coo`001Oooool5oc<0obKooooo00?o0000oo>lU?oc_9@02?oc_9@=ooO3U003o`000?oj
b97on/RA00;on/RA1?ol`7l6oog1N@Coo/5a0ol00003oojoI0Gomkm?00CojJd]o`000?oY[Bgo0000
1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Mooooo`006?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo02Sooooo0_oo0002ooooo`;o<`3o2_ooool3ool000;o<`3o2?ooool3o`000005oooooooo
003oo`00ool00?ooool00_lc0?l00ooooooo<`3ooc<0o`04ooooo`;o<`3o1?ooool01?oo003o<`3o
oc<0oolc0?l6ooooo`?o<`3o1oooool01?lc0?ooo`00ool00?oo000:ooooo`Co<`3o1Oooool3oc<0
o`Coo`000_ooool5oc<0oa3ooooo00?o<`3oool00?oo00000_oo0002o`0000?o<`3o6Oooool4ool0
00;o<`3o0oooool7oc<0oa[ooooo1?oo0003ooooo`Ko<`3o:oooool00ol0003olkbDoo>lU008oo>l
U0goml>D00?o0000oo[8TOojb9400oojb943ooc0O`KooL5i00Coo/5ao`000?l0003o00000_on`G40
1?l0003oo[mToojoI?on_f@5ooNoC`04onV];Ol0003ojJd]o`0000Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
7Oooool001Sooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Tooooo`?oo`0000Co
oooooc<0oolc0?oo<`3o2_ooool2ool00003oooooolc0?oo<`3o00Oooooo0ol00002ooooo`;oo`00
00Gooooooc<0oolc0?oo<`3oooooo`02oc<0o`Cooooo0_lc0?l4ooooo`?o<`3o1oooool2oc<0o`Oo
oooo00Co<`3oool00?oo003oo`002Oooool4oc<0o`Gooooo1?lc0?l3ool000;ooooo1?lc0?lAoooo
o`;o<`3o0ooo0003o`0001_ooooo1?oo0009oc<0oacooooo1Ooo0002ooooo`Go<`3o<_ooool00ol0
003olkbDoo>lU006oo>lU0koml>D00?o0000oo[8TOojb9401?ojb942ooc0O`CooL5i0ol00005ook1
L@04oojoI?l0003oo[mTook9JPGomkm?00CojJd]o`000?oY[Bgo00001oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool2o`0001kooooo000H
ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool08Oooool2ool000;ooooo0_lc0?l:
ooooo`?oo`000olc0?l6ooooo`?o00000_ooool3ool00003oooooolc0?oo<`3o00?ooooo00?o<`3o
ooooooooool00_ooool2oc<0o`?ooooo1?lc0?l6ooooo`?o<`3o1_ooool4ool000Sooooo1?lc0?l6
ooooo`?o<`3o00Coooooool00?oo003oo`001Olc0?lAooooo`;o<`3o1?oo0003o`0001[ooooo1?oo
0006oc<0oaoooooo1?oo0002ooooo`Go<`3o=oooool00ol0003olkbDoo>lU006oo>lU0koml>D00?o
0000oo[8TOojb9401Oojb9400ool`7oooL5io`000002o`0000?ooL5i1_on`G401?on_fCo0000ook9
J_onbFX5ooNoC`03o`000?oY[Bgo000000Sooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000007_ooool001Sooooo00?o
0000ooooooooool0<oooool6o`0003Sooooo00?o0000ooooooooool07Oooool3ool000;ooooo0_lc
0?l9ooooo`?oo`0000?ooooooc<0oolc0?l01_ooool3o`0000;ooooo0ooo00001?oooooo<`3ooc<0
oolc0?l3ooooo`;o<`3o0oooool2oc<0o`;ooooo1Olc0?l5ooooo`?o<`3o1_ooool3ool000Wooooo
0olc0?l6ooooo`Co<`3o1?oo0003oc<0oa;ooooo0olc0?l3ool00004ooooool0003o0000o`0001So
oooo00?o<`3oool00?oo00000_oo0002oc<0ob?ooooo1?oo00000ooooooo<`3ooc<0o`03oc<0ocgo
oooo00?o0000oo>lU?oc_9@01Ooc_9@=ooO3U003o`000?ojb97on/RA00Con/RA1?l00006oog1N@Ko
o/5a00Coo[mTo`000?onbF[oo/UZ1Oog_dl00ooY[Bgo0000o`000009ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01cooooo000Hooooo`03o`000?oooooooooo02oooooo1?l00006oo2_QP?o0000=_ooool00ol0003o
ooooooooo`0Jooooo`;oo`000oooool2oc<0o`Wooooo0_oo0002ooooo`;o<`3o1Oooool3o`0000;o
oooo0ooo0002ooooo`;o<`3o1?ooool2oc<0o`?ooooo0_lc0?l00ooooooo<`3ooc<0o`03oc<0o`Ko
oooo0_lc0?l6ooooo`?oo`002?ooool4oc<0o`Kooooo0olc0?l01?ooooooo`00ool00?oo0003oc<0
oa3ooooo1Olc0?l4ool00004ooooool0003o0000o`0001Cooooo1?lc0?l4ool002Gooooo1?oo0005
oc<0od;ooooo00?o0000oo>lU?oc_9@01?oc_9@>ooO3U004o`000?ojb97on/RAoo[8T@?o00000ooj
b942oog<R`GooL5i1_on`G401?on_fCoo/UZo`000?onbFX5ooNoC`03onV];Ol0003o000000Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07?ooool001Sooooo00?o0000ooooooooool0;_ooool00ol0003ol:n6oo2_
QP0;oo2_QP?o0000=?ooool00ol0003oooooooooo`0Fooooo`?oo`000oooool2oc<0o`Sooooo0ooo
0002ooooo`;o<`3o0oooool4o`0000?ooooo0_oo0002ooooo`?o<`3o1?ooool2oc<0o`?ooooo0_lc
0?l01?oo003o<`3ooc<0ooooool2oc<0o`Gooooo0olc0?l5ooooo`?oo`001oooool4oc<0o`Kooooo
1?lc0?l01Oooooooo`00ool00?oo003o<`3o013ooooo1_lc0?l4ool000;ooooo0ol0000@ooooo`Oo
<`3o1?oo000Uooooo`Coo`001?lc0?m8ooooo`03o`000?oc_9ColkbD00?olkbD3_og`i@4o`0000Ko
n/RA1Oomc8/2oog1N@Goo/5a00Goolenook9J_onbF[o0000ook9JP05ooNoC`03onV];Ol0003o0000
00[ooooo00?o0000ooooooooool04oooool3o`0001Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Looooo`006?ooool00ol0003oooooooooo`0]ooooo`03o`000?o`[hKol:n600oo
l:n600?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`;oo`001?ooool2oc<0o`So
oooo0_oo0002ooooo`?o<`3o0_ooool3o`0000Cooooo0ooo0002ooooo`;o<`3o1_ooool01?lc0?oo
ooooooooooooool8oc<0o`Cooooo0olc0?l5ooooo`?oo`001oooool3oc<0o`Oooooo1?lc0?l4ool0
00kooooo2?lc0?l01?ooooooo`00ool00?oo0002ooooo`Co00003?ooool7oc<0o`;ooooo00?o<`3o
ool00?oo00000_oo000Tooooo`Goo`000olc0?m=ooooo`03o`000?oc_9ColkbD00;olkbD3Oog`i@3
o`0000Won/RA1oomc8/2ook1L@Coolen0oonbFX00ol0003omkm?ooNoC`04ooNoC`03o`000?oY[Bgo
000000[ooooo00?o0000ooooooooool03oooool3o`0000;ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Hooooo`03o`000?oooooooooo
02cooooo00?o0000oo2_Q_o`[hH04Oo`[hH00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00oooooo0ooo0004ooooo`;o<`3o1oooool3ool000;ooooo0_lc0?l2ooooo`?o00001?ooool3ool0
00;ooooo0olc0?l6ooooo`;o<`3o0_ooool4oc<0o`03oooooolc0?oo<`3o00Cooooo0olc0?l5oooo
o`?oo`001_ooool4oc<0o`Kooooo1Olc0?l3ool000cooooo2_lc0?l00oooooooo`00ool00002ool0
00;ooooo0ol00008ooooo`So<`3o1?ooool2oc<0o`Coo`009?ooool4ool000;o<`3oE?ooool01?l0
003olkbDoo>lU?oc_9@9ooO3U0Co00000_og`i@00ol0003on/RAoo[8T@07oo[8T@OooLb;1_oocGh4
ook9JP03o`000?og_doomkm?00?omkm?00?o0000onV];Ol000002oooool00ol0003oooooooooo`0:
ooooo`Co00001Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07?ooool001Sooooo00?o0000ooooooooool0:oooool00ol0003ol:n6oo2_QP0Coo2_
QP;o0000<oooool00ol0003oooooooooo`0<ooooo`;oo`001Oooool2oc<0o`Kooooo0ooo0003oooo
o`;o<`3o00Coooooo`000?l0003o00001?ooool3ool000?ooooo0_lc0?l7ooooo`;o<`3o00?ooooo
ool00?lc0?l00_lc0?l2ooooo`;o<`3o1?ooool2oc<0o`Cooooo00Co<`3oool00?oo003oo`001Ooo
ool4oc<0o`Oooooo1?lc0?l4ool000[ooooo1Olc0?l2ooooo`Co<`3o00?oooooool00?oo00000_oo
0003ooooo`?o00001?ooool7oc<0o`Sooooo0_lc0?l4ool002Cooooo1?oo00000olc0?oooooooooo
o`1Gooooo`04o`000?oc_9ColkbDoo>lU0Koml>D0ol00005ooO3U003o`000?ojb97on/RA00Son/RA
1oomc8/6ooo=OPCoo/UZ00?o0000ooNoCoog_dl00oog_dl00ol0003ojJd]o`00000;ooooo`03o`00
0?oooooooooo00Oooooo0ol00009ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Looooo`005oooool00ol0003oooooooooo`0[ooooo`03o`000?o`
[hKol:n601Kol:n600?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`?oo`001Ooo
ool2oc<0o`Kooooo0_oo0004ooooo`;o<`3o0ol00004ooooo`?oo`000oooool3oc<0o`Oooooo0_lc
0?l01?oo003o<`3ooc<0oolc0?l2ooooo`?o<`3o0oooool3oc<0o`?ooooo00Co<`3oool00?oo003o
o`001Oooool3oc<0o`Oooooo1Olc0?l3ool000Sooooo1_lc0?l3ooooo`Co<`3o0_ooool3ool000Co
oooo0ol00007oc<0o`[ooooo0olc0?l4ool002?ooooo00?o<`3oool00?oo00000_oo001Oooooo`03
o`000?oc_9Coml>D00?oml>D0ol00008ooO3U003o`000?ojb97on/RA00Son/RA1oomc8/6ooo=OPGo
o/UZ00?o0000ooNoCoog_dl00_og_dl00ol0003ojJd]o`00000<ooooo`03o`000?oooooooooo00?o
oooo0ol0000<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Looooo`005oooool00ol0003oooooooooo`0[ooooo`03o`000?o`[hKol:n601Ool:n6
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`05ooooo`;oo`001_ooool2oc<0o`Gooooo
0ooo0003ooooo`?o<`3o0_l00005ooooo`;oo`001?ooool2oc<0o`Wooooo00?o<`3oool00?lc0?l0
0_lc0?l2ooooo`;o<`3o0oooool3oc<0o`?ooooo00Co<`3oool00?oo003oo`001?ooool4oc<0o`Ko
oooo1Olc0?l01?ooooooo`00ool00?oo0006ooooo`Go<`3o1Oooool4oc<0o`;ooooo1?oo0003oooo
o`04oc<0ool0003o0000o`0000?o<`3o3Oooool3oc<0o`Coo`008_ooool00olc0?ooo`00ool00003
ool006?ooooo00?o0000oo>lU?og`i@00ol0000;ooO3U003o`000?ojb97on/RA00Son/RA1oomc8/6
ooo=OPGoo/UZ00?omkm?o`000?og_dl00_og_dl00ol0003ojJd]o`00000=ooooo`Go00003_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0ol0000Mooooo`005oooool00ol0
003oooooooooo`0Zooooo`03o`000?o`[hKol:n601Wol:n600?o0000ooooooooool0<Oooool00ol0
003oooooooooo`02ooooo`;oo`001_ooool2oc<0o`Gooooo0_oo0004ooooo`;o<`3o0_l00005oooo
o`?oo`000oooool3oc<0o`Sooooo00?oo`00oc<0oolc0?l00olc0?l2ooooo`;o<`3o0oooool2oc<0
o`?ooooo1?oo0003ooooo`Co<`3o1_ooool5oc<0o`03oooooooo003oo`0000;oo`000oooool6oc<0
o`Kooooo1?lc0?l3ooooo`?oo`001Olc0?l3o`0000kooooo1Olc0?l3ool0027ooooo0_lc0?l4ool0
06Wooooo0_l0000>ooO3U003o`000?ojb97on/RA00Oon/RA2?omc8/7ooo=OPCoo/UZ00?omkm?o`00
0?og_dl00_og_dl00ol0003ojJd]o`00000;ooooo`Co00004Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool001Oooooo00?o0000oooooooo
ool0:_ooool00ol0003ol:n6oo2_QP0Ioo2_QP03o`000?oooooooooo03;ooooo00Co0000ool00?oo
003oo`001_ooool2oc<0o`Cooooo0ooo0004ooooo`;o<`3o00?o0000ooooooooool00oooool3ool0
00Cooooo0_lc0?l8ooooo`;oo`001Olc0?l2ooooo`;o<`3o0_ooool3oc<0o`;ooooo0ooo0004oooo
o`?o<`3o1Oooool6oc<0o`;ooooo0ooo0002ooooo`Go<`3o2?ooool4oc<0o`;ooooo00?o<`3oool0
0?oo00000_oo0002oc<0o`;ooooo1?l0000=ooooo`Co<`3o00?oooooool00?oo00000_oo000Ooooo
o`?o<`3o1?oo001]ooooo`03o`000?og`iComl>D00goml>D00?o0000oo[8TOojb9401oojb948oog<
R`Ooolen1?onbFX2ooNoC`06o`000?og_doomkm?o`000?oY[Bgo00001oooool4o`0000?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06oooool001Oooooo00?o0000ooooooooool0:Oooool00ol0003ol:n6oo2_QP0K
oo2_QP03o`000?oooooooooo033ooooo0_oo00000ol0003oooooooooo`04ooooo`;o<`3o0oooool3
ool000Cooooo0olc0?l5ooooo`?oo`001?ooool3oc<0o`Oooooo0_oo0003oc<0o`04oooooolc0?oo
<`3oooooo`?o<`3o00Cooooooc<0oolc0?oo<`3o0_ooool3ool000?ooooo1?lc0?l4ooooo`Oo<`3o
0_ooool3ool000Go<`3o2Oooool7oc<0o`Coo`001Oooool3o`0000cooooo1Olc0?l00oooooooo`00
ool00002ool001gooooo1Olc0?l4ool007;ooooo00?o0000ooO3U?og`i@02oog`i@00ol0003on/RA
oo[8T@08oo[8T@SooLb;1ooocGh5ook9JP;omkm?00Go0000ooNoCol0003ojJd]o`000004ooooo`?o
00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Kooooo`005oooool00ol0003oooooooooo`0Xooooo`03o`00
0?o`[hKol:n601gol:n600?o0000ooooooooool0;?ooool3ool000?ooooo00?o0000ooooooooool0
0olc0?l3ooooo`;oo`001?ooool00ol0003o<`3ooc<0o`06ooooo`;oo`001Oooool2oc<0o`Oooooo
0ooo0003oc<0o`04oooooolc0?oo<`3oooooo`;o<`3o0_ooool2oc<0o`;ooooo0ooo0002ooooo`Co
<`3o1?ooool7oc<0o`;ooooo1?oo0002oc<0o`_ooooo1olc0?l01?ooooooo`00ool00?oo0006oooo
o`?o00002oooool4oc<0o`;ooooo1?oo000Looooo`Go<`3o1Ooo001gooooo`03o`000?og`iComl>D
00[oml>D00?o0000oo[8TOojb9402?ojb948oog<R`Ooolen1OonbFX2ooNoC`03o`000?og_doomkm?
00;o000000Coooooo`000?l0003o00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`005oooool00ol0
003oooooooooo`0Xooooo`03o`000?o`[hKol:n601kol:n600?o0000ooooooooool0:Oooool2ool0
00Oooooo0_lc0?l3ooooo`?oo`000oooool2o`0000;o<`3o1Oooool3ool000Cooooo0olc0?l6oooo
o`?oo`001olc0?l01?oooooo<`3ooc<0ooooool3oc<0o`05oooooooo003oo`00ool00?ooool01?lc
0?l3ooooo`So<`3o00?ooooooc<0oolc0?l00ooo00000olc0?ooooooooooo`06ooooo`So<`3o1?oo
ool4ool000Kooooo0ol00009ooooo`Go<`3o0_ooool4ool001_ooooo1Olc0?l00oooooooo`00ool0
0002ool007cooooo00?o0000ooO3U?og`i@02_og`i@00ol0003on/RAoo[8T@08oo[8T@SooLb;1ooo
cGh5ook9JP?omkm?00?o0000ooNoCol000000_l0000@ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000G
ooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH08?o`[hH00ol0003oooooooooo`0U
ooooo`?oo`001oooool2oc<0o`03ooooool0003oo`0000;oo`000oooool3o`0000;o<`3o1?ooool3
ool000Gooooo0_lc0?l6ooooo`?oo`000olc0?l00ooooooo<`3ooc<0o`09oc<0o`?oo`0000Cooooo
oc<0oolc0?oo<`3o0oooool4oc<0o`03oooooolc0?oo<`3o00Go<`3o0ooo0005ooooo`_o<`3o1Ooo
ool3ool000Oooooo0ol00008ooooo`Co<`3o0oooool4ool001[ooooo1Olc0?l2ooooo`Coo`00POoo
ool00ol0003oml>DooO3U009ooO3U003o`000?ojb97on/RA00Son/RA2?omc8/7ooo=OPGoo/UZ0oog
_dl01?l0003omkm?o`000?l0000Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000Gooooo`03o`000?oo
oooooooo02Oooooo00?o0000oo2_Q_o`[hH08Oo`[hH00ol0003oooooooooo`0Rooooo`;oo`002?oo
ool2oc<0o`;ooooo0_oo00000ol0003oooooooooo`03o`0000?o<`3o0oooool3ool000Gooooo0olc
0?l6ooooo`;oo`000olc0?l2ooooo`Ko<`3o00Cooooooc<0oolc0?oo<`3o0ooo0004oc<0o`03oooo
oolc0?oo<`3o00?o<`3o0_ooool6oc<0o`Coo`0000?ooooooc<0oolc0?l01Olc0?l3ooooo`Co<`3o
1Oooool4ool000Oooooo0ol00006ooooo`Go<`3o0oooool4ool001Wooooo1Olc0?l3ooooo`Coo`00
Q_ooool00ol0003oml>DooO3U008ooO3U003o`000?ojb97on/RA00Son/RA2?omc8/7ooo=OPGoo/UZ
1?og_dl3o`0001;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool001Kooooo00?o0000ooooooooool0:?oo
ool00ol0003ol:n6oo2_QP0Roo2_QP03o`000?oooooooooo01kooooo0ooo0008ooooo`;o<`3o00Co
ooooool00?oo003oo`000oooool2o`000003oooooolc0?oo<`3o00Cooooo0_oo0006ooooo`;o<`3o
1_ooool2ool000?o<`3o1?ooool8oc<0o`?oo`000olc0?l00ooooooo<`3ooc<0o`02oc<0o`03oooo
oolc0?oo<`3o00Co<`3o0oooool3ool000Go<`3o1_ooool4oc<0o`Gooooo1?oo0007ooooo`Co0000
1Oooool4oc<0o`Cooooo1?oo000Hooooo`Go<`3o0oooool5ool008[ooooo00?o0000ooO3U?og`i@0
1oog`i@00ol0003on/RAoo[8T@09oo[8T@SooLb;1ooocGh6ook9JP;omkm?1?l0000Cooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo000Fooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH09?o`
[hH00ol0003oooooooooo`0Kooooo`;oo`002Oooool2oc<0o`03oooooooo003oo`0000Kooooo00?o
0000oc<0oolc0?l00oooool3ool000Gooooo0olc0?l5ooooo`?oo`000_lc0?l5ooooo`Ko<`3o1?oo
000>oc<0o`04oooooolc0?oo<`3ooc<0o`?oo`0000?o<`3oooooooooool01oooool4oc<0o`Kooooo
0ooo0008ooooo`?o00001?ooool5oc<0o`Cooooo1?oo000Fooooo`Ko<`3o1?ooool4ool0093ooooo
00?o0000ooO3U?og`i@01_og`i@00ol0003on/RAoo[8T@09oo[8T@SooLb;1ooocGh5ook9JP?o0000
0_og_dl2o`0001Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Sooooo0ol0000Looooo`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?o`
[hKol:n602Col:n600?o0000ooooooooool06?ooool3ool000Wooooo0_lc0?l3ool000Oooooo0_lc
0?l2ooooo`?oo`001_ooool2oc<0o`Gooooo0ooo0003oc<0o`Gooooo1Olc0?l3ool001;o<`3o1?oo
0009ooooo`Co<`3o1_ooool4ool000Sooooo0ol00003ooooo`Co<`3o1Oooool4ool001Gooooo1Olc
0?l6ooooo`Coo`00UOooool00ol0003oml>DooO3U005ooO3U003o`000?ojb97on/RA00Won/RA2?om
c8/7ooo=OP03ook9J_l0003o000000;o000000?oo/UZooNoCoog_dl00_og_dl00ol0003oooooo`00
000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01[ooooo000Fooooo`03o`000?oooooooooo02Oooooo00?o0000
oo2_Q_o`[hH09Oo`[hH00ol0003oooooooooo`0Eooooo`;oo`002_ooool2oc<0o`;oo`001oooool3
oc<0o`04oooooooo003oo`00ool000Kooooo0olc0?l4ooooo`?oo`000olc0?l6ooooo`Co<`3o0ooo
000>oc<0o`Cooooo0ooo0009ooooo`Co<`3o1oooool3ool000Wooooo0ol000000ooooooo<`3ooc<0
o`03oc<0o`Gooooo1?oo000Dooooo`Go<`3o1oooool4ool009Wooooo00?o0000ooO3U?og`i@01Oog
`i@00ol0003on/RAoo[8T@09oo[8T@SooLb;1OoocGh3o`0000Goo/UZ1?og_dl01?l0003ooooooooo
ool0000Cooooo`03o`000?oooooooooo00Gooooo0ol0000Mooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06_ooool001Kooooo00?o0000ooooooooool09oooool00ol0003ol:n6oo2_
QP0Voo2_QP03o`000?oooooooooo017ooooo0ooo000:ooooo`;o<`3o00?oo`00ooooooooool01_oo
ool2oc<0o`05oooooooo003oo`00ool00?l000001_ooool2oc<0o`Cooooo0ooo0003oc<0o`Sooooo
0olc0?l2ool000ko<`3o0oooool4ool000Sooooo1?lc0?l7ooooo`Coo`002Oooool3o`0000Co<`3o
1_ooool4ool001?ooooo1Olc0?l7ooooo`Goo`00W_ooool00ol0003oml>DooO3U004ooO3U003o`00
0?ojb97on/RA00Won/RA2?omc8/00ooocGko0000o`000002o`0000;oolen1_onbFX4ooNoC`05o`00
0?ooooooooooooooool000004oooool01?l0003oooooooooooooool3o`0000;ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo0ol00002oooo
o`?o00002oooool001Kooooo00?o0000ooooooooool09oooool00ol0003ol:n6oo2_QP0Voo2_QP03
o`000?oooooooooo00oooooo0_oo000;ooooo`;o<`3o00?oo`00ooooooooool01_ooool2oc<0o`03
oooooooo003oo`0000?ooooo00Co0000oooooooooooooooo0olc0?l3ooooo`?oo`0000?ooooooc<0
oolc0?l02Oooool2oc<0o`;oo`001_lc0?l4ooooo`?o<`3o1?ooool3ool000Sooooo1?lc0?l7oooo
o`Coo`002_ooool3o`0000?o<`3o1oooool3ool001;ooooo1Olc0?l8ooooo`Coo`00Y?ooool00ol0
003oml>DooO3U002ooO3U003o`000?ojb97on/RA00[on/RA1Oomc8/4o`0000Koolen1_onbFX4ooNo
C`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool4o`0000Cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`0Voooo
o`03o`000?o`[hKol:n602Sol:n600?o0000ooooooooool02oooool3ool000_ooooo0_lc0?l9oooo
o`;o<`3o0ooo0005ooooo`04o`000?oooooo<`3ooc<0o`?ooooo0ooo00001?oooooo<`3ooc<0oolc
0?l9ooooo`03ool00?lc0?ooo`0000;o<`3o1oooool4oc<0o`Cooooo0ooo0007ooooo`Co<`3o2?oo
ool3ool000_ooooo0ol000000olc0?ooooooooooo`06ooooo`Coo`004?ooool5oc<0o`Wooooo1?oo
002Xooooo`03o`000?og`iComl>D00;oml>D00?o0000oo[8TOojb9402Oojb943oog<R`?o00000oom
c8/8ooo=OPKoo/UZ0_og_dl00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo0ol0
00000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool001Kooooo00?o0000ooooooooool09_ooool00ol0003ol:n6oo2_QP0Xoo2_QP03o`000?oooooo
oooo00Wooooo0_oo000;ooooo`03ool00?lc0?oo<`3o00Sooooo0olc0?l2ool000Oooooo0olc0?l2
ooooo`?oo`0000Cooooooc<0oolc0?oo<`3o2Oooool3ool000Wooooo0olc0?l4ooooo`Coo`001_oo
ool4oc<0o`Sooooo1?oo0009ooooo`03oc<0ool0003o000000;o00002?ooool4ool000kooooo1_lc
0?l:ooooo`Coo`00[Oooool01Ol0003oml>DooO3U?og`iCo000000[on/RA1?l00006oog<R`Soolen
1_onbFX2ooNoC`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool4o`0000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
000Fooooo`03o`000?oooooooooo02Kooooo00?o0000oo2_Q_o`[hH0:Oo`[hH00ol0003ooooooooo
o`05ooooo`?oo`002_ooool2ool000;o<`3o2?ooool2oc<0o`;oo`002?ooool2oc<0o`03ooooool0
003oo`0000;oo`0000Cooooooc<0oolc0?oo<`3o2Oooool3ool000Sooooo1?lc0?l4ooooo`?oo`00
1_ooool4oc<0o`Wooooo0ooo0009ooooo`;o<`3o0ol00008ooooo`Coo`003Oooool5oc<0o`_ooooo
1Ooo002booooo`04o`000?og`iComl>Do`0000Oon/RA0ol000000oojb97ooLb;oog<R`07oog<R`So
olen1_onbFX2ooNoC`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000[o
oooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03o`0000_ooooo000Eooooo`03o`000?oooooooooo02Oo
oooo00?o0000oo2_Q_o`[hH0:_o`[hH00ol0003oooooooooo`02ooooo`;oo`002oooool01?oo003o
<`3ooc<0oolc0?l8ooooo`;o<`3o00?oo`00ooooooooool01_ooool3oc<0o`05oooooooo003oo`00
ool00?ooool00olc0?l8ooooo`Coo`002?ooool3oc<0o`Gooooo0ooo0005ooooo`Co<`3o2Oooool4
ool000Oooooo1?lc0?l3o`0000Oooooo1?oo000<ooooo`Go<`3o3?ooool4ool00;Oooooo00Co0000
ooO3U?og`iCo00000oojb944o`0000Con/RA2Oomc8/8ooo=OPKoo/UZ0_og_dl00ol0003ooooooooo
o`07ooooo`Go00003_ooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00_ooooo
000Eooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH0:_o`[hH00ol0003oooooool0
0002ool000[ooooo0_oo0002oc<0o`Sooooo0olc0?l00ooo003oooooooooo`06ooooo`;o<`3o00Ko
ooooool00?oo003oo`00ooooool00002oc<0o`Sooooo0ooo0008ooooo`Co<`3o1?ooool4ool000Co
oooo1?lc0?l9ooooo`Coo`001oooool4oc<0o`04ooooool0003o0000o`0000Kooooo1?oo000;oooo
o`Go<`3o3Oooool4ool00;cooooo0_l000001?ojb97o0000o`000?l00008oo[8T@WooLb;2?oocGh6
ook9JP;omkm?00?o0000ooooooooool01Oooool4o`00017ooooo00?o0000ooooool000008Oooool0
0ol0003oooooooooo`08ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`?o00002_ooool0
01Gooooo00?o0000ooooooooool09oooool00ol0003ol:n6oo2_QP0Zoo2_QP;oo`002_ooool3ool0
00;o<`3o2?ooool2oc<0o`03ool00?oooooooooo00Oooooo0_lc0?l3ool000;ooooo0olc0?l7oooo
o`?oo`001oooool4oc<0o`Gooooo0ooo0004ooooo`Co<`3o2_ooool3ool000Kooooo1Olc0?l2oooo
o`?o00001Oooool4ool000[ooooo1Olc0?l>ooooo`Coo`00`Oooool2o`0000_on/RA2Oomc8/8ooo=
OPOoo/UZ00?o0000ooooooooool00_ooool4o`0000;ooooo1?l0000@ooooo`;o00008Oooool00ol0
003oooooooooo`06ooooo`;o00000_ooool00ol0003oooooooooo`0Iooooo`005Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?o`[hKol:n602Ool:n60ooo00000oo`[hKo0000ooooo`07ooooo`;o
o`0000?ooooooc<0oolc0?l01oooool00ooo003o<`3ooc<0o`09ooooo`?o<`3o0_oo0002ooooo`?o
<`3o0_ooool00ol0003oooooooooo`02ooooo`?oo`001oooool3oc<0o`Kooooo0ooo0003ooooo`Co
<`3o2_ooool4ool000Gooooo1?lc0?l4ooooo`?o00001?ooool4ool000Wooooo1Olc0?l>ooooo`Go
o`00a_ooool00ol0003on/RAoo[8T@09oo[8T@WooLb;2?oocGh7ook9JP03o`000?oooooo000000;o
00000oooool3o`0000Cooooo0_l0000?ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Iooooo`005Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?o`[hKol:n602Gol:n60_oo0005oo2_QP03o`000?oooooooooo00;ooooo0ooo00000ooooooo<`3o
oc<0o`07ooooo`03ool00?lc0?oo<`3o00Wooooo0_lc0?l2ool000;ooooo0olc0?l5ooooo`03o`00
0?ooooooo`0000;oo`001_ooool4oc<0o`Gooooo1?oo0002ooooo`Co<`3o2oooool3ool000Cooooo
1Olc0?l4ooooo`Co00000oooool4ool000Sooooo1Olc0?l?ooooo`Coo`00c?ooool00ol0003on/RA
oo[8T@08oo[8T@WooLb;2?oocGh7ook9JP;o00000oooool3o`0000Wooooo0_l0000:ooooo`?o0000
00?oooooo`000?ooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo
000Eooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH08_o`[hH3ool000Ool:n600?o
0000ooooooooool00_oo0002ooooo`;o<`3o1_ooool01?oo003o<`3ooc<0oolc0?l8ooooo`?o<`3o
00?oo`00ooooooooool00olc0?l7ooooo`?oo`001_ooool3oc<0o`Kooooo0ooo0002ooooo`Co<`3o
2oooool4ool000?ooooo1?lc0?l6ooooo`?o00000oooool4ool000Kooooo1_lc0?l@ooooo`Coo`00
dOooool00ol0003on/RAoo[8T@07oo[8T@WooLb;2?oocGh7ook9JP03o`000?oooooo000000;o0000
3_ooool2o`0000Gooooo1?l00003ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Iooooo`005Oooool00ol0003oooooooooo`0Wooooo`03o`000?o`
[hKol:n6023ol:n60_oo000:oo2_QP?oo`000_ooool2oc<0o`Gooooo0_oo0002oc<0o`Wooooo0_lc
0?l2ool000;ooooo0_lc0?l7ooooo`?oo`0000?oooooo`000?ooool00_ooool4oc<0o`Kooooo0ooo
00000ooooooo<`3ooc<0o`02oc<0o`_ooooo1?oo0002ooooo`Go<`3o1oooool3o`0000;ooooo1?oo
0005ooooo`Go<`3o4_ooool4ool00=Kooooo00?o0000oo[8TOojb9401_ojb949oog<R`Soolen1_on
bFX3o`0001?ooooo1_l00007ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Iooooo`005Oooool00ol0003oooooooooo`0Wooooo`03o`000?o`[hKo
l:n601gol:n60ooo0009oo2_QP?oo`0000?ol:n6o`000?ooool00_lc0?l4ooooo`?oo`000_lc0?l8
ooooo`?o<`3o00?oo`00ooooooooool00olc0?l6ooooo`?oo`001?ooool01?l0003o<`3ooc<0oolc
0?l6ooooo`Coo`001?lc0?l<ooooo`?oo`0000?ooooooc<0oolc0?l00olc0?l9ooooo`?o000000?o
ooooool00?oo00000_oo0004ooooo`Go<`3o4_ooool5ool00=_ooooo00?o0000oo[8TOojb9401Ooj
b949oog<R`Soolen0oonbFX4o`0001?ooooo1Ol0000;ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`005Oooool00ol0003oooooooooo`0W
ooooo`03o`000?o`[hKol:n601_ol:n600?o0000ool00?o`[hH02Oo`[hH2ool000Col:n60_lc0?l4
ooooo`;oo`0000?ooooooc<0oolc0?l02?ooool2oc<0o`03ool00?oooooooooo00?o<`3o1Oooool4
ool000Cooooo1?lc0?l6ooooo`?oo`001?lc0?l<ooooo`Coo`001?lc0?l;ooooo`?o000000Cooooo
ool00?oo003oo`000oooool5oc<0oa?ooooo1?oo003Qooooo`03o`000?ojb97on/RA00Con/RA2Oom
c8/7ooo=OPCo00000_onbFX00ol0003oooooooooo`0?ooooo`Go00003oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool001Cooooo00?o0000
ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Koo2_QP;o00001oo`[hH3ool000Col:n60_lc0?l0
0oo`[hKo0000ooooo`03ool000?o<`3o1oooool3oc<0o`;ooooo0olc0?l5ooooo`?oo`001Oooool3
oc<0o`?ooooo00?o0000ooooooooool01?oo0003oc<0o`gooooo0ooo0004oc<0o`cooooo0ol00004
ool00003oooooolc0?oo<`3o00?o<`3o5?ooool4ool00>Kooooo00?o0000oo[8TOojb9400oojb949
oog<R`Coolen0ol000000ooocGkoo/UZook9JP03ook9JP03o`000?oooooooooo00_ooooo1_l0000B
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`005?ooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n602;ol:n60_oo0005oo2_
QP;o<`3o0_o`[hH3ool00003oooooolc0?oo<`3o00Oooooo00?oo`00oc<0oolc0?l00oooool2oc<0
o`Gooooo0ooo0004ooooo`Co<`3o1_ooool3ool000?o<`3o3Oooool4ool000;o<`3o3Oooool3o`00
00Coo`001Olc0?lEooooo`Coo`00joooool01?l0003on/RAoo[8TOojb94:oog<R`04ooo=O_l0003o
0000o`0000Goolen0oonbFX00ol0003oooooooooo`09ooooo`Go00005oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo0ol0000Jooooo`005?ooool00ol0003oooooooooo`0X
ooooo`03o`000?o`[hKol:n601ool:n60ooo0005oo2_QP;o<`3o00Col:n6ool00?oo003oo`000_o`
[hH2oc<0o`Kooooo00Coo`00oc<0oolc0?oo<`3o0_ooool3oc<0o`Cooooo0ooo0004ooooo`?o<`3o
1oooool3ool000;o<`3o3Oooool4ool000;o<`3o3_ooool2o`0000Coo`001?lc0?lEooooo`Goo`00
l?ooool00ol0003on/RAoo[8T@08oog<R`?o00002?oocGh2ook9JP03o`000?oooooooooo00Oooooo
1Ol0000Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Hooooo`005?ooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n601_ol:n600Co
0000ool00?oo003oo`001_o`[hH2oc<0o`?oo`000oo`[hH2oc<0o`03o`000?oooooooooo00;ooooo
0_oo0002oc<0o`;ooooo0olc0?l4ooooo`?oo`000oooool4oc<0o`Kooooo1?oo00001?lc0?oooooo
ooooool0000;ooooo`?oo`0000?o<`3oooooooooool03_ooool00ol0003oo`00ool00002ool000;o
<`3o5oooool4ool00?Kooooo00?o0000oo[8TOomc8/01?omc8/3o`0000;ooLb;2OoocGh2ook9JP03
o`000?oooooooooo00?ooooo1Ol0000Pooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`005?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?o`[hKol:n601_ol:n600?oo`00o`000?o`[hH01?o`[hH3oc<0o`;oo`000oo`[hH3oc<0o`?ol:n6
00?o0000ool00?oo00000olc0?l01?oooooo<`3ooc<0oolc0?l4ooooo`?oo`000oooool3oc<0o`Oo
oooo0ooo00000olc0?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o<`3oool00?oo
00000_oo000Aooooo`Coo`0000?o<`3oooooooooool05_ooool4ool00?_ooooo00?o0000oog<Room
c8/00ol00005oog<R`Woolen00?oo/UZo`000?ooool00_ooool5o`0002?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo000Dooooo`03o`00
0?oooooooooo02Sooooo00?o0000oo2_Q_o`[hH08?o`[hH2oc<0o`?oo`000oo`[hH2oc<0o`Col:n6
0ooo0002oc<0o`04oooooolc0?oo<`3ooc<0o`Cooooo0ooo0002ooooo`Co<`3o1_ooool01?lc0?oo
o`00ool00?oo000:ooooo`03o`000?oooooooooo00;o<`3o0ooo000@ooooo`03oc<0oooo003oo`00
00;oo`006Oooool4ool00?oooooo0Oooool2o`0000SooLb;2OoocGh00oonbF[o0000o`000004o`00
02Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Sooooo000Dooooo`03o`000?oooooooooo02Wooooo00?o0000oo2_Q_o`[hH07Oo`[hH2oc<0o`;o
o`001?o`[hH2oc<0o`?ol:n60ooo0003oc<0o`03oooooolc0?oo<`3o00Cooooo0ooo0002ooooo`?o
<`3o1_ooool00olc0?ooo`00ool00002ool000_ooooo0olc0?l4ool000kooooo0_lc0?l4ool00003
o`000?oooooooooo01Gooooo1Ooo003oooooo`Oooooo0ol00005oog<R`Soolen1?l0000/ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`00
5?ooool00ol0003oooooooooo`0Yooooo`03o`000?o`[hKol:n601_ol:n60_lc0?l00ooo003ol:n6
oo2_QP02oo2_QP?o<`3o0_o`[hH3ool00004oo2_Q_lc0?oo<`3ooo2_QP?o<`3o0oooool3ool00003
oooooolc0?oo<`3o00;o<`3o1Oooool2oc<0o`?oo`002oooool3oc<0o`Coo`003Oooool3oc<0o`Co
o`000_l0000Fooooo`Coo`00ooooool?ooooo`;o00000oomc8/5ooo=OPCo0000<?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool001Cooooo
00?o0000ooooooooool0:Oooool00ol0003ol:n6oo2_QP0Ioo2_QP;o<`3o1Oo`[hH2oc<0o`;ol:n6
0ooo00000oo`[hKo<`3ooc<0o`04oc<0o`;ol:n61?oo0004oc<0o`Gooooo0olc0?l3ool000Wooooo
1Olc0?l3ool000?ooooo00?o0000ooooooooool01Oooool5oc<0o`Coo`000ol0000Eooooo`Coo`00
oooooolEooooo`?o00000_oocGh3o`0003Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Oooooo000Cooooo`03o`000?oooooooooo02[ooooo00?o
0000oo2_Q_o`[hH05oo`[hH2oc<0o`;o00000oo`[hH2oc<0o`04oo2_Q_oo003oo`00ool000;ol:n6
1Olc0?l2oo2_QP?oo`0000Co0000oc<0oolc0?oo<`3o1Oooool3oc<0o`Coo`002?ooool4oc<0o`03
oooooooo003oo`0000;oo`001_ooool00ol0003oooooooooo`05oc<0o`03oooooooo003oo`0000;o
o`000ol0000Eooooo`Coo`00oooooolLooooo`;o0000>?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool001?ooooo00?o0000ooooooooool0
:_ooool00ol0003ol:n6oo2_QP0Coo2_QP;o00000_lc0?l5oo2_QP;o<`3o0ooo0002oo2_QPGo<`3o
0_o`[hH3ool000Co<`3o00Co0000oooooooooooooooo1?lc0?l3ool000Oooooo1Olc0?l2ooooo`?o
o`002?ooool5oc<0o`?ooooo0ooo00001?oooooo0000o`000?l0000Cooooo`Goo`00oooooomKoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool3o`0001Wooooo000Cooooo`03
o`000?oooooooooo02[ooooo00?o0000oo2_Q_o`[hH04oo`[hH00ol0003o<`3ooo2_QP03oo2_QP?o
<`3o0_oo0003oo2_QPGo<`3o00Col:n6ool00?oo003oo`000olc0?l4oo2_QPCo<`3o00Coooooool0
0?oo003oo`001_ooool4oc<0o`?ooooo1?oo0006ooooo`Go<`3o00Coooooo`000?oooooooooo1?oo
00001?oooooo0000o`000?l0000Booooo`Coo`00oooooomQooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`004oooool00ol0003ooooooooo
o`0Zooooo`03o`000?o`[hKol:n601Ool:n60_lc0?l00ol0003oo`00oo2_QP02oo2_QPGo<`3o00Co
l:n6ool00?oo003oo`000olc0?l3oo2_QPCo<`3o00?o0000ool00?oo00000_oo0004ooooo`Go<`3o
0oooool4ool000Gooooo1Olc0?l5ooooo`Coo`000_ooool3o`00017ooooo1?oo003oooooofGooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo
000Cooooo`03o`000?oooooooooo02_ooooo00?o0000oo2_Q_o`[hH05Oo`[hH00olc0?oo0000oo2_
QP02o`000003oo2_Q_lc0?oo<`3o00;o<`3o00Col:n6ool00?oo003oo`000_lc0?l3oo2_QPCo<`3o
0_o`[hH3ool00004o`000?ooooooooooooooo`Co<`3o1Oooool3ool000Cooooo1Olc0?l6ooooo`Co
o`0000?oooooo`000?ooool00ol0000@ooooo`Coo`00oooooomZooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`004oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?o`[hKol:n601Gol:n60ol00004oc<0o`04oo2_Q_oo003oo`00ool000;o
<`3o0_o`[hH4oc<0o`;ol:n61?oo0002oo2_QPGo<`3o1Oooool4ool000;ooooo1Olc0?l7ooooo`Co
o`000oooool4o`0000oooooo1?oo003oooooofoooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo000Cooooo`03o`000?oooooooooo02_ooooo
00?o0000oo2_Q_o`[hH05_o`[hH01?l0003o<`3ooc<0ool00003ool00003oc<0ooo`[hKol:n600Co
<`3o0oo`[hH3ool000;ol:n61?lc0?l00oo`[hKo0000ooooo`04ooooo`?oo`001_lc0?l8ooooo`Co
o`001?ooool3o`0000;ooooo00?o0000ooooooooool02Oooool5ool00?ooooooM?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool001?ooooo
00?o0000ooooooooool0:oooool00ol0003ol:n6oo2_QP0Goo2_QP05o`000?oo003oo`00oc<0ooo`
[hH01?lc0?l4oo2_QP?oo`001Olc0?l6oo2_QP03o`000?oo003oo`0000;oo`000olc0?l:ooooo`Co
o`001Oooool3o`0000Gooooo00?o0000ooooooooool01Oooool4ool00?ooooooNOooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool001?ooooo
00?o0000ooooooooool0:oooool00ol0003ol:n6oo2_QP0Hoo2_QP;o00000_lc0?l4oo2_QPCoo`00
0olc0?l8oo2_QPCoo`000_lc0?l;ooooo`Coo`001_ooool3o`0000Sooooo00Co0000oooooooooooo
oooo1?oo003oooooogkooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01Kooooo000Booooo`03o`000?oooooooooo02gooooo00?o0000oo2_Q_o`[hH0
6?o`[hH4o`0000?oo`000olc0?l8oo2_QP05oc<0oooo003oo`00ool00?lc0?l00_o`[hH00ol0003o
ooooooooo`07ooooo`Coo`001oooool3o`0000_ooooo1?oo003ooooooh?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo000Booooo`03o`00
0?oooooooooo02gooooo00?o0000oo2_Q_o`[hH05oo`[hH2o`0000?oo`0000?o<`3ooo2_Q_o`[hH0
1_o`[hH2oc<0o`Coo`001_o`[hH00ol0003oooooooooo`03ooooo`Coo`002?ooool3o`0000Wooooo
1Ooo00000ol0003oooooooooo`3oooooohGooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`09ooooo`;o00006?ooool001;ooooo00?o0000ooooooooool0;Oooool00ol0003ol:n6oo2_
QP0Goo2_QP;oo`001?o`[hH2o`000003oo2_Q_lc0?oo<`3o00;o<`3o0ooo000:oo2_QP03o`000?oo
ooooo`0000?oo`002?ooool4o`0000Sooooo1?oo0005ooooo`03o`000?oooooooooo0?ooooooQOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000006?oo
ool001;ooooo00?o0000ooooooooool0;_ooool00ol0003ol:n6oo2_QP0Loo2_QP?o<`3o1?oo000;
oo2_QPCoo`002Oooool3o`0000Sooooo1?oo0009ooooo`03o`000?oooooooooo0?ooooooQ_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool0
01;ooooo00?o0000ooooooooool0;_ooool00ol0003ol:n6oo2_QP0Koo2_QPCoo`003?o`[hH3ool0
00?ol:n600?o0000ooooooooool01?ooool3o`0000Oooooo1?oo000=ooooo`03o`000?oooooooooo
0?ooooooQoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05_ooool001;ooooo00?o0000ooooooooool0;_ooool00ol0003ol:n6oo2_QP0Eoo2_QP;o
000000Col:n6ool00?oo003oo`003?o`[hH4ool000Kol:n600Co0000oooooooooooooooo0ol00005
ooooo`Goo`004Oooool00ol0003oooooooooo`3oooooohSooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo000Booooo`03o`000?oooooooooo
02oooooo00?o0000oo2_Q_o`[hH05?o`[hH00ol0003oo`00ool0000;oo2_QPCoo`002_o`[hH4o`00
00Cooooo1?oo000Fooooo`03o`000?oooooooooo0?ooooooR?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool001;ooooo00?o0000oooooooo
ool0;oooool00ol0003ol:n6oo2_QP0Noo2_QPCoo`003?o`[hH3o`0000?ooooo1?oo000Jooooo`03
o`000?oooooooooo0?ooooooROooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool05Oooool001;ooooo00?o0000ooooooooool0;oooool00ol0003ol:n6
oo2_QP0Joo2_QPCoo`003?o`[hH4o`0000;ol:n61?oo000Nooooo`03o`000?oooooooooo0?oooooo
R_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5Oooool0017ooooo00?o0000ooooooooool0<Oooool00ol0003ol:n6oo2_QP0Coo2_QP;o00001?oo
000=oo2_QP?o000000?ol:n6ool00?oo00000ooo00000oo`[hKo0000ooooo`0Oooooo`03o`000?oo
oooooooo0?ooooooRoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05Oooool0017ooooo00?o0000ooooooooool0<Oooool00ol0003ol:n6oo2_QP0C
oo2_QP;oo`003_o`[hH3o`0000Coo`001_o`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo0?ooooooS?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0000G
ooooo`004Oooool00ol0003oooooooooo`0aooooo`03o`000?o`[hKol:n6023ol:n60_l00004ool0
00[ol:n600?o0000ooooooooool07Oooool00ol0003oooooooooo`3oooooohgooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000001Oooooo000Aooooo`03
o`000?oooooooooo03;ooooo00?o0000oo2_Q_o`[hH07?o`[hH00ol0003oo`00ool00002ool000ko
l:n600?o0000ooooooooool07Oooool00ol0003oooooooooo`3oooooohkooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Gooooo000Aooooo`03o`00
0?oooooooooo03;ooooo00?o0000oo2_Q_o`[hH06?o`[hH5ool001;ol:n600?o0000ooooooooool0
7Oooool00ol0003oooooooooo`3oooooohoooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Gooooo000Aooooo`03o`000?oooooooooo03?ooooo00?o
0000oo2_Q_o`[hH04?o`[hH2o`000003oo2_Q_oo003oo`0000;oo`0000?o0000oo2_Q_o`[hH05?o`
[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0?ooooooSoooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool3o`0000?ooooo0_l0
0006ooooo`004Oooool00ol0003oooooooooo`0cooooo`03o`000?o`[hKol:n6013ol:n600?o0000
ool00?oo00000_l0000Ioo2_QP03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooon@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool0017ooooo00?o0000oooo
ooooool0=?ooool00ol0003ol:n6oo2_QP0=oo2_QP?o00007Oo`[hH00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo0?ooooooTOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00?ooooo000Aooooo`03o`000?oooooooooo03Cooooo00?o0000oo2_Q_o`[hH02_o`[hH3o`00023o
l:n600?o0000ooooooooool07Oooool00ol0003oooooooooo`3ooooooi;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`03ooooo`004?ooool00ol0003oooooooooo`0fooooo`03o`00
0?o`[hKol:n600Kol:n60ol0000Soo2_QP03o`000?oooooooooo01gooooo00?o0000ooooooooool0
oooooonBooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00005ooooo`004?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?o`[hKol:n600?ol:n60ol0000Voo2_QP03o`000?oooooooooo01gooooo
00?o0000ooooooooool0oooooonCooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001Oooool0013ooooo00?o0000ooooooooool0=oooool00ol0003ol:n6o`000002o`0002Wol:n6
00?o0000ooooooooool07Oooool00ol0003oooooooooo`3ooooooiCooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`Co00002Oooool3o`0000;ooooo0_l00006ooooo`004?oo
ool00ol0003oooooooooo`0eooooo`Co0000;?o`[hH00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo0?ooooooUOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05?ooool0013ooooo00?o0000ooooooooool0<_ooool3o`0000?ooooo00?o0000
oo2_Q_o`[hH0:_o`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0?ooooooUOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool0
013ooooo00?o0000ooooooooool0;oooool3o`0000Kooooo00?o0000oo2_Q_o`[hH0:_o`[hH00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo0?ooooooU_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool04oooool0013ooooo00?o0000ooooooooool0;?ooool3o`00
00[ooooo00?o0000oo2_Q_o`[hH0:Oo`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0?ooooooUoooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo01?ooooo000@oooo
o`03o`000?oooooooooo02Wooooo0ol0000=ooooo`03o`000?o`[hKol:n602Sol:n600?o0000oooo
ooooool07_ooool00ol0003oooooooooo`3ooooooiSooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0Cooooo`004?ooool00ol0003oooooooooo`0Vooooo`?o00004Oooool00ol0003o
l:n6oo2_QP0Woo2_QP03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooonHooooo`04
o`000?ooooooooooo`0000cooooo00?o0000ooooooooool04oooool000oooooo00?o0000oooooooo
ool08oooool4o`0001Cooooo00?o0000oo2_Q_o`[hH09oo`[hH00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo0?ooooooVOooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo01?o
oooo000?ooooo`03o`000?oooooooooo023ooooo0ol0000Iooooo`03o`000?o`[hKol:n602Kol:n6
00?o0000ooooooooool07Oooool00ol0003oooooooooo`3ooooooi_ooooo0_l0000<ooooo`03o`00
0?oooooooooo01?ooooo000?ooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`03o`000?o`
[hKol:n602Gol:n600?o0000ooooooooool07Oooool00ol0003oooooooooo`3ooooooi[ooooo0ol0
000;ooooo`?o00005?ooool000oooooo00?o0000ooooooooool06_ooool3o`00023ooooo00?o0000
oo2_Q_o`[hH09?o`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?ooooooUoooool3
o`0000oooooo00?o0000ooooooooool04oooool000oooooo00?o0000ooooooooool05oooool3o`00
02Cooooo00?o0000oo2_Q_o`[hH08oo`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
0?ooooooToooool4o`0001?ooooo00?o0000ooooooooool04_ooool000oooooo00?o0000oooooooo
ool05?ooool3o`0002Oooooo00?o0000oo2_Q_o`[hH08oo`[hH00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo0?ooooooSoooool4o`0001Oooooo00?o0000ooooooooool04_ooool000oooooo
00?o0000ooooooooool04Oooool3o`0002_ooooo00?o0000oo2_Q_o`[hH08_o`[hH00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo0?ooooooS?ooool3o`0001_ooooo00?o0000ooooooooool0
4_ooool000oooooo00?o0000ooooooooool03Oooool4o`0002oooooo00?o0000oo2_Q_o`[hH08?o`
[hH00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?ooooooR?ooool4o`0001kooooo00?o
0000ooooooooool04_ooool000oooooo00?o0000ooooooooool02_ooool3o`0003Cooooo00?o0000
oo2_Q_o`[hH07oo`[hH00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?ooooooQ?ooool4
o`0003Oooooo000>ooooo`03o`000?oooooooooo00Sooooo0ol0000hooooo`03o`000?o`[hKol:n6
01kol:n600?o0000ooooooooool07oooool00ol0003oooooooooo`3ooooooh7ooooo0ol0000koooo
o`003_ooool00ol0003oooooooooo`05ooooo`?o0000??ooool00ol0003ol:n6oo2_QP0Loo2_QP03
o`000?oooooooooo023ooooo00?o0000ooooooooool0oooooommooooo`Co0000?_ooool000kooooo
00?o0000ooooooooool00_ooool3o`00043ooooo00?o0000oo2_Q_o`[hH06oo`[hH00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo0?ooooooN_ooool3o`0004;ooooo000>ooooo`03o`000?oo
oooo000000;o0000A?ooool00ol0003ol:n6oo2_QP0Joo2_QP03o`000?oooooooooo023ooooo00?o
0000ooooooooool0oooooomfooooo`Co0000AOooool000kooooo0_l00018ooooo`03o`000?o`[hKo
l:n601Sol:n600?o0000ooooooooool08Oooool00ol0003oooooooooo`3oooooog;ooooo1?l00019
ooooo`004?ooool00ol0003oooooooooo`16ooooo`;o00005oo`[hH00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo0?ooooooKoooool3o`0004gooooo000Aooooo`03o`000?oooooooooo04Oo
oooo00?o0000oo2_Q_o`[hH04oo`[hH00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0?oo
ooooJoooool4o`00053ooooo000Booooo`03o`000?oooooooooo04Oooooo0_l0000Boo2_QP03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0oooooomWooooo`Co0000E?ooool001?ooooo0_l0
0019ooooo`03o`000?o`[hKol:n600kol:n600?o0000ooooooooool09Oooool00ol0003ooooooooo
o`3oooooofCooooo0ol0001Hooooo`005Oooool00ol0003oooooooooo`17ooooo`03o`000?o`[hKo
l:n600_ol:n60_l0000Xooooo`03o`000?oooooooooo0?ooooooH?ooool4o`0005_ooooo000Foooo
o`03o`000?oooooooooo04Oooooo1Ol00005oo2_QP?o0000:Oooool00ol0003oooooooooo`3ooooo
oekooooo0ol0001Oooooo`005oooool00ol0003oooooooooo`1;ooooo`Go0000;?ooool00ol0003o
ooooooooo`3ooooooe[ooooo1?l0001Rooooo`006?ooool2o`0007cooooo00?o0000ooooooooool0
oooooomFooooo`Co0000I_ooool001[ooooo00?o0000ooooooooool0NOooool00ol0003ooooooooo
o`3ooooooe?ooooo0ol0001Zooooo`006oooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo0?ooooooCoooool4o`0006gooooo000Looooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool0oooooom<ooooo`?o0000LOooool001gooooo0_l0001gooooo`03o`000?oooooooooo0?oo
ooooB?ooool4o`0007Cooooo000Oooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
oooooom4ooooo`Co0000N?ooool0023ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`3ooooood7ooooo0ol0001looooo`008Oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo0?oooooo?Oooool4o`0007oooooo000Rooooo`;o0000L_ooool00ol0003oooooooooo`3ooooo
ocWooooo1?l00023ooooo`009?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0?oo
oooo=_ooool3o`0008Oooooo000Uooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
oooooolbooooo`Co0000R_ooool002Kooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`3ooooooboooooo0ol0002>ooooo`009oooool2o`0006gooooo00?o0000ooooooooool0ooooool[
ooooo`Co0000TOooool002Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`3ooooo
obOooooo1?l0002Eooooo`00:_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo0?oo
oooo9?ooool3o`0009Wooooo000[ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
oooooolPooooo`Co0000W?ooool002cooooo0_l0001Xooooo`03o`000?oooooooooo0?oooooo7?oo
ool4o`000:3ooooo000^ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0oooooolJ
ooooo`?o0000Y?ooool002oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`3ooooo
oaKooooo1?l0002Wooooo`00<?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0?oo
oooo4oooool3o`000:_ooooo000aooooo`;o0000H_ooool00ol0003oooooooooo`3oooooo`oooooo
1?l0002^ooooo`00<oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo0?oooooo2ooo
ool4o`000;;ooooo000dooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0ooooool8
ooooo`?o0000]_ooool003Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`3ooooo
o`Cooooo1?l0002iooooo`00=_ooool2o`0005gooooo00?o0000ooooooooool0ooooool4o`000;go
oooo000hooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0o?ooool3o`000<7ooooo
000iooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool0n?ooool4o`000<Cooooo000j
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0mOooool3o`000<Sooooo000koooo
o`;o0000F?ooool00ol0003oooooooooo`3aooooo`Co0000boooool003gooooo00?o0000oooooooo
ool0EOooool00ol0003oooooooooo`3]ooooo`Co0000coooool003kooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`3Zooooo`?o0000doooool003oooooo00?o0000ooooooooool0Dooo
ool00ol0003oooooooooo`3Vooooo`Co0000e_ooool0043ooooo0_l0001Cooooo`03o`000?oooooo
oooo0>?ooooo0ol0003Jooooo`00@_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
0=oooooo1?l0003Mooooo`00@oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo0=_o
oooo1?l0003Qooooo`00A?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0=Wooooo
0ol0003Uooooo`00AOooool2o`0004gooooo00?o0000ooooooooool0eOooool4o`000>Sooooo0017
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0dOooool4o`000>cooooo0018oooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0c_ooool3o`000?3ooooo0019ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0b_ooool4o`000??ooooo001:ooooo`;o0000
B?ooool00ol0003oooooooooo`37ooooo`?o0000moooool004cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`33ooooo`Co0000n_ooool004gooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`2oooooo`Co0000o_ooool004kooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`2looooo`?o0000ooooool3ooooo`00Coooool2o`0004?ooooo00?o0000oooooooo
ool0^?ooool4o`000?oooooo1_ooool0057ooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`2dooooo`Co0000ooooool:ooooo`00D_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo0;7ooooo0ol0003oooooo`kooooo001Cooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0[Oooool4o`000?oooooo4Oooool005Cooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`2Zooooo`?o0000oooooolEooooo`00EOooool2o`0003gooooo00?o0000oooooooo
ool0Y_ooool4o`000?oooooo6?ooool005Oooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`2Rooooo`Co0000oooooolLooooo`00F?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo09oooooo0ol0003oooooob3ooooo001Iooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0Voooool4o`000?oooooo8oooool005[ooooo0_l0000gooooo`03o`000?oooooooooo
09Sooooo1?l0003oooooobOooooo001Looooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0UOooool3o`000?oooooo:oooool005gooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`2Aooooo`Co0000ooooool^ooooo`00G_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo08kooooo0ol0003ooooooc;ooooo001Oooooo`;o0000<_ooool00ol0003oooooooooo`2:
ooooo`Co0000ooooooleooooo`00HOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
08Kooooo1?l0003oooooocWooooo001Rooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0Poooool3o`000?oooooo?Oooool006?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1oooooo`Co0000oooooom0ooooo`00I?ooool2o`0002gooooo00?o0000ooooooooool0O?oo
ool3o`000?ooooooA?ooool006Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1h
ooooo`Co0000oooooom7ooooo`00Ioooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
07Cooooo1?l0003ooooood_ooooo001Xooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0LOooool3o`000?ooooooCoooool006Wooooo0_l0000Xooooo`03o`000?oooooooooo06gooooo
1?l0003ooooooe;ooooo001[ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0JOoo
ool4o`000?ooooooE_ooool006cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1V
ooooo`?o0000oooooomJooooo`00KOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06;ooooo1?l0003ooooooegooooo001^ooooo`;o00008oooool00ol0003oooooooooo`1Oooooo`?o
0000oooooomQooooo`00L?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05_ooooo
1?l0003oooooofCooooo001aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0F?oo
ool4o`000?ooooooJ?ooool007;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1E
ooooo`?o0000oooooom/ooooo`00Loooool2o`0001gooooo00?o0000ooooooooool0DOooool4o`00
0?ooooooKoooool007Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1=ooooo`Co
0000oooooomcooooo`00M_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04[ooooo
0ol0003oooooogOooooo001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_oo
ool4o`000?ooooooN_ooool007Sooooo0_l0000Hooooo`03o`000?oooooooooo04?ooooo0ol0003o
ooooogkooooo001jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?oooool4o`00
0?ooooooPOooool007_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0kooooo`Co
0000oooooon5ooooo`00O?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Sooooo
0ol0003oooooohWooooo001mooooo`;o00004oooool00ol0003oooooooooo`0dooooo`Co0000oooo
oon<ooooo`00Ooooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo033ooooo1?l0003o
oooooi3ooooo0020ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool3o`00
0?ooooooU?ooool0087ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`Co
0000oooooonGooooo`00P_ooool2o`0000kooooo00?o0000ooooooooool09_ooool3o`000?oooooo
Voooool008Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Rooooo`Co0000oooo
oonNooooo`00QOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo1?l0003o
oooooj;ooooo0026ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool3o`00
0?ooooooY_ooool008Oooooo0_l00008ooooo`03o`000?oooooooooo01Sooooo1?l0003oooooojWo
oooo0029ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool3o`000?oooooo
[Oooool008[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`Co0000oooo
oon`ooooo`00Roooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo1?l0003o
oooookCooooo002<ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`?o0000oooooonhoooo
o`00S_ooool01?l0003oooooooooool00008ooooo`Co0000oooooonkooooo`00Soooool00ol0003o
ooooo`000004ooooo`Co0000oooooonoooooo`00T?ooool2o`000004ooooool0003o0000o`000?oo
oooo`oooool0097ooooo0_l0003oooooolKooooo003oooooooooooooF_ooool00?oooooooooooomJ
ooooo`00oooooooooooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooo
oooooooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[o
oooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003ooooo
ooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooooooooooF_oo
ool00?oooooooooooomJooooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {485.188, 0}} -> {0.00478509, 0.0571636, \
0.00171662, 0.00171662}}]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      RowBox[{"sys", " ", "=", " ", 
        RowBox[{"{", "\[IndentingNewLine]", 
          
          RowBox[{\(Move[WedgeOfRays[30, \ NumberOfRays \[Rule] 9], 50]\), 
            ",", "\[IndentingNewLine]", \(Move[
              WedgeOfRays[30, \ NumberOfRays \[Rule] 9], \ 100, 
              TwistAngle \[Rule] 90]\), ",", "\[IndentingNewLine]", 
            RowBox[{"Move", "[", 
              RowBox[{
                RowBox[{"AsymmetricConicMirror", "[", 
                  RowBox[{
                    RowBox[{"{", 
                      RowBox[{"cx", ",", 
                        StyleBox[\(\(-1\)\/175\),
                          FontColor->RGBColor[1, 0, 0]]}], 
                      StyleBox["}",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    StyleBox[",",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[\({kx, \ \(-1.5\)}\),
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[",",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[\({cy, \ \(-1\)\/150}\),
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[",",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox[\({ky, \(-1.5\)}\),
                      FontColor->RGBColor[1, 0, 0]], ",", " ", "100", ",", 
                    " ", "10"}], "]"}], ",", " ", "200"}], "]"}], ",", 
            "\[IndentingNewLine]", \(Baffle[50]\)}], "\[IndentingNewLine]", 
          "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot\  = \ 
        TurboPlot[{\[IndentingNewLine]sys, \
\[IndentingNewLine]Boundary[{\(-1\), \ \(-55\), \ \(-55\)}, {220, \ 55, \ 
                55}]\[IndentingNewLine]}, SequentialTrace \[Rule] True, \ 
          PlotType \[Rule] Full3D, ShowRange \[Rule] All, \ 
          Axes \[Rule] True, \ ImageSize \[Rule] \ 600, \ 
          ColorView \[Rule] SourceID];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81031 
%%ImageSize: 600 486.189 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00481315 1.00481 -0.0707267 1.00481 [
[.05109 .26124 -6 -8.8147 ]
[.05109 .26124 0 .1853 ]
[.20008 .20604 -11.7303 -9 ]
[.20008 .20604 .2697 0 ]
[.35642 .14814 -16.8044 -9 ]
[.35642 .14814 1.19561 0 ]
[.52068 .08732 -16.0133 -9 ]
[.52068 .08732 1.98667 0 ]
[.69347 .02338 -15.2223 -9 ]
[.69347 .02338 2.77773 0 ]
[.81608 .01469 0 -6.14454 ]
[.81608 .01469 18 2.85546 ]
[.85454 .07423 0 -6.09719 ]
[.85454 .07423 18 2.90281 ]
[.89124 .13104 0 -6.05248 ]
[.89124 .13104 6 2.94752 ]
[.92629 .18531 0 -6.01021 ]
[.92629 .18531 12 2.98979 ]
[.95981 .2372 0 -5.97018 ]
[.95981 .2372 12 3.02982 ]
[.97251 .27422 0 -5.94412 ]
[.97251 .27422 18 3.05588 ]
[.98114 .34489 0 -5.8977 ]
[.98114 .34489 18 3.1023 ]
[.99009 .41825 0 -5.84963 ]
[.99009 .41825 6 3.15037 ]
[.99938 .49442 0 -5.79985 ]
[.99938 .49442 12 3.20015 ]
[1.00904 .5736 0 -5.74824 ]
[1.00904 .5736 12 3.25176 ]
[ 0 0 0 0 ]
[ 1 .81031 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04128 .2769 m
.792 0 L
s
.06016 .26994 m
.06469 .27428 L
s
[(0)] .05109 .26124 1 .95882 Mshowa
.20875 .21513 m
.21309 .21967 L
s
[(50)] .20008 .20604 .95505 1 Mshowa
.36465 .15762 m
.36877 .16237 L
s
[(100)] .35642 .14814 .86715 1 Mshowa
.5284 .09723 m
.53226 .10218 L
s
[(150)] .52068 .08732 .77926 1 Mshowa
.70061 .03371 m
.70418 .03887 L
s
[(200)] .69347 .02338 .69136 1 Mshowa
.125 Mabswid
.08932 .25918 m
.09202 .26181 L
s
.11875 .24832 m
.12143 .25098 L
s
.14847 .23736 m
.15112 .24004 L
s
.17847 .2263 m
.1811 .229 L
s
.23933 .20385 m
.24191 .2066 L
s
.27021 .19246 m
.27276 .19523 L
s
.30138 .18096 m
.30391 .18376 L
s
.33286 .16935 m
.33536 .17217 L
s
.39676 .14578 m
.3992 .14866 L
s
.42918 .13383 m
.43159 .13672 L
s
.46192 .12175 m
.4643 .12467 L
s
.495 .10955 m
.49734 .1125 L
s
.56215 .08478 m
.56443 .08778 L
s
.59623 .07221 m
.59848 .07523 L
s
.63067 .05951 m
.63289 .06255 L
s
.66546 .04667 m
.66764 .04975 L
s
.73613 .02061 m
.73823 .02373 L
s
.77201 .00737 m
.77408 .01052 L
s
.25 Mabswid
.792 0 m
.95795 .2567 L
s
.80429 .019 m
.79839 .02116 L
s
[(-50)] .81608 .01469 -1 .36545 Mshowa
.8427 .07843 m
.83679 .08053 L
s
[(-25)] .85454 .07423 -1 .35493 Mshowa
.87936 .13513 m
.87343 .13718 L
s
[(0)] .89124 .13104 -1 .345 Mshowa
.91438 .1893 m
.90843 .1913 L
s
[(25)] .92629 .18531 -1 .3356 Mshowa
.94787 .2411 m
.9419 .24305 L
s
[(50)] .95981 .2372 -1 .32671 Mshowa
.125 Mabswid
.81212 .03112 m
.80858 .0324 L
s
.81987 .04311 m
.81633 .04439 L
s
.82756 .055 m
.82401 .05627 L
s
.83517 .06677 m
.83162 .06804 L
s
.85017 .08998 m
.84662 .09124 L
s
.85757 .10143 m
.85402 .10268 L
s
.8649 .11277 m
.86135 .11401 L
s
.87217 .124 m
.86861 .12524 L
s
.8865 .14617 m
.88293 .14739 L
s
.89356 .1571 m
.89 .15831 L
s
.90057 .16793 m
.897 .16914 L
s
.90751 .17866 m
.90394 .17987 L
s
.9212 .19985 m
.91763 .20104 L
s
.92796 .2103 m
.92438 .21148 L
s
.93465 .22065 m
.93107 .22184 L
s
.94129 .23092 m
.93771 .2321 L
s
.79638 .00678 m
.79284 .00808 L
s
.95439 .25119 m
.95081 .25235 L
s
.25 Mabswid
.95795 .2567 m
1 .60209 L
s
.96055 .27806 m
.95457 .27997 L
s
[(-50)] .97251 .27422 -1 .32092 Mshowa
.96914 .34862 m
.96315 .35048 L
s
[(-25)] .98114 .34489 -1 .3106 Mshowa
.97806 .42185 m
.97204 .42366 L
s
[(0)] .99009 .41825 -1 .29992 Mshowa
.98732 .49791 m
.98128 .49965 L
s
[(25)] .99938 .49442 -1 .28886 Mshowa
.99694 .57695 m
.99089 .57863 L
s
[(50)] 1.00904 .5736 -1 .27739 Mshowa
.125 Mabswid
.96225 .29196 m
.95866 .29311 L
s
.96395 .30597 m
.96036 .30711 L
s
.96567 .32008 m
.96208 .32121 L
s
.9674 .3343 m
.9638 .33542 L
s
.9709 .36305 m
.9673 .36416 L
s
.97267 .37759 m
.96907 .37869 L
s
.97445 .39223 m
.97085 .39333 L
s
.97625 .40699 m
.97264 .40808 L
s
.97988 .43683 m
.97627 .43791 L
s
.98172 .45193 m
.97811 .453 L
s
.98357 .46714 m
.97996 .4682 L
s
.98544 .48247 m
.98182 .48352 L
s
.98921 .51347 m
.98559 .51451 L
s
.99112 .52916 m
.9875 .53019 L
s
.99305 .54497 m
.98942 .54599 L
s
.99499 .5609 m
.99136 .56191 L
s
.95887 .26425 m
.95529 .26541 L
s
.99891 .59314 m
.99528 .59414 L
s
0 0 m
1 0 L
1 .81031 L
0 .81031 L
closepath
clip
newpath
.5 Mabswid
.93681 .26473 m
.26877 .4811 L
s
.25094 .79334 m
.26877 .4811 L
s
.938 .685 .527 r
.18561 .52611 m .19799 .51949 L .20436 .54081 L F
.17962 .51267 m .19799 .51949 L .18561 .52611 L F
.17962 .51267 m .1891 .4995 L .19799 .51949 L F
.18989 .54045 m .20436 .54081 L .20781 .5621 L F
.18561 .52611 m .20436 .54081 L .18989 .54045 L F
0 g
.19799 .51949 m
.20436 .54081 L
s
.938 .685 .527 r
.17231 .501 m .1891 .4995 L .17962 .51267 L F
.17231 .501 m .17824 .48208 L .1891 .4995 L F
0 g
.1891 .4995 m
.19799 .51949 L
s
.938 .685 .527 r
.19219 .55476 m .20781 .5621 L .2081 .58202 L F
.18989 .54045 m .20781 .5621 L .19219 .55476 L F
0 g
.20436 .54081 m
.20781 .5621 L
s
.938 .685 .527 r
.16413 .49188 m .17824 .48208 L .17231 .501 L F
.16413 .49188 m .16608 .46838 L .17824 .48208 L F
0 g
.17824 .48208 m
.1891 .4995 L
s
.938 .685 .527 r
.19219 .55476 m .2081 .58202 L .19234 .56812 L F
.19234 .56812 m .2081 .58202 L .20517 .59929 L F
0 g
.20781 .5621 m
.2081 .58202 L
s
.938 .685 .527 r
.173 .53285 m .18561 .52611 L .18989 .54045 L F
.16998 .52607 m .18561 .52611 L .173 .53285 L F
.16998 .52607 m .17962 .51267 L .18561 .52611 L F
.17516 .54008 m .18989 .54045 L .19219 .55476 L F
.173 .53285 m .18989 .54045 L .17516 .54008 L F
.15563 .48592 m .16608 .46838 L .16413 .49188 L F
.15563 .48592 m .15339 .45934 L .16608 .46838 L F
0 g
.16608 .46838 m
.17824 .48208 L
s
.938 .685 .527 r
.16628 .52021 m .17962 .51267 L .16998 .52607 L F
.16628 .52021 m .17231 .501 L .17962 .51267 L F
.17631 .5473 m .19219 .55476 L .19234 .56812 L F
.17516 .54008 m .19219 .55476 L .17631 .5473 L F
.19033 .57964 m .20517 .59929 L .19918 .61274 L F
.19234 .56812 m .20517 .59929 L .19033 .57964 L F
0 g
.20517 .59929 m
.2081 .58202 L
s
.938 .685 .527 r
.16216 .51565 m .17231 .501 L .16628 .52021 L F
.16216 .51565 m .16413 .49188 L .17231 .501 L F
.17631 .5473 m .19234 .56812 L .17637 .55401 L F
.17637 .55401 m .19234 .56812 L .19033 .57964 L F
.15789 .51271 m .16413 .49188 L .16216 .51565 L F
.15789 .51271 m .15563 .48592 L .16413 .49188 L F
.14736 .48356 m .15339 .45934 L .15563 .48592 L F
.14736 .48356 m .14099 .45562 L .15339 .45934 L F
0 g
.15339 .45934 m
.16608 .46838 L
s
.938 .685 .527 r
.19033 .57964 m .19918 .61274 L .18625 .58855 L F
.17533 .55978 m .19033 .57964 L .18625 .58855 L F
.17637 .55401 m .19033 .57964 L .17533 .55978 L F
.18625 .58855 m .19918 .61274 L .19045 .6214 L F
0 g
.19918 .61274 m
.20517 .59929 L
s
.938 .685 .527 r
.16016 .53971 m .173 .53285 L .17516 .54008 L F
.16016 .53971 m .16998 .52607 L .173 .53285 L F
.16016 .53971 m .17516 .54008 L .17631 .5473 L F
.16016 .53971 m .16628 .52021 L .16998 .52607 L F
.16016 .53971 m .17631 .5473 L .17637 .55401 L F
0 g
.25094 .79334 m
.97493 .59359 L
s
.938 .685 .527 r
.15375 .51159 m .15563 .48592 L .15789 .51271 L F
.15375 .51159 m .14736 .48356 L .15563 .48592 L F
.16016 .53971 m .16216 .51565 L .16628 .52021 L F
0 0 0 r
2.5 Mabswid
.16257 .51066 Mdot
.938 .685 .527 r
.16016 .53971 m .17637 .55401 L .17533 .55978 L F
.18625 .58855 m .19045 .6214 L .18037 .59422 L F
.17325 .56421 m .18625 .58855 L .18037 .59422 L F
.17533 .55978 m .18625 .58855 L .17325 .56421 L F
.16016 .53971 m .15789 .51271 L .16216 .51565 L F
.16016 .53971 m .17533 .55978 L .17325 .56421 L F
0 0 0 r
.16187 .51913 Mdot
.938 .685 .527 r
.13989 .48502 m .14099 .45562 L .14736 .48356 L F
.13989 .48502 m .12973 .4576 L .14099 .45562 L F
0 g
.5 Mabswid
.14099 .45562 m
.15339 .45934 L
s
0 0 0 r
2.5 Mabswid
.17003 .54842 Mdot
.938 .685 .527 r
.16016 .53971 m .15375 .51159 L .15789 .51271 L F
0 0 0 r
.16125 .52658 Mdot
.938 .685 .527 r
.17325 .56421 m .18037 .59422 L .17027 .56699 L F
.16016 .53971 m .17325 .56421 L .17027 .56699 L F
.15003 .51239 m .14736 .48356 L .15375 .51159 L F
.15003 .51239 m .13989 .48502 L .14736 .48356 L F
.18037 .59422 m .19045 .6214 L .17952 .6246 L F
0 g
.5 Mabswid
.19045 .6214 m
.19918 .61274 L
s
0 0 0 r
2.5 Mabswid
.16559 .5445 Mdot
.938 .685 .527 r
.18037 .59422 m .17952 .6246 L .17304 .59621 L F
.17027 .56699 m .18037 .59422 L .17304 .59621 L F
.16016 .53971 m .15003 .51239 L .15375 .51159 L F
0 0 0 r
.16069 .53332 Mdot
.1628 .54204 Mdot
.938 .685 .527 r
.17027 .56699 m .17304 .59621 L .16659 .56792 L F
.16016 .53971 m .17027 .56699 L .16659 .56792 L F
0 0 0 r
.16118 .54061 Mdot
.938 .685 .527 r
.16016 .53971 m .14699 .51505 L .15003 .51239 L F
.16016 .53971 m .14484 .51942 L .14699 .51505 L F
.16016 .53971 m .14372 .5252 L .14484 .51942 L F
.16016 .53971 m .14374 .53199 L .14372 .5252 L F
.16016 .53971 m .14488 .53933 L .14374 .53199 L F
.16016 .53971 m .14708 .5467 L .14488 .53933 L F
.16016 .53971 m .15017 .55359 L .14708 .5467 L F
.16016 .53971 m .15395 .55951 L .15017 .55359 L F
.16016 .53971 m .15814 .56406 L .15395 .55951 L F
.16016 .53971 m .16245 .56692 L .15814 .56406 L F
.16016 .53971 m .16659 .56792 L .16245 .56692 L F
0 0 0 r
.16016 .53971 Mdot
.16016 .53971 Mdot
.15914 .53881 Mdot
.938 .685 .527 r
.14699 .51505 m .13989 .48502 L .15003 .51239 L F
0 0 0 r
.15752 .53738 Mdot
.15963 .54612 Mdot
.938 .685 .527 r
.16659 .56792 m .16477 .59435 L .16245 .56692 L F
.16659 .56792 m .17304 .59621 L .16477 .59435 L F
.13373 .49024 m .12973 .4576 L .13989 .48502 L F
.14699 .51505 m .13373 .49024 L .13989 .48502 L F
0 0 0 r
.15471 .5349 Mdot
.938 .685 .527 r
.13373 .49024 m .12039 .46526 L .12973 .4576 L F
0 g
.5 Mabswid
.12973 .4576 m
.14099 .45562 L
s
.938 .685 .527 r
.17304 .59621 m .16709 .62199 L .16477 .59435 L F
.17304 .59621 m .17952 .6246 L .16709 .62199 L F
0 g
.17952 .6246 m
.19045 .6214 L
s
.938 .685 .527 r
.14484 .51942 m .13373 .49024 L .14699 .51505 L F
0 0 0 r
2.5 Mabswid
.15906 .55293 Mdot
.938 .685 .527 r
.16245 .56692 m .1561 .58869 L .15814 .56406 L F
.16245 .56692 m .16477 .59435 L .1561 .58869 L F
0 0 0 r
.15021 .53093 Mdot
.15844 .5605 Mdot
.938 .685 .527 r
.14484 .51942 m .12934 .49891 L .13373 .49024 L F
.14372 .5252 m .12934 .49891 L .14484 .51942 L F
.15814 .56406 m .14764 .57961 L .15395 .55951 L F
.15814 .56406 m .1561 .58869 L .14764 .57961 L F
.12934 .49891 m .12039 .46526 L .13373 .49024 L F
0 g
.5 Mabswid
.06205 .28395 m
.26877 .4811 L
s
.938 .685 .527 r
.14372 .5252 m .12705 .51048 L .12934 .49891 L F
.14374 .53199 m .12705 .51048 L .14372 .5252 L F
0 0 0 r
2.5 Mabswid
.15772 .56918 Mdot
0 g
.5 Mabswid
.02461 .61146 m
.06205 .28395 L
s
.938 .685 .527 r
.15395 .55951 m .14001 .56771 L .15017 .55359 L F
.15395 .55951 m .14764 .57961 L .14001 .56771 L F
.16477 .59435 m .15403 .61363 L .1561 .58869 L F
.16477 .59435 m .16709 .62199 L .15403 .61363 L F
0 g
.16709 .62199 m
.17952 .6246 L
s
.938 .685 .527 r
.14374 .53199 m .12703 .52414 L .12705 .51048 L F
.14488 .53933 m .12703 .52414 L .14374 .53199 L F
.15017 .55359 m .13375 .55382 L .14708 .5467 L F
.15017 .55359 m .14001 .56771 L .13375 .55382 L F
.14488 .53933 m .12932 .53894 L .12703 .52414 L F
.14708 .5467 m .12932 .53894 L .14488 .53933 L F
.14708 .5467 m .13375 .55382 L .12932 .53894 L F
.12934 .49891 m .11368 .47818 L .12039 .46526 L F
0 g
.12039 .46526 m
.12973 .4576 L
s
.938 .685 .527 r
.12705 .51048 m .11368 .47818 L .12934 .49891 L F
.1561 .58869 m .14124 .60003 L .14764 .57961 L F
.1561 .58869 m .15403 .61363 L .14124 .60003 L F
0 g
.15403 .61363 m
.16709 .62199 L
s
.02461 .61146 m
.25094 .79334 L
s
.938 .685 .527 r
.12705 .51048 m .11013 .49554 L .11368 .47818 L F
0 g
.11368 .47818 m
.12039 .46526 L
s
.938 .685 .527 r
.12703 .52414 m .11013 .49554 L .12705 .51048 L F
.14764 .57961 m .12966 .58209 L .14001 .56771 L F
.14764 .57961 m .14124 .60003 L .12966 .58209 L F
0 g
.93681 .26473 m
.97493 .59359 L
s
.938 .685 .527 r
.12703 .52414 m .11004 .51616 L .11013 .49554 L F
0 g
.11013 .49554 m
.11368 .47818 L
s
.938 .685 .527 r
.12932 .53894 m .11004 .51616 L .12703 .52414 L F
.14001 .56771 m .12017 .56108 L .13375 .55382 L F
.14001 .56771 m .12966 .58209 L .12017 .56108 L F
0 g
.14124 .60003 m
.15403 .61363 L
s
.938 .685 .527 r
.12932 .53894 m .11346 .53855 L .11004 .51616 L F
.13375 .55382 m .11346 .53855 L .12932 .53894 L F
.13375 .55382 m .12017 .56108 L .11346 .53855 L F
0 g
.11004 .51616 m
.11013 .49554 L
s
.12966 .58209 m
.14124 .60003 L
s
.11004 .51616 m
.11346 .53855 L
s
.12017 .56108 m
.12966 .58209 L
s
.11346 .53855 m
.12017 .56108 L
s
.734 .418 0 r
.82292 .31578 m .82291 .31029 L .8378 .35521 L F
.722 .373 0 r
.811 .28647 m .82291 .31029 L .82292 .31578 L F
.811 .28647 m .80508 .26729 L .82291 .31029 L F
.778 .492 0 r
.83286 .34644 m .8378 .35521 L .84872 .39958 L F
.734 .418 0 r
.82292 .31578 m .8378 .35521 L .83286 .34644 L F
0 g
.82291 .31029 m
.8378 .35521 L
s
.741 .359 0 r
.79789 .26027 m .80508 .26729 L .811 .28647 L F
.79789 .26027 m .7855 .22864 L .80508 .26729 L F
0 g
.80508 .26729 m
.82291 .31029 L
s
.844 .585 .042 r
.84011 .37663 m .84872 .39958 L .85484 .44087 L F
.778 .492 0 r
.83286 .34644 m .84872 .39958 L .84011 .37663 L F
0 g
.8378 .35521 m
.84872 .39958 L
s
.782 .372 0 r
.78445 .2388 m .7855 .22864 L .79789 .26027 L F
.78445 .2388 m .76543 .19662 L .7855 .22864 L F
0 g
.7855 .22864 m
.80508 .26729 L
s
.67769 .05833 m
.77705 .02192 L
s
.06205 .28395 m
.67769 .05833 L
s
.844 .585 .042 r
.84011 .37663 m .85484 .44087 L .84415 .40452 L F
.914 .677 .178 r
.84415 .40452 m .85484 .44087 L .85561 .47657 L F
.2 0 1 r
.30988 .49178 m
.84617 .41722 L
s
.84782 .41699 m
.84786 .41699 L
s
.17003 .54842 m
.84619 .41734 L
s
.84783 .41703 m
.84787 .41702 L
s
0 g
.84872 .39958 m
.85484 .44087 L
s
.85484 .44087 m
.85484 .44087 L
s
.831 .405 0 r
.77154 .22353 m .76543 .19662 L .78445 .2388 L F
.77154 .22353 m .7461 .17336 L .76543 .19662 L F
0 g
.76543 .19662 m
.7855 .22864 L
s
.76543 .19662 m
.76543 .19662 L
s
.896 .566 .076 r
.81713 .32338 m .82292 .31578 L .83286 .34644 L F
.889 .539 .054 r
.81116 .3084 m .82292 .31578 L .81713 .32338 L F
.81116 .3084 m .811 .28647 L .82292 .31578 L F
.914 .604 .122 r
.82209 .33907 m .83286 .34644 L .84011 .37663 L F
.896 .566 .076 r
.81713 .32338 m .83286 .34644 L .82209 .33907 L F
.892 .526 .056 r
.80457 .29509 m .811 .28647 L .81116 .3084 L F
.80457 .29509 m .79789 .26027 L .811 .28647 L F
.967 .748 .31 r
.84465 .42835 m .85561 .47657 L .85087 .50429 L F
.914 .677 .178 r
.84415 .40452 m .85561 .47657 L .84465 .42835 L F
0 g
.85484 .44087 m
.85561 .47657 L
s
.2 0 1 r
.84787 .41702 m
.84844 .41691 L
s
.84786 .41699 m
.84844 .41691 L
s
0 0 0 r
2.5 Mabswid
.84844 .41691 Mdot
.939 .648 .186 r
.82569 .35447 m .84011 .37663 L .84415 .40452 L F
.914 .604 .122 r
.82209 .33907 m .84011 .37663 L .82569 .35447 L F
.902 .526 .078 r
.79781 .28432 m .79789 .26027 L .80457 .29509 L F
.79781 .28432 m .78445 .2388 L .79789 .26027 L F
.939 .648 .186 r
.82569 .35447 m .84415 .40452 L .82767 .3686 L F
.963 .691 .259 r
.82767 .3686 m .84415 .40452 L .84465 .42835 L F
0 g
.5 Mabswid
.84415 .40452 m
.85484 .44087 L
s
.2 0 1 r
.84024 .39598 m
.84075 .39589 L
s
.30988 .49178 m
.83569 .3968 L
s
.84023 .39598 m
.84024 .39598 L
s
.84025 .396 m
.84075 .39589 L
s
.16559 .5445 m
.83574 .39699 L
s
.84024 .396 m
.84025 .396 L
s
.875 .449 .037 r
.75999 .21559 m .7461 .17336 L .77154 .22353 L F
.75999 .21559 m .72871 .16068 L .7461 .17336 L F
0 g
.7461 .17336 m
.76543 .19662 L
s
0 0 0 r
2.5 Mabswid
.84075 .39589 Mdot
.916 .535 .118 r
.79132 .27682 m .78445 .2388 L .79781 .28432 L F
1 0 0 r
.5 Mabswid
.16187 .51913 m
.79189 .27749 L
s
.79541 .27614 m
.79586 .27596 L
s
.46689 .44151 m
.79218 .27782 L
s
.79542 .27619 m
.79586 .27596 L
s
.916 .535 .118 r
.79132 .27682 m .77154 .22353 L .78445 .2388 L F
1 0 0 r
.79018 .25832 m
.7909 .25791 L
s
.46689 .44151 m
.78545 .26101 L
s
.79015 .25822 m
.7909 .25791 L
s
.16257 .51066 m
.78516 .26022 L
s
0 g
.76543 .19662 m
.78445 .2388 L
s
.967 .748 .31 r
.84465 .42835 m .85087 .50429 L .84152 .4465 L F
.982 .725 .331 r
.82789 .38052 m .84465 .42835 L .84152 .4465 L F
.963 .691 .259 r
.82767 .3686 m .84465 .42835 L .82789 .38052 L F
.2 0 1 r
.30988 .49178 m
.8278 .37561 L
s
.1628 .54204 m
.8278 .37569 L
s
.83063 .37499 m
.83101 .37489 L
s
.8306 .37499 m
.83063 .37499 L
s
.83063 .37498 m
.83101 .37489 L
s
.8306 .37498 m
.83063 .37498 L
s
.994 .789 .417 r
.84152 .4465 m .85087 .50429 L .84085 .52188 L F
0 g
.85087 .50429 m
.85561 .47657 L
s
0 0 0 r
2.5 Mabswid
.7909 .25791 Mdot
.966 .649 .268 r
.80503 .33325 m .81713 .32338 L .82209 .33907 L F
.964 .641 .263 r
.80503 .33325 m .81116 .3084 L .81713 .32338 L F
.97 .659 .281 r
.80503 .33325 m .82209 .33907 L .82569 .35447 L F
.963 .636 .263 r
.80503 .33325 m .80457 .29509 L .81116 .3084 L F
0 0 0 r
.83101 .37489 Mdot
.929 .55 .169 r
.78553 .27314 m .77154 .22353 L .79132 .27682 L F
.78553 .27314 m .75999 .21559 L .77154 .22353 L F
.974 .671 .299 r
.80503 .33325 m .82569 .35447 L .82767 .3686 L F
.963 .634 .267 r
.80503 .33325 m .79781 .28432 L .80457 .29509 L F
.978 .682 .321 r
.80503 .33325 m .82767 .3686 L .82789 .38052 L F
0 g
.5 Mabswid
.82767 .3686 m
.84415 .40452 L
s
0 0 0 r
2.5 Mabswid
.79586 .27596 Mdot
.994 .789 .417 r
.84152 .4465 m .84085 .52188 L .83494 .45761 L F
.993 .747 .394 r
.82632 .38942 m .84152 .4465 L .83494 .45761 L F
.982 .725 .331 r
.82789 .38052 m .84152 .4465 L .82632 .38942 L F
.905 .494 .145 r
.75053 .21577 m .72871 .16068 L .75999 .21559 L F
.75053 .21577 m .71435 .15995 L .72871 .16068 L F
0 g
.5 Mabswid
.72871 .16068 m
.7461 .17336 L
s
.963 .633 .275 r
.80503 .33325 m .79132 .27682 L .79781 .28432 L F
1 0 0 r
.16125 .52658 m
.79597 .29596 L
s
.79934 .29473 m
.79989 .29453 L
s
.46689 .44151 m
.79603 .29623 L
s
.79935 .29477 m
.79989 .29453 L
s
0 g
.78445 .2388 m
.79781 .28432 L
s
.982 .692 .344 r
.80503 .33325 m .82789 .38052 L .82632 .38942 L F
.2 0 1 r
.81844 .35418 m
.81858 .35414 L
s
.16118 .54061 m
.81349 .35558 L
s
.81858 .35414 m
.81913 .35399 L
s
.81843 .35418 m
.81858 .35414 L
s
.30988 .49178 m
.81347 .35552 L
s
.81858 .35414 m
.81913 .35399 L
s
0 0 0 r
2.5 Mabswid
.79989 .29453 Mdot
.999 .802 .494 r
.83494 .45761 m .84085 .52188 L .82619 .52764 L F
0 g
.5 Mabswid
.84085 .52188 m
.85087 .50429 L
s
0 0 0 r
2.5 Mabswid
.81913 .35399 Mdot
.964 .635 .287 r
.80503 .33325 m .78553 .27314 L .79132 .27682 L F
1 0 0 r
.5 Mabswid
.80224 .3139 m
.80295 .31363 L
s
.80218 .31392 m
.80224 .3139 L
s
.46689 .44151 m
.79913 .31508 L
s
.80224 .31387 m
.80295 .31363 L
s
.80217 .31389 m
.80224 .31387 L
s
.16069 .53332 m
.79909 .31495 L
s
.939 .569 .226 r
.78083 .27357 m .75999 .21559 L .78553 .27314 L F
.78083 .27357 m .75053 .21577 L .75999 .21559 L F
.993 .747 .394 r
.82632 .38942 m .83494 .45761 L .82305 .39466 L F
.984 .699 .365 r
.80503 .33325 m .82632 .38942 L .82305 .39466 L F
.999 .802 .494 r
.83494 .45761 m .82619 .52764 L .82533 .46069 L F
.995 .756 .442 r
.82305 .39466 m .83494 .45761 L .82533 .46069 L F
0 0 0 r
2.5 Mabswid
.80295 .31363 Mdot
.966 .638 .302 r
.80503 .33325 m .78083 .27357 L .78553 .27314 L F
.995 .756 .442 r
.82305 .39466 m .82533 .46069 L .81831 .39583 L F
.984 .703 .381 r
.80503 .33325 m .82305 .39466 L .81831 .39583 L F
.967 .643 .321 r
.80503 .33325 m .77753 .27818 L .78083 .27357 L F
.968 .651 .341 r
.80503 .33325 m .77586 .2867 L .77753 .27818 L F
.97 .659 .361 r
.80503 .33325 m .77594 .29861 L .77586 .2867 L F
.972 .668 .38 r
.80503 .33325 m .77778 .31308 L .77594 .29861 L F
.2 0 1 r
.5 Mabswid
.78817 .31295 m
.78843 .31286 L
s
.78803 .313 m
.78817 .31295 L
s
.78843 .31286 m
.7887 .31276 L
s
.78817 .31296 m
.78843 .31286 L
s
.78803 .31301 m
.78817 .31296 L
s
.78843 .31286 m
.7887 .31276 L
s
.974 .677 .394 r
.80503 .33325 m .78128 .32911 L .77778 .31308 L F
.2 0 1 r
.30988 .49178 m
.77854 .31656 L
s
.15914 .53881 m
.77851 .31642 L
s
.976 .685 .404 r
.80503 .33325 m .78619 .34553 L .78128 .32911 L F
1 0 0 r
.46689 .44151 m
.78449 .33983 L
s
.2 0 1 r
.30988 .49178 m
.78449 .33983 L
s
1 0 0 r
.16016 .53971 m
.78449 .33983 L
s
.978 .692 .409 r
.80503 .33325 m .7922 .36115 L .78619 .34553 L F
1 0 0 r
.46689 .44151 m
.79076 .35739 L
s
.15963 .54612 m
.79096 .35792 L
s
.98 .697 .41 r
.80503 .33325 m .79889 .37483 L .7922 .36115 L F
0 g
.02461 .61146 m
.71096 .39488 L
s
.981 .701 .408 r
.80503 .33325 m .80579 .38561 L .79889 .37483 L F
0 g
.71096 .39488 m
.7126 .39436 L
s
1 0 0 r
.15906 .55293 m
.79958 .37591 L
s
.46689 .44151 m
.79929 .37546 L
s
.983 .703 .403 r
.80503 .33325 m .81242 .39276 L .80579 .38561 L F
.984 .704 .394 r
.80503 .33325 m .81831 .39583 L .81242 .39276 L F
1 0 0 r
.80604 .37413 m
.80618 .37409 L
s
.80604 .37412 m
.80618 .37409 L
s
.80606 .35342 m
.80611 .35341 L
s
.80606 .35342 m
.80611 .35341 L
s
.80562 .37424 m
.80576 .37421 L
s
.80576 .37421 m
.80604 .37413 L
s
.80562 .3742 m
.80576 .37417 L
s
.80576 .37417 m
.80604 .37412 L
s
0 0 0 r
2.5 Mabswid
.80503 .33325 Mdot
.80503 .33325 Mdot
0 g
.5 Mabswid
.79781 .28432 m
.80503 .33325 L
s
.80503 .33325 m
.82767 .3686 L
s
1 0 0 r
.80532 .35361 m
.80539 .35359 L
s
.80539 .35359 m
.80553 .35356 L
s
.80533 .35364 m
.80539 .35362 L
s
.80539 .35362 m
.80553 .35358 L
s
.80576 .3535 m
.80606 .35342 L
s
.80553 .35356 m
.80576 .3535 L
s
.80576 .35351 m
.80606 .35342 L
s
.80553 .35358 m
.80576 .35351 L
s
.946 .59 .285 r
.77753 .27818 m .75053 .21577 L .78083 .27357 L F
.921 .536 .247 r
.7438 .22434 m .71435 .15995 L .75053 .21577 L F
.7438 .22434 m .70396 .17187 L .71435 .15995 L F
0 g
.71435 .15995 m
.72871 .16068 L
s
.946 .59 .285 r
.77753 .27818 m .7438 .22434 L .75053 .21577 L F
.992 .757 .476 r
.81831 .39583 m .81336 .45524 L .81242 .39276 L F
.81831 .39583 m .82533 .46069 L .81336 .45524 L F
0 0 0 r
2.5 Mabswid
.80611 .35341 Mdot
.992 .798 .543 r
.82533 .46069 m .80789 .52053 L .81336 .45524 L F
.82533 .46069 m .82619 .52764 L .80789 .52053 L F
0 g
.5 Mabswid
.82619 .52764 m
.84085 .52188 L
s
.949 .611 .341 r
.77586 .2867 m .7438 .22434 L .77753 .27818 L F
0 g
.77705 .02192 m
.93681 .26473 L
s
.985 .751 .498 r
.81242 .39276 m .79989 .44137 L .80579 .38561 L F
.81242 .39276 m .81336 .45524 L .79989 .44137 L F
0 0 0 r
2.5 Mabswid
.7887 .31276 Mdot
.80618 .37409 Mdot
.951 .632 .39 r
.77594 .29861 m .74027 .241 L .77586 .2867 L F
.949 .611 .341 r
.77586 .2867 m .74027 .241 L .7438 .22434 L F
.927 .572 .336 r
.74027 .241 m .70396 .17187 L .7438 .22434 L F
.978 .74 .509 r
.80579 .38561 m .78589 .41986 L .79889 .37483 L F
1 0 0 r
.5 Mabswid
.46689 .44151 m
.79248 .39704 L
s
.978 .74 .509 r
.80579 .38561 m .79989 .44137 L .78589 .41986 L F
0 g
.80503 .33325 m
.80579 .38561 L
s
1 0 0 r
.15772 .56918 m
.78661 .42097 L
s
.80244 .41723 m
.80248 .41723 L
s
.80248 .41723 m
.80324 .41705 L
s
.46689 .44151 m
.78635 .41827 L
s
.80246 .4171 m
.80249 .4171 L
s
.80249 .4171 m
.80324 .41705 L
s
.15844 .5605 m
.79201 .39868 L
s
.80475 .39542 m
.80476 .39542 L
s
.80476 .39542 m
.80523 .3953 L
s
.80476 .39537 m
.80477 .39537 L
s
.80477 .39537 m
.80523 .3953 L
s
0 0 0 r
2.5 Mabswid
.80523 .3953 Mdot
.979 .783 .57 r
.81336 .45524 m .78729 .50043 L .79989 .44137 L F
.81336 .45524 m .80789 .52053 L .78729 .50043 L F
0 g
.5 Mabswid
.80412 .36548 m
.97493 .59359 L
s
.80789 .52053 m
.82619 .52764 L
s
.951 .632 .39 r
.77594 .29861 m .74021 .26477 L .74027 .241 L F
.952 .653 .432 r
.77778 .31308 m .74021 .26477 L .77594 .29861 L F
0 g
.77594 .29861 m
.80503 .33325 L
s
.2 0 1 r
.76975 .29275 m
.77013 .29258 L
s
.30988 .49178 m
.76393 .29527 L
s
.76974 .29274 m
.77013 .29258 L
s
.15752 .53738 m
.76381 .29511 L
s
.97 .726 .511 r
.79889 .37483 m .77237 .39216 L .7922 .36115 L F
.79889 .37483 m .78589 .41986 L .77237 .39216 L F
.927 .572 .336 r
.74027 .241 m .69826 .19624 L .70396 .17187 L F
0 g
.70396 .17187 m
.71435 .15995 L
s
0 0 0 r
2.5 Mabswid
.77013 .29258 Mdot
.952 .653 .432 r
.77778 .31308 m .74369 .29407 L .74021 .26477 L F
.2 0 1 r
.5 Mabswid
.74891 .27301 m
.74936 .27278 L
s
.74891 .27301 m
.74891 .27301 L
s
.30988 .49178 m
.74162 .27664 L
s
.74889 .27299 m
.74936 .27278 L
s
.74889 .27299 m
.74889 .27299 L
s
.15471 .5349 m
.74157 .27622 L
s
.954 .673 .465 r
.78128 .32911 m .74369 .29407 L .77778 .31308 L F
.963 .71 .504 r
.7922 .36115 m .76031 .36031 L .78619 .34553 L F
.7922 .36115 m .77237 .39216 L .76031 .36031 L F
0 0 0 r
2.5 Mabswid
.80324 .41705 Mdot
.954 .673 .465 r
.78128 .32911 m .75053 .32675 L .74369 .29407 L F
.958 .692 .489 r
.78619 .34553 m .75053 .32675 L .78128 .32911 L F
.78619 .34553 m .76031 .36031 L .75053 .32675 L F
0 g
.5 Mabswid
.77705 .02192 m
.80412 .36548 L
s
.927 .604 .409 r
.74021 .26477 m .69826 .19624 L .74027 .241 L F
.965 .762 .581 r
.79989 .44137 m .76592 .46832 L .78589 .41986 L F
.79989 .44137 m .78729 .50043 L .76592 .46832 L F
0 g
.79989 .44137 m
.80579 .38561 L
s
.78729 .50043 m
.80789 .52053 L
s
.78729 .50043 m
.79989 .44137 L
s
0 0 0 r
2.5 Mabswid
.74936 .27278 Mdot
.927 .604 .409 r
.74021 .26477 m .69774 .23183 L .69826 .19624 L F
0 g
.5 Mabswid
.69826 .19624 m
.70396 .17187 L
s
.927 .634 .466 r
.74369 .29407 m .69774 .23183 L .74021 .26477 L F
0 g
.74021 .26477 m
.77594 .29861 L
s
.2 0 1 r
.72593 .2537 m
.72644 .2534 L
s
.30988 .49178 m
.71746 .25854 L
s
.72589 .25367 m
.72644 .2534 L
s
.15021 .53093 m
.71702 .25794 L
s
.951 .738 .579 r
.78589 .41986 m .74537 .42634 L .77237 .39216 L F
.78589 .41986 m .76592 .46832 L .74537 .42634 L F
0 0 0 r
2.5 Mabswid
.72644 .2534 Mdot
0 g
.5 Mabswid
.78729 .50043 m
.78729 .50043 L
s
.76592 .46832 m
.78729 .50043 L
s
.927 .634 .466 r
.74369 .29407 m .70257 .27628 L .69774 .23183 L F
0 g
.69774 .23183 m
.69826 .19624 L
s
.69774 .23183 m
.74021 .26477 L
s
.929 .661 .511 r
.75053 .32675 m .70257 .27628 L .74369 .29407 L F
.941 .713 .566 r
.77237 .39216 m .72716 .37766 L .76031 .36031 L F
.77237 .39216 m .74537 .42634 L .72716 .37766 L F
.929 .661 .511 r
.75053 .32675 m .71257 .32623 L .70257 .27628 L F
.933 .688 .544 r
.76031 .36031 m .71257 .32623 L .75053 .32675 L F
.76031 .36031 m .72716 .37766 L .71257 .32623 L F
0 g
.7126 .39436 m
.80412 .36548 L
s
.69774 .23183 m
.70257 .27628 L
s
.69774 .23183 m
.69774 .23183 L
s
.74537 .42634 m
.76592 .46832 L
s
.70257 .27628 m
.71257 .32623 L
s
.72716 .37766 m
.74537 .42634 L
s
.71257 .32623 m
.72716 .37766 L
s
.25 Mabswid
.04128 .2769 m
.792 0 L
s
.06016 .26994 m
.06469 .27428 L
s
[(0)] .05109 .26124 1 .95882 Mshowa
.20875 .21513 m
.21309 .21967 L
s
[(50)] .20008 .20604 .95505 1 Mshowa
.36465 .15762 m
.36877 .16237 L
s
[(100)] .35642 .14814 .86715 1 Mshowa
.5284 .09723 m
.53226 .10218 L
s
[(150)] .52068 .08732 .77926 1 Mshowa
.70061 .03371 m
.70418 .03887 L
s
[(200)] .69347 .02338 .69136 1 Mshowa
.125 Mabswid
.08932 .25918 m
.09202 .26181 L
s
.11875 .24832 m
.12143 .25098 L
s
.14847 .23736 m
.15112 .24004 L
s
.17847 .2263 m
.1811 .229 L
s
.23933 .20385 m
.24191 .2066 L
s
.27021 .19246 m
.27276 .19523 L
s
.30138 .18096 m
.30391 .18376 L
s
.33286 .16935 m
.33536 .17217 L
s
.39676 .14578 m
.3992 .14866 L
s
.42918 .13383 m
.43159 .13672 L
s
.46192 .12175 m
.4643 .12467 L
s
.495 .10955 m
.49734 .1125 L
s
.56215 .08478 m
.56443 .08778 L
s
.59623 .07221 m
.59848 .07523 L
s
.63067 .05951 m
.63289 .06255 L
s
.66546 .04667 m
.66764 .04975 L
s
.73613 .02061 m
.73823 .02373 L
s
.77201 .00737 m
.77408 .01052 L
s
.25 Mabswid
.95795 .2567 m
1 .60209 L
s
.96055 .27806 m
.95457 .27997 L
s
[(-50)] .97251 .27422 -1 .32092 Mshowa
.96914 .34862 m
.96315 .35048 L
s
[(-25)] .98114 .34489 -1 .3106 Mshowa
.97806 .42185 m
.97204 .42366 L
s
[(0)] .99009 .41825 -1 .29992 Mshowa
.98732 .49791 m
.98128 .49965 L
s
[(25)] .99938 .49442 -1 .28886 Mshowa
.99694 .57695 m
.99089 .57863 L
s
[(50)] 1.00904 .5736 -1 .27739 Mshowa
.125 Mabswid
.96225 .29196 m
.95866 .29311 L
s
.96395 .30597 m
.96036 .30711 L
s
.96567 .32008 m
.96208 .32121 L
s
.9674 .3343 m
.9638 .33542 L
s
.9709 .36305 m
.9673 .36416 L
s
.97267 .37759 m
.96907 .37869 L
s
.97445 .39223 m
.97085 .39333 L
s
.97625 .40699 m
.97264 .40808 L
s
.97988 .43683 m
.97627 .43791 L
s
.98172 .45193 m
.97811 .453 L
s
.98357 .46714 m
.97996 .4682 L
s
.98544 .48247 m
.98182 .48352 L
s
.98921 .51347 m
.98559 .51451 L
s
.99112 .52916 m
.9875 .53019 L
s
.99305 .54497 m
.98942 .54599 L
s
.99499 .5609 m
.99136 .56191 L
s
.95887 .26425 m
.95529 .26541 L
s
.99891 .59314 m
.99528 .59414 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 486.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001iR000`400?l00000o`00003ooooooooo
oooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo
003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooolco
oooo0_l0002;ooooo`00ooooooo9ooooo`?o000000?oooooo`000?ooool0R_ooool00?ooooooa_oo
ool3o`0000Gooooo00?o0000ooooooooool0R?ooool00?ooooooa?ooool2o`0000Wooooo00?o0000
ooooooooool0Qoooool00?oooooo`Oooool3o`0000_ooooo0_l0000Aooooo`?o00001?ooool2o`00
06kooooo003ooooookkooooo0ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooo0000013o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0006gooooo003ooooo
ohGooooo1Ol00003ooooo`;o00001?ooool2o`0002Kooooo0ol00005ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`1[ooooo`00oooooon6ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Sooooo`;o00005_ooool00ol0003ooooo
ooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Joooool00?oooooo
Qoooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00008?ooool3o`0001Wooooo00?o0000ooooooooool03?ooool4o`0000?ooooo00Co0000oooo
oooooooo0000KOooool00?ooooooR?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Kooooo`?o00007?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000KOooool00?ooooooQOoo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000Kooooo`;o00008?ooool00ol0003oooooooooo`0;ooooo`Go00000oooool2o`00
06kooooo003oooooohGooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00006?ooool3o`0002;ooooo0_l00024ooooo`00oooooon6
ooooo`?o00001?ooool2o`0000Cooooo0_l0000Fooooo`?o00009?ooool00ol0003oooooo`000024
ooooo`00oooooonXooooo`?o00000_ooool00ol0003oooooooooo`0Dooooo`;o00002oooool01Ol0
003ooooooooooooooooo000008?ooooo003oooooojKooooo0_l00006ooooo`03o`000?oooooooooo
013ooooo0ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo083ooooo003ooooooj?o
oooo0ol0000Hooooo`?o00001?ooool2o`0000oooooo00?o0000ooooooooool0P?ooool00?oooooo
X?ooool3o`0001Sooooo0ol00007ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0
Ooooool00?ooooooW_ooool2o`0001Wooooo0_l0000:ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0O_ooool00?ooooooVoooool3o`0001Sooooo0ol0000<ooooo`04o`000?oooooo
ooooo`0000oooooo0_l0001oooooo`00oooooonHooooo`?o00006?ooool3o`0000oooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooo000007oooooo003ooooooiGooooo1?l0000G
ooooo`?o00004_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0O?oo
ool00?ooooooToooool2o`0000?ooooo00?o0000ooooooooool04oooool2o`0001Kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo07cooooo003ooooooi3ooooo0ol00006
ooooo`03o`000?oooooooooo00oooooo0ol0000Hooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1kooooo`00oooooon=ooooo`?o00002_ooool00ol0
003oooooooooo`0;ooooo`?o00006oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0N_ooool00?ooooooRoooool2o`0001Sooooo0ol0000Nooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00
oooooon8ooooo`?o00005oooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`;o0000Noooool00?ooooooQOooool3o`0001Sooooo0_l0000Tooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001kooooo`00oooooon3
ooooo`;o00006?ooool3o`0002Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo07Sooooo003ooooooh3ooooo0ol000000ooooooo0000ooooo`0Doooo
o`?o0000:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Moooool00?ooooooOOooool3o`0000Gooooo00?o0000ooooooooool03oooool3o`0002co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Oo
oooo003oooooog[ooooo0ol0000Hooooo`;o0000;oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0M_ooool00?ooooooN?ooool2o`0001Sooooo0ol0
000aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1eooooo`00oooooomeooooo`?o00005oooool3o`0003Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`;o0000M_ooool00?ooooooL_ooool3o`0001Oooooo0ol0000goooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001foooo
o`00oooooom`ooooo`;o00006?ooool2o`0003_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07?ooooo003oooooofgooooo0ol0000Gooooo`?o0000
?Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Loooool00?ooooooJ_ooool3o`0000?ooooo00?o0000ooooooooool04Oooool3o`00043ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07;ooooo003o
ooooofOooooo0ol00007ooooo`03o`000?oooooooooo00gooooo0ol00013ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1aooooo`00oooooomUoooo
o`;o00006?ooool2o`0004Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo077ooooo003oooooof;ooooo0ol0000Gooooo`?o0000B?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000Aooooo`Go00000_ooool3o`0005Oo
oooo003ooooooeoooooo0ol0000Gooooo`?o0000Boooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo00004Oooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool0E?ooool00?ooooooGOooool2o`0001Sooooo0_l0001>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`Go00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo003ooooooe[o
oooo0ol0000Gooooo`?o0000D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Co
oooo003oooooob3ooooo0ol00003ooooo`?o00001?ooool2o`0002Sooooo0ol00002ooooo`03o`00
0?oooooooooo01;ooooo0ol0001Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`06o`000?ooooooooooooooool0003ooooo1?l0001Goooo
o`00oooooolQooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo0ol00006ooooo`03o`000?oooooooooo00kooooo0ol0001F
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`07o`000?ooooooooooooooool0003oooooo`00001Jooooo`00oooooolQooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Pooooo`;o0000
6?ooool2o`0005Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0ol00002ooooo`Go0000E_ooool00?oooooo8Oooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07Oooool3o`0001Oooooo
0ol0001Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool3o`0006gooooo
003oooooob7ooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0001co
oooo0ol0000Gooooo`?o0000Goooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`03o`000?oooooooooo06_ooooo003oooooob3ooooo0_l00003ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00006_ooool2o`0001Oooooo0ol0001Rooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Zooooo`00
oooooolQooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0001Sooooo0ol0000Gooooo`;o
0000IOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0J_ooool00?ooooooA?ooool3o`000003ooooool0003ooooo01Cooooo0ol0001Wooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Yooooo`00oooo
oom2ooooo`;o00001Oooool00ol0003oooooooooo`0?ooooo`?o0000J_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0J?ooool00?oooooo?oooool3
o`0001Kooooo0ol0001]ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Xooooo`00oooooollooooo`?o00005oooool2o`00073ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`?o0000JOooool00?oooooo>Oooool3o`0001Oo
oooo0ol0001booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Vooooo`00oooooolgooooo`;o00005oooool3o`0007Gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Kooooo003oooooocCooooo0ol0
000Gooooo`;o0000N?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0IOooool00?oooooo<Oooool4o`0001Kooooo0ol0001jooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Tooooo`00ooooool_oooo
o`;o00000oooool00ol0003oooooooooo`0Aooooo`?o0000OOooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0I?ooool00?oooooo;?ooool3o`0000Ko
oooo00?o0000ooooooooool03Oooool3o`00083ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0<ooooo`;o0000IOooool00?oooooo:Oooool3o`0000[ooooo00?o0000ooooooooool0
2_ooool2o`0008?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooo000006Gooooo003oooooobKooooo0ol0000Gooooo`?o0000Q_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0H_ooool00?oooooo9?ooool2
o`0001Oooooo0ol00029ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Qooooo`00oooooolQooooo`?o00005_ooool3o`0008cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067ooooo003ooooooako
oooo0ol0000Gooooo`;o0000Soooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0H?ooool00?oooooo7?ooool2o`0000?ooooo00?o0000ooooooooool0
4Oooool3o`00097ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo05oooooo003ooooooaWooooo0ol00006ooooo`03o`000?oooooooooo00gooooo0ol0
002Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool2o`00063ooooo003o
oooooaKooooo0ol0000Fooooo`?o0000Uoooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool00000H?ooool00?oooooo4oooool3o`0001Oooooo0_l0002Joooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Moooo
o`00oooooolAooooo`;o00005oooool3o`0009cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05gooooo003oooooo`kooooo0ol0000Fooooo`?o0000
Woooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
G?ooool00?oooooo2oooool3o`0001Oooooo0_l0002Rooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Kooooo`00ooooool9ooooo`;o00000oooool0
0ol0003oooooooooo`0Aooooo`?o0000Y?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00gooooo0_l0000<ooooo`;o0000C_ooool00?oooooo1_ooool3o`0000Kooooo00?o0000oooo
ooooool03Oooool3o`000:Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000000_ooooo00Co0000oooooooooooo0000COooool00?oooooo0oooool3o`00
01Kooooo0ol0002[ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`08ooooo`04o`000?ooooooooooo`0004gooooo003oooooo`7ooooo0_l0000Goooo
o`;o0000[_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0001=ooooo`00oOooool3o`0001Kooooo0ol0002`oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0004gooooo003jooooo`?o00005_ooool3o`000;?ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo0000COooool00;oooooo0ol00004ooooo`;o00001?ooool2o`0002Wooooo0ol0000Foooo
o`?o0000]_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool2o`0004kooooo0030ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Vooooo`;o00000oooool00ol0003oooooooooo`0A
ooooo`;o0000^Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo0_l0001H
ooooo`00`?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool3o`0000Kooooo00?o0000ooooooooool03Oooool3o`000;_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0Eooo
ool00<3ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`00023ooooo0ol0000Fooooo`?o0000__ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0EOooool00<3ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001kooooo0_l0000Fooooo`?o
0000`Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0E?ooool00;oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00006oooool3o`0001Kooooo0_l00034ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1Dooooo`00`?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool2o`0001Wooooo0ol0000Fooooo`?o0000a_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Doooool00>Cooooo0ol0000Fooooo`?o0000
bOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo0_l0001Dooooo`00h_oo
ool2o`0000?ooooo00?o0000ooooooooool04Oooool2o`000<cooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000005Cooooo003Oooooo`?o00001_ooool0
0ol0003oooooooooo`0=ooooo`?o0000coooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0DOooool00=cooooo0ol0000Fooooo`?o0000d_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00=[o
oooo0_l0000Fooooo`?o0000eOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D?ooool00=Oooooo0ol0000Fooooo`;o0000f?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Coooool00=Cooooo0ol0
000Fooooo`?o0000f_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0C_ooool00=;ooooo0ol0000Eooooo`?o0000gOooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00_ooooo0ol0001@ooooo`00coooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool3o`000;Gooooo1Ol0000Vooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1=ooooo`00c?ooool3o`0000Kooooo00?o0000oooooooo
ool03Oooool2o`000;Sooooo00?o0000onMn9OoWORD00_oWORD5o`00027ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04gooooo0039ooooo`?o0000
2_ooool00ol0003oooooooooo`09ooooo`?o0000^Oooool00ol0003ojhToonMn9@06onMn9@;ogg89
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0C?ooool00<Oooooo0_l0000Fooooo`?o0000^oooool01?l0003ojhToon^9
?oo[RCl7onMn9@;ogg890_l0000Nooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1;ooooo`00a?ooool3o`0001Gooooo0ol0002mooooo`03o`000?o[
RCoojhTo00;ojhTo1ooWORD4ommb2@;o00007?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Boooool00<7ooooo0ol0000Fooooo`;o0000_oooool0
0ol0003ojhToon^9?`04on^9?`OoighU1OoOLPT00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool03?ooool2o`0004cooooo002oooooo`Co00005?ooool3o`00
0<3ooooo00?o0000on^9?oo[RCl01_o[RCl7onMn9@Gogg890_l0000Iooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0001;ooooo`00_?ooool3o`00
00Cooooo00?o0000ooooooooool03_ooool3o`000<;ooooo00?o0000on^9?oo[RCl01oo[RCl7onMn
9@Oogg8900?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0BOooool00;Wooooo0ol0000Fooooo`;o0000aOooool00ol0003o
jhToon^9?`08on^9?`OoighU1ooOLPT00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`18ooooo`00]_ooool3o`0001Kooooo
0ol00037ooooo`03o`000?o[RCoojhTo00SojhTo1ooWORD7ommb2@03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Oooooo
002dooooo`;o00005_ooool3o`000<Wooooo00?o0000onfBE_o]TUH02_o[RCl7onMn9@Oogg8900?o
0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0Aoooool00;7ooooo0ol0000Eooooo`?o0000c?ooool01?l0003okI9FonfBE_o]
TUH:on^9?`OoighU1_oOLPT00ooDI`3o0000ooooo`0Eooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool03?ooool2o`0000[ooooo1Ol00002ooooo`?o0000=?ooool00:kooooo0ol0000F
ooooo`;o0000coooool01?l0003okI9FonfBE_o]TUH:on^9?`OoighU1ooOLPT00ooDI`3o0000oooo
o`0Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool0000:ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0aoooo
o`00[?ooool2o`000003ooooool0003ooooo01?ooooo0ol0003Aooooo`03o`000?o]TUKokI9F00;o
kI9F2_o[RCl7onMn9@Kogg890_oDI`000ol0003oooooooooo`0Booooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0<Oooool00:Wooooo0ol00004ooooo`03o`000?oooooooooo00kooooo
0ol0003Dooooo`03o`000?o]TUKokI9F00?okI9F2_o[RCl6onMn9@Oogg8900?oe6L0o`000?ooool0
4oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037ooooo002Vooooo`?o00005Ooo
ool3o`000=Kooooo00?o0000onfBE_o]TUH01Oo]TUH9on^9?`OoighU1_oOLPT2omAW0003o`000?oo
oooooooo017ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Gooooo00Ko0000ooooooooooooooooo`000?ooool4o`0003Cooooo002Sooooo`?o0000
5_ooool2o`000=Wooooo00?o0000onfBE_o]TUH01Oo]TUH:on^9?`OoighU1_oOLPT2omAW0003o`00
0?oooooooooo013ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo000003Oooooo002Qooooo`;o
00005_ooool3o`000=_ooooo00?o0000onfBE_o]TUH01_o]TUH:on^9?`KoighU1_oOLPT3omAW0003
o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`;o
00001oooool3o`0000;ooooo1Ol0000cooooo`00W_ooool3o`0001Gooooo0ol0003Nooooo`03o`00
0?o]TUKokI9F00OokI9F2Oo[RCl7onMn9@Kogg890_oDI`000ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02Oooool2o`000003ooooool0003ooooo04?ooooo
001Yooooo`?o00001?ooool2o`0002Wooooo0ol0000Eooooo`?o0000hOooool00ol0003okI9FonfB
EP08onfBEPWojhTo1_oWORD6ommb2@?oe6L000?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@Oooool006Sooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002Kooooo0_l00002ooooo`03o`00
0?oooooooooo017ooooo0_l0003Sooooo`03o`000?o]TUKokI9F00WokI9F2Oo[RCl7onMn9@Kogg89
0ooDI`000ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`10ooooo`00K?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo027ooooo0ol00005ooooo`03o`000?oooooooooo00gooooo0ol0003Uooooo`03o`00
0?o]TUKokI9F00[okI9F2Oo[RCl7onMn9@Gogg891?oDI`02o`0000kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo043ooooo001/ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool07_ooool3o`0001Gooooo0ol0003Xooooo`03o`00
0?o]TUKokI9F00_okI9F2Oo[RCl6onMn9@Kogg891?oDI`000ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0oooooo`00J?oo
ool4o`0000?ooooo00Co0000oooooooooooo00007_ooool2o`0001Kooooo0_l0003[ooooo`03o`00
0?o]TUKokI9F00cokI9F2?o[RCl7onMn9@Gogg891?oDI`000ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool03?ooool2o`00043ooooo001Xooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00006oooool3o`0001Gooooo0ol0003]ooooo`03o`00
0?o]VVSokI9F00cokI9F2Oo[RCl6onMn9@Gogg891OoDI`000ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooo`000010ooooo`00J?oo
ool5o`0000?ooooo0_l0000Iooooo`?o00005Oooool3o`000?3ooooo00?o0000onfJJ?o]VVP03Oo]
TUH9on^9?`KoighU1OoOLPT4omAW00;o00003?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0?Oooool008Sooooo1?l0000Dooooo`?o0000loooool0
1?l0003okIYXonfJJ?o]VVP=onfBEPSojhTo1ooWORD4ommb2@Goe6L000?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??oo
ool008Kooooo0_l00004ooooo`03o`000?oooooooooo00oooooo0_l0003fooooo`03o`000?o]VVSo
kIYX00;okIYX3?o]TUH9on^9?`KoighU1OoOLPT4omAW00;o00002oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??ooool008?ooooo0ol0000Eoooo
o`?o0000n?ooool00ol0003okIYXonfJJ003onfJJ0cokI9F2Oo[RCl6onMn9@Cogg891OoDI`000ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0kooooo`00P?ooool3o`0001Gooooo0ol0003kooooo`03o`000?o]VVSokIYX00Co
kIYX3?o]TUH8on^9?`KoighU1OoOLPT4omAW00;o00002_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0>_ooool007kooooo0_l0000Eooooo`?o0000
o_ooool00ol0003okIYXonfJJ005onfJJ0cokI9F2?o[RCl6onMn9@Cogg891?oDI`000ol0003ob5l0
o`000009ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02oooool3o`0003cooooo
001kooooo`?o00005Oooool2o`000?oooooo0_ooool00ol0003okIYXonfJJ006onfJJ0_okI9F2?o[
RCl7onMn9@Cogg891?oDI`02o`0000Wooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03Wooooo001hooooo`?o00005Oooool3o`000?oooooo0oooool0
0ol0003okIYXonfJJ008onfJJ0_okI9F2?o[RCl6onMn9@Cogg891?oDI`000ol0003ob5l0o`000008
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0h
ooooo`00MOooool3o`000003ooooool0003ooooo01;ooooo0ol0003oooooo`Kooooo00?o0000onfJ
J?o]VVP02Oo]VVP;onfBEPSojhTo1_oWORD4ommb2@Coe6L00_l00008ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0hooooo`00Loooool2o`0000Go
oooo00?o0000ooooooooool03Oooool3o`000?oooooo2Oooool00ol0003okIYXonfJJ00:onfJJ0_o
kI9F1oo[RCl6oo2A>@;okH`[0_oOLPT4omAW0003o`000?o8G`3o000000Sooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Oooooo001`ooooo`?o0000
2?ooool00ol0003oooooooooo`0:ooooo`;o0000ooooool<ooooo`03o`000?o]VVSokIYX00[okIYX
2oo]TUH7on^9?`03oo:GB?o`TCWol94i00Col94i0_o]S2/2ommb2@Coe6L000?o0000olQO0?l00000
1oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
=oooool006gooooo0ol0000Eooooo`?o0000ooooool>ooooo`03o`000?o]VVSokIYX00_okIYX2oo]
TUH5on^9?`;olYM81_o`TCT4onf<:`Coe6L000?o0000olQO0?l000001oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00_ooooo0ol0000hooooo`00Joooool2o`0001Gooooo0ol0003o
oooooa7ooooo00?o0000onfJJ?o]VVP03?o]VVP;onfBEP?ojhTo1?obUdP5oo2A>@GokH`[1?oDI`00
0ol0003ob5l0o`000006ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0eooooo`00J?ooool3o`0001Gooooo0_l0003ooooooaCooooo00?o0000onfJ
J?o]VVP03Oo]VVP;onfBEP03on^9?oobUdSolYM800?olYM81_o`TCT4onf<:`Coe6L000?o0000olQO
0?l000001_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0=Oooool006Gooooo1?l0000Dooooo`?o0000oooooolFooooo`03o`000?o]VVSokIYX00ko
kIYX2_o]TUH7oo:GB0Gol94i1Oo]S2/4omAW0003o`000?o8G`3o000000Gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Cooooo001Rooooo`?o0000
1?ooool00ol0003oooooooooo`0>ooooo`?o0000oooooolIooooo`03o`000?o]VVSokIYX00ookIYX
2Oo]TUH00oobW5OolYM8oo:GB005oo:GB0Gol94i1?o]S2/01OoZR1koe6L0omAW0?oDI`3o000000;o
b5l000?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0<oooool0063ooooo0_l0000Eooooo`?o0000oooooolLooooo`03o`00
0?o]VVSokIYX013okIYX2?o]TUH2oo:LE`KolYM81Oo`TCT4onf<:`;ojXPN0_oDI`001?l0003ob5l0
olQO0?l00004ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0:ooooo`?o00001?ooool2o`00023ooooo001Mooooo`?o00005Oooool2o`000?oooooo
7oooool2o`0001;okIYX1_o]TUH3oo:LE`OolYM81Oo`TCT4onf<:`;ojXPN0_oDI`001?l0003ob5l0
olQO0?l00003ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool02oooool3o`0000[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001oooooo001Joooo
o`?o00005Oooool3o`000?oooooo8Oooool00ol0003okJ9go`00000BonfJJ0GokI9F1?obW5L6oo:G
B0Gol94i1?o]S2/3onZ87P05omAW0?l0003ob5l0olQO0?l000000oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo01gooooo001Hooooo`;o00005Oooool3o`000?oooooo9?ooool0
1?l0003okJ9gonfRMol0000BonfJJ0CokI9F1OobW5L6oo:GB0Col94i1Oo]S2/3onZ87P05omAW0?l0
003ob5l0okeK0?l000000_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01go
oooo001Eooooo`?o00005?ooool3o`000?oooooo9oooool01?l0003okJ9gonfRMoo]XWL2o`00017o
kIYX0oo]TUH5oo:LE`KolYM81Oo`TCT4onf<:`CojXPN00Co0000olQO0?o8G`3o00000_ooool00ol0
003oooooooooo`15ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool4o`00
00?ooooo00Co0000oooooooooooo00007oooool005;ooooo0ol000000ooooooo0000ooooo`0Boooo
o`;o0000oooooolZooooo`03o`000?o]XWOokJ9g00?okJ9g00?o0000onfJJ?o]VVP03oo]VVP2onfB
EPKolYaG1_obUdP4oo2A>@CokH`[1OoZR1h01_l0003ob5l0okeK0?l0003oooooo`0004Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00007oooool0053ooooo0_l00005ooooo`03o`000?oooooooooo00gooooo0ol0
003oooooobgooooo00?o0000onfRMoo]XWL00oo]XWL00ol0003okIYXonfJJ00?onfJJ0OolYaG1_ob
UdP5oo2A>@CokH`[1?oZR1h01_l0003ob5l0olQO0?l0003oooooo`0004Wooooo00?o0000oooooooo
ool03?ooool2o`0000Kooooo1Ol00003ooooo`;o00008?ooool004gooooo0ol0000Dooooo`?o0000
ooooool`ooooo`03o`000?o]XWOokJ9g00CokJ9g0_l0000?onfJJ0SolYaG1_obUdP4oo2A>@CokH`[
1?oZR1h01ol0003ob5l0olQO0?nmF`3o0000ooooool00000B?ooool00ol0003oooooooooo`0:oooo
o`;o000000?oooooo`000?ooool0;oooool004[ooooo0ol0000Dooooo`?o0000oooooolcooooo`03
o`000?o]XWOokJ9g00KokJ9g00?o0000onfJJ?o]VVP03?o]VVP00oocXF?olYaGoo:LE`06oo:LE`Go
lYM81Oo`TCT3onf<:`GojXPN00Ko0000olQO0?o8G`3o0000ooooool00019ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`00Aoooool3o`00
01Gooooo0_l0003oooooocKooooo00?o0000onfRMoo]XWL01oo]XWL00ol0003okIYXonfJJ00;onfJ
J0;olj5S1oobW5L6oo:GB0Col94i1?o]S2/4onZ87P04o`000?o8G`3ob5l0okeK00;o0000BOooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02gooooo000Iooooo`;o0000:_ooool2o`00
01Gooooo0ol0003oooooocSooooo00?o0000onfRMoo]XWL02?o]XWL2o`0000_okIYX0oocXF<7oo:L
E`KolYM80oo`TCT4onf<:`CojXPN00Co0000onJ64oo8G`3o_E/00_l0001:ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0;?ooool001Sooooo00Co0000oooooooooooo00009_ooool4
o`0001?ooooo0ol0003ooooooc_ooooo00?o0000onfRMoo]XWL02_o]XWL00ol0003okIYXonfJJ008
onfJJ0Colj5S1oobW5L5oo:GB0Col94i1?o]S2/4onZ87P05o`000?o8G`3ob5l0okeK0?l00000Booo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo000Hooooo`04o`000?oooooo
ooooo`0002?ooooo0ol00004ooooo`03o`000?oooooooooo00kooooo0_l0003oooooockooooo00?o
0000onfRMoo]XWL02oo]XWL00ol0003okIYXonfJJ007onfJJ0Colj5S1oobW5L6oo:GB0?ol94i1?o]
S2/4onZ87P04o`000?oVQQ?ob5l0okeK00;o0000B_ooool00ol0003oooooooooo`0=ooooo`;o0000
;?ooool001Sooooo00Co0000oooooooooooo00008Oooool2o`0001Gooooo0ol0003ooooood3ooooo
00?o0000onfRMoo]XWL03?o]XWL2o`0000OokIYX1OocXF<7oo:LE`GolYM81?o`TCT3onf<:`CojXPN
00Co0000onJ64ooVQQ?ob5l00_l0001;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
0000;?ooool001Sooooo00Co0000oooooooooooo00007_ooool3o`0001Cooooo0ol0003ooooood?o
oooo00?o0000onfRMoo]XWL03?o]XWL3o`0000KokIYX1_ocXF<7oo:LE`GolYM80oo`TCT4onf<:`Co
jXPN00Ko0000onJ64oo8G`3o0000okeK0?l0001;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:_ooool001Sooooo00Co0000oooooooooooo00006oooool3o`0001Cooooo0ol0003o
ooooodOooooo00?o0000onfRMoo]XWL03_o]XWL00ol0003okIYXonfJJ003onfJJ0Oolj5S1_obW5L5
oo:GB0Col94i0oo]S2/4onZ87P06o`000?oVQQ?oiXHCo`000?nmF`3o0000Boooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Wooooo000Iooooo`;o00006Oooool3o`0001Gooooo0_l0
003ooooood[ooooo00?o0000onfRMoo]XWL01_o]XWL2oc<0o`OokJ9g00?o0000onfJJ?o]VVP00_o]
VVP7oo>QH`OolYaG1OobUdP3oo2A>@CokH`[0ooZR1h2o`000005onJ64ol0003o_E/0okeK0?l00000
Boooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Sooooo000booooo`;o00005Ooo
ool3o`000?ooooooC?ooool00ol0003okJ9gonfRM`07onfRM`03oc<0ooo]XWOokJ9g00KokJ9g0_l0
0002onfJJ0Solj5S1oobW5L4oo:GB0?ol94i1?o]S2/3onZ87P;o000000GoiXHCo`000?nmF`3o_E/0
o`00001<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool002oooooo0ol0
0002ooooo`03o`000?oooooooooo00oooooo0ol0003oooooodoooooo00?o0000onfRMoo]XWL04_o]
XWL00ol0003okIYXoo>QH`08oo>QH`KolYaG1OobUdP3oo2A>@?okH`[00Soo`00onZ87_oZR1kojXPN
o`000?oVQQ?o0000onJ64`;o_E/000?o0000ooooooooool0BOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Sooooo000/ooooo`?o00001_ooool00ol0003oooooooooo`0;ooooo`?o
0000oooooomBooooo`03o`000?o]XWOokJ9g01?okJ9g00?o0000oo>QHoocXF<02?ocXF<6oo:LE`Co
lYM80oo`TCT4onf<:`?ojXPN00Co0000onJ64ol0003oiXHC0_nmF`000ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool002[ooooo0_l0000Eooooo`;o
0000oooooomEooooo`03o`000?o]XWOokJ9g01CokJ9g0_l00009oo>QH`KolYaG1?obUdP3oo2A>@?o
kH`[0ooZR1h01Ol0003oiXHConJ64ol0003oi8H>00;o_E/000?o0000ooooooooool0B?ooool3o`00
00_ooooo0_l0000Zooooo`009oooool3o`0001Cooooo0ol0003ooooooeKooooo00?o<`3oo`000?o]
XWL05Oo]XWL2oo>WKP03o`000?ocXF?olj5S00Kolj5S1_obW5L5oo:GB0;ol94i0oo]S2/4onZ87P04
o`000?oVQQ?o0000onJ64`;o_E/000?o0000ooooooooool0AOooool3o`0000;ooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0000=ooooo`?o00001?ooool2o`0001?ooooo000Toooo
o`?o00005?ooool3o`000?ooooooEoooool2oc<0o`03ooooool0003okJ9g01GokJ9g0oocYfh00ol0
003olj5Soo>QH`06oo>QH`KolYaG1?obUdP3oo2A>@?okH`[0ooZR1h01Ol0003oiXHCo`000?oVQQ?o
i8H>00;o_E/000?o0000ooooooooool0@Oooool3o`0000Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool0000Booooo`008Oooool3o`0001Cooooo0ol0003ooooooeOooooo0olc0?l2ooooo`03oc<0ool0
003okJ9g01GokJ9g1?ocYfh00ol0003olj5Soo>QH`06oo>QH`GolYaG1OobUdP2oo2A>@?okH`[0ooZ
R1h01Ol0003oiXHCo`000?oVQQ?oi8H>00;o_E/000?o0000ooooooooool0?_ooool3o`0000Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Go00001Oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo013ooooo000Oooooo`;o00000_ooool00ol0003ooooo
ooooo`0@ooooo`;o0000oooooomHooooo`;o<`3o0oooool2oc<0o`;ooooo00?o0000onfRMoo]XWL0
4oo]XWL5oo>WKP03o`000?ocXF?olj5S00Kolj5S1OobW5L4oo:GB0;ol94i1?o]S2/2onZ87P04o`00
0?oVQQ?o0000onJ64`;oi8H>00?o_E/0okQO0?l00000??ooool3o`0000_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool04?ooool001cooooo0ol00005ooooo`03o`000?oooooooooo00cooooo0ol0003ooooooeSo
oooo0_lc0?l3ooooo`;o<`3o1?ooool00ol0003okJ9gonfRM`0DonfRM`ColjM^0_l00007oo>QH`Ko
lYaG1?obUdP2oo2A>@?okH`[0ooZR1h2o`000003onJ64ooTQPkoi8H>00;o_E/000?o0000oooooooo
ool0=oooool3o`0000oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`Co
00000oooool01?l0003oooooooooool0000Booooo`006Oooool3o`0000Wooooo00?o0000oooooooo
ool02?ooool3o`000?ooooooFOooool2oc<0o`?ooooo0_lc0?l6ooooo`03o`000?o]XWOokJ9g01Co
kJ9g1?ocYfh3o`0000Oolj5S1OobW5L4oo:GB0;omj==0_ofXTT01?o]S2_ojXPNonZ87_oZR1h2o`00
00;oiXHC0_oTQPh00onmF`3o0000ooooo`0eooooo`?o00004_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000B
ooooo`006?ooool00ol0003oooooooooo`0Cooooo`;o0000oooooomJooooo`;o<`3o1?ooool00olc
0?ooooooooooo`06ooooo`03o`000?o]XWOokJ9g01CokJ9g00?o<`3ooo>WK_ocYfh01?ocYfh00ol0
003olj5Soo>QH`05oo>QH`GolYaG0oobUdP00oogY5;omj==ooNSC@03ooJRB@;ojXPN0_l00002onJ6
4`;oi8H>00?o_E/0okQO0?l00000<_ooool3o`0001Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`Go00000oooool2o`0001?ooooo000[ooooo`?o0000oooooomJooooo`;o
<`3o1?ooool2oc<0o`Wooooo00?o0000onfYP_o]XWL05?o]XWL8oo>WKP03o`000?ocXF?olj5S00Go
lj5S1OobW5L00oobUdSomjABooNTDP02ooNSC@?omZ9900Coo`00onZ87_oZR1ko00000_oVQQ<2onB6
3P;o_E/000?o0000ooooooooool0;Oooool3o`0001Sooooo00?o0000ooooooooool02Oooool2o`00
02Wooooo000Xooooo`?o0000oooooomKooooo`;o<`3o1?ooool2oc<0o`_ooooo00?o0000onfYP_o]
ZH800_o]ZH8BonfRM`WoljM^00?o0000oo>QHoocXF<01OocXF<4oo:LE`?omjAB0_ogXdd3ooJRB@04
ooJRA_oZR1kojXPNo`0000;oiXHC0ooTQPh00onmF`3o^5l0o`00000[ooooo`?o00006oooool00ol0
003oooooooooo`07ooooo`;o00000_ooool00ol0003oooooooooo`0Vooooo`009Oooool3o`000?oo
ooooG?ooool2oc<0o`Cooooo0_lc0?l>ooooo`03o`000?o]ZH;okJV200?okJV24?o]XWL:oo>WKP03
o`000?ocXF?olj5S00Colj5S1?obW5L01?ogYUOomjABooNTD_ogY582ooNSC@?omZ9900?omZ96onZ8
7_l000000_oVQQ<3onB63P03okeK0?nhG`3o000002Sooooo0ol0000Nooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool09_ooool002Cooooo0_l0003ooooooecooooo0_lc0?l5ooooo`03
oc<0oooooooooooo00kooooo00?o0000onfYP_o]ZH801Oo]ZH8>onfRM`_oljM^00?o0000oo>QHooc
XF<01?ocXF<3oo:LE`04ooNVEoogY5;omjABooNTDP;omj==0oofXTT2ooJRAP;o00000_oVQQ<3onB6
3P03okQO0?l0003ooooo02Cooooo0ol0000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09_ooool002Cooooo00?o0000ooooool00000oooooomIooooo`;o<`3o1Oooool2oc<0oa7o
oooo00?o0000onfYP_o]ZH802?o]ZH8;onfRM`coljM^00?o0000oo>QHoocXF<01?ocXF<01?obW5Oo
mjIGooNVEoogYUL3ooNTDP04ooNSCOofXTWomZ99ooJRB@;omZ960_l00002onJ64`?oi8H>00?o_E/0
okQO0?l000008Oooool3o`0002Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0V
ooooo`009?ooool01?l0003oooooooooool0003ooooooeKooooo0_lc0?l5ooooo`;o<`3o4oooool0
0ol0003okJV2onfYPP0:onfYPPWokJ9g3OocYfh00ol0003olj5Soo>QH`04oo>QH`?omjIG0oogY582
ooNSC@;omZ990oofXTH00ol0003oiXHConJ64`04onB63P03okQO0?l0003ooooo01cooooo1?l0000W
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool002Cooooo00Go0000oooo
ooooooooooooo`00003ooooooe?ooooo0_lc0?l5ooooo`;o<`3o5Oooool00ol0003okJV2onfYPP0=
onfYPPOokJ9g3OocYfh00ol0003olj5Soo>QH`03oo>QH`ComjIG0_ogY582ooNSC@?omZ990_ofXTH0
0ol0003oiXHConJ64`04onB63P;o^5l000?o0000ooooooooool05oooool3o`0002cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`009?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?ooooooC_ooool2oc<0o`Kooooo00?o<`3oooooooooool05_ooool00ol0
003okJV2onfYPP0>onfYPPGokJ9g3_ocYfh00ol0003olj5Soo>QH`02oo>QH`04ooRXG?ogYUOomjIG
ooNVE`?omjAB00Comj==ooJRBOofXTWomZ990_ofXTH00ol0003omZ94onJ64`04onB63P03on>93Onh
G`3o000001Kooooo0ol0000_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_oo
ool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooood[ooooo0olc0?l6
ooooo`;o<`3o6?ooool00olc0?oo0000onfYPP0AonfYPP?okJ9g3oocYfh2o`0000;olj5S0_ohZ5`3
ooNVE`;omjAB0_ogXdd2ooJRB@;omZ960_l00002onJ64`?oi8H>00?ohhT=okQO0?l000004oooool3
o`0003;ooooo00?o0000ooooooooool02Oooool2o`0002Sooooo000Sooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom7ooooo`;o<`3o1oooool2oc<0oaSooooo0_lc0?l00ooo
003o0000onfYPP0DonfYPPooljM^0_l00002oo>QH`;on:QL0oogYUL3ooNTDP03ooNSCOofXTWomZ99
00;omZ960_l000000oofXTCoiXHConB63P02onB63P04on>93OnhG`3o^5l0o`0000oooooo0ol0000e
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000:?ooool002?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooodCooooo0_lc0?l7ooooo`;o<`3o6?ooool2oc<0
o`04oooooolc0?oo<`3oo`0001GokJV20_od[7L:oo>WKP03oc<0ooocYfkoljM^00;oljM^00?o0000
oo>QHoohZ5`00_ohZ5`3ooNVE`;omjAB00Gomj==ooJRBOofXTWomZ99ool00002o`0000;omZ940ooT
QPh2on>93@03okQO0?l0003ooooo00_ooooo0ol0000hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool09Oooool002?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
oooood7ooooo0_lc0?l7ooooo`;o<`3o5oooool01?oo003o<`3ooc<0ooooool2oc<0o`;ooooo00?o
0000onfYP_o]ZH804oo]ZH84ooB/M`koljM^00Co0000ooRXG?ohZ5con:QL0oogYUL2ooNTDP;omj==
0_ofXTT00ooo003o0000o`000002ooJRA0?oi8H>0_oSR@d2okQO0003o`000?oooooooooo00Kooooo
0ol0000kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool002?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`3oooooockooooo0_lc0?l8ooooo`03oc<0oooo
oooooooo01Gooooo0olc0?l00ooooooo<`3ooc<0o`05ooooo`03o`000?o]ZH;okJV201?okJV21Ood
[7L=oo>WKP04o`000?ohZ5con:QLooRXG0?omjIG0_ogY5801?ogXdgomZ99ooJRBOofXTH2o`0000;o
mZ9400?omZ93onB63_oTQPh00ooSR@d00onhG`3o0000ooooo`04ooooo`?o0000?_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo000Sooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0oooooolkooooo`;o<`3o2?ooool2oc<0oaGooooo00?oo`00oc<0oolc0?l0
0_ooool2oc<0o`Oooooo00?o0000onfYP_o]ZH804oo]ZH86ooB/M`coljM^00?o0000ooRXG?ohZ5`0
0_ohZ5`2ooNVE`;omjAB00Comj==ooJRBOofXTWomZ960_l00002ooJRA003ooJR@ooTQPkoi8H>00?o
hhT=00Co^5l0o`000?oooooooooo0ol00011ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09Oooool002?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocSo
oooo0_lc0?l8ooooo`;o<`3o5Oooool00ooo003o<`3ooc<0o`02ooooo`;o<`3o2Oooool00ol0003o
kJV2onfYPP0ConfYPPSom:ag2_ocYfh00oohZf7o0000ooRXG002ooRXG0?omjIG0_ogY5800oogXdgo
mZ99ooJRB@02o`0000;omZ9400?omZ93onB63_oTQPh01?oSR@d00onhG`3o0000o`000015ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool002?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3oooooocGooooo0_lc0?l8ooooo`;o<`3o5?ooool01?oo003o<`3o
oc<0oolc0?l2ooooo`;o<`3o2oooool00ol0003okJV2onfYPP0ConfYPP[om:ag2?ocYfh2ooR[H@04
o`000?ohZ5con:QLooRXG0;omjIG0_ogY5801oogXdgomZ99ooJRBOl0003omZ96o`000?ofXT@00_of
XT<00ooTQPkohhT=on>93@02on>93@03okQO0?l0003ooooo04Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Uooooo`008oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0?oooooo<_ooool2oc<0o`Wooooo00?o<`3oooooooooool04_ooool00ooo003o<`3ooc<0o`03
ooooo`;o<`3o2oooool2ool00003o`000?o]ZH;okJV201?okJV23?od[7L6oo>WKP?on:]Q00Co0000
ooRXG?ohZ5con:QL0_ogYUL02?ogY5;omj==ooJRBOofXTWo0000ooJRA_l0003omZ940_ofXT<00ooT
QPkohhT=on>93@02on>93@;o^5l000?o0000ooooooooool0@oooool00ol0003oooooooooo`09oooo
o`;o00009oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3ooooooboo
oooo0_lc0?l9ooooo`;o<`3o4_ooool2ool000;o<`3o0oooool2oc<0o`cooooo00Goo`00oooooooo
ooooooooo`00000EonfYPPgom:ag1OocYfh3ooR[H@03o`000?ohZ5con:QL00;omjIG0_ogY5801_og
XdgomZ99o`000?ofXTKo0000ooJRA0;omZ9300?oi8H>on>93OoSR@d00ooSR@d00onhG`3o0000oooo
o`14ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000009oooool002;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`3oooooobcooooo0_lc0?l9ooooo`;o<`3o4_ooool2
ool000;o<`3o0oooool2oc<0o`cooooo0_oo0004ooooo`03o`000?o]ZH;okJV201?okJV23_od[7L4
oo>WKPCon:]Q00?o0000ooRXG?ohZ5`00_ogYUL01oogY5;omj==ooJRBOl0003omZ96o`000?ofXT@0
0oofXT<5on>93@03okQO0?l0003ooooo04Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Tooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool2oc<0o`Wooooo0_lc0?lAooooo`;oo`000olc0?l3ooooo`;o<`3o3?ooool2ool000?ooooo0ooo
00000ol0003okJV2onfYPP0ConfYPQ3om:ag0_ocYfh5ooR[H@04o`000?ohZ5con:QLooNVE`;omjAB
0_ofXTT2o`000004ooJRA?ofXT?omZ93ooJR@`KohhT=00?o^5l0o`000?ooool0@oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo000Rooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0oooooolVooooo`;o<`3o2_ooool00olc0?ooooooooooo`0?ooooo`;oo`00
0_lc0?l4ooooo`;o<`3o3?ooool2ool000;ooooo0ooo0003ooooo`03o`000?o]ZH;okJV201?okJV2
4_od[7L5ooR[H@?o00000_ogYUL00oogY5;omj==ooJRB@03o`0000?omZ9300?omZA3on>93OoSR@d0
0ooSR@d00onhG`3o0000ooooo`13ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9?ooool002;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3oooooob;ooooo0olc
0?l:ooooo`;o<`3o3oooool3ool000;o<`3o1?ooool2oc<0o`cooooo0_oo0002ooooo`;oo`001_oo
ool00ol0003okJV2onfYPP0ConfYPQ;om:ag0_oi[F@4ooR[H@;o000000Gon:QLooNVEoogY5;omj==
ool00003o`0000?omZ9300?omZA3on>93OoSR@d00ooSR@d00onhG`3o^f/0o`000013ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09?ooool002;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`3ooooooaoooooo0_lc0?l;ooooo`;o<`3o3oooool2ool00003oooooolc
0?oo<`3o00Cooooo0_lc0?l=ooooo`03ool00?ooooooo`0000;oo`002Oooool00ol0003okJV2onfY
PP0ConfYPQ7om:ag00?o<`3oooV]I?oi[F@01?ohZf402Ol0003on:QLooNVEoogYUOomjABool00?l0
003omZ96o`000002ooJR@`?omZA31OoSR@d00onkJ`3o0000ooooo`13ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool09?ooool002;ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`3ooooooacooooo0_lc0?l;ooooo`;o<`3o3_ooool3ool000?o<`3o1?ooool2oc<0o`go
oooo1?oo0009ooooo`?o<`3o00?o0000onfYP_o]ZH804oo]ZH8BooB/M`?onJeT1?ohZf402?l0003o
n:QLooNVEoogY5;omj==o`000?ofXTKo00000_ofXT<3ooJT@`GohhT=00?o^f/0o`000?ooool0@ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo000Rooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0oooooolIooooo`;o<`3o3?ooool00olc0?ooooooooooo`0<
ooooo`;oo`0000?ooooooc<0oolc0?l01Oooool2oc<0o`gooooo1?oo0009ooooo`Go<`3o00?o0000
onfYP_o]ZH804oo]ZH8BooB/M`GonJeT0oohZf401ol0003on:QLooNVEoogY5;o0000ooJRA_l00000
0_ofXT<4ooJT@`CohhT=00?oiI0Cok][0?l00000@oooool00ol0003oooooooooo`09ooooo`;o0000
9_ooool002;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3ooooooaKooooo0_lc
0?l<ooooo`;o<`3o3?ooool3ool00003oooooolc0?oo<`3o00Gooooo0_lc0?l=ooooo`?oo`002Ooo
ool5oc<0o`04ool00?ooooooooooo`0001GokJV24_od[7L6ooV]I0?on:]Q00Ko0000ooNVEoogY5;o
0000ooJRA_l00002ooJR@`ComZA30ooSR@d2onF@4`03ok][0?l0003ooooo04;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooo`00000Vooooo`008Oooool00ol0003oooooooooo`0Hooooo`;o
0000oooooolDooooo`;o<`3o3?ooool2oc<0o`cooooo0_oo00001?oooooo<`3ooc<0oolc0?l5oooo
o`;o<`3o3Oooool2ool000[ooooo0_lc0?l01?oooooo<`3ooc<0oooo0004ooooo`03o`000?o]ZH;o
kJV201?okJV24_od[7L7ooV]I0;on:]Q00Ko0000ooRXG?ogYUOo0000ooJRA_l00002ooJR@`GomZA3
00KohhT=onF@4ooUT1?oiI0Cok][0?l00013ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool08oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3oooooo`oo
oooo0_lc0?l<ooooo`;o<`3o2oooool3ool00003oooooolc0?oo<`3o00Kooooo0_lc0?l<ooooo`Co
o`002?ooool6oc<0o`03ool00?oooooooooo00Gooooo00?o0000onfYP_o]ZH804oo]ZH8AooB/M`Wo
nJeT00Oon:]Qo`000?ohZ5co0000ooJRBOl0003omZ9300GomZA300?omjI4onF@4ooUT1<00ooUT1<0
0onkJ`3o0000ooooo`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool0
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3oooooo`cooooo0_lc0?l=oooo
o`03oc<0oooooooooooo00Wooooo0_oo0002ooooo`;o<`3o1_ooool2oc<0o`_ooooo1Ooo0008oooo
o`;o<`3o00?ooooooc<0oolc0?l00_oo0007ooooo`;oo`0000?o0000onfYP_o]ZH804oo]ZH8BooB/
M`WonJeT00Kon:]Qo`000?l0003omZ99o`000?ofXT<4ooJT@`?omjI41?oUT1<00onkJ`3o0000oooo
o`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`3oooooo`Wooooo0_lc0?l=ooooo`;o<`3o2Oooool3
ool000;ooooo0_lc0?l6ooooo`;o<`3o2oooool2ool00003oooooooo003oo`0000Oooooo0olc0?l0
0ooooooo<`3ooc<0o`02ool000Oooooo0_oo0002ooooo`03o`000?o^/8_ok[2;01?ok[2;1_oe/Gd<
ooB/M`[onJeT00Gon:]Qo`000?ogY5;omZ96o`000003ooJT@`ComjI41?oUT1<00onkJ`3o0000oooo
o`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`3oooooo`Kooooo0_lc0?l=ooooo`;o<`3o2Oooool2
ool000;ooooo0olc0?l6ooooo`;o<`3o2_ooool3ool000;ooooo00?oo`00ooooooooool01Oooool2
oc<0o`;ooooo0_lc0?l2ool000Kooooo0ooo0004ooooo`03o`000?o^/8_ok[2;01?ok[2;3ooe/Gd3
ooB/M`_onJeT0_l000001?ofXTKo0000ooJT@oofY4<5ooNVA0GoiI0C00?o^f/0o`000?ooool0@?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0ooooool3ooooo`;o<`3o3Oooool2oc<0o`Sooooo0ooo0002
ooooo`;o<`3o1oooool2oc<0o`[ooooo0_oo0003ooooo`;oo`001Oooool3oc<0o`04oooooolc0?oo
<`3ooc<0o`;oo`001Oooool3ool000Sooooo00?o0000onj`Roo^/8/04oo^/8/AooFaO@GonJmW1_oi
[F@01Ol0003onJeTo`000?l0003omZA300OomjI41?oUT1<00onkJ`3o0000ooooo`11ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`3oooooo`;o<`3o3_ooool00olc0?ooooooooooo`06ooooo`;oo`000ooo
ool2oc<0o`Oooooo0_lc0?l9ooooo`?oo`000oooool2ool000Gooooo0_lc0?l2ooooo`;o<`3o00?o
ooooool00?oo00001?ooool3ool000[ooooo00?oo`00o`000?o^/8/05?o^/8/BooFaO@_onJmW0ol0
0008ooNVA0CoiI0C00?o^f/0o`000?ooool0@Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02?ooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0o?ooool2
oc<0o`kooooo0_lc0?l6ooooo`?oo`000oooool2oc<0o`Oooooo0_lc0?l8ooooo`?oo`001?ooool2
ool000Cooooo0olc0?l2ooooo`;o<`3o00?oooooool00?oo00001?ooool2ool000_ooooo0_oo0000
0ooooooo0000onj`R`0Donj`Ra;omK5m2ooi[fL3o`0000;on:Q71_ogYT@5onF@4`03ok][0?l0003o
oooo043ooooo00?o0000ooooooooool02?ooool3o`0002Gooooo000Pooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0n?ooool3oc<0o`kooooo0_lc0?l6ooooo`;oo`000oooool3oc<0
o`Oooooo0_lc0?l8ooooo`;oo`001_ooool00ooo003oooooooooo`02ooooo`;o<`3o0_ooool3oc<0
o`03oooooooo003oo`0000?ooooo0ooo000:ooooo`?oo`0000?oooooo`000?l000000_l0000Eonj`
Ra7omK5m2ooi[fL01?l0003on[5Xo`000?l00004ooRXA`ComjI41?oUT1<00onkJ`3o0000ooooo`10
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08oooool0023ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`3eooooo`;o<`3o3oooool2oc<0o`Gooooo0ooo0003oooo
o`;o<`3o2?ooool2oc<0o`Oooooo0ooo0006ooooo`;oo`000_ooool3oc<0o`;ooooo0_lc0?l2oooo
o`;oo`000_ooool3ool000_ooooo0_oo00001?oooooo0000o`000?l00002ooooo`03oc<0ool0003o
k[2;01Cok[2;4_oe/Gd8ooV_I`;on[5X00Go0000ooZbJ?l0003onZiBo`000006ooRXA`03ooNVA?oU
T1?oiI0C00;oiI0C00?o^f/0o`000?ooool0@?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo1Ol00002ooooo`?o00003_ooool0023ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`3booooo`;o<`3o4?ooool00olc0?ooooooooooo`03ooooo`;oo`001?ooool2
oc<0o`Sooooo0_lc0?l7ooooo`;oo`001oooool2ool000;ooooo0_lc0?l3ooooo`;o<`3o0_ooool2
ool00004oooooooo003oo`00ool000cooooo0_oo0003o`0000;ooooo1?lc0?l00ol0003ok[2;onj`
R`0Conj`Ra;omK5m00?oo`00ooV_Iooi[fL00ooi[fL4ooZaJ006o`000?oj/VSo0000oo^aF?l0003o
nJ]<1_ohZ4L2onVJ7`?oiI0C00?o^f/0o`000?ooool0?oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00_ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0koooool2oc<0
oa3ooooo0_lc0?l3ooooo`?oo`000oooool3oc<0o`Sooooo0_lc0?l6ooooo`?oo`001oooool2ool0
0004oooooolc0?oo<`3ooc<0o`;ooooo0olc0?l2ooooo`;oo`0000?oooooool00?oo00003?ooool3
ool000;o00000_ooool4oc<0o`?ooooo00?oo`00o`000?o^/8/05?o^/8/AooFaO@GonJmW1Ooj/FP0
1ol0003onk=Xo`000?ok/UgonZiBo`000?oiZd`01OohZ4L3onVJ7`;oiI0C00?o^f/0o`000?ooool0
?oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo1Ol00003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`3/ooooo`;o<`3o4?ooool2oc<0o`?ooooo0_oo0004ooooo`;o<`3o2Ooo
ool2oc<0o`Gooooo0ooo0009ooooo`04ool00?oooooo<`3ooc<0o`?ooooo0_lc0?l3ooooo`Goo`00
3?ooool2ool000;o00000_ooool5oc<0o`;ooooo0ooo00000ooooooo0000onj`R`0Donj`Ra;omK5m
0_oi[fL7ooZaJ006o`000?ok/fSo0000oo^cHOok/ESo00000_oiZd`5ooRXA`?ojIXO00?oiI0Cok][
0?l00000@?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo0>Wooooo0_lc0?l@ooooo`;o<`3o0_ooool3ool000Cooooo0_lc0?l9ooooo`;o
<`3o1Oooool2ool000[ooooo00Coo`00oc<0oolc0?oo<`3o0oooool2oc<0o`?ooooo1?oo000=oooo
o`;oo`0000Co0000oooooooooooooooo1?lc0?l2ooooo`?oo`001?ooool00ol0003ok[2;onj`R`0C
onj`Ra;omK5m00?onJmWooZaJ?oj/FP01Ooj/FP02?oj/VSo0000oo^cJ?l0003onk=Qoo^aF?oj[U;o
00000_oiZd`4ooRXA`CojIXO00?oiI0Cok][0?l00000@?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000kooooo000Poooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0i_ooool2oc<0oa7ooooo00?o<`3ooooo
ooooool00_oo0005ooooo`;o<`3o2Oooool2oc<0o`Cooooo0ooo000:ooooo`03ool00?lc0?oo<`3o
00?ooooo0olc0?l3ooooo`?oo`003Oooool00ol0003oo`00ool00003ooooo`Co<`3o0_ooool3ool0
00Gooooo0_oo00000ol0003ok[2;onj`R`0Conj`Ra7omK5m00?om[F1ooZaJ?oj/FP01_oj/FP01_oj
/VSo0000oo^cJ?l0003onkAToo^bG@;onZiB00?o0000ooV[C?oiZd`00oohZ4L5onVJ7`03ok][0?l0
003ooooo03oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`07o`000?oo
ooooooooooooool0003oooooo`00000Aooooo`008?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo0>?ooooo0_lc0?lAooooo`;o<`3o0ooo0004ooooo`?o<`3o2Oooool2oc<0o`Cooooo
0_oo000;ooooo`?o<`3o0oooool2oc<0o`Cooooo0_oo000=ooooo`04o`000?oo003oo`00ool000;o
oooo1Olc0?l01?ooooooo`00ool00?oo0005ooooo`?oo`000oooool00ol0003ok[2;onj`R`0Conj`
R`komK5m1?of]H46ooZaJ0;on[9X00So0000oo^cJ?l0003onkAToo^bGOok/ESonZiBo`0000?onJ]<
0_ohZ4L5onVJ7`03ok][0?l0003ooooo03oooooo00?o0000ooooooooool02Oooool2o`0000gooooo
0ol00002ooooo`Go00003Oooool0023ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`3Pooooo`;o<`3o4Oooool2oc<0o`;oo`001Oooool2oc<0o`[ooooo0_lc0?l3ooooo`?oo`002ooo
ool2oc<0o`Cooooo0_lc0?l3ooooo`?oo`002oooool3o`0000;oo`000_ooool5oc<0o`04oooooooo
003oo`00ool000Kooooo0_oo0006ooooo`03o`000?o^/8_ok[2;01?ok[2;3Ooe/Gd5ooJeP@Kon[5X
0_oj/VP01_l0003onk=Xo`000?ok]6Conk=Qoo^aF0;onZiB00Go0000ooV[C?oiZdconJ]<ooRXA`05
onVJ7`03olMm0?nkJ`3o000003oooooo00?o0000ooooooooool01oooool2o`000003ooooool0003o
oooo02?ooooo000Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0gOooool2oc<0
oa7ooooo0_lc0?l2ool000Gooooo0_lc0?l:ooooo`;o<`3o0_ooool3ool000_ooooo0olc0?l3oooo
o`?o<`3o0_ooool4ool000[ooooo0ol000001?ooooooo`00ool00?ooool5oc<0o`04oooooooo003o
o`00ool000Kooooo0ooo0008ooooo`03o`000?o^/8_ok[2;01?ok[2;2ooe/Gd7ooJeP@Gon[5X0ooj
/VP01ol0003onk=Xo`000?ok]6Conk=Qoo^bGOok/EP00_oj[U801Ol0003onJ]<ooV[C?oiZdcon:Q7
00GojIXO00?oagd0o`000?ooool0?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
027ooooo000Oooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0f_ooool2oc<0oa;o
oooo00?o<`3oool00?ooool01Oooool2oc<0o`[ooooo0_lc0?l2ooooo`;oo`003?ooool2oc<0o`;o
o`000_ooool2oc<0o`;ooooo1Ooo0009ooooo`?o000000Goooooool00?oo003oo`00ooooo`05oc<0
o`?oo`001oooool2ool000cooooo00?o0000onj`Roo^/8/04oo^/8/8ooFaO@[om[F11?oj/FP3ooZb
J007o`000?ok/fSo0000o`000?ok]6Conk9Moo^aF002ooZ^DP;o00000ooiZd`5onVJ7`03olMm0?l0
003ooooo03kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`007oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0=Oooooo0_lc0?lAooooo`03ool00?lc0?oo
<`3o00Gooooo0olc0?l:ooooo`;o<`3o00Coooooool00?oo003oo`002oooool3oc<0o`;oo`000_oo
ool2oc<0o`;ooooo0_oo00000oooooooo`00ool00008ooooo`?o00000_ooool2ool00003oooooolc
0?oo<`3o00?o<`3o0ooo0007ooooo`?oo`003_ooool00ol0003ok[2;onj`R`0Conj`R`OomK5m2oof
]H43ooZaJ0Con[9X00Gonk=Xo`000?l0003o0000oo^dI002oo^bG@04oc<0oooj[U;o0000o`0000?o
nJ]<1OoYVQl2olMm0003o`000?oooooooooo03cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Qooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0=Cooooo
0_lc0?lAooooo`03ool00?lc0?oo<`3o00Gooooo0_lc0?l;ooooo`;o<`3o0ooo000<ooooo`;o<`3o
00Coooooool00?oo003ooooo0olc0?l01Oooooooo`00ool00?oo003ooooo00;oo`001oooool3o`00
00?ooooo0_oo0005oc<0o`03oooooooo003oo`0000Oooooo0ooo000Aooooo`03o`000?o^/8_ok[2;
01?ok[2;1Ooe/Gd=ooJeP@;oo`0000?on[5XooZbJ?oj/VP00_oj/VP02?ok/fSo0000o`000?ok/fOo
nkAToo^cHOok/Ugonk5H0_oj[U801Ol0003onJ]<ooV[C?oiZdcol:D_00CojIXO0_o7O@000ol0003o
ooooooooo`0looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool001oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3Aooooo`;o<`3o4?ooool2ool000;o<`3o
1Oooool2oc<0o`_ooooo0_lc0?l2ool000cooooo0olc0?l2ooooo`05ool00?oooooo<`3ooc<0oooo
ool00ooo0002ooooo`;oo`001_ooool3o`0000Cooooo00?oo`00oc<0oolc0?l01?lc0?l3ool000Oo
oooo0_oo000Eooooo`03o`000?o^/8_ok[2;01?ok[2;0_oe/Gd@ooJeP@03ooZaJ?oj/VSon[9X00?o
n[9X00Oonk=Xo`000?l0003onk=Woo^dI?ok/f7onk9M00;onk5H0_oj[U800ol0003onJ]<ooV[C002
oo2U;`CojIXO00?oagd0o`000?ooool0?_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo027ooooo000Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0cOooool3oc<0
oa3ooooo0_oo00000ooooooo<`3oooooo`03ooooo`?o<`3o2oooool2oc<0o`;oo`003?ooool2oc<0
o`?ooooo0_oo0002oc<0o`?oo`001?ooool00ooo003oooooooooo`03ooooo`?o00001?ooool2ool0
00Go<`3o0ooo0007ooooo`?oo`005?ooool3ool00003o`000?o^/8_ok[2;01?ok[2;00?omK5mooJe
POof]H403oof]H400ooj/FSon[9XooZbJ003ooZbJ006oo^cJ?l0003o0000oo^cIook]6Conk=Q0_ok
/Ud01_ok/ESonZiBooZ^D_oj[U;o0000ooV[C0;ol:D_1?oYVQl2olMm0003o`000?oooooooooo03co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`007oooool00ol0003ooooo
ooooo`0booooo`;o0000boooool2oc<0oa3ooooo0ooo00000ooooooo<`3ooc<0o`03ooooo`;o<`3o
3?ooool2oc<0o`03ool00?oooooooooo00[ooooo0olc0?l3ooooo`;oo`000_lc0?l2ool000Gooooo
0_oo0003ooooo`?o00001Oooool00ooo003o<`3ooc<0o`03oc<0o`?oo`001oooool3ool001Cooooo
0ooo0003ooooo`03o`000?o^/8_ok[2;01;ok[2;00?ol;J@ooJePOof]H404?of]H45ooZbJ0;onk=X
0_l000001Ook/fOonkAToo^dI?ok/f7onk9M00;onk5H0_oj[U800ol0003onJ]<ooV[C002oo2U;`?o
jIXO0_o7O@000ol0003oooooooooo`0looooo`03o`000?oooooooooo00Wooooo0_l0000Sooooo`00
7oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0<Kooooo0_lc0?l@ooooo`;oo`00
0_ooool2oc<0o`?ooooo0_lc0?l<ooooo`;o<`3o00?oo`00ooooooooool02_ooool2oc<0o`Cooooo
00Coo`00oc<0oolc0?oo<`3o0_oo0005ooooo`;oo`000_ooool3o`0000Kooooo1_lc0?l2ool000So
oooo0_oo000Dooooo`?oo`001_ooool00ol0003ok[2;onj`R`0@onj`R`Col;J@4Oof]H400ooh^H;o
n[9XooZbJ002ooZbJ0;onk=X0_l000001Ook/fOonkAToo^dI?ok/f7onk9M00;onk5H0ooj[U801?l0
003onJ]<oo2U;oo`YBl3onVJ7`;oagd000?o0000ooooooooool0??ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000002?ooooo000Oooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0`oooool2oc<0o`oooooo0ooo0002ooooo`;o<`3o0oooool2oc<0o`_ooooo00?oo`00oc<0
oolc0?l03?ooool3oc<0o`Gooooo0_lc0?l2ool000Kooooo0_oo00001?oooooo0000o`000?l00006
ooooo`Ko<`3o0_oo0008ooooo`?oo`004_ooool4ool000[ooooo00?o0000onj`Roo^/8/03Oo^/8/6
oo2fT13om[F10_oh^H84ooZbJ0Co000000Conk=Woo^dI?ok]6Conk=Q0_ok/Ud2oo^aF0;onZiB00?o
0000ooV[C?o`YBl00_o`YBl2onVJ7`;oagd000?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0`?ooool2oc<0o`oooooo0_oo0004ooooo`03oc<0oooooooooooo00?o<`3o2oooool0
0ooo003o<`3ooc<0o`0<ooooo`;o<`3o1_ooool2oc<0o`03ool00?oooooooooo00Gooooo0_oo0003
o`0000Oooooo0_lc0?l00ooooooo<`3ooc<0o`02ool000Sooooo0ooo000Booooo`?oo`003_ooool0
0ol0003ok[2;onj`R`0;onj`R`Sol;J@3oof]H44ooRiPP?o00000_ok/fP2o`000004oo^cIook]6Co
nkAToo^cH@;onk9M0_ok/EP3ooZ^DP03o`000?o`YBool:D_00;ol:D_0_oYVQl2olMm0003o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`007_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo0;gooooo0_lc0?l>ooooo`?oo`001?ooool2
oc<0o`03oooooolc0?oo<`3o00_ooooo0_oo0002oc<0o`_ooooo0olc0?l5ooooo`?o<`3o00?oo`00
ooooooooool01Oooool2ool000;o00001oooool6oc<0o`03ool00?oooooooooo00Oooooo0_oo000B
ooooo`?oo`004Oooool00ol0003ok[2;onj`R`09onj`R`_ol;J@3_of]H401?oh^H;o0000o`000?l0
0003ooZbJ0?onk=X00?o0000oo^cIook]6@00_ok]6@00ook/f7onk9Moo^aF002oo^aF0?onZiB00Co
0000oo2U;oo`YBool:D_0_oYVQl2olMm0003o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo0;[ooooo0_lc0?l>ooooo`;oo`001Oooool2oc<0o`03oooooolc0?oo<`3o00_ooooo0_oo
0002oc<0o`_ooooo0_lc0?l6ooooo`;o<`3o00?oo`00ooooooooool01_ooool2ool00003o`000?oo
oooooooo00Gooooo1_lc0?l00ooo003oooooooooo`07ooooo`?oo`004Oooool3ool001Gooooo00?o
0000onj`Roo^/8/01oo^/8/<oo2fT0com[F10ol00004ooRiPP;on[9X0ook/fP2o`0000?onkAT00?o
nk=Qoo^bGOok/Ud00_ok/EP3ooZ^DP03o`000?o`YBool:D_00;ol:D_00CojIXOolMm0?o7O@3o0000
?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0]oooool2oc<0o`gooooo0ooo0005ooooo`;o<`3o00?o
oooooc<0oolc0?l02_ooool3ool000;o<`3o2_ooool3oc<0o`Gooooo00Coo`00oc<0oolc0?ooo`00
1_ooool2o`0000;oo`001oooool3oc<0o`04ool00?lc0?oo<`3oool000Wooooo0ooo000Aooooo`?o
o`006?ooool00ol0003ok[2;onj`R`05onj`R`ool;J@2?of]H43o`000003ooJePOoh^H;on;V200Co
n;V200?on[9Xoo^cJ?ok/fP00_ok/fP00ol0003onk=Wo`000002oo^dI003oo^cHOok/Ugonk9M00;o
nk5H0ooj[U800oof/4;o0000oo2U;`02oo2U;`04onVJ7oo7O@3oagd0o`0003gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;Cooooo0_lc0?l=ooooo`;oo`001_ooool5oc<0o`Wooooo0ooo00000ooooooo
<`3ooc<0o`0:ooooo`;o<`3o1_ooool3oc<0o`;oo`001?ooool3o`0000;oo`001_ooool3oc<0o`04
ool00?lc0?oo<`3ooc<0o`[ooooo0_oo000Aooooo`?oo`006?ooool3ool00003o`000?o^/8_ok[2;
00?ok[2;4Oo`]Y05ooJeP@?o00000oof]H48ooRiPPConk=X0ol00002oo^dI0;onk=Q0_ok/Ud2oo^a
F0;onZiB00?om[12o`000?l000000oo`YBl00ooYVQooagd0o`00000nooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`2aooooo`;o<`3o3?ooool3ool000Oooooo0olc0?l:ooooo`;oo`000_ooool2oc<0o`Wo
oooo0olc0?l5ooooo`04ool00?lc0?oo<`3oooooo`;oo`000oooool3o`000003oooooooo003oo`00
00Kooooo0_lc0?l01?oooooo<`3ooc<0oolc0?l:ooooo`?oo`004?ooool3ool001Sooooo0ooo0003
ooooo`04ool00?l0003ok[2;onj`Ra?ol;J@0_of]H43o`0000Gom[F12Ooh^H82ool000;onk=X0_l0
00000ook/fOo0000oo^dI002oo^cH@;onk9M0_ok/EP2ooZ^DP03oc<0ool0003o000000Col:D_0_o7
O@000ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool001kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2^ooooo`;o<`3o3?ooool2
ool000Sooooo0olc0?l9ooooo`?oo`000_ooool2oc<0o`Wooooo0_lc0?l5ooooo`;oo`000_lc0?l0
0oooooooo`00ool00002ooooo`?o00000_ooool2ool000Gooooo0olc0?l00ooo003o<`3ooc<0o`0:
ooooo`?oo`003oooool01?lc0?ooo`00ool00?oo000Gooooo`Coo`000_ooool4ool00003ooooool0
003ol;J@01?ol;J@0ol00008ooJeP@Won;V200Gon[f2oo^cJ?ok/fSonk=Xo`000002oo^cI`04oo^d
I?l0003onkAToo^cH@;onk9M0ook/EP01?oj[U;om[12ooJ`@_l00004oo2U;`;oagd000?o0000oooo
ooooool0>oooool00ol0003oooooooooo`09ooooo`;o00008_ooool001kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`2[ooooo`;o<`3o2oooool3ool000Sooooo0olc0?l8ooooo`?o
o`000oooool2oc<0o`Sooooo0olc0?l4ooooo`;oo`000olc0?l2ooooo`03ool00?oooooo000000;o
00000oooool2ool000Cooooo0olc0?l01?oooooo<`3ooc<0oolc0?l:ooooo`;oo`003oooool4ool0
01Kooooo1?oo0003ooooo`?oo`0000?ooooooc<0oolc0?l00_lc0?l00ol0003ol;J@oo2fT00>oo2f
T0Co00000_o`]Y08ooJeP@[on;V200Gon[f2oo^cJ?ok/fSonk=Xo`000002oo^cI`;onkAT00?o0000
oo^cHOok/Ud00_ok/Ud2oo^aF005ooZ^D_of/4;om[12ooJ`@_l000000oo`YBl00ooHU@[oagd0o`00
000mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000008_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`2Xooooo`;o<`3o2oooool2ool000Wooooo0_lc0?l9
ooooo`;oo`001?ooool2oc<0o`Sooooo0_lc0?l5ooooo`;oo`000_lc0?l3ooooo`;oo`000_l00004
ooooo`;oo`000oooool3oc<0o`04oooooolc0?oo<`3ooc<0o`[ooooo0ooo000>ooooo`?oo`005_oo
ool4ool000?ooooo1?oo00000ooooooo<`3ooc<0o`04oc<0o`;ooooo00?o0000oo2fT?o`]Y002_o`
]Y03o`0000Kol;J@2?of]H49ooRiPP?on[f20_ok/fP00ol0003onk=Woo^cI`02oo^dI003o`000?ok
/f7onk=Q00;onk9M0ook/EP3ooJ`@P07o`000?o`YBool:D_oo2U;ooHU@[oagd0o`00000mooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool001gooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`2Tooooo`?o<`3o2_ooool3ool000Wooooo0_lc0?l8ooooo`?oo`00
0oooool3oc<0o`Oooooo0olc0?l4ooooo`?oo`000_lc0?l3ooooo`;oo`0000?o0000ooooooooool0
0oooool2ool000?ooooo0_lc0?l01Oooooooo`00oc<0oolc0?ooo`0000[ooooo0_oo000>ooooo`?o
o`005Oooool4ool000Cooooo0ooo00000ooooooo<`3ooc<0o`04oc<0o`Kooooo00?o0000oo2fT?o`
]Y001oo`]Y03o`0000[ol;J@1_of]H4:ooRiPPCon[f200Conk=Xo`000?ok/fOonk=W0ook]6@01?l0
003onk=Qoo^bGOok/Ud3oo^aF0Com[1200Co0000oo2U;oo`YBool:D_0_o7O@000ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool001gooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`2Qooooo`;o<`3o2oooool2ool000[ooooo0olc0?l7
ooooo`;oo`001?ooool2oc<0o`Sooooo0_lc0?l4ooooo`?oo`000olc0?l2ooooo`03o`000?oo003o
o`0000Kooooo0_oo0002ooooo`?o<`3o00Goo`00oc<0oolc0?oo<`3oool00009ooooo`?oo`003Ooo
ool3ool001Cooooo1?oo0005ooooo`?oo`001olc0?l9ooooo`03o`000?o`]Y3ol;J@00Col;J@0ol0
000=oo2fT0Gom[F12ooh^H84ooZmPP04oo^cJ?l0003onk=Woo^cI`ConkAT00Co0000oo^bGOok/Ugo
nk9M0_ok/EP01Ook^ECom[12ooJ`@_of/4;o000000?ol:D_00?of9D:olMm0?l00000??ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo000Mooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool0W_ooool2oc<0o`_ooooo0_oo0009ooooo`Co<`3o1_ooool3ool000Co
oooo0_lc0?l7ooooo`?o<`3o0oooool3ool00003oooooolc0?oo<`3o00;ooooo0_l00002ool000Ko
oooo0_oo00001Ooooooo<`3ooc<0oolc0?ooo`0000?o<`3o00?oo`00ooooooooool01oooool3ool0
00gooooo0ooo000Cooooo`Coo`001Oooool4ool000Ko<`3o3_ooool00ol0003ol;J@oo2fT003o`00
017ol;J@1?of]H4;ooRiPPGon[f200?o0000oo^cIook/fL01?ok]6@01?ok/f7o0000oo^bGOok/Ud2
oo^aF003oo^iE?of/4;om[1200;om[1200Ko0000oo2U;oo`YBoof9D:olMm0?l0000looooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool07oooool001gooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`2Kooooo`;o<`3o2_ooool3ool000Wooooo1?lc0?l5ooooo`?oo`001Ooo
ool2oc<0o`Oooooo0_lc0?l4ooooo`;oo`000_ooool2oc<0o`06ooooool0003o0000o`000?oooooo
o`001_ooool2ool000?o<`3o0_oo0002oc<0o`;oo`002Oooool2ool000gooooo0ooo000Cooooo`?o
o`001_ooool3ool000Oo<`3o4Oooool3o`0001Col;J@0oof]H4;ooRiPPKon[f200Co0000oo^cIook
/fOonk=W0ook]6@01Ook/f7o0000oo^bGOok/Ugonk5H00;onkUD1?of/4801_l0003ol:D_oo2U;ooH
U@[oagd0o`0003gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`007Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo09Sooooo0_lc0?l:ooooo`;oo`002_oo
ool2oc<0o`03oooooolc0?oooooo00Cooooo0_oo0006ooooo`;o<`3o1_ooool3oc<0o`?ooooo0ooo
00001?oooooo<`3ooc<0oolc0?l3o`0000;ooooo0_oo0005ooooo`;oo`000_lc0?l2ool000?o<`3o
0_oo0008ooooo`?oo`002oooool01?lc0?ooo`00ool00?oo000Booooo`Coo`001_ooool3ool000Ko
<`3o4Oooool00ooo003o0000o`000002o`0001Kol;J@0oof]H4;ooRiPPKon[f200Co0000ooc0Oook
/fOonk=W0ook]6@2oo^cH@03o`000?ok/Ugonk9M00?onkUD0oof/4800ol0003ol:D_oo2U;`02omRE
2P03olMm0?l0003ooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ooooo
o`007Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo09Gooooo0_lc0?l9ooooo`?o
o`002_ooool2oc<0o`03oooooolc0?oo<`3o00?ooooo0ooo0006ooooo`;o<`3o1_ooool2oc<0o`?o
oooo0ooo0002ooooo`;o<`3o0ol00003ooooo`;oo`001Oooool01Ooo003o<`3ooc<0oolc0?ooo`00
00?o<`3o0_oo0008ooooo`?oo`002oooool01?lc0?ooo`00ool00?oo000Aooooo`Coo`001_ooool4
ool000Ko<`3o3oooool3ool000?o00001?ooool00ol0003ol;J@oo2fT00Doo2fT003ooJePOoh^H;o
n;V200[on;V21_oj_H801?l0003oo<1oooc0Oook/fL3oo^dI0;onk=Q00?onk9Mo`000?ok/Ud00ook
^E@4ooJ`@P06o`000?o`YBool:D_omRE2_o7O@3o0000??ooool00ol0003oooooooooo`09ooooo`;o
00008Oooool001gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2Booooo`;o<`3o
2Oooool2ool000[ooooo0olc0?l00ooooooo<`3ooc<0o`03ooooo`;oo`001oooool2oc<0o`Gooooo
0olc0?l2ooooo`?oo`000oooool2oc<0o`;o00001?ooool2ool000Gooooo0olc0?l2ool000;o<`3o
00?oooooool00?oo00002?ooool2ool000_ooooo1?oo000@ooooo`Coo`001oooool3ool000;o<`3o
00Cooooooc<0oolc0?oo<`3o3_ooool5ool000?o00001oooool00ol0003ol;J@oo2fT00Doo2fT0co
n;V21ooj_H801?l0003oo<1oooc0Oool`7l4oo^dI0;onk=Q00?onk9Mo`000?ok^E@00_ok^E@4ooJ`
@P06o`000?o`YBool:D_omRE2_o7O@3o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo0000027ooooo000Mooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Soooool2
oc<0o`Sooooo0ooo000:ooooo`;o<`3o0_ooool2oc<0o`;ooooo0ooo0007ooooo`;o<`3o1Oooool2
oc<0o`?ooooo0_oo0003ooooo`04o`000?lc0?oo<`3oo`0000Kooooo00?oo`00ooooooooool00_oo
ool3oc<0o`;oo`000olc0?l00oooooooo`00ool00007ooooo`?oo`002_ooool3ool0013ooooo1?oo
0008ooooo`?oo`001_lc0?l<ooooo`Goo`001Ol00007ooooo`?oo`0000?o0000oo2fT?o`]Y005?o`
]Y000ooc_9Con;V2ooRiPP09ooRiPPKon[f20_l00003ooc0O`?ooL5i00KonkAToo^cHOok/f7onk9M
o`000?on_f@3oo^iE0Com[120_l00002omRE2P03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Nooooo`007?ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo08cooooo0_lc0?l8ooooo`;oo`002oooool2oc<0o`?ooooo00?o<`3ooooooooo0000
0_oo0008ooooo`;o<`3o1?ooool3oc<0o`;ooooo0ooo0002ooooo`04o`000?lc0?oo<`3ooc<0o`Oo
oooo0_oo0002ooooo`?o<`3o0_oo0003oc<0o`04oooooooo003oo`00ool000Kooooo0ooo000:oooo
o`?oo`003oooool4ool000Sooooo1?oo00000olc0?oooooooc<0o`02oc<0o`_ooooo1Ooo0002oooo
o`?o00002Oooool3ool000;ooooo0_lc0?l00ol0003ol;J@oo2fT00Boo2fT0;olkbD2ooh^H800ooo
003on[f2ooZmPP03ooZmPP;o00000ool`7l4oog1N@;oo/5a0_on_f@01?l0003onkUDoo^iE?ok^E@2
ooJ`@P04oc<0ooof/4;o0000o`0000;of9D:00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01kooooo000Looooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0ROooool2oc<0o`Oooooo0ooo000:ooooo`?o<`3o0oooool2oc<0o`;oo`002Oooool2
oc<0o`Cooooo0_lc0?l2ooooo`?oo`000_ooool2o`0000;o<`3o2?ooool2ool000;ooooo0_lc0?l2
ool00003oooooolc0?oo<`3o00;ooooo0_oo0007ooooo`;oo`002_ooool3ool000kooooo1?oo0009
ooooo`?oo`0000?o<`3ooooooolc0?l00olc0?l8ooooo`Koo`001?ooool3o`0000Sooooo1?oo0005
oc<0o`;ooooo00?o0000oo2fT?o`]Y004Oo`]Y04oo>lU0[on;V21_oj_H800ol0003oo<1oooc0O`02
ooc0O`CooL5i0_on`G43oojoI004o`000?ok^EConkUDoo^iE0Com[1200Go0000omRE2_oHU@[oagd0
o`00000kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool001cooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`26ooooo`;o<`3o1oooool2ool000_ooooo0_lc
0?l4ooooo`;o<`3o0_oo0009ooooo`;o<`3o0oooool3oc<0o`04oooooooo003oo`00ool000;ooooo
0ol00002oc<0o`Sooooo0_oo00001?oooooo<`3ooc<0oolc0?l2ool000?o<`3o0_ooool2ool000Ko
oooo0ooo0009ooooo`?oo`003_ooool3ool000[ooooo0ooo0002ooooo`?o<`3o1oooool5ool000Oo
oooo0ol00007ooooo`Coo`001?lc0?l3ooooo`Co<`3o00?o0000oo2fT?o`]Y004?o`]Y05oo>lU0Wo
n;V21ooj_H800ol0003oo<1oooc0O`02ooc0O`CooL5i0_on`G44oojoI003o`000?ok^EConkUD00Co
m[1200Go0000omRE2_oHU@[of9D:o`00000kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07_ooool001cooooo00?o0000ooooooooool0COooool2o`0008Cooooo0_lc0?l6ooooo`?o
o`002oooool2oc<0o`Cooooo0_lc0?l00ooo003oooooooooo`08ooooo`;o<`3o0oooool2oc<0o`;o
oooo0_oo0002ooooo`?o00000olc0?l9ooooo`04ool00?lc0?oo<`3ooc<0o`;oo`000olc0?l2oooo
o`?oo`001Oooool3ool000Wooooo0ooo000=ooooo`Coo`002Oooool4ool00003oooooolc0?oo<`3o
00;o<`3o1Oooool5ool000Wooooo0ol00007ooooo`?oo`001?lc0?l3ooooo`Co<`3o1Oooool00ol0
003ol;J@oo2fT00>oo2fT0OolkbD2?oh^H87ooZmPP03o`000?ol`7ooo<1o00;oo<1o1?om`GT3ook1
L@?oo[mT00?o0000oo^iE?ok^E@01Oof/4801?l0003of9D:omRE2_l0000looooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07_ooool001cooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`1oooooo`;o<`3o1_ooool2ool000cooooo0_lc0?l4ooooo`03ool00?lc0?oooooo
00[ooooo0_lc0?l2ooooo`?o<`3o00Goooooool00?oo003oo`00ooooo`03o`000003oooooolc0?oo
<`3o00[ooooo0olc0?l3ool000;o<`3o0oooool2ool000Kooooo0_oo0008ooooo`04oc<0oooo003o
o`00ool000cooooo1?oo0009ooooo`04oc<0oooo003oo`00ool000;ooooo0olc0?l4ooooo`Goo`00
2oooool3o`0000Kooooo1?oo0002oc<0o`Cooooo1?lc0?l9ooooo`03o`000?o`]Y3ol;J@00kol;J@
1ooc_9@8ooRiPPOon[f200?o0000ooc0Oool`7l00_ol`7l4oog1N@?oo/5a0oon_f@01?ok^ECo0000
oo^iE?ok^E@4ooJ`@P04o`000?oHU@[of9D:o`0003cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Nooooo`007?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo07_o
oooo0olc0?l5ooooo`?oo`002oooool3oc<0o`?ooooo0_oo0002oc<0o`[ooooo0_lc0?l2ooooo`;o
<`3o00Goooooool00?oo003oo`00ooooo`03o`0000;ooooo0_lc0?l:ooooo`;o<`3o0_oo00001?oo
oooo<`3ooc<0oolc0?l3ooooo`;oo`001Oooool3ool000Oooooo00Co<`3oool00?oo003oo`002ooo
ool4ool000[ooooo00Go<`3oool00?oo003oo`00ooooo`04oc<0o`;ooooo1Ooo000<ooooo`Co0000
1_ooool3ool000;o<`3o1?ooool4oc<0o`Kooooo1ooo00000ooooooo0000oo2fT00=oo2fT0WolkbD
1ooh^H87ooZmPP03o`000?ol`7ooo<1o00;oo<1o1Oom`GT2ook1L@?oo[mT0_ok^E@00ol0003onkUD
ooJ`@P04ooJ`@P03o`000?oHU@[o000003cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Nooooo`007?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo07Sooooo0_lc
0?l6ooooo`;oo`003?ooool2oc<0o`Cooooo0_oo0002oc<0o`[ooooo0_lc0?l01?oooooo<`3ooc<0
oolc0?l3ool00004ooooool0003o0000o`0000;ooooo0olc0?l9ooooo`?o<`3o00?oo`00oooooolc
0?l00_lc0?l4ooooo`;oo`001Oooool2ool000Oooooo1?oo000:ooooo`Coo`002_ooool00olc0?oo
o`00ool00002ool00005oooooolc0?oo<`3ooc<0ooooool01Ooo000>ooooo`?o00001_ooool4ool0
00Gooooo1?lc0?l2ooooo`Soo`002?ooool00ol0003ol;J@oo2fT00;oo2fT0[olkbD1_oh^H88ooZm
PP03o`000?ol`7ooo<1o00;oo<1o1Oom`GT2ook1L@Coo[mT0_ok^E@00ol0003om[12ooJ`@P03ooJ`
@P04o`000?oHU@[of9D:o`0003_ooooo00?o0000ooooooooool02Oooool2o`00023ooooo000Loooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0MOooool2oc<0o`Gooooo0ooo000<oooo
o`;o<`3o0oooool3ool000;o<`3o2_ooool2oc<0o`04oooooolc0?oo<`3oooooo`;oo`0000Cooooo
o`000?l0003o00000oooool2oc<0o`Wooooo0olc0?l00ooo003oooooooooo`02oc<0o`04ool00?oo
ooooooooooooo`?oo`001?ooool3ool000Kooooo0ooo000:ooooo`Coo`002_ooool2oc<0o`?oo`00
00Cooooooc<0oolc0?oo<`3o1Ooo000@ooooo`?o00001?ooool00olc0?ooo`00ool00002ool000Go
oooo0olc0?l7ool0013ooooo00?o0000oo2fT?o`]Y002_o`]Y0<oo>lU0Gon;V22?oj_H800ol0003o
o<1oooc0O`02ooc0O`GooL5i0_on`G44oojoI0;onkUD00?o0000oo^iE?of/4800oof/4801?l0003o
f9D:omRE2_l0000kooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00007oooool0
01cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1booooo`;o<`3o1Oooool2ool0
00gooooo0_lc0?l2ooooo`?oo`000_ooool00olc0?ooooooooooo`08ooooo`Go<`3o0ooo0003o`00
00Cooooo0_lc0?l8ooooo`?o<`3o0ooo0003oc<0o`04ool00?ooooooooooooooo`;oo`001?ooool3
ool000Kooooo0ooo0009ooooo`Coo`002_ooool3oc<0o`?oo`0000?ooooooc<0oooo00001?oo000B
ooooo`?o00000oooool2oc<0o`?oo`001Oooool7ool001Sooooo00?o0000oo2fT?o`]Y002?o`]Y0=
oo>lU0Gon;V22?oj_H800ol0003oo<1oooc0O`02ooc0O`GooL5i0oon`G43oojoI0?onkUD00?o0000
ooJ`@_of/4800_of/4801?oY[Bgo0000omRE2_l0000kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool2o`0001Gooooo000Kooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0Koooool2oc<0o`Cooooo0ooo000<ooooo`?o<`3o0_ooool2ool000?ooooo0_lc0?l9
ooooo`Co<`3o0ooo0003o`0000Cooooo0olc0?l8ooooo`;o<`3o00?oo`00oooooooo00000olc0?l2
ool000?ooooo0_oo0004ooooo`;oo`001_ooool3ool000Wooooo0ooo000;ooooo`;o<`3o2Ooo000D
ooooo`?o000000Cooooooc<0oolc0?oo<`3o1?oo00000oooooooo`00ool00005ool001cooooo0ooo
00000ol0003ol;J@oo2fT008oo2fT0kolkbD0ooh^H89ooZmPP03o`000?ol`7ooo<1o00;oo<1o1Oom
`GT3ook1L@?oo[mT1?ok^E@02?l0003om[12ooJ`@_of/4;ojJd]o`000?oHU@[o0000>oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00005?ooool0
01_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`1/ooooo`;o<`3o1?ooool2ool0
00gooooo0_lc0?l2ooooo`?oo`000oooool2oc<0o`Wooooo1?lc0?l2ool000?o00001Oooool2oc<0
o`Sooooo0olc0?l2ooooo`04ool00?lc0?oo<`3oooooo`;oo`000_ooool3ool000?ooooo0ooo0005
ooooo`?oo`002?ooool4ool000[ooooo0olc0?l7ool001Kooooo0ol00004oc<0o`Soo`000olc0?lL
ooooo`Coo`0000Cooooooc<0oolc0?oo00002Oo`]Y0?oo>lU0?on;V22Ooj_H800ol0003oo<1oooc0
O`02ooc0O`GooL5i0oon`G44oojoI0ConkUD00Oo0000ooJ`@_of/4;ojJd]o`000?oHU@[o000003_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
01Cooooo000Kooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0JOooool2oc<0o`?o
oooo0ooo000=ooooo`;o<`3o0_ooool2ool000Cooooo0_lc0?l9ooooo`?o<`3o0ooo0002o`0000Ko
oooo0_lc0?l7ooooo`?o<`3o0oooool3oc<0o`03oooooooo003oo`0000;ooooo0_oo0003ooooo`?o
o`001?ooool01?lc0?ooo`00ool00?oo0007ooooo`Coo`002_ooool4oc<0o`Goo`000_lc0?lEoooo
o`Co00001ooo0003ooooo`Co<`3o7?ooool4ool000Go<`3o0oooool00ol0003ol;J@oo2fT005oo2f
T17olkbD0_oh^H88ooZmPP03o`000?ol`7ooo<1o00?oo<1o1Oom`GT3ook1L@Coo[mT1?ok^E@01?l0
003om[12ooJ`@_oY[Bd3o`0003_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`04o`000?ooooooooooo`0001Cooooo000Kooooo`03o`000?oooooooooo05Sooooo00?o0000
ooooooooool0I_ooool2oc<0o`?ooooo0_oo000=ooooo`?o<`3o00Coooooool00?oo003oo`001Ooo
ool00olc0?ooooooooooo`07ooooo`;o<`3o0ooo00000ol0003oooooooooo`05ooooo`?o<`3o1_oo
ool3oc<0o`?ooooo0olc0?l01?oo003oooooool00?oo0002ooooo`;oo`000oooool2ool000Cooooo
00Co<`3oool00?oo003oo`001_ooool4ool000_ooooo0_lc0?l5ool000?o<`3o5_ooool:ool000?o
oooo1?lc0?lLooooo`Coo`000olc0?l7ooooo`;o<`3o00?o0000oo2fT?o`]Y001?o`]Y0Boo>lU0;o
n;V22?oj_H82o`0000Coo<1o1Oom`GT3ook1L@Coo[mT1Ook^E@00ol0003om[12onV];@02o`000003
omRE2_l0003ooooo03[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0001Cooooo000Kooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool0Hoooool2oc<0o`;ooooo0ooo000=ooooo`;o<`3o00Coooooool00?oo003oo`001_ooool2oc<0
o`Oooooo0olc0?l2ool00003o`000?oooooooooo00Kooooo0_lc0?l6ooooo`?o<`3o1?ooool2oc<0
o`;oo`0000?oooooool00?oo00000_ooool2ool000;ooooo0ooo0003ooooo`Coo`001Oooool4ool0
00_ooooo1ooo0004oc<0oa7ooooo2?oo00000olc0?ooooooooooo`03ool000?ooooo1?lc0?lLoooo
o`Coo`0000?o<`3oooooooooool01oooool4oc<0o`;ooooo00?o0000oo2fT?o`]Y000oo`]Y0Doo>l
U003ool00?oj_H;on[f200Kon[f20_l00004ooc0O`GooL5i1?on`G44oojoI0ConkUD00Oom[12o`00
0?oY[BgojJd]o`000?oHU@[o000003_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0001Cooooo000Kooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool0H?ooool2oc<0o`;ooooo0_oo000>ooooo`;o<`3o00?oooooool00?oo00001ooo
ool2oc<0o`Oooooo0olc0?l00ooo003o0000ooooo`08ooooo`;o<`3o1Oooool00ooo003o<`3ooc<0
o`04ooooo`?o<`3o0_oo00001?ooooooo`00ool00?ooool3ool00004oooooooo003oo`00ool000?o
oooo0ooo0005ooooo`Coo`002_ooool5ool00004oooooooo003oo`00ool000?o<`3o3_ooool7ool0
00;o<`3o0ol00002ooooo`Coo`000_ooool4oc<0oa[ooooo0_lc0?l4ool000Wooooo1Olc0?l7oooo
o`03o`000?o`]Y3ol;J@00;ol;J@5?oc_9@00ooo003on[f2ooZmPP06ooZmPP03o`000?ol`7ooo<1o
00?oo<1o1_om`GT3ook1L@Coo[mT1?ok^E@2ooJ`@P05o`000?oY[Bgo0000omRE2_l00000>oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l0000Eooooo`006oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo05gooooo0_lc0?l01?ooooooo`00ool00?oo000>
ooooo`;o<`3o0ooo0007ooooo`;o<`3o1_ooool4oc<0o`03ool00?oooooooooo00Oooooo0olc0?l4
ooooo`04ool00?lc0?oo<`3ooc<0o`?ooooo0olc0?l01?ooooooo`00ool00?ooool2ool00003oooo
oooo003oo`0000;ooooo0_oo0003ooooo`?oo`001?ooool4ool000Wooooo1Ooo00000olc0?oooooo
ool00003ool000?o<`3o2_ooool7ool000;ooooo1?lc0?l3o`000003oooooooo003oo`0000;oo`00
0_ooool4oc<0oaWooooo0olc0?l4ool000Wooooo1?lc0?l00oooooooo`00ool00009ool00004o`00
0?o`]Y3ol;J@oo2fT1GolkbD00?oml>DooZmP_oj_H801_oj_H800ol0003oo<1oooc0O`03ooc0O`Ko
oL5i0oon`G44oojoI0GonkUD00Com[12o`000?oY[BgojJd]0_l0000kooooo`03o`000?oooooooooo
00Wooooo0_l0000Oooooo`006oooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo05[o
oooo0_lc0?l00oooooooo`00ool0000>ooooo`?o<`3o0_oo0009ooooo`03oc<0oooooooooooo00Co
oooo1?lc0?l:ooooo`;o<`3o1Oooool3oc<0o`Cooooo0_lc0?l3ooooo`05ool00?ooooooo`00ool0
0?ooool00_oo00001?ooooooo`00ool00?oo0002ooooo`?oo`001?ooool3ool000Sooooo1Ooo0002
oc<0o`;ooooo0ooo0003oc<0o`Kooooo2?oo0005ooooo`Co<`3o00Goooooo`000?l0003o0000oooo
o`03ool000;ooooo1?lc0?lGooooo`Go<`3o1?oo0004ooooo`koo`002oooool00ol0003ol;J@oo2f
T00Eoo>lU0?oml>D1ooj_H800ol0003oo<1oooc0O`03ooc0O`KooL5i0oon`G44oojoI0GonkUD00Co
m[12onV];Ol0003ojJd]0_l0000kooooo`03o`000?oooooooooo00Oooooo0_l00002ooooo`03o`00
0?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0Eooo
ool2oc<0o`?oo`003_ooool2oc<0o`;oo`002_ooool2oc<0o`Cooooo1Olc0?l:ooooo`;o<`3o1?oo
ool3oc<0o`Cooooo0olc0?l3ooooo`[oo`000_ooool3ool000?ooooo1?oo0006ooooo`Goo`001?lc
0?l2ooooo`?oo`000_lc0?l3ooooo`Ooo`002?ooool5oc<0o`03ooooool0003o000000;o00001?oo
00000ooooooo<`3ooc<0o`02oc<0oaKooooo1?lc0?l>ool000Co<`3o5_ooool00ol0003olkbDoo>l
U00Doo>lU0?oml>D1ooj_H800ol0003oo<1oooc0O`04ooc0O`GooL5i0oon`G45oojoI0ConkUD00?o
m[12onV];OoY[Bd00ol0000kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?oo
ool001[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Cooooo`?o<`3o0_oo000?
ooooo`;o<`3o0_oo000:ooooo`;o<`3o1?ooool2oc<0o`03ool00?lc0?oo<`3o00[ooooo0_lc0?l3
ooooo`03ool00?lc0?oo<`3o00Cooooo0olc0?l4ooooo`Koo`0000Goooooool00?oo003ooooooc<0
o`03ool000;ooooo1?oo0005ooooo`Goo`0000?ooooooc<0oolc0?l00_lc0?l2ooooo`Coo`0000?o
<`3oool00?oo00001Ooo000;ooooo`Co<`3o0oooool3o`000005oooooooo003oo`00ool00?ooool0
1?lc0?l?oooooa7oo`001oooool5oc<0oa[ooooo00?o0000oo>lU?oc_9@05?oc_9@4ooO3U0Kon[f2
00?o0000ooc0Oool`7l01?ol`7l5oog1N@Coo/5a1?on_f@5oo^iE0?ojJd]0ol0000jooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1@ooooo`;o<`3o0ooo000?ooooo`;o<`3o00?oo`00ooooooooool02Ooo
ool2oc<0o`?ooooo0olc0?l00ooo003o<`3ooc<0o`09ooooo`?o<`3o0_ooool01?oo003o<`3ooc<0
oolc0?l4ooooo`;o<`3o1Oooool9ool00005oc<0oooo003oo`00ool00?ooool01?oo0004ooooo`Go
o`000oooool3oc<0o`?ooooo2?oo000=ooooo`Go<`3o1?ooool3o`0000Coo`001?lc0?l5ooooo`ko
o`001Olc0?l5ooooo`?oo`001oooool4oc<0ob3ooooo00?o0000oo>lU?oc_9@04_oc_9@5ooO3U0Ko
n[f200?o0000ooc0Oool`7l01?ol`7l5oog1N@Coo/5a1?on_f@5oo^iE0?ojJd]0ol0000jooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool0
HOooool00ol0003oooooooooo`1=ooooo`;o<`3o0_oo000?ooooo`?o<`3o00?oo`00ooooooooool0
2_ooool01?lc0?ooooooooooool00002oc<0o`04ool00?oooooo<`3ooc<0o`Wooooo0_lc0?l2oooo
o`04ool00?lc0?oo<`3ooc<0o`Cooooo0olc0?l6ooooo`Ooo`0000?o<`3oool00?oo00001Ooo0003
ooooo`Goo`001?ooool3oc<0o`Ooo`000_lc0?l?ooooo`Co<`3o1_ooool2o`00017oo`002?ooool6
oc<0o`Kooooo1?oo0005ooooo`Go<`3o7oooool5ool00003o`000?oc_9ColkbD01;olkbD1_og`i@5
ooZmPP03o`000?ol`7ooo<1o00Coo<1o1Oom`GT4ook1L@Coo[mT1Ook^E@4onV];@;o0000>oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0B_ooool2oc<0o`;oo`003oooool2oc<0o`03ool00?oooooooooo
00_ooooo0_lc0?l01?l0003o<`3ooc<0oolc0?l2ooooo`;o<`3o2Oooool2oc<0o`03oooooooo003o
<`3o00;o<`3o1?ooool3oc<0o`Oooooo3Ooo0002ooooo`Goo`001Oooool:ool000;o<`3o3_ooool5
oc<0o`ooo`0000?o<`3oooooooooool03Oooool6oc<0o`Sooooo1?oo0004ooooo`Go<`3o7_ooool2
oc<0o`Coo`0000?o<`3oooooooooool00oooool00ol0003olkbDoo>lU00@oo>lU0Soml>D1?oj_H80
0ol0003oo<1oooc0O`04ooc0O`GooL5i1?on`G45oojoI0ConkUD00Comkm?onV];OoY[BgojJd]0_l0
000kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`17ooooo`;o<`3o00?oo`00ooooooooool03_ooool2
oc<0o`kooooo0_lc0?l00ol0003o<`3ooc<0o`03ooooo`;o<`3o2?ooool3oc<0o`;oo`000_lc0?l5
ooooo`;o<`3o2?ooool;ool00003oooooooo003oo`0000?oo`000oooool7ool000Cooooo0ooo0002
oc<0o`Sooooo3_oo0004ooooo`03o`000?oo003oo`0000;oo`000olc0?l>ooooo`Go<`3o2_ooool4
ool000Cooooo1?lc0?lLooooo`Go<`3o1?oo000:ooooo`03o`000?oc_9ColkbD013olkbD2?og`i@3
ooZmPP03o`000?ol`7ooo<1o00Goo<1o1Oom`GT4ook1L@Goo[mT1?ok^E@00oog_doojJd]onV];@02
onV];@;o0000>_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Joooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0A?ooool2oc<0o`03ool00?oooooooooo
00gooooo0olc0?l>ooooo`Go<`3o0oooool2oc<0o`Sooooo0_lc0?l2ool000?o<`3o1?ooool3oc<0
o`Sooooo5_oo0004oc<0o`?ooooo4Ooo00000ooooooo<`3ooc<0o`02oc<0o`Wooooo00?o0000ool0
0?oo00000_oo0003oc<0o`cooooo1_lc0?l;ooooo`Coo`000oooool5oc<0oaWooooo1olc0?l00ooo
ooooo`00ool00002ool000_ooooo1?lc0?l00ol0003olkbDoo>lU00>oo>lU0[oml>D0_oj_H800ol0
003oo<1oooc0O`05ooc0O`GooL5i1Oon`G44oojoI0?onkUD0_og_dl4onV];@;o0000>_ooool00ol0
003oooooooooo`0:ooooo`;o00007Oooool001[ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`11ooooo`;o<`3o4?ooool2oc<0o`gooooo0ol00003oc<0o`Cooooo0_lc0?l8ooooo`;o
<`3o00Coo`00oc<0oolc0?oo<`3o1?ooool3oc<0o`[ooooo3ooo0003ooooo`ooo`002_ooool5oc<0
o`[ooooo00Co0000ool00?oo003oo`000olc0?l;ooooo`Go<`3o3Oooool4ool000?ooooo1?lc0?lF
ooooo`So<`3o0oooool5ool000[ooooo1Olc0?l4ooooo`03o`000?oc_9ColkbD00kolkbD2_og`i@2
ooZmPP03o`000?ol`7ooo<1o00Goo<1o1_om`GT4ook1L@Goo[mT0_ok^E@2ooNoC`CojJd]0ol0000i
ooooo`03o`000?oooooooooo00Sooooo0_l000000ooooooo0000ooooo`0Looooo`006_ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooooooo03gooooo00?oo`00oc<0oolc0?l03oooool00ooo
003o<`3ooc<0o`0<ooooo`?o000000Coo`00oc<0oolc0?oo<`3o1?ooool2oc<0o`Oooooo1_lc0?l5
ooooo`;o<`3o2ooooolDool00003oc<0oooooooooooo00?ooooo0ooo00000olc0?ooooooooooo`09
ooooo`Co<`3o3?ooool4ool000;o<`3o2Oooool6oc<0o`kooooo1?oo0002ooooo`Go<`3o4oooool7
oc<0o`Oooooo1?oo000:ooooo`Go<`3o2_ooool00ol0003olkbDoo>lU00=oo>lU0_oml>D00?on[f2
o`000?ol`7l01_ol`7l6oog1N@Coo/5a1Oon_f@2oo^iE0;omkm?1OoY[Bd00ol0003oooooo`00000h
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool001Wooooo00?o0000oooo
ooooool0J?ooool2o`0003_ooooo00?oo`00oc<0oolc0?l03_ooool2ool000;o<`3o2oooool3o`00
0004oooooooo003o<`3ooc<0o`Gooooo0_lc0?l7ooooo`Go<`3o1Oooool3oc<0o`[ooooo00?o<`3o
ool00?oo00001_oo0008ooooo`?o<`3o1Oooool4ool00003oc<0oooooooooooo00Oooooo1Olc0?l=
ooooo`?oo`000_lc0?l8ooooo`Go<`3o4?ooool4ool000;ooooo1?lc0?lAooooo`Oo<`3o2_ooool4
ool000Wooooo1Olc0?l?ooooo`03o`000?oc_9ColkbD00colkbD3Oog`i@00ol0003oo<1oooc0O`05
ooc0O`KooL5i1?on`G45oojoI0;onkUD0oog_dl4onV];@04o`000?ooooooooooo`0003Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Kooooo`006Oooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo03Gooooo0_oo0002oc<0o`kooooo00Coo`00oc<0oolc0?oo<`3o2_oo
ool3o`000003oooooooo003o<`3o00;o<`3o1Oooool2oc<0o`Kooooo00?oo`00oc<0oolc0?l00_lc
0?l5ooooo`?o<`3o2_ooool01?lc0?ooo`00ool00?oo000<ooooo`Co<`3o1Oooool3ool00003oc<0
oooooooooooo00Oooooo1?lc0?l>ooooo`Coo`0000?o<`3oooooooooool01?ooool6oc<0oa7ooooo
1?oo00000ooooooo<`3ooc<0o`03oc<0o`kooooo1olc0?l=ooooo`Coo`002?ooool5oc<0oaGooooo
00?o0000oo>lU?oc_9@02ooc_9@=ooO3U003o`000?ol`7ooo<1o00Goo<1o1_om`GT4ook1L@Goo[mT
0_ok^E@3ooNoC`CojJd]00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01_ooooo000Iooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
<_ooool2ool000;o<`3o3Oooool2ool000;o<`3o2_ooool3o`000003oooooooo003oo`0000?o<`3o
1Oooool2oc<0o`Kooooo1Olc0?l5ooooo`;o<`3o2_ooool01?lc0?ooo`00ool00?oo000;ooooo`Co
<`3o1_ooool3ool00003oc<0oooooooooooo00Gooooo1Olc0?l>ooooo`Coo`0000?o0000oooooooo
ool00_ooool6oc<0oa?ooooo1?oo00000ooooooo<`3ooc<0o`02oc<0o`_ooooo2?lc0?l?ooooo`Go
o`001_ooool6oc<0oa[ooooo00?o0000oo>lU?oc_9@02_oc_9@>ooO3U003o`000?ojb97oo<1o00Go
o<1o1_om`GT5ook1L@Goo[mT1?og_dl4onV];@05o`000?ooooooooooooooool00000=oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo000Iooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool0;_ooool3ool000;o<`3o3?ooool3ool000;o<`3o2Oooool3o`000003
oooooooo003oo`0000Go<`3o1?ooool2oc<0o`Gooooo00?oo`00oc<0oolc0?l00_lc0?l5ooooo`?o
<`3o2Oooool4ool000_ooooo0olc0?l6ooooo`Coo`001oooool4oc<0oa3ooooo0ooo0002o`0000;o
oooo1Olc0?lEooooo`Coo`001Olc0?l8ooooo`Oo<`3o4oooool4ool000Kooooo1Olc0?lQooooo`03
o`000?oc_9ColkbD00WolkbD3Oog`i@01?l0003on/RAoo[8TOojb945ooc0O`KooL5i1Oon`G45oojo
I0Comkm?1?oY[Bd00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Kooooo`006Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo02_ooooo0_oo00000ooooooo<`3ooc<0o`0<ooooo`;oo`0000?ooooooc<0oolc
0?l02?ooool3o`0000;ooooo0_oo0002oc<0o`03oooooolc0?oo<`3o00Cooooo0_lc0?l4ooooo`;o
o`000olc0?l5ooooo`?o<`3o2Oooool3ool000_ooooo1?lc0?l6ooooo`?oo`0000?o<`3ooooooooo
ool00oooool5oc<0oa3ooooo1?oo00000ol0003o<`3ooc<0o`04oc<0oaOooooo0ooo0004oc<0o`Ko
oooo1olc0?lFooooo`Coo`001Oooool5oc<0obKooooo00?o0000oo>lU?oc_9@02Ooc_9@=ooO3U003
o`000?ojb97on/RA00;on/RA1?ol`7l6oog1N@Goo/5a1Oon_f@4ooNoC`CojJd]00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06oooool001Wooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Wooooo`?oo`00
00?ooooooc<0oolc0?l02oooool3ool000?o<`3o1oooool3o`0000;ooooo0_oo0003oc<0o`03oooo
oolc0?oo<`3o00Cooooo0_lc0?l3ooooo`;oo`000olc0?l6ooooo`;o<`3o2Oooool3ool000[ooooo
1?lc0?l7ooooo`?oo`001Oooool4oc<0oa7ooooo1?oo0002o`0000?o<`3o6Oooool4ool000?o<`3o
0oooool7oc<0oaWooooo1?oo0004ooooo`Go<`3o:oooool00ol0003olkbDoo>lU008oo>lU0koml>D
00?o0000oo[8TOojb9400oojb943ooc0O`KooL5i1Oon`G45oojoI0Gomkm?0ooY[Bd00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Kooooo`006Oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo02Cooooo0_oo
00001?oooooo<`3ooc<0oolc0?l;ooooo`;oo`0000?ooooooc<0oolc0?l01oooool3o`0000;ooooo
0ooo0002oc<0o`;ooooo0_lc0?l4ooooo`;o<`3o0_ooool3ool000?o<`3o1Oooool3oc<0o`Sooooo
0ooo0009ooooo`Co<`3o1oooool4ool000?ooooo1Olc0?lAooooo`04oc<0oooo003oo`00ool000?o
000000?o<`3oooooooooool06?ooool4ool000[o<`3o6oooool5ool000?ooooo1Olc0?laooooo`03
o`000?oc_9ColkbD00OolkbD3_og`i@00ol0003on/RAoo[8T@04oo[8T@;oo<1o1_om`GT5ook1L@Co
o[mT00?oo/UZooNoCoog_dl00oog_dl3onV];@03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0:ooooo`;o00007?ooool001Wooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0Pooooo`?oo`0000?ooooooc<0oolc0?l02oooool3ool00003oooo
oolc0?oo<`3o00Kooooo0ol00002ooooo`?oo`000olc0?l3ooooo`03oc<0oooooooooooo00;ooooo
0_lc0?l01?ooooooo`00ool00?oo0003oc<0o`Gooooo0olc0?l7ooooo`04oc<0oooo003oo`00ool0
00Wooooo0olc0?l8ooooo`?oo`000oooool4oc<0oa;ooooo00?o<`3oool00?oo00000_oo0003o`00
01[ooooo1?oo0006oc<0oaoooooo1?oo0003ooooo`Go<`3o=_ooool00ol0003olkbDoo>lU006oo>l
U0koml>D00?o0000oo[8TOojb9401_ojb9400ool`7oooL5ioog1N@05oog1N@Goo/5a0_on_f@3ook9
JPComkm?0ooY[Bd00ol0003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooo`00000Looooo`006Oooool00ol0003oooooooooo`0cooooo`Ko
0000>?ooool00ol0003oooooooooo`0Mooooo`;oo`000_ooool2oc<0o`[ooooo0ooo00001?oooooo
<`3ooc<0oolc0?l5ooooo`?o00000oooool2ool00003oooooolc0?oo<`3o00Cooooo0_lc0?l3oooo
o`;o<`3o0ooo0004oc<0o`Gooooo0_lc0?l7ooooo`04oc<0oooo003oo`00ool000Sooooo1?lc0?l7
ooooo`05oc<0oooo003oo`00ool00?ooool01Olc0?lAooooo`?o<`3o0ooo00001?oooooo0000o`00
0?l0000Iooooo`Coo`000olc0?lRooooo`Coo`0000?ooooooc<0oolc0?l01?lc0?llooooo`03o`00
0?oc_9ColkbD00GolkbD3_og`i@00ol0003on/RAoo[8T@07oo[8T@OooL5i1Oon`G42oojoI0?oo/UZ
1?og_dl3onV];@03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo000Hooooo`03o`000?oooooooooo033ooooo1?l0
0006oo2_QP?o0000=_ooool00ol0003oooooooooo`0Iooooo`?oo`000_ooool2oc<0o`[ooooo0_oo
0002ooooo`;o<`3o1Oooool3o`0000?ooooo0ooo0003oc<0o`Cooooo0_lc0?l3ooooo`;o<`3o0_oo
00001?oooooo<`3ooc<0oolc0?l5ooooo`?o<`3o1_ooool01?lc0?ooo`00ool00?oo0007ooooo`Co
<`3o2?ooool4ool000Co<`3o4?ooool5oc<0o`Coo`001?l0000Dooooo`Co<`3o1?oo00000olc0?oo
ooooooooo`0Qooooo`Goo`001Olc0?m2ooooo`03o`000?oc_9ColkbD00GolkbD3_og`i@00ol0003o
n/RAoo[8T@07oo[8T@;ooLb;1Oom`GT5ook1L@03oojoI?onbF[oo/UZ00;oo/UZ1Oog_dl2onV];@03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01[ooooo000Hooooo`03o`000?oooooooooo02oooooo00?o0000oo2_Q_o`[hH0
2oo`[hH3o`0003Cooooo00?o0000ooooooooool05_ooool2ool000?ooooo0_lc0?l9ooooo`?oo`00
0_ooool2oc<0o`?ooooo1?l00003ooooo`?oo`0000?ooooooc<0oolc0?l01Oooool2oc<0o`?ooooo
0_lc0?l00ooo003ooooooc<0o`03oc<0o`Cooooo0olc0?l6ooooo`04oc<0oooo003oo`00ool000Oo
oooo0olc0?l8ooooo`04oc<0oooo003oo`00ool000Co<`3o3oooool6oc<0o`Coo`0000Coooooo`00
0?l0003o00004Oooool7oc<0o`Coo`009?ooool4ool000Go<`3oB?ooool00ol0003olkbDoo>lU003
oo>lU0ooml>D00?o0000oo[8TOojb9401oojb945oog<R`;ooL5i1?on`G400ooocGkoo/UZook9JP03
ook9JPGomkm?0_oY[Bd00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`0^oooo
o`03o`000?o`[hKol:n600ool:n600?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Boooo
o`?oo`000oooool2oc<0o`Wooooo0_oo0003ooooo`;o<`3o0_ooool3o`0000Gooooo0_oo00001?oo
oooo<`3ooc<0oolc0?l6ooooo`04oc<0ooooooooooooool000;o<`3o00?ooooooc<0oolc0?l00olc
0?l4ooooo`;o<`3o1_ooool4ool000Kooooo1?lc0?l8ooooo`04oc<0oooo003oo`00ool000;o<`3o
3_ooool6oc<0o`03oooooolc0?oo<`3o00?oo`000_ooool3o`0000gooooo1olc0?l2ooooo`03oc<0
oooo003oo`0000;oo`009?ooool4ool000Co<`3oCOooool00ol0003olkbDoo>lU003oo>lU0ooml>D
00?o0000oo[8TOojb9401oojb947oog<R`03ook1LOoocGkoolen00;oolen1OonbFX5ooNoC`;ojJd]
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool0;Oooool00ol0003ol:n6oo2_
QP0Aoo2_QP03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool2ool000Cooooo0_lc
0?l8ooooo`?oo`000_ooool3oc<0o`04ooooool0003o0000o`0000Gooooo0ooo00000ooooooo<`3o
oc<0o`07ooooo`;o<`3o0_oo0008oc<0o`?ooooo0olc0?l5ooooo`?oo`001_ooool4oc<0o`Sooooo
00?o<`3oool00?oo00000_oo00000olc0?ooooooooooo`0;ooooo`Go<`3o0oooool2oc<0o`Coo`00
0_ooool3o`0000Wooooo1olc0?l4ooooo`;o<`3o1?oo000Tooooo`Coo`000olc0?mCooooo`04o`00
0?oc_9ColkbDoo>lU0ooml>D00?o0000oo[8TOojb9402?ojb947oog<R`Goolen1OonbFX5ooNoC`;o
jJd]00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool0;?ooool00ol0003ol:n6
oo2_QP0Coo2_QP03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool3ool000Cooooo
0_lc0?l7ooooo`?oo`000oooool2oc<0o`04ooooool0003o0000o`0000Gooooo0ooo00001?oooooo
<`3ooc<0oolc0?l7ooooo`;o<`3o0_oo0004oc<0o`03oooooolc0?oo<`3o00?ooooo0olc0?l5oooo
o`?oo`001Oooool4oc<0o`Wooooo00Co<`3oool00?oo003oo`003?ooool6oc<0o`Cooooo0_lc0?l4
ool000?ooooo0ol00004ooooo`So<`3o1oooool2oc<0o`Coo`008oooool5ool000;o<`3oF?ooool0
1?l0003olkbDoo>lU?oc_9@?ooO3U003o`000?ojb97on/RA00Son/RA1oomc8/5ooo=OPGoo/UZ1Oog
_dl2onV];@03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01[ooooo000Hooooo`03o`000?oooooooooo02_ooooo00?o0000
oo2_Q_o`[hH05Oo`[hH00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo0_oo0005
ooooo`;o<`3o1oooool2ool000Cooooo0_lc0?l3o`0000Gooooo0ooo0002ooooo`;o<`3o2?ooool2
oc<0o`03ool00?oooooo<`3o00;o<`3o0_ooool2oc<0o`?ooooo0_lc0?l4ooooo`04oc<0oooo003o
o`00ool000Gooooo0olc0?l8ooooo`?o<`3o0ooo000:ooooo`Go<`3o1_ooool3oc<0o`?oo`001?oo
ool3o`0000Oo<`3o2_ooool3oc<0o`Coo`008oooool4ool00003oc<0oooooooooooo05gooooo00?o
0000oo>lU?og`i@03oog`i@00ol0003on/RAoo[8T@08oo[8T@OooLb;1OoocGh6ook9JPGomkm?00?o
jJd]o`000?ooool02oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06_ooool001Sooooo00?o0000ooooooooool0:oooool00ol0003ol:n6oo2_QP0F
oo2_QP03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool3ool000Gooooo0_lc0?l6
ooooo`?oo`001?ooool2oc<0o`;o00001_ooool2ool000;ooooo0olc0?l8ooooo`04ool00?lc0?oo
ooooooooo`?o<`3o00Cooooooc<0oolc0?oo<`3o0_ooool3oc<0o`?ooooo00Co<`3oool00?oo003o
o`001?ooool4oc<0o`Oooooo0olc0?l4ool000Oooooo1_lc0?l7ooooo`?o<`3o1?oo0003ooooo`Co
00000olc0?l=ooooo`?o<`3o1?oo000Rooooo`03oc<0oooo003oo`0000;oo`00I?ooool00ol0003o
lkbDooO3U00?ooO3U003o`000?ojb97on/RA00Oon/RA2?omc8/6ooo=OPGoo/UZ1Oog_dl00ooY[Bgo
0000ooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02_ooool2o`0001_o
oooo000Hooooo`03o`000?oooooooooo02[ooooo00?o0000oo2_Q_o`[hH06?o`[hH00ol0003ooooo
ooooo`0booooo`04o`000?ooooooooooooooo`;oo`001_ooool2oc<0o`Kooooo0_oo0004ooooo`?o
<`3o00?o0000ooooooooool01?ooool3ool000;ooooo0_lc0?l8ooooo`;oo`001Olc0?l2ooooo`;o
<`3o0_ooool3oc<0o`?ooooo00Co<`3oool00?oo003oo`000oooool4oc<0o`Kooooo1Olc0?l3ool0
00Kooooo1Olc0?l9ooooo`Co<`3o0ooo0004oc<0o`?o00003oooool5oc<0o`?oo`008Oooool2oc<0
o`Coo`00JOooool00ol0003oml>DooO3U00=ooO3U003o`000?ojb97on/RA00Son/RA2?omc8/6ooo=
OPGoo/UZ1Oog_dl00ooY[Bgo0000ooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooo`00000Kooooo`006?ooool00ol0003oooooooooo`0Zooooo`03
o`000?o`[hKol:n601Sol:n600?o0000ooooooooool0<oooool3ool000Kooooo0_lc0?l5ooooo`?o
o`001?ooool2oc<0o`03o`000?oooooooooo00Cooooo0ooo0002ooooo`?o<`3o1oooool3ool000Go
<`3o0_ooool2oc<0o`;ooooo0_lc0?l3ooooo`04oc<0oooo003oo`00ool000?ooooo0olc0?l6oooo
o`Ko<`3o0ooo0003ooooo`Ko<`3o2_ooool4oc<0o`Coo`000olc0?l01?oooooo0000o`000?l0000>
ooooo`Co<`3o00?oooooool00?oo00000_oo000Oooooo`;o<`3o1Ooo001]ooooo`03o`000?og`iCo
ml>D00goml>D00?o0000oo[8TOojb9402?ojb948oog<R`Koolen1OonbFX5ooNoC`03onV];Ol0003o
oooo00gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Wooooo000Gooooo`03o`000?oooooooooo02[ooooo00?o0000oo2_Q_o`[hH06_o`[hH00ol0
003oooooooooo`0`ooooo`;oo`0000?oooooo`000?ooool01?ooool2oc<0o`Cooooo0ooo0004oooo
o`03o`000?lc0?oo<`3o00Kooooo0ooo0003ooooo`;o<`3o1oooool3ool00003oooooolc0?oo<`3o
00?o<`3o00Gooooooc<0oolc0?oo<`3oooooo`03oc<0o`;ooooo1?oo0002ooooo`Co<`3o1?ooool7
oc<0o`Coo`001_lc0?l<ooooo`Co<`3o1?oo0005ooooo`?o00003?ooool5oc<0o`03oooooooo003o
o`0000;oo`007_ooool3oc<0o`Coo`00Loooool00ol0003oml>DooO3U00<ooO3U003o`000?ojb97o
n/RA00Son/RA2?omc8/6ooo=OPGoo/UZ1Oog_dl00ooY[Bgo0000ooooo`0>ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`005oooool00ol0
003oooooooooo`0Yooooo`03o`000?o`[hKol:n601col:n600?o0000ooooooooool0;?ooool3ool0
00Cooooo00?o0000oooooolc0?l00_lc0?l4ooooo`;oo`001?ooool01?l0003o<`3ooc<0oolc0?l6
ooooo`;oo`000oooool3oc<0o`Kooooo0ooo0002ooooo`Go<`3o00Cooooooc<0oolc0?oooooo0olc
0?l2ooooo`?oo`000_ooool4oc<0o`Cooooo1?lc0?l01?oooooo<`3ooc<0oolc0?l3ool000Co<`3o
2oooool7oc<0o`04oooooooo003oo`00ool000Kooooo0ol0000;ooooo`Co<`3o0_ooool4ool001co
oooo1Olc0?l4ool007Sooooo00?o0000ooO3U?og`i@02oog`i@00ol0003on/RAoo[8T@08oo[8T@So
oLb;1_oocGh5ook9JPKomkm?00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool001Oooooo00?o0000ooooooooool0
:Oooool00ol0003ol:n6oo2_QP0Moo2_QP03o`000?oooooooooo02Wooooo0_oo0007ooooo`;o<`3o
1?ooool3ool000?ooooo0_l00002oc<0o`Kooooo0ooo0003ooooo`;o<`3o1_ooool3ool000;ooooo
1_lc0?l01?oooooo<`3ooc<0ooooool2oc<0o`;ooooo0ooo0002ooooo`?o<`3o0oooool5oc<0o`;o
oooo0_lc0?l4ool000;o<`3o2Oooool:oc<0o`03oooooooo003oo`0000;oo`001_ooool3o`0000Wo
oooo1Olc0?l2ooooo`Coo`006oooool5oc<0o`03oooooooo003oo`0000;oo`00O?ooool00ol0003o
ml>DooO3U00:ooO3U003o`000?ojb97on/RA00Won/RA2?omc8/6ooo=OPGoo/UZ1_og_dl00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Iooooo`005oooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n601ool:n6
00?o0000ooooooooool09Oooool3ool000Oooooo0_lc0?l2ooooo`04o`000?oo003oo`00ool000?o
oooo0ol00002oc<0o`Gooooo0ooo0003ooooo`?o<`3o1Oooool3ool000;ooooo3Olc0?l01Ooooooo
o`00ool00?oo003ooooo00Co<`3o0_ooool4oc<0o`?ooooo0olc0?l3ool000Oooooo2?lc0?l2oooo
o`Co<`3o0_ooool3ool000Kooooo1?l00008ooooo`Co<`3o0oooool4ool001[ooooo1Olc0?l00ooo
ooooo`00ool00003ool0087ooooo00?o0000ooO3U?og`i@02Oog`i@00ol0003on/RAoo[8T@09oo[8
T@SooLb;1_oocGh6ook9JPGomkm?00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool001Oooooo00?o0000oooooooo
ool0:?ooool00ol0003ol:n6oo2_QP0Poo2_QP03o`000?oooooooooo02;ooooo0_oo0008ooooo`;o
<`3o0oooool2ool00003o`000?oooooooooo00?o000000?ooooooc<0oolc0?l01?ooool3ool000Co
oooo0_lc0?l5ooooo`?oo`000oooool2oc<0o`03oooooolc0?oo<`3o00So<`3o0ooo0004oc<0o`03
oooooolc0?oo<`3o00?o<`3o0_ooool5oc<0o`?oo`000oooool7oc<0o`Kooooo1?lc0?l2ooooo`Co
o`001_ooool3o`0000Oooooo1Olc0?l3ooooo`Coo`006Oooool5oc<0o`;ooooo1?oo0027ooooo`03
o`000?og`iComl>D00Soml>D00?o0000oo[8TOojb9402Oojb948oog<R`Koolen1_onbFX5ooNoC`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo02Sooooo00?o0000oo2_Q_o`[hH0
8Oo`[hH00ol0003oooooooooo`0Nooooo`?oo`002?ooool2oc<0o`;ooooo0ooo0003ooooo`;o0000
00Cooooooc<0oolc0?oo<`3o1?ooool2ool000Cooooo0olc0?l4ooooo`?oo`000oooool3oc<0o`;o
oooo2?lc0?l3ool000?o<`3o00?ooooooc<0oolc0?l00_lc0?l2ooooo`Ko<`3o1?oo0006oc<0o`Wo
oooo1?lc0?l2ooooo`Coo`001oooool3o`0000Kooooo1?lc0?l4ooooo`Coo`006?ooool5oc<0o`?o
oooo1?oo002;ooooo`03o`000?og`iComl>D00Soml>D00?o0000oo[8TOojb9402Oojb948oog<R`Ko
olen1_onbFX5ooNoC`03o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo000Gooooo`03o`000?oooooooooo02Oooooo
00?o0000oo2_Q_o`[hH08oo`[hH00ol0003oooooooooo`0Kooooo`;oo`002Oooool2oc<0o`;ooooo
0_oo0006ooooo`03o`000?lc0?oo<`3o00Cooooo0ooo0004ooooo`;o<`3o1?ooool3ool000?ooooo
0olc0?l3ooooo`Oo<`3o0ooo000@oc<0o`?oo`000olc0?l<ooooo`Co<`3o0oooool3ool000Sooooo
0ol00004ooooo`Go<`3o1?ooool4ool001Kooooo1_lc0?l4ooooo`Coo`00T?ooool00ol0003oml>D
ooO3U006ooO3U003o`000?ojb97on/RA00Won/RA2Oomc8/7ooo=OPGoo/UZ1?og_dl00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02Oooool3o`0001[ooooo
000Gooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH08oo`[hH00ol0003ooooooooo
o`0Hooooo`?oo`002Oooool2oc<0o`04oooooooo003oo`00ool000Oooooo0_lc0?l3ooooo`?oo`00
1?ooool3oc<0o`?ooooo0ooo0003ooooo`?o<`3o1?ooool6oc<0o`?oo`004?lc0?l3ool000kooooo
1?lc0?l3ooooo`Coo`002?ooool3o`0000;ooooo1Olc0?l5ooooo`Coo`005Oooool5oc<0o`Gooooo
1Ooo002Eooooo`03o`000?og`iComl>D00Goml>D00?o0000oo[8TOojb9402Oojb949oog<R`Ooolen
1OonbFX4ooNoC`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo000Fooooo`03o`000?oooooooooo02Sooooo00?o
0000oo2_Q_o`[hH09?o`[hH00ol0003oooooooooo`0Eooooo`;oo`002_ooool2oc<0o`?oo`002?oo
ool2oc<0o`03ooooool0003oo`0000;oo`001Oooool2oc<0o`?ooooo0ooo0003ooooo`?o<`3o1Ooo
ool4oc<0o`Coo`003olc0?l4ool000gooooo1?lc0?l3ooooo`Coo`002Oooool3o`000003oooooolc
0?oo<`3o00;o<`3o1_ooool4ool001Cooooo1Olc0?l6ooooo`Coo`00V_ooool00ol0003oml>DooO3
U005ooO3U003o`000?ojb97on/RA00Won/RA2Oomc8/7ooo=OPGoo/UZ1?og_dl00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Hooooo`005_ooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n602Gol:n600?o0000
ooooooooool04Oooool3ool000[ooooo0_lc0?l2ool000Sooooo0olc0?l2ooooo`;oo`001Oooool3
oc<0o`;ooooo0ooo0004ooooo`;o<`3o1oooool3oc<0o`;oo`002_lc0?l2ooooo`Co<`3o0ooo000=
ooooo`Co<`3o1?ooool3ool000Wooooo1?l00004oc<0o`Kooooo1?oo000Cooooo`Go<`3o1oooool4
ool009oooooo00?o0000ooO3U?og`i@01?og`i@00ol0003on/RAoo[8T@09oo[8T@WooLb;1ooocGh5
ook9JPComkm?00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool5o`0000;ooooo0ol00009ooooo`005_ooool00ol0
003oooooooooo`0Xooooo`03o`000?o`[hKol:n602Gol:n600?o0000ooooooooool03oooool2ool0
00_ooooo0_lc0?l2ool000Sooooo0_lc0?l2ooooo`?oo`0000?oooooo`000?ooool00_ooool2oc<0
o`?ooooo0_oo0004ooooo`?o<`3o1oooool2oc<0o`;oo`001_lc0?l6ooooo`?o<`3o00Coooooool0
0?oo003oo`003?ooool4oc<0o`Cooooo1?oo0009ooooo`?o00000olc0?l8ooooo`?oo`004_ooool5
oc<0o`Sooooo1?oo002Tooooo`03o`000?og`iComl>D00?oml>D00?o0000oo[8TOojb9402Oojb949
oog<R`Ooolen1_onbFX3ooNoC`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00Kooooo000Fooooo`03o`000?oooooooooo02Oooooo00?o
0000oo2_Q_o`[hH09oo`[hH00ol0003oooooooooo`0;ooooo`?oo`002oooool2oc<0o`03ool00?oo
oooooooo00Oooooo0_lc0?l01?ooooooo`00ool00?oo0004ooooo`04o`000?lc0?oo<`3ooc<0o`;o
oooo0ooo0003ooooo`?o<`3o2?ooool00ooo003o<`3oool00002oc<0o`Wooooo1?lc0?l4ool000_o
oooo1?lc0?l5ooooo`?oo`002_ooool3o`0000;o<`3o2?ooool4ool000oooooo1_lc0?l8ooooo`Go
o`00Z?ooool00ol0003oml>DooO3U002ooO3U003o`000?ojb97on/RA00[on/RA2Oomc8/7ooo=OPKo
o/UZ0_og_dl00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool001Kooooo00?o0000ooooooooool09oooool00ol0003ol:n6oo2_QP0Xoo2_QP03o`00
0?oooooooooo00Sooooo0_oo000<ooooo`;o<`3o00?oo`00ooooooooool01_ooool3oc<0o`?oo`00
1_ooool2oc<0o`;ooooo0ooo0003ooooo`?o<`3o2?ooool3ool000_ooooo0olc0?l01?ooooooo`00
ool00?oo000;ooooo`Co<`3o1Oooool4ool000Wooooo00Co<`3oo`000?l0003o00002Oooool4ool0
00kooooo1Olc0?l:ooooo`Coo`00[_ooool01Ol0003oml>DooO3U?og`iCo000000con/RA2Oomc8/7
ooo=OPKoo/UZ0_og_dl00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool001Kooooo00?o0000ooooooooool09oooool00ol0003ol:n6oo2_QP0Yoo2_
QP03o`000?oooooooooo00Cooooo0ooo000;ooooo`03ool00?lc0?oo<`3o00Wooooo0_lc0?l00ooo
ooooo`00ool00006ooooo`?o<`3o00Coooooool00?oo003oo`001?ooool2oc<0o`Sooooo0ooo000:
ooooo`Co<`3o00Coooooool00?oo003oo`002_ooool4oc<0o`Gooooo1?oo0008ooooo`?o<`3o0ol0
0008ooooo`Coo`003Oooool5oc<0o`_ooooo1?oo002cooooo`04o`000?og`iComl>Do`0000con/RA
2Oomc8/7ooo=OPKoo/UZ0_og_dl00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00009ooooo`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?o`[hKol:n602Wo
l:n600?o0000ooooooooool00_ooool2ool000cooooo0olc0?l9ooooo`;o<`3o0ooo0006ooooo`;o
<`3o00Coooooool00?oo003oo`001?ooool3oc<0o`Oooooo0ooo000:ooooo`?o<`3o00?oooooool0
0?oo00000_oo0009ooooo`Co<`3o1_ooool3ool000Sooooo1?lc0?l3o`0000Oooooo1?oo000<oooo
o`Go<`3o3?ooool4ool00;Oooooo00Co0000ooO3U?og`iCo00003?ojb949oog<R`Ooolen1_onbFX2
ooNoC`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000cooooo
000Fooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH0:_o`[hH01?l0003oo`00ool0
0?oo000;ooooo`03ool00?lc0?oo<`3o00[ooooo0_lc0?l2ool000Kooooo0olc0?l3ool000;ooooo
00?o0000oooooolc0?l00_lc0?l7ooooo`?oo`002Oooool4oc<0o`04oooooooo003oo`00ool000Wo
oooo1?lc0?l6ooooo`Coo`001_ooool5oc<0o`Co00001_ooool4ool000_ooooo1Olc0?l<ooooo`Go
o`00_?ooool2o`0000gon/RA2Oomc8/7ooo=OPKoo/UZ0_og_dl00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool3o`0000Oooooo0ol00002ooooo`Go
00002?ooool001Kooooo00?o0000ooooooooool09oooool00ol0003ol:n6oo2_QP0Yoo2_QP;oo`00
00?o0000ooooooooool02?ooool2ool000;o<`3o2Oooool3oc<0o`03ool00?oooooooooo00Gooooo
0_lc0?l3ool000Cooooo0olc0?l6ooooo`Coo`002Oooool3oc<0o`;ooooo0ooo0008ooooo`Co<`3o
1_ooool4ool000Kooooo1?lc0?l2ooooo`?o00001_ooool4ool000[ooooo1Olc0?l=ooooo`Coo`00
`_ooool2o`0000_on/RA2_omc8/8ooo=OPGoo/UZ0_og_dl00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool01oooool2o`0000;ooooo00?o0000ooooooooool0
5oooool001Gooooo00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Voo2_QP?oo`000_o`
[hH00ol0003oooooooooo`06ooooo`;oo`000_lc0?l9ooooo`;o<`3o00?oo`00ooooooooool01Ooo
ool3oc<0o`;oo`001Oooool2oc<0o`03ooooool0003ooooo00?ooooo0ooo0009ooooo`Co<`3o00?o
ooooool00?oo00000_oo0007ooooo`Co<`3o1oooool3ool000Gooooo1Olc0?l3ooooo`?o00001Ooo
ool4ool000Sooooo1_lc0?l>ooooo`Coo`00aoooool00ol0003on/RAoo[8T@09oo[8T@[ooLb;2?oo
cGh6ook9JP03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Oooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000
oo2_Q_o`[hH09?o`[hH2ool000Kol:n600?o0000ooooooooool00_ooool3ool000;o<`3o2Oooool2
oc<0o`03ool00?oooooooooo00Gooooo0_lc0?l2ool000Gooooo0olc0?l3ooooo`03o`000?oooooo
o`0000;oo`002Oooool3oc<0o`;ooooo0ooo0007ooooo`Co<`3o1oooool4ool000Cooooo1?lc0?l5
ooooo`?o00001?ooool4ool000Oooooo1Olc0?l@ooooo`Coo`00c?ooool00ol0003on/RAoo[8T@08
oo[8T@[ooLb;2?oocGh6ook9JP03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo000Eooooo`03o`000?oooooooooo
02Sooooo00?o0000oo2_Q_o`[hH08Oo`[hH3ool000Sol:n600?o0000ooooooooool00_oo00000ooo
oooo<`3ooc<0o`08ooooo`03ool00?lc0?oo<`3o00Oooooo0olc0?l00ooo003oooooooooo`03oooo
o`?o<`3o1Oooool3ool000Sooooo1?lc0?l2ooooo`?oo`001_ooool4oc<0o`Sooooo0ooo0003oooo
o`Go<`3o1_ooool3o`0000?ooooo1?oo0006ooooo`Go<`3o4?ooool5ool00=7ooooo00?o0000oo[8
TOojb9401oojb94:oog<R`Soolen1_onbFX00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`005Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?o`[hKol:n601ool:n60_oo000;oo2_QP?oo`0000?ooooooc<0oolc
0?l02?ooool3oc<0o`Oooooo0_lc0?l00ooo003oooooooooo`03ooooo`?o<`3o1Oooool3ool00003
ooooool0003ooooo00Gooooo0olc0?l2ooooo`Coo`001Oooool4oc<0o`Sooooo1?oo00000ooooooo
<`3ooc<0o`03oc<0o`Sooooo0ol00002ooooo`Coo`001Oooool5oc<0oa7ooooo1?oo003Gooooo`03
o`000?ojb97on/RA00Kon/RA2_omc8/8ooo=OPKoo/UZ00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool001Gooooo
00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Loo2_QP?oo`002_o`[hH3ool00004oo2_
Q_l0003o<`3ooc<0o`Oooooo00?oo`00oc<0oolc0?l01oooool3oc<0o`Gooooo0olc0?l5ooooo`?o
o`001?ooool00ol0003oooooooooo`04oc<0o`;ooooo0ooo0005ooooo`Co<`3o2?ooool4ool00003
oooooolc0?oo<`3o00;o<`3o2Oooool4o`000003oooooooo003oo`0000;oo`001?ooool5oc<0oa;o
oooo1?oo003Looooo`03o`000?ojb97on/RA00Gon/RA2_omc8/8ooo=OPGoo/UZ00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05oooool001Gooooo00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Joo2_QP03o`00
0?oo003ol:n600[ol:n60_oo0003oo2_QP;o<`3o00?o0000ooooooooool00oooool2ool000;o<`3o
1oooool2oc<0o`Kooooo0_lc0?l5ooooo`?oo`001oooool3oc<0o`?ooooo0ooo0004ooooo`Co<`3o
2Oooool3ool000Go<`3o2_ooool3o`0000;ooooo0ooo0002ooooo`Ko<`3o4oooool4ool00>7ooooo
00?o0000oo[8TOojb9401?ojb94:oog<R`Soolen1OonbFX00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`005Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n601[ol:n60_l00008oo2_QP?oo`000oo`
[hH2oc<0o`;ol:n600?o0000ooooooooool00_oo0003oc<0o`Kooooo0olc0?l5ooooo`?o<`3o1?oo
ool3ool000Kooooo1?lc0?l00ol0003oooooool00003ool000?ooooo1?lc0?l9ooooo`Coo`000olc
0?l<ooooo`?o000000?oooooool00?oo00000_oo0005oc<0oaCooooo1Ooo003Vooooo`03o`000?oj
b97on/RA00?on/RA2_omc8/8ooo=OPCoo/UZ00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool001Gooooo00?o0000
ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Roo2_QP;oo`001?o`[hH2oc<0o`Col:n600?o0000
ool00?oo00000_lc0?l6ooooo`03ool00?lc0?oo<`3o00Gooooo0olc0?l3ooooo`Coo`001_ooool3
oc<0o`?ooooo0ooo0003ooooo`Co<`3o2Oooool4ool000?o<`3o3Oooool3o`0000Coo`001?lc0?lE
ooooo`Coo`00k?ooool00ol0003on/RAoo[8T@02oo[8T@[ooLb;2?oocGh4ook9JP03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:ooooo`;o00006?ooool0
01Gooooo00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Ooo2_QP?oo`001?o`[hH2oc<0
o`Col:n60ooo0002oc<0o`Gooooo00Coo`00oc<0oolc0?oo<`3o1?ooool3oc<0o`?ooooo0ooo0006
ooooo`Co<`3o0oooool3ool00003ooooool0003o<`3o00?o<`3o2_ooool3ool000;o<`3o3oooool2
o`0000Coo`000olc0?lFooooo`Coo`00lOooool00ol0003on/RAoo[8T@0;oog<R`Woolen0_onbFX0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooo`00000Hooooo`005?ooool00ol0003oooooooooo`0Yooooo`03o`000?o`[hKol:n6
01col:n60ooo0005oo2_QP;o<`3o0oo`[hH3ool00004oo2_Q_lc0?oo<`3oo`0000?ooooo0_oo0002
oc<0o`Gooooo0_lc0?l3ooooo`?oo`001Oooool4oc<0o`?ooooo1?oo00000ooooooo<`3ooc<0o`02
oc<0o`[ooooo1?oo00000olc0?ooooooooooo`0>ooooo`03o`000?oo003oo`0000;oo`000_lc0?lG
ooooo`Coo`00m_ooool00ol0003on/RAoog<R`0:oog<R`Woolen0_onbFX00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`005?ooool00ol0003oooooooooo`0Yooooo`03o`000?o`[hKol:n601[ol:n600?o0000ool0
0?o`[hH01?o`[hH3oc<0o`;ol:n60ooo00001?o`[hKo<`3ooc<0oolc0?l3oo2_QP;oo`000olc0?l4
ooooo`?o<`3o0_ooool3ool000Gooooo0olc0?l4ooooo`?oo`0000?ooooooc<0oolc0?l00_lc0?l3
ooooo`03o`000?oooooooooo00Cooooo00Co<`3oool00?oo003oo`004Oooool00ol0003oo`00ool0
0002ool00003oc<0oooooooooooo01Gooooo1Ooo003kooooo`03o`000?omc8_ooLb;00WooLb;2Ooo
cGh00oonbF[o0000ooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Fooooo`005?ooool00ol0003oooooooooo`0Yooooo`03o`000?o`[hKo
l:n601[ol:n60_l00003oo2_QP;o<`3o0oo`[hH2ool000;ol:n60_lc0?l3oo2_QP?oo`000_lc0?l4
ooooo`?o<`3o0_ooool3ool000Cooooo1?lc0?l4ooooo`?oo`001?lc0?l7ooooo`04o`000?oooooo
<`3ooc<0o`Coo`003oooool2oc<0o`Coo`006?ooool4ool00?oooooo0_ooool2o`0000WooLb;2Ooo
cGh00oonbF[o0000ooooo`0Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Fooooo`005?ooool00ol0003oooooooooo`0Zooooo`03o`000?o`[hKo
l:n601col:n60_lc0?l2oo2_QP?oo`000_o`[hH2oc<0o`;ol:n60ooo0003oc<0o`03o`000?oooooo
oooo00?o<`3o0_ooool3ool000Cooooo0olc0?l4ooooo`Coo`000olc0?l9ooooo`;o<`3o1?oo000>
ooooo`?o<`3o1?oo000Hooooo`Coo`00ooooool8ooooo`?o00001_omc8/8ooo=OP;o0000;Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool0
01Cooooo00?o0000ooooooooool0:_ooool00ol0003ol:n6oo2_QP0Joo2_QP;o<`3o00Col:n6ool0
0?oo003oo`000oo`[hH2oc<0o`05oo2_Q_oo003oo`00ool00?o`[hH00_lc0?l4oo2_QP;o<`3o0_oo
ool3ool000?ooooo1?lc0?l4ooooo`?oo`000olc0?l8ooooo`Co<`3o0ooo00000ol0003ooooooooo
o`0:ooooo`Co<`3o1?oo00000ol0003oooooooooo`0Eooooo`Coo`00ooooool?ooooo`?o00000oom
c8/5ooo=OP?o0000<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05Oooool001Cooooo00?o0000ooooooooool0:_ooool00ol0003ol:n6oo2_QP0H
oo2_QP;o<`3o0ooo0003oo2_QP?o<`3o0ooo00001?o`[hKo<`3ooc<0oolc0?l3oo2_QP?o<`3o1?oo
0003ooooo`?o<`3o1?ooool4ool000;o<`3o2?ooool4oc<0o`Coo`000_ooool00ol0003ooooooooo
o`06ooooo`Go<`3o1?oo0002o`0001Gooooo1Ooo003ooooooaKooooo0ol00002ooo=OP?o0000=?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Ooo
ool001Cooooo00?o0000ooooooooool0:_ooool00ol0003ol:n6oo2_QP0Foo2_QP;o<`3o00?ol:n6
ool00?l000000oo`[hH2oc<0o`?oo`000_o`[hH2oc<0o`?ol:n60olc0?l3ool00003o`000?oooooo
oooo00Co<`3o1?ooool3ool000;o<`3o1oooool5oc<0o`04oooooooo003oo`00ool000Kooooo00Co
0000oooooooooooooooo1Olc0?l00oooooooo`00ool00002ool000?o00005?ooool4ool00?oooooo
7_ooool2o`0003Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Gooooo000Dooooo`03o`000?oooooooooo02[ooooo00?o0000oo2_Q_o`[hH05?o`
[hH2oc<0o`Kol:n60_lc0?l2ool000;ol:n60olc0?l2oo2_QP?o<`3o0ooo0003oo2_QP?o<`3o1Ooo
ool3ool00003oc<0oooooooooooo00Gooooo1?lc0?l2ooooo`Coo`001oooool6oc<0o`?ooooo0ooo
0004o`0001?ooooo1?oo003ooooooecooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0:ooooo`;o00005oooool001?ooooo00?o0000ooooooooool0:oooool00ol0003ol:n6oo2_QP0B
oo2_QP03o`000?lc0?ool:n600Col:n60olc0?l01?oo003ol:n6oo2_Q_o`[hH2oc<0o`;ol:n60olc
0?l3ool000;ol:n61?lc0?l01?o`[hKo0000ooooooooool4ool000Kooooo1Olc0?l2ooooo`Coo`00
1_ooool5oc<0o`;ooooo00?o0000ooooooooool01?oo0003o`0001;ooooo1Ooo003oooooof7ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000001Oooooo
000Cooooo`03o`000?oooooooooo02_ooooo00?o0000oo2_Q_o`[hH04_o`[hH2o`0000?ol:n60_lc
0?l01?oo003ol:n6oo2_Q_o`[hH3oc<0o`;ol:n60_lc0?l3ool000;ol:n60olc0?l4oo2_QP04oc<0
oooo003oo`00ool000Gooooo1Olc0?l4ooooo`?oo`001Oooool5oc<0o`Kooooo1?oo00001?oooooo
0000o`000?l0000Aooooo`Coo`00oooooomWooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Eooooo`004oooool00ol0003oooooooooo`0/ooooo`03
o`000?o`[hKol:n601Col:n600?o0000oc<0ooo`[hH00_l000000oo`[hKo<`3ooc<0o`02oo2_QP;o
<`3o0ooo00000oo`[hKo<`3ooc<0o`02oc<0o`?ol:n60_lc0?l3ool00004o`000?oooooooooooooo
o`Co<`3o1Oooool4ool000?ooooo1Olc0?l7ooooo`Coo`0000?oooooo`000?l000000_l0000@oooo
o`Coo`00oooooom[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Eooooo`004oooool00ol0003oooooooooo`0/ooooo`03o`000?o`[hKol:n601Co
l:n60_l000001Oo`[hKo<`3ooc<0oolc0?ool:n600;o<`3o0ooo00001?o`[hKo<`3ooc<0oolc0?l3
oo2_QP;o<`3o1?oo0002oo2_QPGo<`3o1Oooool4ool000;ooooo1Olc0?l8ooooo`Coo`000oooool3
o`0000oooooo1?oo003oooooog3ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Gooooo000Cooooo`03o`000?oooooooooo02cooooo00?o0000oo2_
Q_o`[hH05Oo`[hH00ol0003o<`3oo`000002oc<0o`?oo`001?lc0?l2oo2_QP?o<`3o0ooo0002oo2_
QPCo<`3o00?ol:n6o`000?ooool01?ooool3ool00003oooooolc0?oo<`3o00?o<`3o2Oooool4ool0
00Cooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo1Ooo003oooooogGooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo000Cooooo`03
o`000?oooooooooo02cooooo00?o0000oo2_Q_o`[hH05Oo`[hH2o`000003oc<0oooo003oo`0000?o
<`3o0_o`[hH4oc<0o`?oo`001Olc0?l6oo2_QP03o`000?oo003oo`0000;oo`001?lc0?l:ooooo`Co
o`001?ooool4o`0000Gooooo00?o0000ooooooooool01?ooool4ool00?ooooooNoooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool001?ooooo
00?o0000ooooooooool0;?ooool00ol0003ol:n6oo2_QP0Goo2_QP04o`000?lc0?oo<`3ooo2_QPCo
<`3o1?oo0003oc<0o`Wol:n60ooo0002oc<0o`cooooo1?oo0005ooooo`?o00002Oooool00ol0003o
ooooooooo`04ool00?ooooooOoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool05?ooool001?ooooo00?o0000ooooooooool0;?ooool00ol0003ol:n6
oo2_QP0Ioo2_QP;o<`3o00Col:n6ool00?oo003oo`000olc0?l8oo2_QP03oc<0oooo003oo`0000;o
o`000_o`[hH00ol0003oooooooooo`08ooooo`Coo`001_ooool3o`0000_ooooo1?oo003oooooohCo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Co
oooo000Cooooo`03o`000?oooooooooo02gooooo00?o0000oo2_Q_o`[hH06?o`[hH3ool00003oc<0
ooo`[hKol:n600Kol:n60_lc0?l4ool000Kol:n600?o0000ooooooooool01?ooool4ool000Oooooo
0ol00009ooooo`Goo`0000?oooooo`000?ooool0oooooon6ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02_ooool2o`0001Kooooo000Booooo`03o`000?oooooooooo02kooooo00?o
0000oo2_Q_o`[hH05_o`[hH2ool00003oo2_Q_l0003o000000Col:n61?lc0?l3ool000[ol:n600?o
0000ooooooooool01?oo0008ooooo`?o00002?ooool4ool000Kooooo00?o0000ooooooooool0oooo
oon6ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
000Fooooo`004_ooool00ol0003oooooooooo`0^ooooo`03o`000?o`[hKol:n601Kol:n60_l00004
oo2_QP?o<`3o1?oo000<oo2_QPCoo`002Oooool3o`0000Oooooo1?oo000:ooooo`03o`000?oooooo
oooo0?ooooooQ_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool05?ooool001;ooooo00?o0000ooooooooool0;_ooool00ol0003ol:n6oo2_QP0Koo2_
QPCoo`003Oo`[hH3ool000;ol:n600?o0000ooooooooool01?ooool4o`0000Kooooo1?oo000>oooo
o`03o`000?oooooooooo0?ooooooQoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05?ooool001;ooooo00?o0000ooooooooool0;oooool00ol0003o
l:n6oo2_QP0Goo2_QP?oo`003Oo`[hH4ool000Gol:n600Co0000oooooooooooooooo0ol00005oooo
o`Goo`004_ooool00ol0003oooooooooo`3oooooohSooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo000Booooo`03o`000?oooooooooo02oo
oooo00?o0000oo2_Q_o`[hH05?o`[hH00ol0003oo`00ool0000<oo2_QPCoo`002Oo`[hH4o`0000Co
oooo1?oo000Fooooo`03o`000?oooooooooo0?ooooooR_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool001;ooooo00?o0000ooooooooool0
;oooool00ol0003ol:n6oo2_QP0Doo2_QP;o00002Oo`[hH4ool000_ol:n60ol00003ooooo`Coo`00
6_ooool00ol0003oooooooooo`3ooooooh[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01?ooooo000Booooo`03o`000?oooooooooo02oooooo00?o
0000oo2_Q_o`[hH06oo`[hH4ool000col:n60ol00002oo2_QPCoo`007_ooool00ol0003ooooooooo
o`3ooooooh_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01?ooooo000Booooo`03o`000?oooooooooo02oooooo00?o0000oo2_Q_o`[hH05oo`[hH4
ool000gol:n60ol00005ool00003oo2_Q_l0003ooooo01oooooo00?o0000ooooooooool0oooooon<
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`004_ooool00ol0003oooooooooo`0`ooooo`03o`000?o`[hKol:n601?ol:n600?o0000ool0
0?oo00003Oo`[hH3o`0000Coo`001_o`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
0?ooooooSOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool0017ooooo00?o0000ooooooooool0<Oooool00ol0003ol:n6oo2_QP0Coo2_QP;o
00002oo`[hH2o`0000Coo`002_o`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oo
ooooSOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0ol0000Eooooo`00
4Oooool00ol0003oooooooooo`0aooooo`03o`000?o`[hKol:n601gol:n600?o0000ool00?oo0000
0_oo000>oo2_QP03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooon>ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`004Ooo
ool00ol0003oooooooooo`0booooo`03o`000?o`[hKol:n601Sol:n61Ooo000Boo2_QP03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0oooooon?ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`004Oooool00ol0003oooooooooo`0b
ooooo`03o`000?o`[hKol:n601Col:n61?oo00000ol0003ol:n6oo2_QP0Doo2_QP03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0oooooon@ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`?o00001?ooool2o`0000Cooooo000Aoooo
o`03o`000?oooooooooo03?ooooo00?o0000oo2_Q_o`[hH04Oo`[hH2ool000;o00006Oo`[hH00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo0?ooooooT?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000oooool0017ooooo00?o0000ooooooooool0<oooool0
0ol0003ol:n6oo2_QP0>oo2_QPGo00006oo`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo0?ooooooTOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo000A
ooooo`03o`000?oooooooooo03Cooooo00?o0000oo2_Q_o`[hH02_o`[hH3o`00023ol:n600?o0000
ooooooooool07_ooool00ol0003oooooooooo`3ooooooi;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`01ooooo`004Oooool00ol0003oooooooooo`0dooooo`03o`000?o`[hKo
l:n600Ool:n60ol0000Too2_QP03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooonC
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`Co00000oooool01?l0003oooooooooool00003ooooo`004?ooool00ol0003oooooooooo`0f
ooooo`03o`000?o`[hKol:n600?ol:n60ol0000Woo2_QP03o`000?oooooooooo01gooooo00?o0000
ooooooooool0oooooonCooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000ooo
ool0013ooooo00?o0000ooooooooool0=_ooool00ol0003ol:n6oo2_QP03o`0002[ol:n600?o0000
ooooooooool07Oooool00ol0003oooooooooo`3ooooooiCooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`;o00001_ooool5o`0000?ooooo0_l00004ooooo`004?ooool00ol0
003oooooooooo`0fooooo`?o0000;Oo`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
0?ooooooUOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo0_l000000ooo
oooo0000ooooo`0Cooooo`004?ooool00ol0003oooooooooo`0booooo`Co000000?oooooo`000?o`
[hH0;Oo`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0?ooooooU_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool0013ooooo
00?o0000ooooooooool0;oooool3o`0000Kooooo00?o0000oo2_Q_o`[hH0:oo`[hH00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo0?ooooooUoooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04Oooool0013ooooo00?o0000ooooooooool0;?oo
ool3o`0000Wooooo00?o0000oo2_Q_o`[hH0:oo`[hH00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo0?ooooooV?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
4Oooool0013ooooo00?o0000ooooooooool0:Oooool3o`0000gooooo00?o0000oo2_Q_o`[hH0:_o`
[hH00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0?ooooooVOooool01?l0003ooooooooo
ool0000=ooooo`03o`000?oooooooooo017ooooo000@ooooo`03o`000?oooooooooo02Kooooo0ol0
000Aooooo`03o`000?o`[hKol:n602Sol:n600?o0000ooooooooool07Oooool00ol0003ooooooooo
o`3ooooooi[ooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0Aooooo`004?ooool0
0ol0003oooooooooo`0Sooooo`?o00005?ooool00ol0003ol:n6oo2_QP0Xoo2_QP03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0oooooonJooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool04Oooool000oooooo00?o0000ooooooooool08?ooool4o`0001Sooooo00?o0000
oo2_Q_o`[hH09oo`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0?ooooooVoooool0
0ol0003oooooo`00000<ooooo`03o`000?oooooooooo017ooooo000?ooooo`03o`000?oooooooooo
01gooooo0ol0000Mooooo`03o`000?o`[hKol:n602Kol:n600?o0000ooooooooool07Oooool00ol0
003oooooooooo`3ooooooicooooo0_l0000<ooooo`;o00004_ooool000oooooo00?o0000oooooooo
ool06_ooool3o`00027ooooo00?o0000oo2_Q_o`[hH09Oo`[hH00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo0?ooooooVoooool3o`0000[ooooo0ol0000Cooooo`003oooool00ol0003ooooo
ooooo`0Gooooo`?o00009?ooool00ol0003ol:n6oo2_QP0Too2_QP03o`000?oooooooooo01kooooo
00?o0000ooooooooool0oooooonHooooo`?o00004?ooool00ol0003oooooooooo`0@ooooo`003ooo
ool00ol0003oooooooooo`0Dooooo`?o0000:?ooool00ol0003ol:n6oo2_QP0Soo2_QP03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0oooooonDooooo`Co00004oooool00ol0003ooooooooo
o`0@ooooo`003oooool00ol0003oooooooooo`0Aooooo`?o0000;?ooool00ol0003ol:n6oo2_QP0R
oo2_QP03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooon@ooooo`Co00005oooool0
0ol0003oooooooooo`0@ooooo`003oooool00ol0003oooooooooo`0=ooooo`Co0000;oooool00ol0
003ol:n6oo2_QP0Roo2_QP03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooon=oooo
o`?o00006oooool00ol0003oooooooooo`0@ooooo`003oooool00ol0003oooooooooo`0:ooooo`?o
0000=?ooool00ol0003ol:n6oo2_QP0Poo2_QP03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0oooooon9ooooo`Co0000<Oooool000oooooo00?o0000ooooooooool01oooool3o`0003Sooooo
00?o0000oo2_Q_o`[hH07oo`[hH00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo
QOooool4o`0003Gooooo000>ooooo`03o`000?oooooooooo00Gooooo0ol0000looooo`03o`000?o`
[hKol:n601gol:n600?o0000ooooooooool08?ooool00ol0003oooooooooo`3ooooooh;ooooo0ol0
000iooooo`003_ooool00ol0003oooooooooo`02ooooo`?o0000@?ooool00ol0003ol:n6oo2_QP0L
oo2_QP03o`000?oooooooooo023ooooo00?o0000ooooooooool0oooooomnooooo`Co0000??ooool0
00kooooo00?o0000ooooool000000_l00014ooooo`03o`000?o`[hKol:n601[ol:n600?o0000oooo
ooooool08?ooool00ol0003oooooooooo`3oooooog_ooooo1?l00010ooooo`003_ooool2o`0004So
oooo00?o0000oo2_Q_o`[hH06Oo`[hH00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0?oo
ooooN?ooool3o`0004Cooooo000@ooooo`03o`000?oooooooooo04Kooooo0_l0000Hoo2_QP03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0oooooomdooooo`Co0000Aoooool0017ooooo00?o
0000ooooooooool0Aoooool00ol0003ol:n6oo2_QP0Doo2_QP03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0oooooomaooooo`?o0000Boooool001;ooooo00?o0000ooooooooool0Aoooool2
o`0001?ol:n600?o0000ooooooooool08oooool00ol0003oooooooooo`3oooooofgooooo1?l0001>
ooooo`004oooool2o`0004Wooooo0_l0000@oo2_QP03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0oooooomYooooo`Co0000D_ooool001Gooooo00?o0000ooooooooool0B?ooool00ol0003o
l:n6oo2_QP0<oo2_QP03o`000?oooooooooo02Gooooo00?o0000ooooooooool0oooooomVooooo`?o
0000E_ooool001Kooooo00?o0000ooooooooool0B?ooool3o`0000Wol:n60_l0000Xooooo`03o`00
0?oooooooooo0?ooooooH_ooool4o`0005Wooooo000Gooooo`03o`000?oooooooooo04[ooooo0ol0
0003oo2_QP?o0000:_ooool00ol0003oooooooooo`3ooooooekooooo1?l0001Mooooo`006?ooool2
o`0004gooooo0ol0000]ooooo`03o`000?oooooooooo0?ooooooFoooool3o`00067ooooo000Joooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool0oooooomGooooo`Co0000I?ooool001_o
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`3ooooooe?ooooo1?l0001Xooooo`00
7?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo0?ooooooD?ooool3o`0006cooooo
000Mooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool0oooooom<ooooo`Co0000Kooo
ool001kooooo0_l0001gooooo`03o`000?oooooooooo0?ooooooBOooool3o`0007?ooooo000Poooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0oooooom5ooooo`Co0000M_ooool0027o
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`3ooooood7ooooo1?l0001jooooo`00
8_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo0?oooooo?oooool3o`0007kooooo
000Sooooo`;o0000LOooool00ol0003oooooooooo`3ooooooc_ooooo1?l00021ooooo`009Oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo0?oooooo=oooool4o`0008Gooooo000Voooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool0ooooooldooooo`?o0000ROooool002Oo
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`3ooooooc3ooooo1?l0002<ooooo`00
:?ooool2o`0006cooooo00?o0000ooooooooool0ooooool/ooooo`Co0000T?ooool002[ooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`3oooooobWooooo0ol0002Dooooo`00:oooool0
0ol0003oooooooooo`1Xooooo`03o`000?oooooooooo0?oooooo9Oooool4o`0009Oooooo000/oooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0oooooolQooooo`Co0000Voooool002go
oooo0_l0001Wooooo`03o`000?oooooooooo0?oooooo7_ooool3o`0009oooooo000_ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0oooooolJooooo`Co0000X_ooool0033ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`3ooooooaOooooo0ol0002Vooooo`00<Oooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo0?oooooo4oooool4o`000:Wooooo000boooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0ooooool?ooooo`Co0000[Oooool003?o
oooo0_l0001Qooooo`03o`000?oooooooooo0?oooooo3?ooool3o`000;7ooooo000eooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0ooooool8ooooo`Co0000]?ooool003Kooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`3oooooo`Cooooo1?l0002hooooo`00=oooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0?oooooo0_ooool3o`000;cooooo000hoooo
o`;o0000Foooool00ol0003oooooooooo`3mooooo`Co0000_oooool003[ooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`3iooooo`Co0000`oooool003_ooooo00?o0000ooooooooool0
Eoooool00ol0003oooooooooo`3fooooo`?o0000aoooool003cooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`3booooo`Co0000b_ooool003gooooo0_l0001Fooooo`03o`000?oooooo
oooo0>oooooo0ol0003>ooooo`00?oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
0>_ooooo1?l0003Aooooo`00@?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0>Oo
oooo1?l0003Eooooo`00@Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0>Cooooo
0ol0003Iooooo`00@_ooool2o`00057ooooo00?o0000ooooooooool0h?ooool4o`000=cooooo0014
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0g?ooool4o`000>3ooooo0015oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0fOooool3o`000>Cooooo0016ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0eOooool4o`000>Oooooo0017ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0dOooool4o`000>_ooooo0018ooooo`;o0000Booo
ool00ol0003oooooooooo`3>ooooo`?o0000koooool004[ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`3:ooooo`Co0000l_ooool004_ooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`38ooooo`?o0000m_ooool004cooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`34ooooo`Co0000nOooool004gooooo0_l00015ooooo`03o`000?oooooooooo0<3ooooo
1?l0003mooooo`00Coooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo0;gooooo0ol0
003oooooo`;ooooo001@ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0^Oooool4
o`000?oooooo1Oooool0057ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2eoooo
o`Co0000ooooool9ooooo`00D_ooool2o`00043ooooo00?o0000ooooooooool0/_ooool3o`000?oo
oooo3Oooool005Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2^ooooo`Co0000
ooooool@ooooo`00EOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0:[ooooo1?l0
003ooooooaCooooo001Fooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Yoooool3
o`000?oooooo6?ooool005Oooooo0_l0000kooooo`03o`000?oooooooooo0:?ooooo1?l0003ooooo
oa_ooooo001Iooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0X?ooool3o`000?oo
oooo7oooool005[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2Looooo`Co0000
oooooolRooooo`00Foooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo09Sooooo1?l0
003oooooobKooooo001Looooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0UOooool3
o`000?oooooo:_ooool005gooooo0_l0000eooooo`03o`000?oooooooooo097ooooo1?l0003ooooo
obgooooo001Oooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0SOooool4o`000?oo
oooo<Oooool0063ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2;ooooo`?o0000
ooooooleooooo`00HOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08Oooooo1?l0
003oooooocSooooo001Rooooo`;o0000;oooool00ol0003oooooooooo`23ooooo`Co0000ooooooll
ooooo`00I?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo083ooooo0ol0003ooooo
od3ooooo001Uooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0O?ooool4o`000?oo
oooo@oooool006Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1iooooo`?o0000
oooooom7ooooo`00Ioooool2o`0002[ooooo00?o0000ooooooooool0MOooool4o`000?ooooooB_oo
ool006Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`Co0000oooooom>
ooooo`00J_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06kooooo0ol0003ooooo
oe;ooooo001[ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0J_ooool4o`000?oo
ooooEOooool006cooooo0_l0000Uooooo`03o`000?oooooooooo06Kooooo1?l0003ooooooeWooooo
001^ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Hoooool3o`000?ooooooGOoo
ool006oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Oooooo`Co0000oooooomP
ooooo`00L?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05_ooooo1?l0003ooooo
ofCooooo001aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0F?ooool3o`000?oo
ooooJ?ooool007;ooooo0_l0000Oooooo`03o`000?oooooooooo05Cooooo1?l0003oooooof_ooooo
001dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0DOooool4o`000?ooooooKooo
ool007Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1>ooooo`?o0000oooooomc
ooooo`00M_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04[ooooo1?l0003ooooo
ogKooooo001gooooo`;o00006Oooool00ol0003oooooooooo`17ooooo`?o0000oooooomjooooo`00
NOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04?ooooo1?l0003ooooooggooooo
001jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0?oooool4o`000?ooooooPOoo
ool007_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0looooo`?o0000oooooon5
ooooo`00O?ooool2o`0001Cooooo00?o0000ooooooooool0>?ooool4o`000?ooooooR?ooool007ko
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0dooooo`Co0000oooooon<ooooo`00
Ooooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo0ol0003ooooooi3ooooo
0020ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool4o`000?ooooooTooo
ool0087ooooo0_l0000?ooooo`03o`000?oooooooooo02Wooooo1?l0003ooooooiOooooo0023oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09_ooool3o`000?ooooooVoooool008Co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Rooooo`Co0000oooooonNooooo`00
QOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo0ol0003ooooooj;ooooo
0026ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool4o`000?ooooooYOoo
ool008Oooooo0_l00009ooooo`03o`000?oooooooooo01Oooooo1?l0003oooooojWooooo0029oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool3o`000?oooooo[Oooool008[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`Co0000oooooon`ooooo`00
Roooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo1?l0003ooooookCooooo
002<ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`?o0000oooooonhooooo`00S_ooool0
1?l0003oooooooooool00008ooooo`Co0000oooooonkooooo`00Soooool00ol0003oooooo`000004
ooooo`Co0000oooooonoooooo`00T?ooool2o`000004ooooool0003o0000o`000?oooooo`oooool0
097ooooo0_l0003oooooolKooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooo
oooooooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[o
oooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003ooooo
ooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooooooooooF_oo
ool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooooooooooF_ooool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {485.188, 0}} -> {0.00478509, 0.0585825, \
0.00171077, 0.00171077}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConstructMeritFunction[sys]", "Input"],

Cell[BoxData[
    \({RayTraceFunction \[Rule] 
        "RayTraceFunction[{cx, cy, kx, ky}, -raytrace code: 672328 Bytes- ]", 
      SymbolicValues \[Rule] {cx \[Rule] \(-0.005714285714285714`\), 
          cy \[Rule] \(-0.006666666666666667`\), kx \[Rule] \(-1.5`\), 
          ky \[Rule] \(-1.5`\)}, 
      RayTracePrecision \[Rule] 15.954589770191003`, 
      ReportedParameters \[Rule] {SurfaceCoordinates, Intensity}, 
      ReportedFunction \[Rule] \((\(({TV1, TV2, TV3} = 
                Plus @@ \(\(({#1\[LeftDoubleBracket]3\[RightDoubleBracket]\ \
#1\[LeftDoubleBracket]1\[RightDoubleBracket], #1\[LeftDoubleBracket]3\
\[RightDoubleBracket]\ #1\[LeftDoubleBracket]2\[RightDoubleBracket], #1\
\[LeftDoubleBracket]3\[RightDoubleBracket]} &)\) /@ #1\); {TV1, 
                  TV2} = {TV1\/TV3, TV2\/TV3}; 
              TV4 = Plus @@ \(\((#1\[LeftDoubleBracket]3\[RightDoubleBracket]\
\ \((\((#1\[LeftDoubleBracket]1\[RightDoubleBracket] - TV1)\)\^2 + \((#1\
\[LeftDoubleBracket]2\[RightDoubleBracket] - TV2)\)\^2)\) &)\) /@ #1\); \
\@\(TV4\/TV3\))\) &)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sol", " ", "=", " ", 
      RowBox[{
        StyleBox["OptimizeSystem",
          "Input"], "[", \(sys, SequentialTrace \[Rule] True\), 
        "]"}]}]], "Input"],

Cell[BoxData[
    \({SymbolicValues \[Rule] {cx \[Rule] \(-0.005931070258842998`\), 
          cy \[Rule] \(-0.007500000000000001`\), 
          kx \[Rule] \(-0.8754072851169298`\), 
          ky \[Rule] \(-0.1111111111143162`\)}, NumberOfCycles \[Rule] 580, 
      FinalMerit \[Rule] 0.40773731348729053`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
 TurboPlot[plot,sol,SequentialTrace\[Rule]True, \
PlotType\[Rule]Full3D,ShowRange\[Rule]All, Axes\[Rule]True, ImageSize\[Rule] \
600, ColorView\[Rule]SourceID];\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81031 
%%ImageSize: 600 486.189 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00481315 1.00481 -0.0707267 1.00481 [
[.05109 .26124 -6 -8.8147 ]
[.05109 .26124 0 .1853 ]
[.20008 .20604 -11.7303 -9 ]
[.20008 .20604 .2697 0 ]
[.35642 .14814 -16.8044 -9 ]
[.35642 .14814 1.19561 0 ]
[.52068 .08732 -16.0133 -9 ]
[.52068 .08732 1.98667 0 ]
[.69347 .02338 -15.2223 -9 ]
[.69347 .02338 2.77773 0 ]
[.81608 .01469 0 -6.14454 ]
[.81608 .01469 18 2.85546 ]
[.85454 .07423 0 -6.09719 ]
[.85454 .07423 18 2.90281 ]
[.89124 .13104 0 -6.05248 ]
[.89124 .13104 6 2.94752 ]
[.92629 .18531 0 -6.01021 ]
[.92629 .18531 12 2.98979 ]
[.95981 .2372 0 -5.97018 ]
[.95981 .2372 12 3.02982 ]
[.97251 .27422 0 -5.94412 ]
[.97251 .27422 18 3.05588 ]
[.98114 .34489 0 -5.8977 ]
[.98114 .34489 18 3.1023 ]
[.99009 .41825 0 -5.84963 ]
[.99009 .41825 6 3.15037 ]
[.99938 .49442 0 -5.79985 ]
[.99938 .49442 12 3.20015 ]
[1.00904 .5736 0 -5.74824 ]
[1.00904 .5736 12 3.25176 ]
[ 0 0 0 0 ]
[ 1 .81031 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04128 .2769 m
.792 0 L
s
.06016 .26994 m
.06469 .27428 L
s
[(0)] .05109 .26124 1 .95882 Mshowa
.20875 .21513 m
.21309 .21967 L
s
[(50)] .20008 .20604 .95505 1 Mshowa
.36465 .15762 m
.36877 .16237 L
s
[(100)] .35642 .14814 .86715 1 Mshowa
.5284 .09723 m
.53226 .10218 L
s
[(150)] .52068 .08732 .77926 1 Mshowa
.70061 .03371 m
.70418 .03887 L
s
[(200)] .69347 .02338 .69136 1 Mshowa
.125 Mabswid
.08932 .25918 m
.09202 .26181 L
s
.11875 .24832 m
.12143 .25098 L
s
.14847 .23736 m
.15112 .24004 L
s
.17847 .2263 m
.1811 .229 L
s
.23933 .20385 m
.24191 .2066 L
s
.27021 .19246 m
.27276 .19523 L
s
.30138 .18096 m
.30391 .18376 L
s
.33286 .16935 m
.33536 .17217 L
s
.39676 .14578 m
.3992 .14866 L
s
.42918 .13383 m
.43159 .13672 L
s
.46192 .12175 m
.4643 .12467 L
s
.495 .10955 m
.49734 .1125 L
s
.56215 .08478 m
.56443 .08778 L
s
.59623 .07221 m
.59848 .07523 L
s
.63067 .05951 m
.63289 .06255 L
s
.66546 .04667 m
.66764 .04975 L
s
.73613 .02061 m
.73823 .02373 L
s
.77201 .00737 m
.77408 .01052 L
s
.25 Mabswid
.792 0 m
.95795 .2567 L
s
.80429 .019 m
.79839 .02116 L
s
[(-50)] .81608 .01469 -1 .36545 Mshowa
.8427 .07843 m
.83679 .08053 L
s
[(-25)] .85454 .07423 -1 .35493 Mshowa
.87936 .13513 m
.87343 .13718 L
s
[(0)] .89124 .13104 -1 .345 Mshowa
.91438 .1893 m
.90843 .1913 L
s
[(25)] .92629 .18531 -1 .3356 Mshowa
.94787 .2411 m
.9419 .24305 L
s
[(50)] .95981 .2372 -1 .32671 Mshowa
.125 Mabswid
.81212 .03112 m
.80858 .0324 L
s
.81987 .04311 m
.81633 .04439 L
s
.82756 .055 m
.82401 .05627 L
s
.83517 .06677 m
.83162 .06804 L
s
.85017 .08998 m
.84662 .09124 L
s
.85757 .10143 m
.85402 .10268 L
s
.8649 .11277 m
.86135 .11401 L
s
.87217 .124 m
.86861 .12524 L
s
.8865 .14617 m
.88293 .14739 L
s
.89356 .1571 m
.89 .15831 L
s
.90057 .16793 m
.897 .16914 L
s
.90751 .17866 m
.90394 .17987 L
s
.9212 .19985 m
.91763 .20104 L
s
.92796 .2103 m
.92438 .21148 L
s
.93465 .22065 m
.93107 .22184 L
s
.94129 .23092 m
.93771 .2321 L
s
.79638 .00678 m
.79284 .00808 L
s
.95439 .25119 m
.95081 .25235 L
s
.25 Mabswid
.95795 .2567 m
1 .60209 L
s
.96055 .27806 m
.95457 .27997 L
s
[(-50)] .97251 .27422 -1 .32092 Mshowa
.96914 .34862 m
.96315 .35048 L
s
[(-25)] .98114 .34489 -1 .3106 Mshowa
.97806 .42185 m
.97204 .42366 L
s
[(0)] .99009 .41825 -1 .29992 Mshowa
.98732 .49791 m
.98128 .49965 L
s
[(25)] .99938 .49442 -1 .28886 Mshowa
.99694 .57695 m
.99089 .57863 L
s
[(50)] 1.00904 .5736 -1 .27739 Mshowa
.125 Mabswid
.96225 .29196 m
.95866 .29311 L
s
.96395 .30597 m
.96036 .30711 L
s
.96567 .32008 m
.96208 .32121 L
s
.9674 .3343 m
.9638 .33542 L
s
.9709 .36305 m
.9673 .36416 L
s
.97267 .37759 m
.96907 .37869 L
s
.97445 .39223 m
.97085 .39333 L
s
.97625 .40699 m
.97264 .40808 L
s
.97988 .43683 m
.97627 .43791 L
s
.98172 .45193 m
.97811 .453 L
s
.98357 .46714 m
.97996 .4682 L
s
.98544 .48247 m
.98182 .48352 L
s
.98921 .51347 m
.98559 .51451 L
s
.99112 .52916 m
.9875 .53019 L
s
.99305 .54497 m
.98942 .54599 L
s
.99499 .5609 m
.99136 .56191 L
s
.95887 .26425 m
.95529 .26541 L
s
.99891 .59314 m
.99528 .59414 L
s
0 0 m
1 0 L
1 .81031 L
0 .81031 L
closepath
clip
newpath
.5 Mabswid
.93681 .26473 m
.26877 .4811 L
s
.25094 .79334 m
.26877 .4811 L
s
.938 .685 .527 r
.18561 .52611 m .19799 .51949 L .20436 .54081 L F
.17962 .51267 m .19799 .51949 L .18561 .52611 L F
.17962 .51267 m .1891 .4995 L .19799 .51949 L F
.18989 .54045 m .20436 .54081 L .20781 .5621 L F
.18561 .52611 m .20436 .54081 L .18989 .54045 L F
0 g
.19799 .51949 m
.20436 .54081 L
s
.938 .685 .527 r
.17231 .501 m .1891 .4995 L .17962 .51267 L F
.17231 .501 m .17824 .48208 L .1891 .4995 L F
0 g
.1891 .4995 m
.19799 .51949 L
s
.938 .685 .527 r
.19219 .55476 m .20781 .5621 L .2081 .58202 L F
.18989 .54045 m .20781 .5621 L .19219 .55476 L F
0 g
.20436 .54081 m
.20781 .5621 L
s
.938 .685 .527 r
.16413 .49188 m .17824 .48208 L .17231 .501 L F
.16413 .49188 m .16608 .46838 L .17824 .48208 L F
0 g
.17824 .48208 m
.1891 .4995 L
s
.938 .685 .527 r
.19219 .55476 m .2081 .58202 L .19234 .56812 L F
.19234 .56812 m .2081 .58202 L .20517 .59929 L F
0 g
.20781 .5621 m
.2081 .58202 L
s
.938 .685 .527 r
.173 .53285 m .18561 .52611 L .18989 .54045 L F
.16998 .52607 m .18561 .52611 L .173 .53285 L F
.16998 .52607 m .17962 .51267 L .18561 .52611 L F
.17516 .54008 m .18989 .54045 L .19219 .55476 L F
.173 .53285 m .18989 .54045 L .17516 .54008 L F
.15563 .48592 m .16608 .46838 L .16413 .49188 L F
.15563 .48592 m .15339 .45934 L .16608 .46838 L F
0 g
.16608 .46838 m
.17824 .48208 L
s
.938 .685 .527 r
.16628 .52021 m .17962 .51267 L .16998 .52607 L F
.16628 .52021 m .17231 .501 L .17962 .51267 L F
.17631 .5473 m .19219 .55476 L .19234 .56812 L F
.17516 .54008 m .19219 .55476 L .17631 .5473 L F
.19033 .57964 m .20517 .59929 L .19918 .61274 L F
.19234 .56812 m .20517 .59929 L .19033 .57964 L F
0 g
.20517 .59929 m
.2081 .58202 L
s
.938 .685 .527 r
.16216 .51565 m .17231 .501 L .16628 .52021 L F
.16216 .51565 m .16413 .49188 L .17231 .501 L F
.17631 .5473 m .19234 .56812 L .17637 .55401 L F
.17637 .55401 m .19234 .56812 L .19033 .57964 L F
.15789 .51271 m .16413 .49188 L .16216 .51565 L F
.15789 .51271 m .15563 .48592 L .16413 .49188 L F
.14736 .48356 m .15339 .45934 L .15563 .48592 L F
.14736 .48356 m .14099 .45562 L .15339 .45934 L F
0 g
.15339 .45934 m
.16608 .46838 L
s
.938 .685 .527 r
.19033 .57964 m .19918 .61274 L .18625 .58855 L F
.17533 .55978 m .19033 .57964 L .18625 .58855 L F
.17637 .55401 m .19033 .57964 L .17533 .55978 L F
.18625 .58855 m .19918 .61274 L .19045 .6214 L F
0 g
.19918 .61274 m
.20517 .59929 L
s
.938 .685 .527 r
.16016 .53971 m .173 .53285 L .17516 .54008 L F
.16016 .53971 m .16998 .52607 L .173 .53285 L F
.16016 .53971 m .17516 .54008 L .17631 .5473 L F
.16016 .53971 m .16628 .52021 L .16998 .52607 L F
.16016 .53971 m .17631 .5473 L .17637 .55401 L F
0 g
.25094 .79334 m
.97493 .59359 L
s
.938 .685 .527 r
.15375 .51159 m .15563 .48592 L .15789 .51271 L F
.15375 .51159 m .14736 .48356 L .15563 .48592 L F
.16016 .53971 m .16216 .51565 L .16628 .52021 L F
.16016 .53971 m .17637 .55401 L .17533 .55978 L F
.18625 .58855 m .19045 .6214 L .18037 .59422 L F
.17325 .56421 m .18625 .58855 L .18037 .59422 L F
.17533 .55978 m .18625 .58855 L .17325 .56421 L F
.16016 .53971 m .15789 .51271 L .16216 .51565 L F
.16016 .53971 m .17533 .55978 L .17325 .56421 L F
.13989 .48502 m .14099 .45562 L .14736 .48356 L F
.13989 .48502 m .12973 .4576 L .14099 .45562 L F
0 g
.14099 .45562 m
.15339 .45934 L
s
.938 .685 .527 r
.16016 .53971 m .15375 .51159 L .15789 .51271 L F
.17325 .56421 m .18037 .59422 L .17027 .56699 L F
.16016 .53971 m .17325 .56421 L .17027 .56699 L F
.15003 .51239 m .14736 .48356 L .15375 .51159 L F
.15003 .51239 m .13989 .48502 L .14736 .48356 L F
.18037 .59422 m .19045 .6214 L .17952 .6246 L F
0 g
.19045 .6214 m
.19918 .61274 L
s
.938 .685 .527 r
.18037 .59422 m .17952 .6246 L .17304 .59621 L F
.17027 .56699 m .18037 .59422 L .17304 .59621 L F
.16016 .53971 m .15003 .51239 L .15375 .51159 L F
.17027 .56699 m .17304 .59621 L .16659 .56792 L F
.16016 .53971 m .17027 .56699 L .16659 .56792 L F
0 0 0 r
2.5 Mabswid
.16125 .54067 Mdot
.16125 .54067 Mdot
.16114 .54058 Mdot
.16114 .54058 Mdot
.16085 .54032 Mdot
.16085 .54032 Mdot
.16067 .54016 Mdot
.16067 .54016 Mdot
.938 .685 .527 r
.16016 .53971 m .14699 .51505 L .15003 .51239 L F
.16016 .53971 m .14484 .51942 L .14699 .51505 L F
.16016 .53971 m .14372 .5252 L .14484 .51942 L F
.16016 .53971 m .14374 .53199 L .14372 .5252 L F
.16016 .53971 m .14488 .53933 L .14374 .53199 L F
.16016 .53971 m .14708 .5467 L .14488 .53933 L F
.16016 .53971 m .15017 .55359 L .14708 .5467 L F
.16016 .53971 m .15395 .55951 L .15017 .55359 L F
.16016 .53971 m .15814 .56406 L .15395 .55951 L F
.16016 .53971 m .16245 .56692 L .15814 .56406 L F
.16016 .53971 m .16659 .56792 L .16245 .56692 L F
0 0 0 r
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.16016 .53971 Mdot
.15965 .53926 Mdot
.15965 .53926 Mdot
.15948 .5391 Mdot
.15948 .5391 Mdot
.15918 .53884 Mdot
.15918 .53884 Mdot
.15908 .53875 Mdot
.15908 .53875 Mdot
.938 .685 .527 r
.14699 .51505 m .13989 .48502 L .15003 .51239 L F
.16659 .56792 m .16477 .59435 L .16245 .56692 L F
.16659 .56792 m .17304 .59621 L .16477 .59435 L F
.13373 .49024 m .12973 .4576 L .13989 .48502 L F
.14699 .51505 m .13373 .49024 L .13989 .48502 L F
.13373 .49024 m .12039 .46526 L .12973 .4576 L F
0 g
.5 Mabswid
.12973 .4576 m
.14099 .45562 L
s
.938 .685 .527 r
.17304 .59621 m .16709 .62199 L .16477 .59435 L F
.17304 .59621 m .17952 .6246 L .16709 .62199 L F
0 g
.17952 .6246 m
.19045 .6214 L
s
.938 .685 .527 r
.14484 .51942 m .13373 .49024 L .14699 .51505 L F
.16245 .56692 m .1561 .58869 L .15814 .56406 L F
.16245 .56692 m .16477 .59435 L .1561 .58869 L F
.14484 .51942 m .12934 .49891 L .13373 .49024 L F
.14372 .5252 m .12934 .49891 L .14484 .51942 L F
.15814 .56406 m .14764 .57961 L .15395 .55951 L F
.15814 .56406 m .1561 .58869 L .14764 .57961 L F
.12934 .49891 m .12039 .46526 L .13373 .49024 L F
0 g
.06205 .28395 m
.26877 .4811 L
s
.938 .685 .527 r
.14372 .5252 m .12705 .51048 L .12934 .49891 L F
.14374 .53199 m .12705 .51048 L .14372 .5252 L F
0 g
.02461 .61146 m
.06205 .28395 L
s
.938 .685 .527 r
.15395 .55951 m .14001 .56771 L .15017 .55359 L F
.15395 .55951 m .14764 .57961 L .14001 .56771 L F
.16477 .59435 m .15403 .61363 L .1561 .58869 L F
.16477 .59435 m .16709 .62199 L .15403 .61363 L F
0 g
.16709 .62199 m
.17952 .6246 L
s
.938 .685 .527 r
.14374 .53199 m .12703 .52414 L .12705 .51048 L F
.14488 .53933 m .12703 .52414 L .14374 .53199 L F
.15017 .55359 m .13375 .55382 L .14708 .5467 L F
.15017 .55359 m .14001 .56771 L .13375 .55382 L F
.14488 .53933 m .12932 .53894 L .12703 .52414 L F
.14708 .5467 m .12932 .53894 L .14488 .53933 L F
.14708 .5467 m .13375 .55382 L .12932 .53894 L F
.12934 .49891 m .11368 .47818 L .12039 .46526 L F
0 g
.12039 .46526 m
.12973 .4576 L
s
.938 .685 .527 r
.12705 .51048 m .11368 .47818 L .12934 .49891 L F
.1561 .58869 m .14124 .60003 L .14764 .57961 L F
.1561 .58869 m .15403 .61363 L .14124 .60003 L F
0 g
.15403 .61363 m
.16709 .62199 L
s
.02461 .61146 m
.25094 .79334 L
s
.938 .685 .527 r
.12705 .51048 m .11013 .49554 L .11368 .47818 L F
0 g
.11368 .47818 m
.12039 .46526 L
s
.938 .685 .527 r
.12703 .52414 m .11013 .49554 L .12705 .51048 L F
.14764 .57961 m .12966 .58209 L .14001 .56771 L F
.14764 .57961 m .14124 .60003 L .12966 .58209 L F
0 g
.93681 .26473 m
.97493 .59359 L
s
.938 .685 .527 r
.12703 .52414 m .11004 .51616 L .11013 .49554 L F
0 g
.11013 .49554 m
.11368 .47818 L
s
.938 .685 .527 r
.12932 .53894 m .11004 .51616 L .12703 .52414 L F
.14001 .56771 m .12017 .56108 L .13375 .55382 L F
.14001 .56771 m .12966 .58209 L .12017 .56108 L F
0 g
.14124 .60003 m
.15403 .61363 L
s
.938 .685 .527 r
.12932 .53894 m .11346 .53855 L .11004 .51616 L F
.13375 .55382 m .11346 .53855 L .12932 .53894 L F
.13375 .55382 m .12017 .56108 L .11346 .53855 L F
0 g
.11004 .51616 m
.11013 .49554 L
s
.12966 .58209 m
.14124 .60003 L
s
.11004 .51616 m
.11346 .53855 L
s
.12017 .56108 m
.12966 .58209 L
s
.11346 .53855 m
.12017 .56108 L
s
0 0 .294 r
.80949 .28696 m .80114 .26859 L .81991 .31126 L F
0 0 .24 r
.82177 .31615 m .81991 .31126 L .83571 .35587 L F
0 0 .294 r
.80949 .28696 m .81991 .31126 L .82177 .31615 L F
.727 .445 0 r
.83204 .3467 m .83571 .35587 L .84726 .40003 L F
0 0 .24 r
.82177 .31615 m .83571 .35587 L .83204 .3467 L F
0 g
.82101 .31436 m
.82404 .32291 L
s
.655 .267 0 r
.79612 .26085 m .80114 .26859 L .80949 .28696 L F
0 g
.80759 .28325 m
.81527 .30071 L
s
.655 .267 0 r
.79612 .26085 m .78084 .23021 L .80114 .26859 L F
.818 .563 .008 r
.83954 .37681 m .84726 .40003 L .8536 .44124 L F
.727 .445 0 r
.83204 .3467 m .84726 .40003 L .83954 .37681 L F
0 g
.83571 .35587 m
.84726 .40003 L
s
.704 .283 0 r
.78257 .23943 m .78084 .23021 L .79612 .26085 L F
.78257 .23943 m .76046 .19832 L .78084 .23021 L F
0 g
.78084 .23021 m
.80114 .26859 L
s
.67181 .06049 m
.77705 .02192 L
s
.06205 .28395 m
.67181 .06049 L
s
.818 .563 .008 r
.83954 .37681 m .8536 .44124 L .84367 .40467 L F
.907 .678 .174 r
.84367 .40467 m .8536 .44124 L .85412 .47702 L F
.2 0 1 r
.16125 .54067 m
.84551 .41741 L
s
0 g
.84726 .40003 m
.8536 .44124 L
s
.8536 .44124 m
.8536 .44124 L
s
.77 .328 0 r
.76975 .22413 m .76046 .19832 L .78257 .23943 L F
.76975 .22413 m .74136 .175 L .76046 .19832 L F
0 g
.76046 .19832 m
.78084 .23021 L
s
.76046 .19832 m
.76046 .19832 L
s
.877 .541 .037 r
.81687 .32347 m .82177 .31615 L .83204 .3467 L F
.866 .509 .009 r
.81081 .30851 m .82177 .31615 L .81687 .32347 L F
.81081 .30851 m .80949 .28696 L .82177 .31615 L F
.9 .588 .093 r
.8219 .33913 m .83204 .3467 L .83954 .37681 L F
.877 .541 .037 r
.81687 .32347 m .83204 .3467 L .8219 .33913 L F
.869 .495 .009 r
.80417 .29522 m .80949 .28696 L .81081 .30851 L F
.80417 .29522 m .79612 .26085 L .80949 .28696 L F
.97 .762 .328 r
.84407 .42852 m .85412 .47702 L .8487 .50493 L F
.907 .678 .174 r
.84367 .40467 m .85412 .47702 L .84407 .42852 L F
0 g
.8536 .44124 m
.85412 .47702 L
s
.2 0 1 r
.30988 .49178 m
.84389 .41754 L
s
.84705 .41713 m
.84714 .41711 L
s
.84714 .41711 m
.84772 .41701 L
s
.84705 .4171 m
.84713 .41709 L
s
.84713 .41709 m
.84772 .41701 L
s
0 0 0 r
2.5 Mabswid
.84772 .41701 Mdot
.84772 .41701 Mdot
.932 .642 .171 r
.82556 .35452 m .83954 .37681 L .84367 .40467 L F
.9 .588 .093 r
.8219 .33913 m .83954 .37681 L .82556 .35452 L F
.882 .495 .032 r
.79738 .28446 m .79612 .26085 L .80417 .29522 L F
.79738 .28446 m .78257 .23943 L .79612 .26085 L F
.932 .642 .171 r
.82556 .35452 m .84367 .40467 L .82756 .36863 L F
.963 .693 .259 r
.82756 .36863 m .84367 .40467 L .84407 .42852 L F
0 g
.5 Mabswid
.84367 .40467 m
.8536 .44124 L
s
.2 0 1 r
.83984 .39605 m
.84037 .39596 L
s
.30988 .49178 m
.83535 .39686 L
s
.83982 .39606 m
.83984 .39605 L
s
.83984 .39607 m
.84037 .39596 L
s
.15965 .53926 m
.83538 .39701 L
s
.83983 .39607 m
.83984 .39607 L
s
.835 .388 0 r
.75845 .21611 m .74136 .175 L .76975 .22413 L F
.75845 .21611 m .72464 .1621 L .74136 .175 L F
0 g
.74136 .175 m
.76046 .19832 L
s
0 0 0 r
2.5 Mabswid
.84037 .39596 Mdot
.84037 .39596 Mdot
.899 .507 .075 r
.79091 .27696 m .78257 .23943 L .79738 .28446 L F
1 0 0 r
.5 Mabswid
.16016 .53971 m
.79162 .27778 L
s
.79476 .27647 m
.79529 .27625 L
s
.46689 .44151 m
.79182 .278 L
s
.79477 .27652 m
.79529 .27625 L
s
.899 .507 .075 r
.79091 .27696 m .76975 .22413 L .78257 .23943 L F
1 0 0 r
.78901 .25899 m
.78988 .25849 L
s
.46689 .44151 m
.78469 .26143 L
s
.78898 .2589 m
.78988 .25849 L
s
.16016 .53971 m
.78448 .2609 L
s
0 g
.76046 .19832 m
.78257 .23943 L
s
.97 .762 .328 r
.84407 .42852 m .8487 .50493 L .84068 .44675 L F
.984 .732 .342 r
.82776 .38056 m .84407 .42852 L .84068 .44675 L F
.963 .693 .259 r
.82756 .36863 m .84407 .42852 L .82776 .38056 L F
.2 0 1 r
.30988 .49178 m
.82768 .37564 L
s
.15918 .53884 m
.82768 .3757 L
s
.83047 .37502 m
.83085 .37493 L
s
.83042 .37503 m
.83047 .37502 L
s
.83047 .37501 m
.83085 .37493 L
s
.83042 .37502 m
.83047 .37501 L
s
.997 .805 .448 r
.84068 .44675 m .8487 .50493 L .83769 .52281 L F
0 g
.8487 .50493 m
.85412 .47702 L
s
0 0 0 r
2.5 Mabswid
.78988 .25849 Mdot
.78988 .25849 Mdot
.964 .644 .259 r
.80503 .33325 m .81687 .32347 L .8219 .33913 L F
.962 .635 .253 r
.80503 .33325 m .81081 .30851 L .81687 .32347 L F
.968 .655 .273 r
.80503 .33325 m .8219 .33913 L .82556 .35452 L F
.961 .63 .253 r
.80503 .33325 m .80417 .29522 L .81081 .30851 L F
.917 .527 .132 r
.78518 .27325 m .76975 .22413 L .79091 .27696 L F
.78518 .27325 m .75845 .21611 L .76975 .22413 L F
0 0 0 r
.83085 .37493 Mdot
.83085 .37493 Mdot
.973 .669 .295 r
.80503 .33325 m .82556 .35452 L .82756 .36863 L F
.961 .628 .257 r
.80503 .33325 m .79738 .28446 L .80417 .29522 L F
0 0 0 r
.79529 .27625 Mdot
.79529 .27625 Mdot
.978 .683 .322 r
.80503 .33325 m .82756 .36863 L .82776 .38056 L F
0 g
.5 Mabswid
.82756 .36863 m
.84367 .40467 L
s
.997 .805 .448 r
.84068 .44675 m .83769 .52281 L .83373 .45797 L F
.995 .756 .411 r
.82613 .38948 m .84068 .44675 L .83373 .45797 L F
.984 .732 .342 r
.82776 .38056 m .84068 .44675 L .82613 .38948 L F
.883 .452 .084 r
.74934 .21618 m .72464 .1621 L .75845 .21611 L F
.74934 .21618 m .71121 .16105 L .72464 .1621 L F
0 g
.72464 .1621 m
.74136 .175 L
s
.961 .628 .265 r
.80503 .33325 m .79091 .27696 L .79738 .28446 L F
1 0 0 r
.16016 .53971 m
.79572 .29614 L
s
.79902 .29488 m
.79963 .29465 L
s
.46689 .44151 m
.79578 .29635 L
s
.79902 .29492 m
.79963 .29465 L
s
0 g
.78257 .23943 m
.79738 .28446 L
s
.982 .695 .349 r
.80503 .33325 m .82776 .38056 L .82613 .38948 L F
.2 0 1 r
.81837 .3542 m
.81854 .35415 L
s
.15948 .5391 m
.81341 .35559 L
s
.81854 .35415 m
.81909 .354 L
s
.81837 .35419 m
.81854 .35415 L
s
.30988 .49178 m
.81339 .35554 L
s
.81854 .35415 m
.81909 .354 L
s
0 0 0 r
2.5 Mabswid
.79963 .29465 Mdot
.79963 .29465 Mdot
.999 .817 .529 r
.83373 .45797 m .83769 .52281 L .82197 .52886 L F
0 g
.5 Mabswid
.83769 .52281 m
.8487 .50493 L
s
0 0 0 r
2.5 Mabswid
.81909 .354 Mdot
.81909 .354 Mdot
.962 .629 .276 r
.80503 .33325 m .78518 .27325 L .79091 .27696 L F
1 0 0 r
.5 Mabswid
.80207 .31396 m
.80289 .31365 L
s
.80201 .31399 m
.80207 .31396 L
s
.46689 .44151 m
.79903 .31512 L
s
.80207 .31394 m
.80289 .31365 L
s
.80201 .31396 m
.80207 .31394 L
s
.16016 .53971 m
.799 .31502 L
s
.932 .551 .197 r
.78056 .27366 m .75845 .21611 L .78518 .27325 L F
.78056 .27366 m .74934 .21618 L .75845 .21611 L F
.995 .756 .411 r
.82613 .38948 m .83373 .45797 L .82278 .39475 L F
.984 .702 .372 r
.80503 .33325 m .82613 .38948 L .82278 .39475 L F
.999 .817 .529 r
.83373 .45797 m .82197 .52886 L .82375 .46117 L F
.996 .765 .462 r
.82278 .39475 m .83373 .45797 L .82375 .46117 L F
0 0 0 r
2.5 Mabswid
.80289 .31365 Mdot
.80289 .31365 Mdot
.964 .633 .292 r
.80503 .33325 m .78056 .27366 L .78518 .27325 L F
.996 .765 .462 r
.82278 .39475 m .82375 .46117 L .81796 .39594 L F
.985 .706 .39 r
.80503 .33325 m .82278 .39475 L .81796 .39594 L F
.966 .639 .313 r
.80503 .33325 m .77734 .27824 L .78056 .27366 L F
.968 .648 .336 r
.80503 .33325 m .77572 .28675 L .77734 .27824 L F
.97 .658 .361 r
.80503 .33325 m .77583 .29865 L .77572 .28675 L F
.971 .669 .382 r
.80503 .33325 m .77765 .31313 L .77583 .29865 L F
.2 0 1 r
.5 Mabswid
.78813 .31297 m
.78843 .31286 L
s
.78796 .31303 m
.78813 .31297 L
s
.78843 .31286 m
.78866 .31278 L
s
.78814 .31297 m
.78843 .31286 L
s
.78797 .31303 m
.78814 .31297 L
s
.78843 .31286 m
.78866 .31278 L
s
.974 .679 .399 r
.80503 .33325 m .78108 .32917 L .77765 .31313 L F
.2 0 1 r
.30988 .49178 m
.7784 .31661 L
s
.16085 .54032 m
.77837 .3165 L
s
.976 .688 .41 r
.80503 .33325 m .78592 .34562 L .78108 .32917 L F
1 0 0 r
.46689 .44151 m
.78424 .33991 L
s
.2 0 1 r
.30988 .49178 m
.78424 .33991 L
s
1 0 0 r
.16016 .53971 m
.78424 .33991 L
s
.978 .696 .416 r
.80503 .33325 m .79185 .36126 L .78592 .34562 L F
1 0 0 r
.46689 .44151 m
.79042 .35748 L
s
.16016 .53971 m
.79057 .35789 L
s
.98 .701 .417 r
.80503 .33325 m .79847 .37496 L .79185 .36126 L F
0 g
.02461 .61146 m
.7096 .39531 L
s
.982 .704 .415 r
.80503 .33325 m .80535 .38575 L .79847 .37496 L F
0 g
.7096 .39531 m
.71115 .39482 L
s
.983 .707 .41 r
.80503 .33325 m .81201 .39289 L .80535 .38575 L F
.984 .707 .403 r
.80503 .33325 m .81796 .39594 L .81201 .39289 L F
1 0 0 r
.8057 .3742 m
.80592 .37414 L
s
.8057 .37419 m
.80592 .37414 L
s
.80596 .35345 m
.80605 .35342 L
s
.80536 .35362 m
.80561 .35355 L
s
.80561 .35355 m
.80596 .35345 L
s
.80596 .35345 m
.80605 .35342 L
s
.80536 .3536 m
.8056 .35354 L
s
.8056 .35354 m
.80596 .35345 L
s
.80541 .37424 m
.8057 .37419 L
s
.80541 .37427 m
.8057 .3742 L
s
.80528 .37431 m
.80541 .37427 L
s
.80528 .37427 m
.80541 .37424 L
s
0 0 0 r
2.5 Mabswid
.80503 .33325 Mdot
.80503 .33325 Mdot
.80503 .33325 Mdot
.80503 .33325 Mdot
0 g
.5 Mabswid
.79738 .28446 m
.80503 .33325 L
s
.80503 .33325 m
.82756 .36863 L
s
1 0 0 r
.80516 .35366 m
.80522 .35364 L
s
.80522 .35364 m
.80536 .3536 L
s
.80516 .35368 m
.80522 .35366 L
s
.80522 .35366 m
.80536 .35362 L
s
.911 .51 .211 r
.74295 .22463 m .71121 .16105 L .74934 .21618 L F
.74295 .22463 m .70173 .17264 L .71121 .16105 L F
0 g
.71121 .16105 m
.72464 .1621 L
s
.942 .577 .265 r
.77734 .27824 m .74934 .21618 L .78056 .27366 L F
.77734 .27824 m .74295 .22463 L .74934 .21618 L F
.991 .765 .497 r
.81796 .39594 m .81149 .45581 L .81201 .39289 L F
.81796 .39594 m .82375 .46117 L .81149 .45581 L F
.988 .81 .577 r
.82375 .46117 m .80285 .522 L .81149 .45581 L F
.82375 .46117 m .82197 .52886 L .80285 .522 L F
0 g
.82197 .52886 m
.83769 .52281 L
s
0 0 0 r
2.5 Mabswid
.80605 .35342 Mdot
.80605 .35342 Mdot
.947 .604 .331 r
.77572 .28675 m .74295 .22463 L .77734 .27824 L F
0 g
.5 Mabswid
.77705 .02192 m
.93681 .26473 L
s
.984 .758 .518 r
.81201 .39289 m .79791 .44198 L .80535 .38575 L F
.81201 .39289 m .81149 .45581 L .79791 .44198 L F
1 0 0 r
.16016 .53971 m
.79907 .3759 L
s
.46689 .44151 m
.79885 .37555 L
s
0 0 0 r
2.5 Mabswid
.78866 .31278 Mdot
.78866 .31278 Mdot
.80592 .37414 Mdot
.80592 .37414 Mdot
.947 .604 .331 r
.77572 .28675 m .73967 .2412 L .74295 .22463 L F
.949 .629 .389 r
.77583 .29865 m .73967 .2412 L .77572 .28675 L F
.922 .558 .32 r
.73967 .2412 m .70173 .17264 L .74295 .22463 L F
.976 .747 .528 r
.80535 .38575 m .784 .42045 L .79847 .37496 L F
1 0 0 r
.5 Mabswid
.16016 .53971 m
.791 .39843 L
s
.46689 .44151 m
.7914 .39719 L
s
.976 .747 .528 r
.80535 .38575 m .79791 .44198 L .784 .42045 L F
0 g
.80503 .33325 m
.80535 .38575 L
s
1 0 0 r
.80117 .41731 m
.80124 .4173 L
s
.80124 .4173 m
.80213 .41713 L
s
.80407 .39546 m
.80409 .39546 L
s
.80409 .39546 m
.80462 .39539 L
s
.46689 .44151 m
.78465 .4184 L
s
.80119 .4172 m
.80125 .41719 L
s
.80125 .41719 m
.80213 .41713 L
s
.80406 .39551 m
.80408 .39551 L
s
.80408 .39551 m
.80462 .39539 L
s
0 0 0 r
2.5 Mabswid
.80462 .39539 Mdot
.80462 .39539 Mdot
.972 .793 .602 r
.81149 .45581 m .78191 .50203 L .79791 .44198 L F
.81149 .45581 m .80285 .522 L .78191 .50203 L F
1 0 0 r
.5 Mabswid
.16016 .53971 m
.78408 .42057 L
s
0 g
.80412 .36548 m
.97493 .59359 L
s
.80285 .522 m
.82197 .52886 L
s
.949 .629 .389 r
.77583 .29865 m .7397 .26494 L .73967 .2412 L F
.95 .652 .437 r
.77765 .31313 m .7397 .26494 L .77583 .29865 L F
0 g
.77583 .29865 m
.80503 .33325 L
s
.2 0 1 r
.76959 .29282 m
.76998 .29265 L
s
.30988 .49178 m
.76367 .29538 L
s
.76958 .29281 m
.76998 .29265 L
s
.16114 .54058 m
.76358 .29526 L
s
.968 .732 .529 r
.79847 .37496 m .77076 .39267 L .79185 .36126 L F
.79847 .37496 m .784 .42045 L .77076 .39267 L F
.922 .558 .32 r
.73967 .2412 m .69669 .19678 L .70173 .17264 L F
0 g
.70173 .17264 m
.71121 .16105 L
s
0 0 0 r
2.5 Mabswid
.76998 .29265 Mdot
.76998 .29265 Mdot
.95 .652 .437 r
.77765 .31313 m .74308 .29427 L .7397 .26494 L F
.2 0 1 r
.5 Mabswid
.30988 .49178 m
.74108 .27691 L
s
.74856 .27318 m
.74903 .27295 L
s
.74855 .27319 m
.74856 .27318 L
s
.16067 .54016 m
.74105 .27657 L
s
.74854 .27317 m
.74903 .27295 L
s
.74853 .27318 m
.74854 .27317 L
s
.952 .675 .475 r
.78108 .32917 m .74308 .29427 L .77765 .31313 L F
.961 .715 .521 r
.79185 .36126 m .75906 .36071 L .78592 .34562 L F
.79185 .36126 m .77076 .39267 L .75906 .36071 L F
0 0 0 r
2.5 Mabswid
.80213 .41713 Mdot
.80213 .41713 Mdot
.952 .675 .475 r
.78108 .32917 m .74965 .32703 L .74308 .29427 L F
.956 .696 .503 r
.78592 .34562 m .74965 .32703 L .78108 .32917 L F
.78592 .34562 m .75906 .36071 L .74965 .32703 L F
0 g
.5 Mabswid
.77705 .02192 m
.80412 .36548 L
s
.924 .598 .407 r
.7397 .26494 m .69669 .19678 L .73967 .2412 L F
.957 .771 .61 r
.79791 .44198 m .76078 .46988 L .784 .42045 L F
.79791 .44198 m .78191 .50203 L .76078 .46988 L F
0 g
.79791 .44198 m
.80535 .38575 L
s
.78191 .50203 m
.80285 .522 L
s
0 0 0 r
2.5 Mabswid
.74903 .27295 Mdot
.74903 .27295 Mdot
.924 .598 .407 r
.7397 .26494 m .69641 .23228 L .69669 .19678 L F
0 g
.5 Mabswid
.69669 .19678 m
.70173 .17264 L
s
.923 .632 .474 r
.74308 .29427 m .69641 .23228 L .7397 .26494 L F
0 g
.7397 .26494 m
.77583 .29865 L
s
.2 0 1 r
.72529 .25406 m
.72585 .25375 L
s
.30988 .49178 m
.71657 .25905 L
s
.72526 .25404 m
.72585 .25375 L
s
.15908 .53875 m
.71622 .25859 L
s
.944 .746 .606 r
.784 .42045 m .741 .4277 L .77076 .39267 L F
.784 .42045 m .76078 .46988 L .741 .4277 L F
0 g
.78191 .50203 m
.79791 .44198 L
s
.76078 .46988 m
.78191 .50203 L
s
.78191 .50203 m
.78191 .50203 L
s
0 0 0 r
2.5 Mabswid
.72585 .25375 Mdot
.72585 .25375 Mdot
.923 .632 .474 r
.74308 .29427 m .70098 .27681 L .69641 .23228 L F
0 g
.5 Mabswid
.69641 .23228 m
.69669 .19678 L
s
.69641 .23228 m
.7397 .26494 L
s
.923 .663 .526 r
.74965 .32703 m .70098 .27681 L .74308 .29427 L F
.934 .72 .59 r
.77076 .39267 m .72382 .37872 L .75906 .36071 L F
.77076 .39267 m .741 .4277 L .72382 .37872 L F
.923 .663 .526 r
.74965 .32703 m .71025 .32698 L .70098 .27681 L F
.927 .692 .564 r
.75906 .36071 m .71025 .32698 L .74965 .32703 L F
.75906 .36071 m .72382 .37872 L .71025 .32698 L F
0 g
.71115 .39482 m
.80412 .36548 L
s
.69641 .23228 m
.70098 .27681 L
s
.69641 .23228 m
.69641 .23228 L
s
.741 .4277 m
.76078 .46988 L
s
.70098 .27681 m
.71025 .32698 L
s
.72382 .37872 m
.741 .4277 L
s
.71025 .32698 m
.72382 .37872 L
s
.25 Mabswid
.04128 .2769 m
.792 0 L
s
.06016 .26994 m
.06469 .27428 L
s
[(0)] .05109 .26124 1 .95882 Mshowa
.20875 .21513 m
.21309 .21967 L
s
[(50)] .20008 .20604 .95505 1 Mshowa
.36465 .15762 m
.36877 .16237 L
s
[(100)] .35642 .14814 .86715 1 Mshowa
.5284 .09723 m
.53226 .10218 L
s
[(150)] .52068 .08732 .77926 1 Mshowa
.70061 .03371 m
.70418 .03887 L
s
[(200)] .69347 .02338 .69136 1 Mshowa
.125 Mabswid
.08932 .25918 m
.09202 .26181 L
s
.11875 .24832 m
.12143 .25098 L
s
.14847 .23736 m
.15112 .24004 L
s
.17847 .2263 m
.1811 .229 L
s
.23933 .20385 m
.24191 .2066 L
s
.27021 .19246 m
.27276 .19523 L
s
.30138 .18096 m
.30391 .18376 L
s
.33286 .16935 m
.33536 .17217 L
s
.39676 .14578 m
.3992 .14866 L
s
.42918 .13383 m
.43159 .13672 L
s
.46192 .12175 m
.4643 .12467 L
s
.495 .10955 m
.49734 .1125 L
s
.56215 .08478 m
.56443 .08778 L
s
.59623 .07221 m
.59848 .07523 L
s
.63067 .05951 m
.63289 .06255 L
s
.66546 .04667 m
.66764 .04975 L
s
.73613 .02061 m
.73823 .02373 L
s
.77201 .00737 m
.77408 .01052 L
s
.25 Mabswid
.95795 .2567 m
1 .60209 L
s
.96055 .27806 m
.95457 .27997 L
s
[(-50)] .97251 .27422 -1 .32092 Mshowa
.96914 .34862 m
.96315 .35048 L
s
[(-25)] .98114 .34489 -1 .3106 Mshowa
.97806 .42185 m
.97204 .42366 L
s
[(0)] .99009 .41825 -1 .29992 Mshowa
.98732 .49791 m
.98128 .49965 L
s
[(25)] .99938 .49442 -1 .28886 Mshowa
.99694 .57695 m
.99089 .57863 L
s
[(50)] 1.00904 .5736 -1 .27739 Mshowa
.125 Mabswid
.96225 .29196 m
.95866 .29311 L
s
.96395 .30597 m
.96036 .30711 L
s
.96567 .32008 m
.96208 .32121 L
s
.9674 .3343 m
.9638 .33542 L
s
.9709 .36305 m
.9673 .36416 L
s
.97267 .37759 m
.96907 .37869 L
s
.97445 .39223 m
.97085 .39333 L
s
.97625 .40699 m
.97264 .40808 L
s
.97988 .43683 m
.97627 .43791 L
s
.98172 .45193 m
.97811 .453 L
s
.98357 .46714 m
.97996 .4682 L
s
.98544 .48247 m
.98182 .48352 L
s
.98921 .51347 m
.98559 .51451 L
s
.99112 .52916 m
.9875 .53019 L
s
.99305 .54497 m
.98942 .54599 L
s
.99499 .5609 m
.99136 .56191 L
s
.95887 .26425 m
.95529 .26541 L
s
.99891 .59314 m
.99528 .59414 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 486.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001iR000`400?l00000o`00003ooooooooo
oooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo
003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooolco
oooo0_l0002;ooooo`00ooooooo9ooooo`?o000000?oooooo`000?ooool0R_ooool00?ooooooa_oo
ool3o`0000Gooooo00?o0000ooooooooool0R?ooool00?ooooooa?ooool2o`0000Wooooo00?o0000
ooooooooool0Qoooool00?oooooo`Oooool3o`0000_ooooo0_l0000Aooooo`?o00001?ooool2o`00
06kooooo003ooooookkooooo0ol000000ooooooo0000ooooo`0:ooooo`03o`000?oooooo0000013o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0006gooooo003ooooo
ohGooooo1Ol00003ooooo`;o00001?ooool2o`0002Kooooo0ol00005ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`1[ooooo`00oooooon6ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000Sooooo`;o00005_ooool00ol0003ooooo
ooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0Joooool00?oooooo
Qoooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00008?ooool3o`0001Wooooo00?o0000ooooooooool03?ooool4o`0000?ooooo00Co0000oooo
oooooooo0000KOooool00?ooooooR?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Kooooo`?o00007?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000KOooool00?ooooooQOoo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0000Kooooo`;o00008?ooool00ol0003oooooooooo`0;ooooo`Go00000oooool2o`00
06kooooo003oooooohGooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00006?ooool3o`0002;ooooo0_l00024ooooo`00oooooon6
ooooo`?o00001?ooool2o`0000Cooooo0_l0000Fooooo`?o00009?ooool00ol0003oooooo`000024
ooooo`00oooooonXooooo`?o00000_ooool00ol0003oooooooooo`0Dooooo`;o00002oooool01Ol0
003ooooooooooooooooo000008?ooooo003oooooojKooooo0_l00006ooooo`03o`000?oooooooooo
013ooooo0ol000000ooooooo0000ooooo`0?ooooo`03o`000?oooooooooo083ooooo003ooooooj?o
oooo0ol0000Hooooo`?o00001?ooool2o`0000oooooo00?o0000ooooooooool0P?ooool00?oooooo
X?ooool3o`0001Sooooo0ol00007ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0
Ooooool00?ooooooW_ooool2o`0001Sooooo0ol0000:ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0O_ooool00?ooooooVoooool3o`0001Oooooo0ol0000=ooooo`04o`000?oooooo
ooooo`0000oooooo0_l0001oooooo`00oooooonHooooo`?o00006?ooool2o`00013ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooo000007oooooo003ooooooiGooooo1?l0000G
ooooo`?o00004_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0O?oo
ool00?ooooooToooool2o`0000?ooooo00?o0000ooooooooool04_ooool3o`0001Kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo07cooooo003ooooooi3ooooo0ol00006
ooooo`03o`000?oooooooooo00kooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1kooooo`00oooooon=ooooo`?o00002_ooool00ol0
003oooooooooo`0:ooooo`?o00007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0N_ooool00?ooooooRoooool2o`0001Sooooo0_l0000Oooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1jooooo`00
oooooon8ooooo`?o00005oooool3o`00027ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`;o0000Noooool00?ooooooQOooool3o`0001Oooooo0ol0000Tooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001kooooo`00oooooon3
ooooo`;o00005oooool3o`0002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo07Sooooo003ooooooh3ooooo0ol000000ooooooo0000ooooo`0Coooo
o`?o0000:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0Moooool00?ooooooOOooool3o`0000Gooooo00?o0000ooooooooool03_ooool3o`0002go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Oo
oooo003oooooog[ooooo0ol0000Gooooo`;o0000<?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0M_ooool00?ooooooN?ooool2o`0001Oooooo0ol0
000booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1eooooo`00oooooomeooooo`?o00005_ooool3o`0003Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`;o0000M_ooool00?ooooooL_ooool3o`0001Kooooo0ol0000hoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001foooo
o`00oooooom`ooooo`;o00005_ooool3o`0003cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo07?ooooo003oooooofgooooo0ol0000Fooooo`;o0000
?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Loooool00?ooooooJ_ooool3o`0000?ooooo00?o0000ooooooooool04?ooool3o`00047ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07;ooooo003o
ooooofOooooo0ol00007ooooo`03o`000?oooooooooo00cooooo0ol00014ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1aooooo`00oooooomUoooo
o`;o00005_ooool3o`0004Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo077ooooo003oooooof;ooooo0ol0000Fooooo`;o0000B_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000Aooooo`Go00000_ooool3o`0005Oo
oooo003ooooooeoooooo0ol0000Fooooo`?o0000C?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo00004Oooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool0E?ooool00?ooooooGOooool2o`0001Kooooo0ol0001?oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08oooo
o`Go00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo003ooooooe[o
oooo0ol0000Fooooo`;o0000D_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Co
oooo003oooooob3ooooo0ol00003ooooo`?o00001?ooool2o`0002Sooooo0ol00002ooooo`03o`00
0?oooooooooo017ooooo0ol0001Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`06o`000?ooooooooooooooool0003ooooo1?l0001Goooo
o`00oooooolQooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo02;ooooo0ol00006ooooo`03o`000?oooooooooo00gooooo0ol0001G
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`07o`000?ooooooooooooooool0003oooooo`00001Jooooo`00oooooolQooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Pooooo`;o0000
5_ooool3o`0005[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0ol00002ooooo`Go0000E_ooool00?oooooo8Oooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool07Oooool3o`0001Kooooo
0_l0001Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool3o`0006gooooo
003oooooob7ooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0001co
oooo0ol0000Fooooo`?o0000H?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wo
oooo0_l00002ooooo`03o`000?oooooooooo06_ooooo003oooooob3ooooo0_l00003ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00006_ooool2o`0001Kooooo0ol0001Sooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Zooooo`00
oooooolQooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0001Sooooo0ol0000Fooooo`;o
0000I_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0J_ooool00?ooooooA?ooool3o`000003ooooool0003ooooo01?ooooo0ol0001Xooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Yooooo`00oooo
oom2ooooo`;o00001Oooool00ol0003oooooooooo`0>ooooo`?o0000Joooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0J?ooool00?oooooo?oooool3
o`0001Gooooo0ol0001^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Xooooo`00oooooollooooo`?o00005_ooool2o`00077ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`?o0000JOooool00?oooooo>Oooool3o`0001Ko
oooo0ol0001cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Vooooo`00oooooolgooooo`;o00005_ooool3o`0007Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06Kooooo003oooooocCooooo0ol0
000Eooooo`?o0000NOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0IOooool00?oooooo<Oooool4o`0001Gooooo0_l0001looooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Tooooo`00ooooool_oooo
o`;o00000oooool00ol0003oooooooooo`0@ooooo`?o0000O_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0I?ooool00?oooooo;?ooool3o`0000Ko
oooo00?o0000ooooooooool03?ooool3o`00087ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0<ooooo`;o0000IOooool00?oooooo:Oooool3o`0000[ooooo00?o0000ooooooooool0
2Oooool2o`0008Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooo000006Gooooo003oooooobKooooo0ol0000Fooooo`?o0000Qoooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0H_ooool00?oooooo9?ooool2
o`0001Kooooo0ol0002:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Qooooo`00oooooolQooooo`?o00005Oooool3o`0008gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo067ooooo003ooooooako
oooo0ol0000Fooooo`;o0000T?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0H?ooool00?oooooo7?ooool2o`0000?ooooo00?o0000ooooooooool0
4?ooool3o`0009;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo05oooooo003ooooooaWooooo0ol00006ooooo`03o`000?oooooooooo00cooooo0ol0
002Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool2o`00063ooooo003o
oooooaKooooo0ol0000Eooooo`?o0000V?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooool00000H?ooool00?oooooo4oooool3o`0001Kooooo0_l0002Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Moooo
o`00oooooolAooooo`;o00005_ooool3o`0009gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo05gooooo003oooooo`kooooo0ol0000Eooooo`?o0000
X?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
G?ooool00?oooooo2oooool3o`0001Kooooo0_l0002Sooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1Kooooo`00ooooool9ooooo`;o00000oooool0
0ol0003oooooooooo`0@ooooo`?o0000YOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00gooooo0_l0000<ooooo`;o0000C_ooool00?oooooo1_ooool3o`0000Kooooo00?o0000oooo
ooooool03?ooool3o`000:Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000000_ooooo00Co0000oooooooooooo0000COooool00?oooooo0oooool3o`00
01Gooooo0ol0002/ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`08ooooo`04o`000?ooooooooooo`0004gooooo003oooooo`7ooooo0_l0000Foooo
o`;o0000[oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooool0001=ooooo`00oOooool3o`0001Gooooo0ol0002aoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0004gooooo003jooooo`?o00005Oooool3o`000;Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo0000COooool00;oooooo0ol00004ooooo`;o00001?ooool2o`0002Wooooo0ol0000Foooo
o`;o0000]oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool2o`0004kooooo0030ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Vooooo`;o00000oooool00ol0003oooooooooo`0@
ooooo`?o0000^Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo0_l0001H
ooooo`00`?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00008oooool3o`0000Kooooo00?o0000ooooooooool03?ooool3o`000;cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0Eooo
ool00<3ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`00023ooooo0ol0000Eooooo`?o0000_oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0EOooool00<3ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001kooooo0_l0000Fooooo`;o
0000`_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0E?ooool00;oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00006oooool3o`0001Gooooo0ol00034ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1Dooooo`00`?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool2o`0001Wooooo0ol0000Eooooo`?o0000aoooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0Doooool00>Cooooo0ol0000Eooooo`?o0000
b_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo0_l0001Dooooo`00h_oo
ool2o`0000?ooooo00?o0000ooooooooool04?ooool2o`000<gooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000005Cooooo003Oooooo`?o00001_ooool0
0ol0003oooooooooo`0<ooooo`?o0000d?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0DOooool00=cooooo0ol0000Eooooo`?o0000doooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00=[o
oooo0_l0000Fooooo`;o0000e_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D?ooool00=Oooooo0ol0000Eooooo`?o0000f?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Coooool00=Cooooo0ol0
000Eooooo`?o0000foooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0C_ooool00=;ooooo0ol0000Dooooo`?o0000g_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00_ooooo0ol0001@ooooo`00coooool3o`0000;ooooo00?o0000oooo
ooooool04?ooool2o`000>7ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04gooooo003<ooooo`?o00001_ooool00ol0003oooooooooo`0<ooooo`?o
0000]_ooool5o`0002Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04gooooo0039ooooo`?o00002_ooool00ol0003oooooooooo`08ooooo`?o0000
^Oooool00ol0003ohW<Eon9c5@02on9c5@Go00008oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0C?ooool00<Oooooo0_l0000Fooooo`;o0000^ooo
ool00ol0003ojH8fon9c5@06on9c5@;oeF<000?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Boooool00<Cooooo0ol0000E
ooooo`?o0000_?ooool01?l0003ojH8fonV2=_oYPSH7on9c5@;oeF<00_l0000Pooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1;ooooo`00`Oooool3
o`0001Gooooo0ol0002nooooo`03o`000?oYPSKojH8f00;ojH8f2?oRLaD3omES0003o`000?oooooo
oooo01gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0<ooooo`;o0000C?ooool0
0;oooooo1?l0000Cooooo`?o0000`Oooool00ol0003ojH8fonV2=P03onV2=POohW<E1?oEH`000ol0
003oooooooooo`0Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool0001;ooooo`00_?ooool3o`0000Cooooo00?o0000ooooooooool03_ooool2o`00
0<?ooooo00?o0000onV2=_oYPSH01OoYPSH7on9c5@CoeF<00_l0000Looooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`19ooooo`00^Oooool3o`0001Go
oooo0ol00034ooooo`03o`000?oYPSKojH8f00KojH8f2?oRLaD5omES0003o`000?oooooooooo01[o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04So
oooo002fooooo`?o00005Oooool3o`000<Oooooo00?o0000onV2=_oYPSH01ooYPSH7on9c5@KoeF<0
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Aoooool00;Cooooo0_l0000Eooooo`?o0000b_ooool00ol0003ojH8fonV2
=P08onV2=POohW<E1OoEH`000ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`17ooooo`00/Oooool3o`0001Gooooo0_l0003<
ooooo`03o`000?o/SU7ok8iA00[ojH8f1_oRLaD6omES0003o`000?oooooooooo01Sooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`;o00002_ooool5o`0000;ooooo0ol0000d
ooooo`00[_ooool3o`0001Gooooo0ol0003>ooooo`04o`000?o/SU7ok8iAonb>D@WojH8f1ooRLaD5
omES0003olEC0?l0003ooooo01Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000[ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo037ooooo002/ooooo`;o000000?oooooo`000?ooool04_ooool3o`000=7ooooo
00?o0000onb>DOo/SU400_o/SU49onV2=POohW<E1OoEH`000oo5D`3o0000ooooo`0Gooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0<Oooool00:Wooooo0ol00004ooooo`03o`000?oo
oooooooo00kooooo0_l0003Dooooo`03o`000?o/SU7ok8iA00;ok8iA2_oYPSH6on9c5@GoeF<00_o5
D`000ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<Ooo
ool00:Kooooo0ol0000Eooooo`?o0000e_ooool00ol0003ok8iAonb>D@03onb>D@WojH8f1ooRLaD5
omES0003olEC0?l0003ooooo01Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooo`000?ooool4o`0003Cooooo
002Sooooo`?o00005Oooool3o`000=Sooooo00?o0000onb>DOo/SU401Oo/SU49onV2=POohW<E1OoE
H`000oo5D`3o0000ooooo`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`00000gooooo`00
XOooool2o`0001Gooooo0ol0003Kooooo`03o`000?o/SU7ok8iA00Kok8iA2OoYPSH6on9c5@GoeF<0
0_o5D`000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
3?ooool2o`0000Oooooo0ol00002ooooo`Go0000<oooool009kooooo0ol0000Eooooo`;o0000g_oo
ool00ol0003ok8iAonb>D@07onb>D@SojH8f1ooRLaD5omES00;oaE<000?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000oooo
o`13ooooo`00JOooool3o`0000Cooooo0_l0000Yooooo`?o00005Oooool3o`000>3ooooo00?o0000
onb>DOo/SU401oo/SU49onV2=POohW<E1?oEH`02olEC0003o`000?oooooooooo01;ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo047ooooo001Xoooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Vooooo`;o00000_oo
ool00ol0003oooooooooo`0@ooooo`?o0000hoooool00ol0003ok8iAonb>D@08onb>D@WojH8f1_oR
LaD5omES00;oaE<000?o0000ooooooooool04Oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0@?ooool006cooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0003oooooooooo`0=ooooo`;o0000iOoo
ool00ol0003ok8iAonb>D@0:onb>D@SojH8f1ooRLaD4omES00?oaE<000?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0@?oo
ool006cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Nooooo`?o00005Ooo
ool3o`000>Oooooo00?o0000onb>DOo/SU402oo/SU48onV2=POohW<E1?oEH`03olEC00;o00004Ooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0?ooo
ool006Sooooo1?l00003ooooo`04o`000?ooooooooooo`0001kooooo0_l0000Eooooo`?o0000j_oo
ool00ol0003ok8iAonb>D@0<onb>D@SojH8f1_oRLaD4omES00CoaE<000?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00cooooo0_l00010ooooo`00J?ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001_ooooo0ol0000Dooooo`?o0000kOoo
ool00ol0003ok8iAonb>D@0<onb>D@SojH8f1ooRLaD4omES00?oaE<000?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000@?oo
ool006Sooooo1Ol00003ooooo`;o00006Oooool3o`0001Gooooo0_l0003`ooooo`03o`000?o/VFSo
k8iA00gok8iA2?oYPSH7on9c5@CoeF<00oo5D`000ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0mooooo`00R?ooool4o`00
01Cooooo0ol0003booooo`03o`000?o/VFSok9UX00kok8iA2?oYPSH6on9c5@CoeF<00oo5D`02o`00
00oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03cooooo0026ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`?o0000mOooool01?l0003o
k9UXonbIJ?o/VFP>onb>D@SojH8f1_oRLaD4omES00?oaE<000?o0000ooooooooool03Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0??ooool008?o
oooo0ol0000Dooooo`?o0000n?ooool00ol0003ok9UXonbIJ002onbIJ0kok8iA1ooYPSH6on9c5@Co
eF<01?o5D`000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0kooooo`00P?ooool3o`0001Gooooo0_l0003kooooo`03o`00
0?o/VFSok9UX00?ok9UX3Oo/SU48onV2=PKohW<E1?oEH`03olEC00;o00003Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>_ooool007kooooo0_l0
000Eooooo`?o0000oOooool00ol0003ok9UXonbIJ004onbIJ0gok8iA2?oYPSH6on9c5@?oeF<01?o5
D`000ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02ooo
ool3o`0003cooooo001kooooo`?o00005?ooool3o`000?oooooo0Oooool00ol0003ok9UXonbIJ005
onbIJ0gok8iA1ooYPSH6on9c5@CoeF<00oo5D`02o`0000cooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Wooooo001hooooo`?o00005Oooool2o`00
0?oooooo1?ooool00ol0003ok9UXonbIJ006onbIJ0gok8iA1ooYPSH6on9c5@?oeF<01?o5D`02o`00
00_ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03Sooooo001eooooo`?o000000?oooooo`000?ooool04_ooool3o`000?oooooo1_ooool00ol0003o
k9UXonbIJ007onbIJ0gok8iA1ooYPSH6on9c5@?oeF<00oo5D`02o`0000_ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo001cooooo`;o0000
1Oooool00ol0003oooooooooo`0=ooooo`?o0000ooooool9ooooo`03o`000?o/VFSok9UX00Sok9UX
3?o/SU47onV2=PKokXdb0_oZQR42omES00?oaE<00_l0000;ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0gooooo`00L?ooool3o`0000Sooooo00?o
0000ooooooooool02Oooool3o`000?oooooo3?ooool00ol0003ok9UXonbIJ009onbIJ0cok8iA1_oY
PSH00ooaTd?okXdbonj=<P04onj=<P;ojXHQ00?oeF<0olEC0?o5D`000_o5D`02o`0000[ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo001]
ooooo`?o00005Oooool2o`000?oooooo3oooool00ol0003ok9UXonbIJ00:onbIJ0cok8iA1?oYPSH2
oo6C@`KokXdb0ooZQR401?oEH`3oaE<0olEC0?o5D`02o`0000[ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0;ooooo`?o0000>?ooool006_ooooo0_l0000Eooooo`?o0000oooooolA
ooooo`03o`000?o/VFSok9UX00_ok9UX3?o/SU42onV2=PColI=31_o^SC83onZ68@CoaE<00_l00009
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0e
ooooo`00J?ooool3o`0001Cooooo0ol0003ooooooaCooooo00?o0000onbIJ?o/VFP03?o/VFP<onb>
D@03onV2=_oaTd?olI=300?olI=31Oo^SC84onZ68@?oaE<000?o0000okA80?l000002?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0=Oooool006Go
oooo1?l0000Cooooo`?o0000oooooolGooooo`03o`000?o/VFSok9UX00gok9UX2oo/SU46oo6C@`Ko
kXdb0ooZQR401?oVPA?oaE<0olEC0?o5D`02o`0000Sooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Cooooo001Rooooo`?o00001?ooool00ol0003o
ooooooooo`0>ooooo`;o0000oooooolJooooo`03o`000?o/VFSok9UX00kok9UX2_o/SU400oobVUCo
lI=3oo6C@`04oo6C@`GokXdb1?oZQR401_oVPA?oaE<0olEC0?l0003o]4P0o`0000Oooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo001Poooo
o`;o00005Oooool3o`000?oooooo7?ooool00ol0003ok9UXonbIJ00?onbIJ0Wok8iA0_obVU@5oo6C
@`GokXdb1?oZQR42onJ14`;oaE<000?o0000okA80?l000001_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool3o`0000Cooooo0_l0000Poooo
o`00GOooool3o`0001Cooooo0ol0003ooooooaoooooo0_l0000AonbIJ0Ook8iA0oobVU@6oo6C@`Go
kXdb1?oZQR42onJ14`04olEC0?l0003o]4P0o`0000Kooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0;ooooo`?o00002_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00007oooool005[ooooo0ol0000Eooooo`;o0000oooooolRooooo`03o`000?o/XGWo
0000017ok9UX1_o/SU44oo:JE0GolI=31Oo^SC84onZ68@?oiX4C00CoaE<0o`000?ndB03o00001Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01gooooo001Hooooo`;o00005Ooo
ool3o`000?oooooo9?ooool01?l0003ok:5ionbQNOl0000AonbIJ0Gok8iA1OobVU@5oo6C@`GokXdb
0ooZQR44onJ14`03olEC0?l0003o000000Gooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Mooooo`00EOooool3o`0001Cooooo0ol0003oooooobOooooo00Co0000onbQNOo/XGWo
k:5i0_l0000@onbIJ0Cok8iA1OobVU@6oo6C@`CokXdb1?oZQR44onJ14`03o`000?ndB03o000000Co
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo1?l00003ooooo`04o`000?ooooooooooo`0001oooooo001Booooo`?o000000?oooooo`000?oo
ool04Oooool3o`000?oooooo:_ooool00ol0003ok:5ionbQN@03onbQN@03o`000?o/VFSok9UX00ko
k9UX0oo/SU46oo:JE0GolI=31Oo^SC83onZ68@GoiX4C0_l00004ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00007oooool0053ooooo0_l00005ooooo`03o`000?oooooooooo00go
oooo0_l0003oooooobgooooo00?o0000onbQNOo/XGT01?o/XGT00ol0003ok9UXonbIJ00>onbIJ003
onb>DOobVUColYYD00GolYYD1_oaTd<4onj=<PCojXHQ1?oVPA<00ol0003o]4P0o`000003ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool03?ooool2o`0000Kooooo1Ol00003ooooo`;o
00008?ooool004gooooo0ol0000Dooooo`?o0000ooooool_ooooo`03o`000?o/XGWok:5i00Gok:5i
0_l0000?onbIJ0SolYYD1OoaTd<5onj=<P?ojXHQ1?oVPA<01?l0003o]4P0ojM40?l00003ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo02oo
oooo001:ooooo`?o00005?ooool3o`000?oooooo<oooool00ol0003ok:5ionbQN@06onbQN@03o`00
0?o/VFSok9UX00cok9UX2OobVU@5oo6C@`CokXdb1?oZQR44onJ14`03o`000?ndB03o000000?ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;Oooool004Oooooo0ol0000Eooooo`;o0000oooooolfooooo`03o`000?o/
XGWok:5i00Ook:5i00?o0000onbIJ?o/VFP02oo/VFP00oobXF?olYYDoo:JE006oo:JE0KolI=31?o^
SC83onZ68@CoiX4C00Co0000okA80?nWA03o00000_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;Oooool001Wooooo0_l0000Zooooo`;o00005Ooo
ool3o`000?oooooo>?ooool00ol0003ok:5ionbQN@08onbQN@;o00002oo/VFP2oo:QH`SolYYD1Ooa
Td<4onj=<P?ojXHQ1?oVPA<01?l0003ohGh8okA80?l00002ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`006?ooool01?l0003ooooooooo
ool0000Vooooo`Co00004oooool3o`000?oooooo>oooool00ol0003ok:5ionbQN@0:onbQN@03o`00
0?o/VFSok9UX00Sok9UX0oobXF<8oo:JE0GolI=30oo^SC84onZ68@CoiX4C00Ko0000okA80?nWA03o
0000ooooool0001;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;?ooool001So
oooo00Co0000oooooooooooo00008oooool3o`0000Cooooo00?o0000ooooooooool03Oooool3o`00
0?oooooo?_ooool00ol0003ok:5ionbQN@0;onbQN@03o`000?o/VFSok9UX00Ook9UX1?obXF<7oo:J
E0GolI=31?o^SC83onZ68@CoiX4C00Ko0000on5n2?ndB03o0000ooooool0001;ooooo`03o`000?oo
oooooooo00gooooo0_l0000/ooooo`006?ooool01?l0003oooooooooool0000Qooooo`;o00005Ooo
ool2o`000?oooooo@Oooool00ol0003ok:5ionbQN@0<onbQN@03o`000?o/VFSok9UX00Kok9UX1?ob
XF<8oo:JE0GolI=30oo^SC84onZ68@?oiX4C00Co0000on5n2?oQOPSoYd@00_l0001<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooool00000;?ooool001Sooooo00Co0000oooooooooooo0000
7_ooool3o`0001Cooooo0ol0003ooooood?ooooo00?o0000onbQNOo/XGT03?o/XGT3o`0000Kok9UX
1OobXF<8oo:JE0ColI=31?o^SC83onZ68@CoiX4C00?o0000on5n2?ndB0000_l0001=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:_ooool001Sooooo00Co0000oooooooooooo0000
6oooool3o`0001Cooooo0ol0003oooooodKooooo00?o0000onbQNOo/XGT03?o/XGT2o`000003onbQ
NOl0003ok9UX00Cok9UX1_obXF<7oo:JE0GolI=30oo^SC84onZ68@?oiX4C00Go0000on5n2?oQOPSo
Yd@0o`00001=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool001Wooooo
0_l0000Iooooo`?o00005?ooool3o`000?ooooooBOooool00ol0003ok:5ionbQN@0@onbQN@03o`00
0?o/VFSok9UX00;ok9UX1oobXF<7oo:JE0GolI=30oo^SC83onZ68@?oiX4C0_l000000ooQOPSo]4P0
o`00001>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:?ooool003;ooooo0_l0
000Eooooo`;o0000oooooom<ooooo`03o`000?o/XGWok:5i017ok:5i0_l00002onbIJ0SolZ5S1oob
VU@4oo6C@`?okXdb0ooZQR43onJ14`;o00000_oQOPP2o`0004kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Xooooo`00;oooool3o`0000;ooooo00?o0000ooooooooool03oooool3
o`000?ooooooC_ooool00ol0003ok:5ionbQN@0ConbQN@03o`000?o/VFSolZ5S00OolZ5S1oobVU@5
oo6C@`?okXdb0ooZQR401?oo003oiX4ConJ14ol00002on5n2003o`000?nWA03o000004gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`00;?ooool3o`0000Kooooo00?o0000
ooooooooool02oooool3o`000?ooooooDOooool00ol0003ok:5ionbQN@0DonbQN@03o`000?obXF?o
lZ5S00OolZ5S1oobVU@4oo6C@`?okXdb0ooZQR43onJ14`06o`000?oQOPSohGh8o`000?nWA03o0000
C_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo000Zooooo`;o00005Ooo
ool2o`000?ooooooE?ooool00ol0003ok:5ionbQN@0EonbQN@;o00002?obXF<7oo:JE0ColI=30oo^
SC83onZ68@;oiX4C00Oo0000on5n2?oQOPSohGh8o`000?nWA03o000004cooooo0ol0000;ooooo`;o
0000:_ooool002Oooooo0ol0000Dooooo`?o0000oooooomGooooo`03o`000?o/XGWok:5i01Cok:5i
0_ocYVl00ol0003olZ5Soo:QH`06oo:QH`KolYYD1?oaTd<3onj=<P?ojXHQ0ooVPA<01_l0003ohGh8
on5n2?l0003oYd@0o`0004Wooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo00003Oooool3o`0000Cooooo0_l0000Cooooo`009?ooool3o`0001Cooooo0ol0003ooooo
oeSooooo0_lc0?l00ol0003ok:5ionbQN@0DonbQN@?oljI_00?o0000oo:QHoobXF<01_obXF<6oo:J
E0ColI=30_o^SC84onZ68@;oiX4C00Oo0000on5n2?oQOPSo0000omin0_nWA03o000004Gooooo0ol0
0005ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00004_ooool0027ooooo0ol0000Dooooo`?o0000
oooooomIooooo`?o<`3o00?oooooo`000?o/XGT05Oo/XGT4oo>VK`03o`000?obXF?olZ5S00KolZ5S
1OobVU@5oo6C@`;okXdb0ooZQR42onJ14`06o`000?oQOPSohGh8o`000?oNOP;oYd@0@oooool3o`00
00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`Go00001Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo013ooooo000Oooooo`;o00000_ooool00ol0
003oooooooooo`0@ooooo`;o0000oooooomJooooo`Co<`3o0_ooool00ol0003ok:5ionbQN@0DonbQ
N@GoljI_00?o0000oo:QHoobXF<01OobXF<6oo:JE0ColI=30_o^SC83onZ68@;oiX4C00Co0000on5n
2?oQOPSo00000_oNOP800onWA03oooooooooo`0mooooo`?o00002oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`0@ooooo`007?ooool3o`0000Gooooo00?o0000ooooooooool03?ooool3o`000?ooooooF_ooool4
oc<0o`Cooooo00?o0000onbQNOo/XGT05Oo/XGT3oo>VK`?o00001oobXF<6oo:JE0ColI=30_o^SC83
onZ68@;oiX4C00?o0000on5n2?l000000_oNOP800onWA03oooooooooo`0jooooo`?o00003oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo1?l00003ooooo`04o`000?oooooo
ooooo`0001;ooooo000Iooooo`?o00002Oooool00ol0003oooooooooo`08ooooo`?o0000oooooomK
ooooo`Co<`3o1_ooool00ol0003ok:5ionbQN@0EonbQN@?oljI_0_l000000oocYVoo0000oo:QH`06
oo:QH`GolYYD1?oaTd<2ooJRBP;omZ5600OojXHQonJ14ooVPA?o0000on5n2?l0003ohGh800;ogWh2
>Oooool3o`0001;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00004_ooool001Sooooo00?o0000ooooooooool0
4oooool2o`000?ooooooG?ooool2oc<0o`03oooooolc0?oooooo00Oooooo00?o0000onbQNOo/XGT0
5Oo/XGT00olc0?ooljI_oo>VK`04oo>VK`03o`000?obXF?olZ5S00GolZ5S1OobVU@3oo6C@`03ooNS
D?ofXT[omZ9:00?omZ5600GoiX4Co`000?l0003o0000on5n2002omin0P03ojM40?oooooooooo03?o
oooo0ol0000Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool5o`0000?o
oooo0_l0000Cooooo`00:oooool3o`000?ooooooG?ooool2oc<0o`03oooooolc0?oo<`3o00Wooooo
00?o0000onbYQ_o/XGT05Oo/XGT8oo>VK`03o`000?obXF?olZ5S00GolZ5S1OobVU@00ooaTd?omj=@
ooNSD002ooJRBP?omZ5600Goo`00o`000?l0003o0000on5n2002omin0P03ojM40?oooooooooo033o
oooo0ol0000Hooooo`03o`000?oooooooooo00Wooooo0_l0000Yooooo`00:?ooool3o`000?oooooo
GOooool2oc<0o`03oooooolc0?oo<`3o00_ooooo00?o0000onbYQ_o/ZHH00_o/ZHHConbQN@WoljI_
00?o0000oo:QHoobXF<01?obXF<5oo:JE0?omj=@0_ofXTX3ooJQAP05ooJP@ooVPA?o0000o`000?oQ
OPP00ooNOP800ol004_oooooooooo`0/ooooo`?o00006oooool00ol0003oooooooooo`07ooooo`;o
00000_ooool00ol0003oooooooooo`0Vooooo`009Oooool3o`000?ooooooG_ooool2oc<0o`03oooo
oolc0?oo<`3o00kooooo00?o0000onbYQ_o/ZHH00oo/ZHHAonbQN@[oljI_00?o0000oo:QHoobXF<0
1?obXF<4oo:JE004ooNUE_ogXe3omj=@ooNSD0;omZ9:0oofXDH01?ofX4?o0000o`000?oQOPP3omin
0P03ojM40?oooooooooo02Wooooo0ol0000Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool09_ooool002Cooooo0_l0003ooooooekooooo0_lc0?l2ooooo`03oc<0oooooooooooo00ko
oooo00?o0000onbYQ_o/ZHH01_o/ZHH>onbQN@_oljI_00?o0000oo:QHoobXF<01?obXF<3oo:JE004
ooNUE_ogXe3omj=@ooNSD0;omZ9:0oofXDH00oofX4?oiX4Co`000002on5n20?ogWh200?o0000oooo
ooooool09Oooool3o`00027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Voooo
o`009?ooool00ol0003oooooo`00003ooooooe_ooooo0_lc0?l2ooooo`;o<`3o4Oooool00ol0003o
k:V6onbYQP08onbYQPcok:5i3?ocYVl00ol0003olZ5Soo:QH`04oo:QH`04oo:JE?ogYEKomjEFooNU
EP?omj=@00ComZ9:ooJQA_ofXDKomZ560_ofX4<00ol0003ohGh8on5n2003omin0P03o`000?oooooo
oooo02;ooooo0ol0000Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool0
02Cooooo00Co0000oooooooooooo0000oooooomHooooo`;o<`3o0_ooool2oc<0oa?ooooo00?o0000
onbYQ_o/ZHH02oo/ZHH9onbQN@goljI_00?o0000oo:QHoobXF<01?obXF<3ooNUEP?omj=@0_ofXTX2
ooJQAP;omZ130_l000000ooQOPSogWh2omin0P02omin0P03o`000?oooooooooo01gooooo1?l0000W
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool002Cooooo00Go0000oooo
ooooooooooooo`00003ooooooeGooooo0_lc0?l2ooooo`;o<`3o5Oooool00ol0003ok:V6onbYQP0=
onbYQPSok:5i3OocYVl00ol0003olZ5Soo:QH`03oo:QH`ComjEF0_ogXe02ooJRBP?omZ5600ComZ13
o`000?l0003ohGh81?oNOP800ol0003oooooooooo`0Jooooo`?o0000;?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Kooooo000Tooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooom@ooooo`;o<`3o0oooool00olc0?ooooooooooo`0Fooooo`03o`000?o/ZHKo
k:V600ook:V61Oo/XGT>oo>VK`03o`000?obXF?olZ5S00;olZ5S00Con:QLooNUE_ogYEKomjEF0oog
Xe001OofXT[omZ56ooJQA_ofXDKomZ1300;o000000?ohGh8omin0_oNOP800_oNOP800ooMPP;o0000
ooooo`0Gooooo`?o0000;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo
000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom=ooooo`;o<`3o0ooo
ool2oc<0oaWooooo00?o0000onbYQ_o/ZHH04Oo/ZHH3onbQN@ooljI_0_l00002oo:QH`;on:QL0oog
YEH2ooNSD0;omZ9:0_ofXDH2ooJP@`03o`000?oQOPSohGh800?ogWh200?ogH82o`000?ooool05?oo
ool3o`0003;ooooo00?o0000ooooooooool02Oooool2o`0002Sooooo000Sooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`;o<`3o0oooool2oc<0oa[ooooo00?o<`3o
o`000?o/ZHH05Oo/ZHH?oo>VK`;o00000_obXF<2ooRXG0?omjEF0oogXe000oofXT[omZ56ooJQAP02
ooJP@`;o000000CohGh8omin0_oNOP;ogWh20_oMPP800ol0003oooooooooo`0?ooooo`?o0000=Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo000002Sooooo000Sooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0oooooom7ooooo`;o<`3o0oooool2oc<0oa[ooooo0olc0?l0
0ol0003ok:V6onbYQP0DonbYQP;oljai2_ocYVl00olc0?ooljI_oo>VK`02oo>VK`03o`000?obXF?o
n:QL00;on:QL0oogYEH2ooNSD005ooJRB_ofXDKomZ56ooJQA_ofX4<00_l000001?ofX47ogWh2omin
0_oNOP82omf20P03o`000?oooooooooo00cooooo0ol0000hooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool09Oooool002?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooodCooooo0_lc0?l4ooooo`03oc<0oooooooooooo01Oooooo1Olc0?l00ooo003o0000onbY
QP0EonbYQPColjai3_ocYVl01?l0003on:QLooRXG?ohZ5`3ooNUEP;omj=@0_ofXTX2ooJQAP04ooJP
@ol0003omZ11ooJP@@?ogWh20ooMPP800ol0003oooooooooo`08ooooo`?o0000>oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Gooooo000Sooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0oooooom1ooooo`;o<`3o1?ooool2oc<0oaSooooo0_lc0?l00ooooooo<`3o
oc<0o`02ool000;ooooo00?o0000onbYQ_o/ZHH05?o/ZHH5oo>/N@goljI_00Co0000ooRXG?ohZ5co
n:QL0oogYEH2ooNSD005ooJRB_ofXDKomZ56ooJP@ol000000_ofX4401?ofXD3ogWh2omin0_oNOP82
omf20P03o`000?oooooooooo00Gooooo0ol0000nooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09Oooool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooo
ockooooo0_lc0?l4ooooo`;o<`3o6?ooool2oc<0o`03oooooolc0?oo<`3o00;oo`001?ooool00ol0
003ok:V6onbYQP0DonbYQPKoljai3?ocYVl00ol0003on:QLooRXG002ooRXG0;omjEF0_ogXe001?of
XT[omZ56ooJQA_ofX4<2o`000003ooJP@OofXD3ogWh200;ogWh20ooMPP801?l0003ooooooooooooo
ool3o`00047ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`008oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo>oooool2oc<0o`Cooooo0_lc0?lH
ooooo`;o<`3o00Cooooooc<0oolc0?ooo`001oooool00ol0003ok:V6onbYQP0DonbYQPSoljai2_oc
YVl00oohZf7o0000ooRXG002ooRXG0?omjEF0_ogXe000oofXT[omZ56ooJQAP02o`000003ooJP@Oof
XD3omZ5000;ogWh20ooMPP801?oooooo0000o`000?l00015ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09Oooool002?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`3oooooocSooooo0_lc0?l5ooooo`03oc<0oooooooooooo01Kooooo0_lc0?l01?oooooo<`3ooc<0
oooo0009ooooo`03o`000?o/ZHKok:V601Cok:V62_oc[7T8oo>VK`;on:]Q00Co0000ooRXG?ohZ5co
n:QL0_ogYEH2ooNSD003ooJRB_ofXDKomZ5600;o000000?omZ11ooJQ@?ofXD000_oNOP83omf20P03
o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`00
8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo=Oooool2oc<0o`Gooooo
0_lc0?lFooooo`?o<`3o00Cooooooc<0oolc0?ooo`002_ooool00ooo003o0000onbYQP0EonbYQPco
ljai1_ocYVl3ooR[H@04o`000?ohZ5con:QLooRXG0;omjEF00Comj=@ooJRB_ofXDKomZ560_l00000
1OofX47omZ50ooJQ@?ofXD3ogWh200CogH82B?ooool00ol0003oooooooooo`09ooooo`;o00009ooo
ool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3ooooooc;ooooo0_lc0?l5
ooooo`;o<`3o5_ooool2oc<0o`;ooooo0_lc0?l00ooo003oooooooooo`09ooooo`04ool00?oooooo
ooooo`0001Kok:V63Ooc[7T5oo>VK`?on:]Q00?o0000ooRXG?ohZ5`00_ogYEH2ooNSD005ooJRB_of
XDKo0000o`000?ofX4400oofXD000ooNOP;ogH82omf20P02omf20TSooooo00?o0000ooooooooool0
2?ooool00ol0003oooooo`00000Wooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0?oooooo;oooool2oc<0o`Gooooo0_lc0?lFooooo`;o<`3o0_ooool2oc<0o`cooooo0_oo
0003ooooo`03o`000?o/ZHKok:V601Cok:V63_oc[7T4oo>VK`Con:]Q00?o0000ooRXG?ohZ5`00_og
YEH00oogXe3omZ9:ooJQAP02o`000003ooJP@OofXD3omZ5000;omZ501OoMPP97ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09?ooool002;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3oooooobcooooo0_lc0?l6ooooo`03oc<0oooooooooooo01Cooooo0_lc0?l2
ooooo`;o<`3o3?ooool2ool000Gooooo00?o0000onbYQ_o/ZHH05?o/ZHH@oo>/N@;oljI_1OohZf40
1?l0003on:QLooRXG?ogYEH2ooNSD0;omZ560_l00004ooJQ@0GogH82Aoooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Cooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0oooooolYooooo`;o<`3o1_ooool2oc<0oaGooooo0_lc0?l2ooooo`;o<`3o3?ooool2
ool000Oooooo00?o0000onbYQ_o/ZHH05?o/ZHHBoo>/N@Gon:]Q0ol00002ooNUEP03ooNSD?ofXT[o
mZ5600?o00000oofXD000oofXT3ogH82omf20P03omf20TKooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Tooooo`008_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0?oooooo9_ooool2oc<0o`Kooooo0_lc0?lDooooo`?o<`3o00Coooooool00?lc0?oo<`3o3?ooool2
ool000Kooooo0ooo00000ol0003ok:V6onbYQP0DonbYQQ;oljai0_oi[FH4ooR[H@;o000000Gon:QL
ooNUE_ogXe3omZ9:ool00003o`0000?omZ5000?omZ90omf20_oMPP800ooMPP800ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool002;ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`3oooooob?ooooo0_lc0?l6ooooo`;o<`3o5?ooool2
oc<0o`;ooooo00?oo`00oc<0oolc0?l03Oooool00ooo003oooooooooo`04ooooo`;oo`001?ooool0
0ol0003ok:V6onbYQP0DonbYQQ7oljai00?o<`3oooV]I_oi[FH01?ohZf401_l0003on:QLooNUE_og
YEKomj=@ool000;o000000?omZ11ooJQ@?ofXD000oofXT05omf20TKooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Tooooo`008_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0?oooooo8?ooool2oc<0o`Oooooo00?o<`3oooooooooool04_ooool2oc<0o`;ooooo00?o
o`00oc<0oolc0?l03Oooool2ool000Cooooo0ooo0005ooooo`03oc<0ool0003ok:V601Gok:V64_oc
[7T3ooV]IPCon:]Q00Go0000ooRXG?ogYEKomj=@ooJRBP02o`000003ooJP@OofXD3omZ5000?omZ90
1OoMPP800ol0003oooooooooo`13ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9?ooool002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooagooooo0_lc
0?l7ooooo`;o<`3o4oooool2oc<0o`;ooooo00?oo`00oc<0oolc0?l03Oooool2ool000Cooooo0_oo
0005ooooo`Co<`3o00?o0000onbYQ_o/ZHH05?o/ZHHBoo>/N@GonJeV0oohZf401?l0003on:QLooNU
E_ogXe02o`000003ooJP@OofXD3omZ5000ComZ901?oMPP800ooPRPWoooooooooo`13ooooo`03o`00
0?oooooooooo00Wooooo0_l0000Vooooo`008_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo0?oooooo6_ooool2oc<0o`Oooooo0_lc0?lBooooo`?o<`3o00?oooooool00?oo00000_lc
0?l=ooooo`;oo`000oooool3ool000Gooooo1?lc0?l00ooo003oooooo`00000FonbYQQ;oljai1_oi
[FH3ooR[H@06o`000?ogYEKomj=@o`000?ofX4?o00000_ofXD04ooJR@0?ogH820_oPRPU5ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000009_ooool0027ooooo00?o0000ooooooooool0
6?ooool2o`000?oooooo6?ooool2oc<0o`Oooooo0_lc0?lBooooo`;o<`3o0_ooool2ool000;o<`3o
3_ooool01?oo003oooooooooooooool2ool000Gooooo1Olc0?l01Ooo003ooooooooooooooooo0000
01Kok:V64_oc[7T7ooV]IP;on:]Q00Ko0000ooRXG?ogYEKo0000ooJP@ol00002ooJQ@0GomZ9000Go
gH82on2:2OoPRPWoh8X9o`000014ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooooa?ooooo0_lc
0?l8ooooo`03oc<0oooooooooooo013ooooo0_lc0?l2ooooo`;oo`000_lc0?l>ooooo`;oo`000_oo
ool2ool000Gooooo1Olc0?l00ooo003oooooooooo`04ooooo`03o`000?o/ZHKok:V601Cok:V64Ooc
[7T9ooV]IP07ooR[HOl0003on:QLo`000?ofXDKo0000ooJQ@005ooJR@003ooJT@_oPRPWoh8X900?o
h8X9A?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0ooooool@ooooo`;o<`3o2?ooool2oc<0oa7ooooo
0_lc0?l2ooooo`;oo`000_lc0?l>ooooo`;oo`0000Coooooool00?oo003oo`001Oooool4oc<0o`;o
o`002?ooool00ol0003ok:V6onbYQP0DonbYQQ;oljai2Ooi[FH01_ohZf7o0000o`000?ofXDKo0000
ooJQ@0ComZ900oofY484on2:2DCooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0S
ooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0?oooooo3Oooool2oc<0
o`Sooooo0_lc0?lAooooo`;o<`3o00Coooooool00?oo003oo`000_lc0?l>ooooo`;oo`0000?ooooo
ool00?oo00001Oooool5oc<0o`;oo`002?ooool2ool00003o`000?o]/I3okK6@01CokK6@1_od/X0<
oo>/N@[onJeV00Gon:]Qo`000?ogXe3o0000ooJQ@003ooJR@0ComZA21?oPRPU4ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`3oooooo`_ooooo00?o<`3oooooooooool01_ooool2oc<0oa3ooooo0olc0?l0
1?ooooooo`00ool00?ooool2oc<0o`oooooo1?oo0005ooooo`;o<`3o00?ooooooc<0oolc0?l00_oo
0008ooooo`;oo`000_ooool00ol0003okK6@onfaT00DonfaT0oom;:00ooc[7T;ooV]IP;o000000Co
mZ13o`000?ofXT3omZ901OofY485on2:2D?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oooooo2?oo
ool2oc<0o`Sooooo00?o<`3oooooooooool03_ooool2oc<0o`;ooooo0_oo00000ooooooo<`3ooc<0
o`0?ooooo`?oo`001Oooool6oc<0o`;oo`001oooool3ool000Gooooo00?o0000onfaT?o]/I005?o]
/I0AooBbP0GonK1X1_oi[FH01Ol0003onJeVo`000?l0003omZ9000OomZA21?oPRPU4ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`3oooooo`Gooooo0_lc0?l8ooooo`;o<`3o3oooool2oc<0o`;ooooo0_oo
00000ooooooo<`3ooc<0o`0?ooooo`?oo`001Oooool2oc<0o`04oooooolc0?oo<`3oooooo`;oo`00
1oooool2ool000Oooooo00?oo`00o`000?o]/I005Oo]/I0BooBbP0_onK1X0ol00008ooJT@PCoh8X9
A?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0ooooool2ooooo`;o<`3o2?ooool2oc<0o`oooooo0_lc
0?l2ooooo`;oo`0000?ooooooc<0oolc0?l03oooool3ool000Cooooo0olc0?l01?oooooo<`3ooc<0
ooooool2ool000Kooooo0ooo0007ooooo`;oo`0000?oooooo`000?o]/I005Oo]/I0BooBbP0_onK1X
0ol00002ooNWA@KomZA21OoPRPU3ooooo`03o`000?oooooooooo00Sooooo0ol0000Uooooo`008?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0?kooooo0_lc0?l8ooooo`;o<`3o3ooo
ool2oc<0o`05oooooooo003oo`00ool00?ooool00_lc0?l?ooooo`;oo`001Oooool2oc<0o`05oooo
oolc0?oo<`3ooc<0ooooool00_oo0005ooooo`?oo`002?ooool2ool000;ooooo0_l0000FonfaT1;o
m;:02ooi/6P01?l0003on[9Zo`000?l00004ooNWA@ComZA21?oPRPU3ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool08oooool0023ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`3kooooo`;o<`3o2Oooool00olc0?ooooooooooo`0<ooooo`?o<`3o00?oooooool00?oo
00000_ooool2oc<0o`kooooo1?oo0003ooooo`?o<`3o00?ooooooc<0oolc0?l00_ooool2ool000Go
oooo0_oo0008ooooo`?oo`0000Coooooo`000?l0003o00000_ooool00ol0003okK6@onfaT00Donfa
T1;om;:02?oi/6P2ooZbJP05o`000?oj/f[o0000ooZ^D_l000001_ogYdD00oofY4;oh8X9on2:2@02
on2:2D?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`Go00000_ooool3
o`0000kooooo000Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0n?ooool2oc<0
o`Wooooo0_lc0?l=ooooo`;o<`3o0_ooool2ool000;ooooo0_lc0?l>ooooo`Coo`000oooool2oc<0
o`;ooooo0_lc0?l2ooooo`;oo`001?ooool3ool000Sooooo0_oo00001?oooooo0000o`000?l00002
ooooo`?o<`3o00?o0000onfaT?o]/I005?o]/I0BooBbP003ool00?oi/6SonK1X00?onK1X1?oj/VX0
1_l0003on[=Zo`000?ok/EWo0000ooV[B`KomjM50_oVUQL3on2:2D;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`0;ooooo`008?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?Go
oooo0_lc0?l9ooooo`;o<`3o3Oooool2oc<0o`;ooooo0_oo0002ooooo`;o<`3o3Oooool5ool000;o
oooo0olc0?l01?oooooo<`3ooc<0oolc0?l2ooooo`;oo`001?ooool2ool000Wooooo0_oo0003o`00
00?ooooo0olc0?l2ooooo`03o`000?o]/I3okK6@01CokK6@4_od/X05ooV`J0Gon[9Z00Oo0000oo^d
J_l0003onk=OooZ^D_l0003onJ];00GomjM50ooVUQL2on2:2D;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`04ooooo`Go00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo000Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0l_ooool2
oc<0o`Wooooo0_lc0?l=ooooo`;o<`3o00Coooooool00?oo003oo`000_ooool2oc<0o`gooooo0_oo
0002ooooo`03ool00?oooooooooo00;o<`3o0_ooool2oc<0o`?ooooo0_oo0003ooooo`?oo`002?oo
ool3ool000;o00000oooool4oc<0o`?ooooo00?oo`00o`000?o]/I005Oo]/I0CooBbP0;onK1X1ooj
/VX01_l0003onkAZo`000?ol]6?onk5Io`0000;onJ];1OogYdD3onJF5`03on2:2Ooooooooooo043o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02oooool0023ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`3_ooooo`;o<`3o2_ooool00olc0?ooooooooooo`0;ooooo`;o<`3o00?oooooool00?oo0000
0oooool2oc<0o`gooooo0_oo0002ooooo`;oo`0000?ooooooc<0oolc0?l00_ooool2oc<0o`?ooooo
0_oo0002ooooo`?oo`002Oooool2ool000;o00000oooool4oc<0o`Cooooo0_oo0002ooooo`03o`00
0?o]/I3okK6@01CokK6@4_od/X000ooi/6Son[9ZooZbJP05ooZbJP08ooZcJ_l0003onkAZo`000?ol
]6?onk5IooZ^D_l00002ooV[B`ComjM51?oVUQL00ooPRPWoooooooooo`10ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool01_l0003ooooooooooooooooo0000ooooo`Co0000
3_ooool0023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3/ooooo`;o<`3o2_oo
ool2oc<0o`_ooooo0olc0?l00oooooooo`00ool00003ooooo`;o<`3o3?ooool3ool000;ooooo0_oo
0003oc<0o`04oooooolc0?oo<`3ooc<0o`?ooooo0_oo0002ooooo`;oo`002_ooool2ool00004o`00
0?ooooooooooooooo`Co<`3o1?ooool3ool000?ooooo00?oo`00o`000?o]/I005Oo]/I0AooBbP003
ooJgQOoj/V[on[9Z00Kon[9Z00Kon[=Zo`000?ok]6[o0000oobdHook/el2ooZ^DP03o`000?oiZd_o
nJ];00?omjM51OoVUQM2ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
1ol0003ooooooooooooooooo0000ooooool000004Oooool0023ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`3Yooooo`;o<`3o2_ooool2oc<0o`_ooooo0_lc0?l2ooooo`;oo`000ooo
ool2oc<0o`cooooo0_oo0003ooooo`;oo`000_lc0?l2ooooo`;o<`3o1?ooool2ool00004oooooooo
003oo`00ool000Wooooo00?o0000ool00?oo00001?ooool4oc<0o`?ooooo0ooo0003ooooo`?oo`00
00?oooooo`000?o]/I005Oo]/I0?ooBbP0Com[N51_oj/VX2ooZcJP08o`000?ok]6[o0000oo^dIook
/eoonk5IooZ^D_l00003ooV[B`;omjM51OoVUQM2ooooo`03o`000?oooooooooo00Wooooo0_l0000=
ooooo`?o00000_ooool5o`0000gooooo000Pooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0i_ooool2oc<0o`[ooooo0_lc0?l;ooooo`;o<`3o00Coooooool00?oo003oo`000oooool2
oc<0o`_ooooo0ooo0003ooooo`04ool00?lc0?oo<`3ooc<0o`;ooooo0_lc0?l4ooooo`;oo`0000?o
ooooool00?oo00002?ooool2o`0000?oo`000oooool4oc<0o`?ooooo0ooo0004ooooo`;oo`001?oo
ool00ol0003okK6@onfaT00DonfaT0kom;:01Oof]hD6ooZbJP;on[=Z00Ko0000oo^dJ_l0003onkAW
oobdHook/ET2ooZ^DP05o`000?oiZd_onJ];ooV[BoogYdD01OoVUQL00onjL@3oooooooooo`0ooooo
o`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`0Sooooo`007oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo0>?ooooo0_lc0?l;ooooo`03oc<0oooooooooooo00Wo
oooo0_lc0?l00oooooooo`00ool00004ooooo`;o<`3o2oooool2ool000Gooooo0_lc0?l2ooooo`?o
<`3o1?ooool5ool000Oooooo0ol00002ool000?ooooo1?lc0?l3ooooo`?oo`001?ooool3ool000Oo
oooo00?o0000onfaT?o]/I005?o]/I0;ooBbP0Oom[N51Ooj/VX3ooZcJP07o`000?ok]6[o0000oo^d
Iool]6?onk=Ooo^aF@02ooZ^DP05o`000?oiZd_onJ];ooV[BoogYdD01OoVUQM1ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool08Oooool001oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`3Pooooo`;o<`3o2oooool2oc<0o`Wooooo0olc0?l00oooooooo`00ool00004
ooooo`;o<`3o2oooool2ool000Cooooo0olc0?l2ooooo`;o<`3o1Oooool4ool000Oooooo0ol00000
0oooooooo`00ool00002ooooo`Go<`3o0_ooool3ool000Gooooo0_oo000:ooooo`03o`000?o]/I3o
kK6@01CokK6@2Ood/X0:ooJgQ@Con[9Z0ooj/fX01ol0003onkAZo`000?l0003oo;ASoo^cGook/ET0
0_oj[U82o`0000?onJ];1OoVUQM1ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
8Oooool001oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3Mooooo`;o<`3o2ooo
ool2oc<0o`Wooooo0_lc0?l2ooooo`;oo`001?ooool2oc<0o`[ooooo0ooo0004ooooo`;o<`3o00?o
o`00ooooooooool00_lc0?l5ooooo`?oo`001oooool3o`0000;ooooo0_oo0002ooooo`Co<`3o0ooo
ool2ool000Gooooo0ooo000<ooooo`03o`000?o]/I3okK6@01CokK6@1ood/X0<ooJgQ@?on[9Z1?oj
/fX01Ook]6[o0000o`000?l0003oo;AS00;onk=O00Co<`3oooZ^D_l0003o00000ooiZd/5onJF5`03
okYa0?l0003ooooo03kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Qooooo`00
7oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo0=[ooooo0_lc0?l;ooooo`;o<`3o
2Oooool2oc<0o`04oooooooo003oo`00ool000Cooooo0_lc0?l:ooooo`;oo`001?ooool3oc<0o`03
ool00?oooooo<`3o00;o<`3o1Oooool3ool000Kooooo0ol00002ooooo`?oo`0000?ooooooc<0oolc
0?l00_lc0?l3ooooo`?oo`001?ooool3ool0013ooooo00?o0000onfaT?o]/I004oo]/I05ooBbP0ko
m[N500?oo`00ooZbJ_oj/VX01?oj/fX02?ok]6[o0000o`000?ok]6SonkAWoobdHook/eoonk5I0_oj
[U801Ol0003onJ];ooV[BooiZd_okZ@[00CoiYHG00?o^W40o`000?ooool0?_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo027ooooo000Oooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0eoooool2oc<0o`cooooo00?o<`3oooooooooool01oooool2oc<0o`03oooooooo
003oo`0000Gooooo0_lc0?l9ooooo`?oo`001?ooool2oc<0o`03oooooooo003ooooo00;o<`3o1_oo
ool2ool000Kooooo0ol00003ooooo`;oo`0000?ooooooc<0oolc0?l00olc0?l2ooooo`?oo`001Ooo
ool2ool001?ooooo00?o0000onfaT?o]/I005?o]/I03ooBbP13om[N500?on[9ZooZcJ_oj/fX00ooj
/fX01ook]6[o0000o`000?ok]6SonkAWoobdHook/el00_ok/ET2ooZ^DP03o`000?oiZd_onJ];00;o
kZ@[1?oVUQL00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool08Oooool001oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3Dooooo`;o<`3o
3?ooool2oc<0o`Sooooo0_lc0?l00oooooooo`00ool00005ooooo`;o<`3o2Oooool2ool000Cooooo
0olc0?l00oooooooo`00ool00002oc<0o`Gooooo0ooo0005ooooo`?o00001?ooool2ool000Go<`3o
0_ooool3ool000Gooooo0ooo000Dooooo`03ool00?l0003okK6@01GokK6@00?om;:0ooJgQOof]hD0
4?of]hD00ooj/V[on[=ZooZcJP03ooZcJP06oo^dJ_l0003o0000oo^dJ?ok]6Ooo;AS0_ok/el01_ok
/EWonZiBooZ^D_oj[U;o0000ooV[B`;okZ@[1?oVUQL00onjL@3o0000ooooo`0nooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool08Oooool001oooooo00?o0000ooooooooool0<_ooool2
o`000=;ooooo0_lc0?l<ooooo`;o<`3o1oooool3oc<0o`03oooooooo003oo`0000Gooooo0_lc0?l8
ooooo`?oo`001?ooool2oc<0o`;ooooo0_oo0002oc<0o`Cooooo1Ooo0003ooooo`?o00001?ooool3
ool000Co<`3o0_ooool3ool000Gooooo0ooo000Dooooo`?oo`0000?oooooo`000?o]/I005?o]/I00
0oo_^9Oom[N5ooJgQ@0AooJgQ@Gon[=Z0_ok]6X2o`000005oo^dJ?ok]6Ooo;ASoobdHook/el00_ok
/ET2ooZ^DP03o`000?oiZd_onJ];00;okZ@[0ooVUQL00onjL@3o0000ooooo`0nooooo`03o`000?oo
oooooooo00Wooooo0_l0000Sooooo`007oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo0<gooooo0_lc0?l<ooooo`;o<`3o1oooool2oc<0o`04oooooooo003oo`00ool000Gooooo0_lc
0?l8ooooo`;oo`001Oooool2oc<0o`;ooooo00Coo`00oc<0oolc0?oo<`3o1?ooool2ool00003oooo
oooo003oo`0000;ooooo0ol00005ooooo`;oo`001Olc0?l01?ooooooo`00ool00?oo0006ooooo`;o
o`005?ooool3ool000Gooooo00?o0000onfaT?o]/I004?o]/I04onnhUa;om[N500?omk^7ooZcJ_oj
/fX00_oj/fX2oo^dJP;o000000GonkAXoo^dIool]6?oo;ASoo^cG`02oo^aF@?onZiB00Co0000ooV[
Boo^Y2_okZ@[0ooVUQL00onjL@3o0000ooooo`0nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooool000008oooool001oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3:oooo
o`;o<`3o3Oooool00olc0?ooooooooooo`05ooooo`;o<`3o00?oooooool00?oo00001_ooool2oc<0
o`Sooooo0_oo0004ooooo`?o<`3o0oooool2oc<0o`Cooooo0ooo00001?ooooooo`00ool00?ooool3
o`0000Kooooo00?oo`00oc<0oolc0?l00olc0?l2ooooo`;oo`001_ooool3ool001;ooooo1?oo0008
ooooo`03o`000?o]/I3okK6@00kokK6@1_o_^9LAooJgQ@;omk^71?oj/fX4o`000004oo^dJ?ok]6Oo
nkAWoobdH`;onk=O0_ok/ET2ooZ^DP03o`000?oiZd_okZ@[00;okZ@[0_oVUQL00onjL@3o0000oooo
o`0nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool001kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`37ooooo`;o<`3o3Oooool2oc<0o`Kooooo0_lc0?l0
0oooooooo`00ool00006ooooo`;o<`3o1oooool3ool000Cooooo0_lc0?l4ooooo`;o<`3o1?ooool2
ool000;ooooo0_oo0003o`0000Oooooo1Olc0?l2ooooo`?oo`001Oooool3ool001;ooooo0ooo000<
ooooo`03o`000?o]/I3okK6@00gokK6@1oo_^9L@ooJgQ@Comk^70ol00002oo^dJP;o000000ConkAX
oo^dIook]6Ooo;AS0_ok/el2oo^aF@?onZiB00?o0000onjT:oo^Y2/00_o^Y2/2onJF5`03okYa0?l0
003ooooo03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`007_ooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo0<Cooooo0_lc0?l=ooooo`;o<`3o1_ooool2
oc<0o`03oooooooo003oo`0000Kooooo0_lc0?l7ooooo`;oo`001?ooool3oc<0o`?ooooo0olc0?l3
ooooo`?oo`000_ooool2ool000;o00001oooool00ooo003o<`3ooc<0o`03oc<0o`04oooooooo003o
o`00ool000Kooooo0_oo000Booooo`?oo`003oooool00ol0003okK6@onfaT00;onfaT0[okkRG3oof
]hD01?og^hOo0000o`000?l00003ooZcJP?onkAZ00Co0000oo^dJ?ok]6OonkAW0_ol]6<01?ok/eoo
nk5Ioo^aFOok/ET3ooZ^DP04o`000?o^Y2_okZ@[onjT:`;oiYHG00?o^W40o`000?ooool0?Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0`Oooool2oc<0o`gooooo0_lc0?l5ooooo`?o<`3o0ooo0006oooo
o`;o<`3o1_ooool3ool000Cooooo0_lc0?l4ooooo`;o<`3o00?oo`00ooooooooool00ooo0003oooo
o`;oo`0000?o0000ooooooooool01_ooool5oc<0o`04oooooooo003oo`00ool000Kooooo0ooo000A
ooooo`?oo`004oooool00ol0003okK6@onfaT008onfaT0cokkRG3Oof]hD3o`0000Comk^70_oj/fX3
oo^dJP;o00000_ok]6L2oobdH`;onk=O0_ok/ET3ooZ^DP03o`000?o^Y2_okZ@[00;okZ@[00?oiYHG
okYa0?l00000?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo023ooooo000Noooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0__ooool2oc<0o`kooooo00?o<`3ooooo
ooooool00oooool2oc<0o`03oooooooo003oo`0000Oooooo0_lc0?l6ooooo`;oo`001?ooool3oc<0
o`Cooooo0_lc0?l00ooo003oooooooooo`02ool000;ooooo0_l00002ool000Sooooo1Olc0?l01?oo
ooooo`00ool00?oo0006ooooo`?oo`004Oooool3ool001Kooooo00?o0000onfaT?o]/I001_o]/I0>
onnhU`[om[N50ol000000oof]hGomk^7ooNkQ`04ooNkQ`03ooZcJ_ok]6[onkAZ00;onkAZ00Co0000
oo^dJ?l0003onkAW0_ol]6<2oo^cG`;onk5I0ooj[U800oof/D;o0000onjT:`02onjT:`03onJF5onj
L@3o000003kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`007_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;_ooooo0_lc0?l>ooooo`;o<`3o1?ooool2
oc<0o`03oooooooo003oo`0000Oooooo0_lc0?l6ooooo`;oo`001?ooool2oc<0o`Cooooo0olc0?l5
ool00004ooooool0003o0000o`0000;oo`001oooool6oc<0o`?oo`001oooool2ool0017ooooo0ooo
000Hooooo`03ool00?l0003okK6@00GokK6@4Oo_^9L6ooJgQ@?o00000oof]hD8ooNkQ`ConkAZ0ol0
00001?ok]6Ooo;ASoobdHool]6<2oo^cG`;onk5I0_oj[U800oof/D;o0000o`000003onjT:`03onJF
5ol0003ooooo03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`007_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0;Sooooo0_lc0?l>ooooo`;o<`3o1?oo
ool2oc<0o`03oooooooo003oo`0000Oooooo0_lc0?l5ooooo`?oo`000oooool3oc<0o`Cooooo0_lc
0?l00oooooooo`00ool00002ool00005ooooool0003o0000o`000?ooool00_oo0007ooooo`Go<`3o
00?oooooool00?oo00001oooool3ool0013ooooo0ooo000Gooooo`Goo`0000?o0000onfaT?o]/I00
0oo]/I0BonnhU`;om[N51?l00005ooJgQ@Womk^700Coo`00oo^dJ_ok]6[onkAZ0_l000000ook]6So
0000oo^dI`02oobdH`;onk=O0_ok/ET2ooZ^DP03oc<0ool0003o000000CokZ@[00?o^W40o`000?oo
ool0?Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0]Oooool2oc<0o`oooooo00?o<`3oooooooooool0
0_ooool2oc<0o`03oooooooo003oo`0000Oooooo0_lc0?l5ooooo`;oo`001?ooool2oc<0o`Gooooo
0_lc0?l00oooooooo`00ool00002ool000?o00000_ooool2ool000Kooooo1Olc0?l01?ooooooo`00
ool00?oo0006ooooo`?oo`003oooool01?lc0?ooo`00ool00?oo000Fooooo`Coo`0000Coooooool0
0?oo003oo`000_ooool00ol0003okK6@onfaT00ConnhU`?o00002Oof]hD9ooNkQ`05ooVoQook]6[o
nkAZoo^dJ_l000000_ok]6P01?ok]6Oo0000oobdHool]6<2oo^cG`?onk5I00ConZiBooJa@_of/D;o
00001?o^Y2/00onjL@3o0000ooooo`0mooooo`03o`000?oooooooooo00Wooooo0_l0000Rooooo`00
7_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0;;ooooo0_lc0?l?ooooo`;o<`3o
0_ooool3oc<0o`?oo`001oooool2oc<0o`Cooooo0ooo0003ooooo`?o<`3o1?ooool3oc<0o`04oooo
oooo003oo`00ool000?o00000oooool2ool000Gooooo1_lc0?l3ool000Oooooo0_oo000?ooooo`Co
o`005Oooool4ool00003oooooooo003oo`0000;oo`000oooool2oc<0o`03o`000?o_^9OokkRG013o
kkRG0ol00002onnhU`Wom[N52_og^hL01Ooi_hOonkAZoo^dJ_ok]6[o000000;onkAX0_ok]6L00ol0
003oo;ASoo^cG`02oo^cG`;onk5I00ConZiBooJa@_of/D;o00001?o^Y2/00onjL@3o0000ooooo`0m
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000008_ooool001gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`2_ooooo`;o<`3o3oooool2oc<0o`;ooooo0_lc0?l00ooo
ooooo`00ool00008ooooo`;o<`3o1?ooool2ool000Cooooo0_lc0?l5ooooo`;o<`3o0_ooool3ool0
00;o00001?ooool2ool000Cooooo1_lc0?l3ool000Oooooo0ooo000>ooooo`?oo`005Oooool4ool0
00;ooooo0ooo0004ooooo`Go<`3o00?o0000onnhUoo_^9L03Oo_^9L3o`0000GokkRG2?of]hD:ooNk
Q`?onKn70_ok]6X00ol0003onkAXoo^dJ002oo^dI`03o`000?ol]6?oo;AS00;onk=O0ook/ET3ooJa
@P06o`000?o^Y2_okZ@[onjT:ooAT0;o0000?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01oooooo000Mooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0[?ooool2
oc<0o`oooooo0_lc0?l2ooooo`;o<`3o00?oooooool00?oo00001oooool3oc<0o`Cooooo0_oo0004
ooooo`;o<`3o1Oooool2oc<0o`03oooooooo003oo`0000;oo`0000?o0000ooooooooool00oooool2
ool000Cooooo0_lc0?l00ooooooo<`3ooc<0o`03ool000Sooooo0_oo000>ooooo`?oo`005Oooool3
ool000;ooooo1?oo0003ooooo`Ko<`3o1?ooool00ol0003okkRGonnhU`09onnhU`?o00002Oo_^9L7
ooJgQ@[omk^71?oi_hL01?ok]6[o0000oo^dJ?ok]6P2oo^dI`03oobdHol0003oo;AS00;onk=O0ook
/ET3ooJa@P07o`000?o^Y2_okZ@[onjT:ooAT0;o^W40o`00000mooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool07oooool001gooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`2Yooooo`;o<`3o4?ooool00olc0?ooooooooooo`02oc<0o`03oooooooo003oo`0000Oooooo
0_lc0?l4ooooo`?oo`000oooool3oc<0o`Cooooo0olc0?l00oooooooo`00ool00002ool000Kooooo
0_oo0003ooooo`Ko<`3o0_oo0008ooooo`?oo`003Oooool3ool001Cooooo1?oo0002ooooo`?oo`00
0oooool6oc<0o`Sooooo00?o0000onnhUoo_^9L01Oo_^9L4o`0000cokkRG1_of]hD;ooNkQ`ConKn7
00ConkAZo`000?ok]6SonkAX0ook]6L00ool]6?o0000oo^cG`02oo^cG`;onk5I00Gonk]GooJa@_of
/D;om[52o`000003onjT:`03okYa0?l0003ooooo03cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Oooooo`007Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0:Ko
oooo0_lc0?l@ooooo`;o<`3o00?ooooooc<0oolc0?l00ooo0007ooooo`;o<`3o1?ooool2ool000Co
oooo0_lc0?l5ooooo`;o<`3o00?oooooool00?oo00000ooo0006ooooo`;oo`000_ooool6oc<0o`;o
o`002?ooool3ool000gooooo0ooo000Cooooo`Coo`000oooool3ool000;ooooo1olc0?l;ooooo`03
o`000?o_^9OokkRG00;okkRG0ol0000@onnhU`Gom[N52oog^hL6ooVoQ`03o`000?ok]6SonkAX00?o
nkAW0_ol]6<00ol0003onk=Ooo^cG`02oo^aF@05oo^kEoof/D;om[52ooJa@_l000000oo^Y2/00ooA
T0;o0000ooooo`0looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool001go
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Sooooo`;o<`3o4?ooool5oc<0o`;o
o`002?ooool2oc<0o`?ooooo0ooo0003ooooo`?o<`3o1Oooool2oc<0o`?oo`0000?o0000oooooooo
00001_ooool2ool000;ooooo0_lc0?l00ooooooo<`3ooc<0o`03ool000Sooooo0_oo000=ooooo`?o
o`004_ooool4ool000?ooooo1?oo0002ooooo`Ko<`3o4?ooool4o`0001CokkRG1?of]hD;ooNkQ`Ko
nKn700Co0000oo^dJ?ok]6SonkAX0_ok]6L2oobdH`04o`000?ok/eoonk=Ooo^aF@;onk]G1?of/D80
1Ol0003okZ@[onjT:ooAT0;o000003kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Oooooo`007Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0:3ooooo0_lc0?l@
ooooo`Co<`3o00?oooooool00?oo00002?ooool2oc<0o`?ooooo0_oo0004ooooo`;o<`3o1Oooool3
oc<0o`;oo`0000?o0000ooooooooool00_oo0005ooooo`;oo`0000?ooooooc<0oolc0?l01?lc0?l2
ool000Sooooo0ooo000;ooooo`04oc<0oooo003oo`00ool0017ooooo1?oo0004ooooo`?oo`000_oo
ool7oc<0oa7ooooo0ol0000GonnhU`?om[N53?og^hL6ooVoQ`04o`000?ok`XConkAXoo^dJ0;onkAW
0ool]6<00ol0003onk=Ooo^cG`03oo^kE`?om[5200Ko0000onjT:oo^Y2_odI02okYa0?l0000moooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool001gooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`2Mooooo`;o<`3o4Oooool3oc<0o`03oooooooo003oo`0000So
oooo0_lc0?l2ooooo`?oo`000oooool3oc<0o`Gooooo0_lc0?l3ool000?ooooo0_oo0005ooooo`;o
o`001_lc0?l2ool000Sooooo0ooo000;ooooo`04oc<0oooo003oo`00ool0013ooooo1?oo0004oooo
o`Coo`0000?ooooooc<0oolc0?l01Olc0?l@ooooo`;oo`000ol00002ooooo`03o`000?o_^9OokkRG
01GokkRG0oof]hD;ooNkQ`OonKn700Co0000oo_2Q?ok`XConkAX0_ok]6L3oobdH`03oo^cGol0003o
nk=O00?onk]G0oof/D801_l0003okZ@[onjT:ooAT0;o^W40o`0003gooooo00?o0000ooooooooool0
2Oooool2o`00027ooooo000Mooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0V_oo
ool2oc<0oa7ooooo0olc0?l3ool000Sooooo0_lc0?l2ooooo`;oo`001?ooool2oc<0o`Kooooo0_lc
0?l2ool000Cooooo0_oo0005ooooo`05ool00?lc0?oo<`3ooc<0ooooool00_lc0?l3ool000Sooooo
0_oo000;ooooo`Coo`004?ooool3ool000Gooooo0ooo0002ooooo`Ko<`3o3oooool4ool000?o0000
1Oooool00ooo003o0000onnhU`0FonnhU`03ooJgQOog^hOomk^700[omk^71ooi_hL01?l0003onl:4
oo_2Q?ok`X@3oo^dI`?oo;AS00?onk=Oo`000?ok^eL00_ok^eL4ooJa@P05o`000?o^Y2_odI02om6@
0_l00000?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo0000027ooooo000Mooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0Uoooool2oc<0oa7ooooo0olc0?l2ool000Wo
oooo0_lc0?l2ooooo`;oo`000oooool3oc<0o`Gooooo00?o0000oc<0oolc0?l00_oo0005ooooo`03
ool00?oooooooooo00?ooooo00Coo`00oc<0oolc0?oooooo0olc0?l3ool000Oooooo0ooo000:oooo
o`?oo`004?ooool4ool000Cooooo1?oo00000ooooooo<`3ooc<0o`05oc<0o`gooooo1Ooo0004o`00
00Cooooo1?oo00000ooooooo0000onnhU`0FonnhU`gomk^71_oi_hL2o`0000?onl:40_om`gl01ook
]6Ooo;ASoobdHool]6?onk=Oo`000?on`FT00ook^eL3ooJa@P?o000000?odI02o`000?ooool0??oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo000Looooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0U?ooool2oc<0oa7ooooo0_lc0?l00oooooooo`00ool00009
ooooo`;o<`3o00Coooooool00?oo003oo`000oooool2oc<0o`Gooooo00Go0000oc<0oolc0?oo<`3o
ool00006ooooo`;oo`001?ooool6oc<0o`?oo`001oooool3ool000[ooooo0ooo000?ooooo`Coo`00
1Oooool3ool00003oooooolc0?oo<`3o00Go<`3o3?ooool5ool00004ooooool0003o0000o`0000Go
oooo1?oo0005ooooo`03o`000?o_^9OokkRG01GokkRG00?olKjKooNkQoog^hL02_og^hL6ooVoQ`;o
00000ook`X@3oog3O`;oo;AS00Coo/=fook1JOon`FWo00000ook^eL4ooJa@P;o000000?odI02o`00
0?ooool0??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo000Looooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool0TOooool2oc<0oa7ooooo0_lc0?l00ooooooo
o`00ool00009ooooo`;o<`3o00?oooooool00?oo00000oooool3oc<0o`Cooooo0_l00002oc<0o`03
ool00?oooooooooo00Gooooo0_oo0003ooooo`?o<`3o00?ooooooc<0oolc0?l01?oo0007ooooo`;o
o`002_ooool3ool000kooooo1?oo0005ooooo`Coo`002?lc0?l9ooooo`Koo`000oooool3o`0000Co
oooo1?oo0005ooooo`Go<`3o00?o0000onnhUoo_^9L04oo_^9L2oo6nV`_omk^700?oo`00ooVoQooi
_hL01?oi_hL00ol0003onl:4oo_2Q002oo_2Q0?ooL=o0oon`gH3ook1J@04o`000?ok^eOonk]Goo^k
E`?om[5200Go0000om6@0_oAT0;odI02o`00000looooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07_ooool001cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2>oooo
o`;o<`3o4Oooool3oc<0o`;oo`002Oooool2oc<0o`?oo`000oooool2oc<0o`Cooooo0ol00002oc<0
o`03ool00?oooooooooo00Gooooo0_oo0002ooooo`?o<`3o00Coo`00oc<0oolc0?oo<`3o1?oo0006
ooooo`?oo`002Oooool3ool000gooooo1?oo0006ooooo`?oo`0000Gooooooc<0oolc0?oo<`3ooooo
o`03oc<0o`Sooooo1Ooo0006ooooo`?o00000oooool4ool000Gooooo1?lc0?l2ooooo`?o<`3o00?o
0000onnhUoo_^9L04_o_^9L4oo6nV`[omk^71ooi_hL00ol0003onl:4oo_2Q002oo_2Q0?ooL=o0oon
`gH4ook1J@03o`000?ok^eOonk]G00Com[5200Co0000om6@0_oAT0;o0000??ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01kooooo000Looooo`03o`000?oooooooooo04gooooo0_l0
002<ooooo`;o<`3o4Oooool3oc<0o`03ool00?oooooooooo00Sooooo0_lc0?l2ool000Cooooo0_lc
0?l3ooooo`?o00000olc0?l9ooooo`03ool00?oooooooooo00;o<`3o00Koo`00oc<0oolc0?oo<`3o
ool00?ooool2ool000Kooooo0ooo0009ooooo`?oo`003?ooool4ool000Kooooo1?oo0008oc<0o`Ko
oooo1Ooo0008ooooo`?o00000_ooool4ool000Cooooo1Olc0?l2ooooo`Co<`3o0oooool00ol0003o
kkRGonnhU`0AonnhU`GolKjK2_og^hL7ooVoQ`03o`000?ok`XConl:400;onl:40oom`gl4ook3MP?o
o/5Y00?o0000oo^kEook^eL01?of/D801?l0003odI02om6@0_l0000mooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07_ooool001cooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`27ooooo`;o<`3o4?ooool4oc<0o`03ool00?oooooooooo00Sooooo0_lc0?l2ool000?o
oooo0olc0?l2ooooo`?o000000Cooooooc<0oolc0?ooo`002Oooool2ool000?o<`3o00Coo`00oc<0
oolc0?ooo`000_ooool2ool000Kooooo0_oo0008ooooo`04oc<0oooo003oo`00ool000_ooooo1?oo
0007ooooo`?oo`001?lc0?l01?oooooo<`3ooc<0oolc0?l5ooooo`Goo`002_ooool3o`0000;ooooo
0ooo0004ooooo`Co<`3o0_ooool5oc<0o`Sooooo00?o0000onnhUoo_^9L03oo_^9L7oo6nV`Somk^7
2?oi_hL00ol0003onl:4oo_2Q002oo_2Q0?ooL=o1?on`gH3ook1J@04oo^kEol0003onk]Goo^kE`?o
m[5200Co0000om6@0_oAT0;o0000?Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01kooooo000Looooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Q?ooool2oc<0oa3o
oooo0_lc0?l00ooooooo<`3oool0000:ooooo`;o<`3o0_oo0003ooooo`;o<`3o0_ooool3o`000004
oooooooo003o<`3ooc<0o`[ooooo00Goo`00oc<0oolc0?oo<`3oooooo`03oc<0o`?ooooo0_oo0005
ooooo`?oo`001oooool01?lc0?ooo`00ool00?oo000;ooooo`?oo`002?ooool3ool000?o<`3o00?o
oooooc<0oolc0?l00_lc0?l3ooooo`Goo`002oooool4o`000003oooooooo003oo`0000;oo`000_oo
ool5oc<0o`;ooooo1?lc0?l7ooooo`Koo`0000?o0000onnhUoo_^9L03_o_^9L8oo6nV`Somk^72?oi
_hL00ol0003onl:4oo_2Q002oo_2Q0?ooL=o1?on`gH3ook1J@;onk]G00?o0000oo^kEoof/D800oof
/D800ol0003odI02o`00000mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_oo
ool001cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`21ooooo`;o<`3o4?ooool2
oc<0o`03ool00?lc0?oo<`3o00[ooooo0_lc0?l01?oo003oooooooooooooool3oc<0o`04ooooool0
003o0000o`0000;ooooo0olc0?l:ooooo`?o<`3o00Cooooooc<0oolc0?oo<`3o0oooool3ool000Go
oooo0_oo0007ooooo`Coo`002_ooool4ool000Oooooo1?oo0007oc<0o`;ooooo1Ooo000=ooooo`?o
000000?oooooool00?oo00000_oo0002ooooo`Co<`3o0oooool4oc<0o`Cooooo1ooo0007ooooo`03
o`000?o_^9OokkRG00cokkRG2_oa_Y/7ooNkQ`SonKn700?o0000oo_2Q?ok`X@00_ok`X@4oog3O`?o
o/=f1?on`FT2oo^kE`03o`000?of/D;om[5200;om[5200Co0000om6@0_oAT0;o0000??ooool00ol0
003oooooooooo`09ooooo`;o00008?ooool001cooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`1nooooo`;o<`3o4?ooool2oc<0o`03ool00?lc0?oo<`3o00[ooooo0_lc0?l01?oo003o
ooooooooooooool2oc<0o`04ooooool0003o0000o`0000;ooooo00?oo`00oc<0oolc0?l02oooool2
oc<0o`;ooooo0_lc0?l01?oo003oooooooooooooool2ool000Gooooo0ooo0006ooooo`?oo`002_oo
ool4ool000Sooooo0ooo0003oc<0o`05oooooolc0?oo<`3ooc<0ooooool01Ooo000?ooooo`?o0000
1?oo00000ooooooo<`3ooc<0o`03oc<0o`?ooooo1?lc0?l8ool000kooooo00?o0000onnhUoo_^9L0
3?o_^9L:oo6nV`Oomk^71ooi_hL00ol0003onl:4oo_2Q003oo_2Q0CooL=o0oon`gH4ook1J@;onk]G
00?o0000oo^kEoof/D800_of/D801?l0003odI02om6@0_l0000looooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00007oooool001cooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`1kooooo`;o<`3o4?ooool2oc<0o`03ool00?lc0?oo<`3o00[ooooo0_lc0?l3ooooo`?o
<`3o0ol00003ooooo`03ool00?lc0?oo<`3o00[ooooo0olc0?l01Ooo003o<`3ooc<0oolc0?ooo`00
00?ooooo0_oo0004ooooo`?oo`001_ooool3ool000Wooooo1?oo0008ooooo`Coo`000_lc0?l01?oo
oooo<`3ooc<0oolc0?l5ool0017ooooo0_l00004ool00003oooooolc0?oo<`3o00;o<`3o1?ooool0
0olc0?ooo`00ool00005ool001Gooooo00?oo`00o`000?o_^9L03?o_^9L<oo6nV`Gomk^72?oi_hL0
0ol0003onl:4oo_2Q003oo_2Q0CooL=o1?on`gH3ook1J@?onk]G00So0000ooJa@_of/D;om[52onR]
;?l0003odI02o`0003cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`;o
00005Oooool001_ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1hooooo`;o<`3o
3oooool3oc<0o`;oo`0000?o<`3oooooooooool01oooool00ooo003o<`3ooc<0o`03ooooo`;o<`3o
0ol00003ooooo`04ool00?lc0?oo<`3ooc<0o`Wooooo0olc0?l01?oo003o<`3ooc<0oolc0?l2ool0
00?ooooo0_oo0004ooooo`;oo`001_ooool3ool000Sooooo1?oo0009ooooo`?oo`000_lc0?l2oooo
o`03oc<0oooo003oo`0000?oo`004oooool00ol0003oo`00ool00002ool000Go<`3o0_ooool7ool0
01Sooooo1?oo0002ooooo`03o`000?o_^9OokkRG00WokkRG3Ooa_Y/5ooNkQ`SonKn700?o0000oo_2
Q?ok`X@00ook`X@4oog3O`Coo/=f0oon`FT4oo^kE`07o`000?of/D;om[52onR];?l0003odI02o`00
000looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool0000Dooooo`006oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo07Gooooo0_lc
0?l?ooooo`;o<`3o0ooo0002oc<0o`Sooooo00?oo`00oc<0oolc0?l00_ooool3oc<0o`;o00000ooo
ool2ool000;o<`3o2Oooool3oc<0o`05oooooooo003o<`3ooc<0ooooool00_oo0002ooooo`?oo`00
0oooool3ool000Gooooo0ooo0007ooooo`Coo`002Oooool4ool000;o<`3o00?oooooool00?oo0000
0ooo000Eooooo`Coo`001?lc0?l7ool000;o<`3o6?ooool5ool000Gooooo00?o<`3oo`000?o_^9L0
2Oo_^9L?oo6nV`Comk^72?oi_hL00ol0003onl:4oo_2Q003oo_2Q0CooL=o1?on`gH4ook1J@Conk]G
00Ko0000ooJa@_oX[Bco0000om6@0_l0000looooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool0000Dooooo`006oooool00ol0003oooooooooo`1Goooo
o`03o`000?oooooooooo07;ooooo0_lc0?l?ooooo`;o<`3o0_oo00000ooooooo<`3ooc<0o`08oooo
o`03ool00?lc0?oo<`3o00;ooooo0_lc0?l2o`0000Cooooo0_oo0002oc<0o`Wooooo0_lc0?l00ooo
ooooo`00oc<0o`02oc<0o`03oooooooo003oo`0000;ooooo0_oo0003ooooo`?oo`001?ooool01?lc
0?ooo`00ool00?oo0007ooooo`?oo`002_ooool3ool000;o<`3o1Ooo000Fooooo`coo`0000?ooooo
oc<0oolc0?l00_lc0?lHooooo`Coo`001?ooool6oc<0o`03ooooool0003okkRG00SokkRG4?oa_Y/3
ooNkQ`WonKn700?o0000oo_2Q?ok`X@00ook`X@4oog3O`Coo/=f1?on`FT4oo^kE`04o`000?of/D;o
j:d/onR];0;o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00005?ooool001_ooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`1_ooooo`;o<`3o3oooool2oc<0o`;oo`0000?ooooooc<0oolc0?l01oooool2ool000;o<`3o00Co
oooooc<0oolc0?oo<`3o1Oooool2ool000?o<`3o2?ooool3oc<0o`06oooooolc0?oo<`3ooc<0oooo
003ooooo0_oo0002ooooo`;oo`000oooool2ool000Cooooo00Co<`3oool00?oo003oo`001_ooool4
ool000Wooooo2Ooo0002oc<0oaGooooo2?oo0005ooooo`Co<`3o6?ooool4ool000?ooooo1Olc0?l5
ooooo`?o<`3o00?o0000onnhUoo_^9L01Oo_^9LBoo6nV`;omk^72?oi_hL2o`0000Gonl:41?om`gl4
ook3MPCoo/5Y1Ook^eL00ol0003om[52oc<0o`03o`0003cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0001Cooooo000Kooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool0K?ooool2oc<0o`oooooo0_lc0?l2ool000;ooooo00?o<`3o
ooooooooool01Oooool2ool000;o<`3o00?o0000oc<0oolc0?l01_ooool2ool000;o<`3o2?ooool3
oc<0o`04oooooooo003o<`3ooc<0o`;oo`0000Coooooool00?oo003ooooo0ooo0002ooooo`?oo`00
0oooool4ool000Gooooo1?oo000:ooooo`Ooo`000olc0?lCooooo`Ooo`000_lc0?l6ooooo`Co<`3o
5oooool5ool00003oooooolc0?oo<`3o00Co<`3o1Oooool5oc<0o`?ooooo00?o0000onnhUoo_^9L0
1Oo_^9LBoo6nV`;omk^72?oi_hL2o`0000Gonl:41?om`gl5ook3MPCoo/5Y1?ok^eL00oof/D;o0000
onR];003o`0003cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0001Cooooo000Kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
JOooool2oc<0o`kooooo0olc0?l2ool000;ooooo0_lc0?l5ooooo`?oo`000_lc0?l00ol0003o<`3o
oc<0o`05ooooo`?oo`000_lc0?l7ooooo`?o<`3o00?oooooool00?lc0?l00_lc0?l2ool00004oooo
oooo003oo`00ooooo`;oo`000_ooool3ool000?ooooo0ooo0005ooooo`Coo`002_ooool5ool000;o
oooo0olc0?l@ooooo`Woo`000_l00006ooooo`Go<`3o5oooool4ool00003oooooolc0?oo<`3o00?o
<`3o1_ooool5oc<0o`Sooooo00?o0000onnhUoo_^9L01?o_^9LDoo6nV`03ool00?oi_hOonKn700Oo
nKn700?o0000oo_2Q?ok`X@00ook`X@4oog3O`Goo/=f1?on`FT4oo^kE`;om[520_l000000ooAT0;o
0000ooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0001Go
oooo000Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0I_ooool2oc<0o`kooooo
0_lc0?l2ool000?ooooo0_lc0?l5ooooo`;oo`0000?ooooooc<0oolc0?l00olc0?l4ooooo`?oo`00
0olc0?l7ooooo`;o<`3o00?oooooool00?lc0?l00_lc0?l01?ooooooo`00ool00?ooool2ool00003
oooooooo003oo`0000;ooooo0_oo0003ooooo`?oo`001?ooool4ool000Wooooo1_oo0002ooooo`Co
<`3o2oooool8ool000;ooooo1?oo0002o`0000Gooooo1?lc0?lGooooo`Goo`001Olc0?l7ooooo`Co
<`3o1?ooool:ool00003o`000?o_^9OokkRG00;okkRG5Ooa_Y/9ooVoQ`03o`000?ok`XConl:400Co
nl:41Oom`gl4ook3MPCoo/5Y1Ook^eL00oof/D;o0000onR];002o`0003cooooo00?o0000oooooooo
ool02Oooool2o`0001oooooo000Kooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
Hoooool2oc<0o`kooooo0_lc0?l2ool000?ooooo0_lc0?l5ooooo`;oo`0000?o0000oc<0oolc0?l0
0_lc0?l5ooooo`;oo`0000?ooooooc<0oolc0?l01oooool3oc<0o`;oo`000_lc0?l3ooooo`05ool0
0?ooooooo`00ool00?ooool00_oo00001?ooooooo`00ool00?oo0002ooooo`?oo`000oooool4ool0
00Sooooo1ooo0003ooooo`?o<`3o2?ooool7ool000Kooooo1?oo0003o`0000Cooooo1?lc0?lGoooo
o`Coo`001?lc0?l7ooooo`koo`002_ooool01?l0003okkRGonnhUoo_^9LFoo6nV`03ooC5W?oi_hOo
nKn700KonKn700?o0000oo_2Q?ok`X@01?ok`X@5oog3O`Coo/=f1?on`FT5oo^kE`03ooJa@_oX[Bco
000000;o0000??ooool00ol0003oooooooooo`07ooooo`;o00000_ooool00ol0003oooooooooo`0L
ooooo`006_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo063ooooo0_lc0?l>oooo
o`;o<`3o0_oo0004ooooo`03oc<0oooooooooooo00;ooooo0ooo00000ol0003o<`3ooc<0o`02oc<0
o`Cooooo0ooo00000ooooooo<`3ooc<0o`06ooooo`?o<`3o0_oo0003oc<0o`?ooooo2_oo0002oooo
o`?oo`000oooool3ool000Oooooo2Ooo0002ooooo`Co<`3o1?ooool7ool000Sooooo00?o<`3oool0
0?oo00000_oo00001?oooooo0000o`000?l00003ooooo`Co<`3o5_ooool5ool00003oc<0oooo003o
o`0000coo`0000?o<`3oooooooooool05Oooool00ol0003okkRGonnhU`0Foo6nV`?om<FL1ooi_hL0
0ol0003onl:4oo_2Q004oo_2Q0GooL=o1?on`gH5ook1J@Conk]G00?om[52onR];?oX[B`00_l0000l
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`1Mooooo`;o<`3o3Oooool3oc<0o`;oo`001?ooool2oc<0
o`?ooooo0_oo0002o`0000?o<`3o1Oooool2ool000;ooooo0_lc0?l5ooooo`?o<`3o00?oooooool0
0?lc0?l00_lc0?l4ooooo`Koo`0000Goooooool00?oo003ooooooc<0o`03ool000;ooooo1?oo0005
ooooo`Goo`0000?ooooooc<0oooo00000_oo0003ooooo`?o<`3o00?oooooool00?oo00001Ooo000;
ooooo`03oc<0oooo003oo`0000;oo`0000?oooooo`000?l000000_l00002ooooo`Co<`3o4_ooool>
ool000Gooooo1Olc0?lMooooo`03o`000?oa_Y_olKjK01GolKjK0oodaI`7ooVoQ`03o`000?ok`XCo
nl:400Conl:41Oom`gl5ook3MPCoo/5Y1Ook^eL3onR];0;o0000>oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool0F_ooool2oc<0o`gooooo0_lc0?l3ool000Cooooo0_lc0?l2ooooo`?oo`0000?o0000oooo
oolc0?l00_lc0?l4ooooo`?oo`0000Cooooooc<0oolc0?oo<`3o1Oooool2oc<0o`03oooooooo003o
o`0000;o<`3o1Oooool9ool00005oc<0oooo003oo`00ool00?ooool01?oo0004ooooo`Goo`000ooo
ool4ool000;ooooo2?oo000=ooooo`;o<`3o1?oo0002ooooo`?o00000_ooool4oc<0o`Oooooo4ooo
000;ooooo`Co<`3o7_ooool4ool00003o`000?oa_Y_olKjK01ColKjK1OodaI`6ooVoQ`03o`000?ok
`XConl:400Conl:41Oom`gl5ook3MPCoo/5Y1Ook^eL3onR];0;o0000>oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0Eoooool2oc<0o`gooooo0_lc0?l2ool000Gooooo0_lc0?l2ooooo`;oo`0000?o0000
ooooooooool00_lc0?l4ooooo`?oo`000_ooool2oc<0o`Gooooo0olc0?l2ool000?o<`3o1_ooool7
ool00003oc<0oooo003oo`0000Goo`000oooool5ool000Cooooo00?o<`3oool00?oo00001ooo000A
ooooo`;o<`3o1?oo0003ooooo`?o000000?ooooooc<0oooo00003Ooo0008ooooo`;o<`3o1?oo000;
ooooo`Go<`3o7Oooool5ool000;ooooo0olc0?l00ol0003olKjKoo6nV`0Coo6nV`Kom<FL1Ooi_hL0
0ol0003onl:4oo_2Q004oo_2Q0GooL=o1Oon`gH4ook1J@Gonk]G0ooX[B`2o`0003cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo05Cooooo0_lc0?l=ooooo`;o<`3o0_oo0006ooooo`03oc<0ooooooooo`00
00;oo`000_ooool3oc<0o`Cooooo0_oo0003ooooo`;o<`3o1?ooool3oc<0o`;oo`000olc0?l7oooo
o`goo`000_ooool5ool000Gooooo1ooo0004oc<0o`oooooo0olc0?l@ool0017ooooo0_lc0?l5ool0
00[ooooo1Olc0?lMooooo`Goo`001olc0?l3ooooo`03o`000?oa_Y_olKjK01;olKjK1oodaI`5ooVo
Q`03o`000?ok`XConl:400Conl:41Oom`gl5ook3MPGoo/5Y1?ok^eL3onR];0?o0000>oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool0DOooool2oc<0o`gooooo0_lc0?l2ool000Kooooo0_lc0?l2ool000?o
oooo0olc0?l3ooooo`?oo`000_ooool3oc<0o`Cooooo0_lc0?l3ool000;o<`3o2?ooool;ool00003
oooooooo003oo`0000?oo`000_ooool9ool000;ooooo1?lc0?l:ooooo`koo`000oooool3o`0000?o
<`3o4?ooool4oc<0o`Coo`002_ooool5oc<0oacooooo1_oo0005oc<0o`_ooooo00?o0000oo6nVooa
_Y/04Ooa_Y/8ooC5W0ConKn700?o0000oo_2Q?ok`X@01?ok`X@5oog3O`Goo/=f1Oon`FT4oo^kE`07
ooS3DooX[Bcoj:d/onR];?l0003oooooo`00000jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool07?ooool001[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1>oooo
o`;o<`3o3?ooool3oc<0o`;oo`001_ooool2oc<0o`;oo`000_ooool4oc<0o`?ooooo0_oo0003oooo
o`;o<`3o1?ooool3oc<0o`;oo`000olc0?l8oooooaGoo`0000?ooooooc<0oooo00000ooo0002oooo
o`?o<`3o3_oo00001?oooooo<`3ooc<0oolc0?l4ool000Kooooo0ol00002oc<0o`oooooo1?lc0?l5
ool000[ooooo1?lc0?lLooooo`Goo`000olc0?l=ooooo`Ko<`3o00?o0000oo6nVooa_Y/04?oa_Y/:
ooC5W0;onKn700?o0000oo_2Q?ok`X@01Ook`X@5oog3O`Goo/=f1Oon`FT3oo^kE`;on<=C0ooX[B`0
0ol0003oooooo`00000jooooo`03o`000?oooooooooo00[ooooo0_l0000Mooooo`006_ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo04_ooooo0_lc0?l<ooooo`;o<`3o0_oo0005oooo
o`;o00000_lc0?l2ool000;ooooo1?lc0?l2ooooo`?oo`000oooool2oc<0o`?ooooo0olc0?l2ool0
00?o<`3o2_ooool?ool000?ooooo3ooo000:ooooo`Co<`3o1?oo0006ooooo`Co000000?o<`3ooooo
ooooool02oooool6oc<0o`Coo`002_ooool5oc<0oa[ooooo00?o<`3oool00?oo00000ooo00000olc
0?ooooooooooo`0=ooooo`Go<`3o1_ooool00ol0003olKjKoo6nV`0@oo6nV`[om<FL0_oi_hL00ol0
003onl:4oo_2Q005oo_2Q0KooL=o1Oon`gH5ook1J@;onk]G0_oh`e<3onR];0;o000000?oooooo`00
0?ooool0>?ooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?ooool07?ooool001[o
oooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`18ooooo`;o<`3o3?ooool2oc<0o`;o
o`001?ooool3o`000003oooooolc0?ooo`0000?ooooo1?lc0?l01?ooooooo`00ool00?oo0003oooo
o`?o<`3o0_ooool3oc<0o`?oo`000_lc0?l;oooooaOoo`000_ooool3oc<0o`gooooo1?lc0?l01?oo
ooooo`00ool00?oo0006ooooo`05oc<0ool0003o0000o`000?lc0?l03?ooool5oc<0o`03oooooooo
003oo`0000?oo`002Oooool5oc<0oaSooooo0_lc0?l6ool000oooooo1_lc0?l<ooooo`03o`000?oa
_Y_olKjK00kolKjK3?odaI`00ooi_hOo0000oo_2Q006oo_2Q0KooL=o1Oon`gH5ook1J@;onk]G0_oh
`e<4onR];004o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Kooooo`006Oooool00ol0003oooooooooo`1Xooooo`;o0000A_ooool2oc<0o`cooooo0_lc
0?l2ool000?ooooo0ol000001?ooooooo`00oc<0oolc0?l2ooooo`Go<`3o00?oooooool00?oo0000
1?ooool2oc<0o`?ooooo0_lc0?l3ool000?o<`3o2_ooool00olc0?ooo`00ool00006ool000Sooooo
0_lc0?l4ool00003oooooolc0?oo<`3o00;o<`3o2oooool5oc<0o`03oooooooo003oo`0000;oo`00
1Oooool2oc<0o`?o00002_ooool6oc<0o`;ooooo1?oo000:ooooo`Co<`3o5Oooool5oc<0o`Goo`00
4?ooool5oc<0oa;ooooo00?o0000oo6nVooa_Y/03_oa_Y/=ooC5W003o`000?ok`XConl:400Gonl:4
1_om`gl5ook3MPGoo/5Y0_ok^eL2ooS3D`Coj:d/00Go0000ooooooooooooooooo`00000gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool001Wooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`11ooooo`;o<`3o3?ooool2oc<0o`;oo`000_ooool3o`0000;ooooo
00?oo`00oc<0oolc0?l00_ooool2oc<0o`03oooooolc0?oo<`3o00?oo`001?ooool2oc<0o`;ooooo
0olc0?l2ool000?o<`3o2_ooool01?lc0?ooo`00ool00?oo000<ooooo`?o<`3o0ooo0002ooooo`?o
<`3o2oooool4oc<0o`;ooooo1?oo0005ooooo`?o<`3o0ol00007ooooo`Ko<`3o0oooool5ool000Wo
oooo1Olc0?lBooooo`Oo<`3o1Ooo000?ooooo`Ko<`3o6?ooool00ol0003olKjKoo6nV`0<oo6nV`ko
m<FL00?o0000oo_2Q?ok`X@01Ook`X@6oog3O`Goo/=f1Oon`FT2oo^kE`;on<=C1?oX[B`01Ol0003o
oooooooooooooooo000003Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Koooo
o`006Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo03kooooo0_lc0?l;ooooo`?o
<`3o00?oo`00ooooooooool00ol00003ooooo`04ool00?lc0?oo<`3oooooo`?o<`3o00?ooooooc<0
oolc0?l00_oo0004ooooo`?o<`3o00Cooooooc<0oolc0?oo<`3o0_oo00000ooooooo<`3ooc<0o`0:
ooooo`04oc<0oooo003oo`00ool000_ooooo0olc0?l4ool00003oooooolc0?oo<`3o00;o<`3o2Ooo
ool5oc<0o`;ooooo1?oo0005ooooo`Co<`3o0ol00005ooooo`Go<`3o1Oooool4ool000Wooooo1Olc
0?l@ooooo`Oo<`3o0_ooool5ool000oooooo1Olc0?lNooooo`03o`000?oa_Y_olKjK00colKjK3_od
aI`00ol0003on<^Joo_2Q005oo_2Q0KooL=o1Oon`gH6ook1J@Con<=C0ooX[B`00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Kooooo`006Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo03_ooooo0_lc0?l;
ooooo`;o<`3o0_oo00001?oooooo0000o`000?l00003ooooo`?oo`0000Co<`3ooooooolc0?oo<`3o
0_ooool2oc<0o`;oo`001?ooool2oc<0o`04oooooolc0?oo<`3ooc<0o`;oo`0000Cooooooc<0oolc
0?oo<`3o2Oooool4ool000_ooooo0olc0?l3ool00003oooooolc0?oo<`3o00;o<`3o2Oooool4oc<0
o`?ooooo1?oo0005ooooo`Co<`3o00Coooooo`000?l0003o00000_ooool6oc<0o`Gooooo1Ooo0008
ooooo`Go<`3o3_ooool7oc<0o`?ooooo1_oo000>ooooo`Ko<`3o9?ooool00ol0003olKjKoo6nV`0:
oo6nV`kom<FL00Co0000ooS;V_ohbi[on<^J1Ook`X@6oog3O`Koo/=f1Oon`FT4ooS3D`?oj:d/00?o
0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06oooool001Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0h
ooooo`;o<`3o2oooool2oc<0o`;oo`000ol00004ooooo`;oo`0000?ooooooc<0oolc0?l00_lc0?l2
ooooo`;o<`3o00?oo`00ooooooooool00oooool2oc<0o`03oooooolc0?oo<`3o00?oo`000olc0?l9
ooooo`?oo`002oooool3oc<0o`Coo`0000Cooooooc<0oolc0?oo<`3o2?ooool5oc<0o`?ooooo1?oo
0005ooooo`Co<`3o00?oooooo`000?l000000_l00005oc<0o`Oooooo1?oo0009ooooo`Co<`3o3?oo
ool7oc<0o`Gooooo1Ooo000?ooooo`Go<`3o:_ooool00ol0003olKjKoo6nV`0:oo6nV`kom<FL00?o
0000ooS;V_ohbiX00_ohbiX4oo_2Q0KooL=o1_on`gH5ook1J@Con<=C0ooX[B`00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Kooooo`006Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo03Gooooo0_lc0?l;
ooooo`;o<`3o0_oo0002o`0000Cooooo0ooo00001?oooooo<`3ooc<0oolc0?l3ooooo`;o<`3o1Ooo
ool6oc<0o`;oo`0000?ooooooc<0oolc0?l02Oooool3ool000[ooooo1?lc0?l3ool00003oooooolc
0?oo<`3o00;o<`3o1oooool4oc<0o`Cooooo1?oo0005ooooo`Co<`3o0_ooool3o`0000Co<`3o1ooo
ool5ool000Sooooo1Olc0?l8ooooo`So<`3o1oooool5ool000kooooo1_lc0?l`ooooo`03o`000?oa
_Y_olKjK00WolKjK3_odaI`00ol0003on<^JooS;VP03ooS;VP?onl:41_om`gl6ook3MPGoo/5Y1?oh
`e<3onR];003o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01_ooooo000Iooooo`03o`000?oooooooooo06oooooo00?o0000
ooooooooool0<_ooool2oc<0o`_ooooo0_lc0?l00ooo003o0000o`000005ooooo`;oo`000_ooool3
oc<0o`;ooooo00?oo`00oc<0oolc0?l01Oooool5oc<0o`;oo`0000Cooooooc<0oolc0?oo<`3o2?oo
ool3ool000Wooooo1?lc0?l4ool00004oooooolc0?oo<`3ooc<0o`Kooooo1Olc0?l4ooooo`Coo`00
1Oooool4oc<0o`;ooooo00Go<`3oo`000?l0003o0000oc<0o`09ooooo`Coo`002?ooool5oc<0o`Ko
oooo1olc0?l:ooooo`Goo`003_ooool5oc<0ocKooooo00?o0000oo6nVooa_Y/02?oa_Y/>ooC5W003
o`000?ohbi[on<^J00Gon<^J0_ok`X@6oog3O`Koo/=f1?on`FT00ooocW;on<=CooS3D`02ooS3D`?o
j:d/00?o0000ooooooooool01Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[o
oooo0_l0000Looooo`006Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo02oooooo
0_lc0?l:ooooo`?o<`3o00?oo`00o`000?ooool01Oooool2ool000;ooooo0_lc0?l3ooooo`03ool0
0?lc0?oo<`3o00Gooooo1?lc0?l2ool00004oooooolc0?oo<`3ooc<0o`Oooooo00Co<`3oool00?oo
003oo`002Oooool3oc<0o`05oooooooo003oo`00ool00?ooool01?lc0?l5ooooo`Co<`3o1Oooool4
ool000Gooooo2?lc0?l3o`0000Wooooo1?oo0007ooooo`Go<`3o1?ooool7oc<0o`_ooooo1_oo000=
ooooo`Ko<`3o>oooool00ol0003olKjKoo6nV`08oo6nV`kom<FL00?o0000ooS;V_ohbiX01_ohbiX0
0ook`XCooL=ooog3O`05oog3O`Goo/=f1?on`FT00ooocW;on<=CooS3D`03ooS3D`;oj:d/00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooool000007?ooool001Wooooo00?o0000ooooooooool0<oooool6o`0003Sooooo00?o0000oooo
ooooool0;?ooool2oc<0o`[ooooo0_lc0?l2ool000Kooooo0ooo00000ooooooo<`3ooc<0o`02oc<0
o`03oooooooo003oo`0000;o<`3o1?ooool4oc<0o`;oo`000_ooool2oc<0o`Oooooo00Co<`3oool0
0?oo003oo`002?ooool4oc<0o`Coo`0000Cooooooc<0oolc0?oo<`3o1?ooool5oc<0o`Gooooo1?oo
0005ooooo`So<`3o00Coooooo`000?l0003o00001oooool5ool000Oooooo1?lc0?l2ooooo`Oo<`3o
3Oooool5ool000kooooo1Olc0?m2ooooo`03o`000?oa_Y_olKjK00KolKjK3oodaI`00ol0003on<^J
ooS;VP07ooS;VPOooL=o1_on`gH2ook1J@?oolib1?oh`e<2onR];003o`000?oooooooooo00Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo
000Hooooo`03o`000?oooooooooo033ooooo1?l00006oo2_QP?o0000=_ooool00ol0003ooooooooo
o`0Yooooo`;o<`3o2_ooool2oc<0o`;oo`001_ooool2ool000;ooooo1?lc0?l3ool000;o<`3o1?oo
ool4oc<0o`03ool00?oooooooooo00?o<`3o1_ooool01?lc0?ooo`00ool00?oo0007ooooo`Co<`3o
00Goooooool00?oo003oo`00ooooo`04oc<0o`?ooooo1?lc0?l6ooooo`Coo`001?ooool8oc<0o`?o
oooo0ol00006ooooo`Coo`001oooool;oc<0o`oooooo1Ooo000=ooooo`Ko<`3oAoooool00ol0003o
lKjKoo6nV`06oo6nV`oom<FL00?o0000ooS;V_ohbiX01oohbiX2ooc?T`GooL=o1_on`gH00oon`FWo
olibooo>LP02ooo>LPCon<=C0_oX[B`00ol0003oooooooooo`07ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`006?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?o`[hKol:n600_ol:n60ol0000dooooo`03o`000?oooooooooo02Kooooo
0_lc0?l8ooooo`;o00000_lc0?l00ooo003oooooooooo`04ooooo`?oo`000_ooool4oc<0o`;oo`00
00?ooooooc<0oolc0?l01?ooool3oc<0o`;oo`0000Cooooooc<0oolc0?oo<`3o1_ooool01?lc0?oo
o`00ool00?oo0007ooooo`?o<`3o0_ooool3ool00004oooooolc0?oo<`3ooc<0o`;ooooo1Olc0?l7
ooooo`?oo`001?ooool6oc<0o`Kooooo0ol00004ooooo`Goo`001_ooool9oc<0oa7ooooo1Ooo000=
ooooo`Go<`3oC_ooool00ol0003olKjKoo6nV`04oo6nV`oom<FL00?o0000ooS;V_ohbiX02?ohbiX5
ooc?T`;ooL=o1_on`gH00oon`FWoolibooo>LP02ooo>LPCon<=C0_oX[B`00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0J
ooooo`006?ooool00ol0003oooooooooo`0^ooooo`03o`000?o`[hKol:n600ool:n600?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Sooooo`;o<`3o1oooool3o`0000;o<`3o00?oo`00oooo
ooooool01?ooool2ool000;ooooo0olc0?l01Ooooooo<`3oool00?oo003ooooo00;o<`3o0oooool3
oc<0o`;oo`000_ooool2oc<0o`Kooooo1?oo0006ooooo`Co<`3o00?oooooool00?oo00000_oo0004
oc<0o`03oooooolc0?oo<`3o00;o<`3o2?ooool4ool000;ooooo1_lc0?l7ooooo`Co00000oooool4
ool000Gooooo1olc0?lCooooo`Koo`003?ooool6oc<0oe?ooooo00?o0000oo6nVooa_Y/01?oa_Y/?
ooC5W003o`000?ohbi[on<^J00Son<^J1oolci<3ook3MP?oom671OoocW84ooS3D`;oj:d/00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06_ooool001Sooooo00?o0000ooooooooool0;Oooool00ol0003ol:n6oo2_QP0Aoo2_
QP03o`000?oooooooooo03;ooooo00?o0000ooooooooool08?ooool2oc<0o`Kooooo0ol00003oc<0
o`03ool00?oooooooooo00?ooooo0ooo0002ooooo`;o<`3o0_ooool2oc<0o`;ooooo0_lc0?l3oooo
o`?o<`3o00?oo`00ooooooooool00olc0?l5ooooo`?oo`001_ooool4oc<0o`;ooooo0ooo0009oc<0
o`Sooooo1?oo0007oc<0o`Wooooo0ol00002ooooo`Goo`000_ooool8oc<0oaCooooo1Ooo000=oooo
o`Go<`3oF_ooool00ol0003olKjKoo6nV`02oo6nVa3om<FL00?o0000ooS;V_ohbiX02?ohbiX7ooc?
T`Koom671OoocW84ooS3D`;oj:d/00?o0000ooooooooool02_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool001Sooooo00?o0000oooooooo
ool0;?ooool00ol0003ol:n6oo2_QP0Coo2_QP03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool07Oooool2oc<0o`Gooooo0ol000000ooooooo<`3ooc<0o`02ool000Gooooo0_oo0002ooooo`?o
<`3o00Coooooool00?lc0?oo<`3o0_ooool2oc<0o`;ooooo0olc0?l00ooo003oooooooooo`03oc<0
o`Gooooo0ooo0005ooooo`Co<`3o0_ooool4ool000Oo<`3o2Oooool4ool000Oo<`3o2_ooool3o`00
0003oooooooo003oo`0000;oo`002olc0?lCooooo`Goo`003?ooool6oc<0oeoooooo00?o0000oo6n
Vooa_Y/00_oa_Y/?ooC5W003o`000?ohbi[on<^J00Won<^J1oolci<6oooAQ`Goolib1Ooh`e<00ooX
[Bco0000ooooo`0;ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Jooooo`006?ooool00ol0003oooooooooo`0[ooooo`03o`000?o`[hKol:n601Go
l:n600?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Jooooo`;o<`3o1?ooool3o`0000;o
oooo0_lc0?l00ooo003oooooooooo`04ooooo`;oo`000_ooool2oc<0o`03oooooooo003oo`0000;o
<`3o0_ooool2oc<0o`03oooooolc0?oo<`3o00;o<`3o0oooool2oc<0o`Cooooo00Co<`3oool00?oo
003oo`001Oooool3oc<0o`?ooooo0ooo0007oc<0o`Wooooo1?oo0007oc<0o`_ooooo0_l00005ool0
00Co<`3o00?ooooooc<0oolc0?l00olc0?lCooooo`Goo`002oooool6oc<0ofGooooo00Co0000oo6n
Vooa_Y_olKjK4?odaI`00ol0003on<^JooS;VP08ooS;VPSoo<nC1_oodHL5ooo>LPGon<=C00?oj:d/
o`000?ooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06_ooool001Sooooo00?o0000ooooooooool0:oooool00ol0003ol:n6oo2_QP0Foo2_
QP03o`000?oooooooooo03;ooooo00?o0000ooooooooool05oooool2oc<0o`?ooooo0ol00003oooo
o`;o<`3o00?oo`00ooooooooool00oooool3ool00005oooooolc0?oo<`3ooc<0ooooool00_oo0000
1?oooooo<`3oooooooooool7oc<0o`;ooooo0olc0?l3ooooo`04oc<0oooo003oo`00ool000Cooooo
1?lc0?l2ooooo`Coo`001Olc0?l:ooooo`Coo`0000?o<`3oooooooooool01?lc0?l;ooooo`03oc<0
ool0003oo`0000?oo`000_lc0?l3ooooo`Go<`3o4_ooool6ool000_ooooo1Olc0?m/ooooo`03o`00
0?oa_Y_olKjK013om<FL00?o0000ooS;V_ohbiX02?ohbiX8ooc?T`Koom671OoocW85ooS3D`03onR]
;?l0003ooooo00gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`;o0000
6oooool001Sooooo00?o0000ooooooooool0:_ooool00ol0003ol:n6oo2_QP0Hoo2_QP03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool05Oooool00olc0?ooooooooooo`03o`0000?ooooo0olc
0?l00ooo003oooooooooo`03ooooo`;oo`000_ooool2oc<0o`05oooooooo003oo`00ool00?ooool0
0_lc0?l00ooooooo<`3ooc<0o`04oc<0o`;ooooo0olc0?l3ooooo`04oc<0oooo003oo`00ool000?o
oooo1?lc0?l3ooooo`?oo`001Olc0?l8ooooo`;o<`3o1?oo0003ooooo`Co<`3o2?ooool4oc<0o`Go
o`001Oooool4oc<0oa;ooooo1Ooo000;ooooo`Ko<`3oLOooool00ol0003olKjKooC5W00@ooC5W003
o`000?ohbi[on<^J00Son<^J2?olci<6oooAQ`Goolib1Ooh`e<00ooX[Bco0000ooooo`0>ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000Kooooo`00
6?ooool00ol0003oooooooooo`0Zooooo`03o`000?o`[hKol:n601Sol:n600?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Booooo`;o<`3o0ol00004ooooo`;o<`3o0_oo0004ooooo`?oo`00
00Gooooooc<0oolc0?oo<`3oooooo`02ool000;ooooo0_lc0?l00ooooooo<`3ooc<0o`04oc<0o`;o
oooo0_lc0?l3ooooo`04oc<0oooo003oo`00ool000?ooooo0olc0?l3ooooo`Coo`000olc0?l8oooo
o`?o<`3o1?oo0003ooooo`Co<`3o1Oooool7oc<0o`Coo`0000?o0000ooooooooool00_ooool5oc<0
oa7ooooo1Ooo000;ooooo`Go<`3oN?ooool00ol0003om<FLooC5W00>ooC5W003o`000?ohbi[on<^J
00Won<^J2?olci<6oooAQ`Koolib1?oh`e<00ooX[Bco0000ooooo`0>ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`005oooool00ol0003o
ooooooooo`0Zooooo`03o`000?o`[hKol:n601[ol:n600?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0?ooooo`;o<`3o0_l00005ooooo`;o<`3o0_oo0004ooooo`;oo`000_ooool2oc<0o`04
oooooooo003oo`00ool000;ooooo0_lc0?l00ooooooo<`3ooc<0o`04oc<0o`04oooooolc0?oo<`3o
oc<0o`;ooooo1?oo0002ooooo`Co<`3o0oooool3ool000Co<`3o1Oooool5oc<0o`Coo`000oooool4
oc<0o`;ooooo1olc0?l2ooooo`Goo`0000Co0000oooooooooooooooo1Olc0?lAooooo`Goo`002_oo
ool6oc<0oggooooo00?o0000ooC5W?odaI`03_odaI`00ol0003on<^JooS;VP09ooS;VPSoo<nC1_oo
dHL6ooo>LPCon<=C00?oj:d/o`000?ooool03oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06Oooool001Oooooo00?o0000ooooooooool0:Oooool0
0ol0003ol:n6oo2_QP0Loo2_QP03o`000?oooooooooo03?ooooo00?o0000ooooooooool03?ooool2
oc<0o`03o`000?oooooooooo00Cooooo0_lc0?l00ooo003oooooooooo`03ooooo`;oo`0000Cooooo
oc<0oolc0?oo<`3o0ooo0004ooooo`05oc<0oooooooo<`3ooc<0oooo00000_lc0?l01?oooooo<`3o
oc<0oolc0?l2ooooo`?oo`000_ooool4oc<0o`?ooooo1?oo0003oc<0o`Cooooo1Olc0?l00ooooooo
o`00ool00002ool000?ooooo2_lc0?l5ooooo`Coo`000ol00002ooooo`Co<`3o4?ooool6ool000[o
oooo1Olc0?n4ooooo`03o`000?odaIcom<FL00gom<FL00?o0000ooS;V_ohbiX02OohbiX8ooc?T`Ko
om671_oocW85ooS3D`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo000Gooooo`03o`000?oooooooooo02Wooooo
00?o0000oo2_Q_o`[hH07Oo`[hH00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo
00?o0000oc<0oolc0?l01oooool2oc<0o`03ool00?oooooooooo00;ooooo0ooo00001?oooooo<`3o
oc<0ooooool2ool000Gooooo1?lc0?l01?oooooo<`3ooc<0ooooool2oc<0o`;ooooo0ooo0002oooo
o`?o<`3o0oooool01?lc0?ooo`00ool00?oo0004oc<0o`03oooooolc0?oo<`3o00Co<`3o0oooool3
ool000;ooooo1olc0?l8ooooo`Goo`0000Coooooo`000?l0003o00001Olc0?l?ooooo`Goo`002_oo
ool6oc<0oh[ooooo00?o0000ooC5W?odaI`02oodaI`00ol0003on<^JooS;VP0:ooS;VPSoo<nC1ooo
dHL5ooo>LPGon<=C00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06Oooool001Oooooo00?o0000ooooooooool0:?ooool0
0ol0003ol:n6oo2_QP0Ooo2_QP03o`000?oooooooooo03?ooooo00?o0000ooooooooool01?ooool2
o`0000;o<`3o1_ooool3oc<0o`03ool00?oooooooooo00;ooooo0_oo0002ooooo`;o<`3o0ooo0005
ooooo`[o<`3o00Goooooool00?oo003oo`00ooooo`04oc<0o`;ooooo0_lc0?l3ool000So<`3o1Ooo
ool4ool000Go<`3o2oooool4ool000?ooooo0ol00003oc<0o`oooooo1Ooo000:ooooo`Go<`3oT?oo
ool00ol0003om<FLooC5W00;ooC5W003o`000?ohbi[on<^J00[on<^J2?olci<7oooAQ`Goolib1Ooh
`e<00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Iooooo`005oooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKo
l:n6023ol:n600?o0000ooooooooool0<oooool00ol0003oooooooooo`03o`0000;o<`3o1_ooool2
oc<0o`;oo`000oooool3ool00004oooooolc0?oo<`3ooc<0o`;oo`001Oooool;oc<0o`?oo`001?lc
0?l01?oooooo<`3ooc<0oolc0?l4ool000Ko<`3o1Oooool00olc0?ooo`00ool00002ool000Go<`3o
2_ooool5ool000?ooooo00Go<`3oo`000?l0003o0000oc<0o`0>ooooo`Koo`002Oooool6oc<0oiKo
oooo00?o0000ooC5W?odaI`02_odaI`00ol0003on<^JooS;VP09ooS;VPWoo<nC1ooodHL5ooo>LPGo
n<=C00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06Oooool001Oooooo00?o0000ooooooooool0:?ooool00ol0003ol:n6
oo2_QP0Qoo2_QP03o`000?oooooooooo03?ooooo0_l000000ooooooo<`3ooc<0o`06ooooo`;o<`3o
00?oo`00ooooooooool00_ooool2ool000;ooooo0_lc0?l3ool000Gooooo2_lc0?l3ool000?o<`3o
00?ooooooc<0oolc0?l00_lc0?l3ool000Co<`3o1?ooool4oc<0o`Coo`0000?ooooooc<0oolc0?l0
0_lc0?l:ooooo`Coo`001?ooool00olc0?oo0000o`000002o`0000gooooo1Ooo000:ooooo`Go<`3o
WOooool00ol0003om<FLooC5W009ooC5W003o`000?ohbi[on<^J00Won<^J2Oolci<7oooAQ`Goolib
1Ooh`e<00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Hooooo`005oooool00ol0003oooooooooo`0Wooooo`03o`000?o`
[hKol:n602?ol:n600?o0000ooooooooool0<_ooool00ol0003o<`3ooc<0o`06ooooo`;o<`3o00Co
o`00oooooooooooooooo0ooo00001?oooooo<`3ooc<0oolc0?l2ool000Gooooo2_lc0?l3ool000Oo
<`3o1?oo0002oc<0o`03oooooolc0?oo<`3o00Ko<`3o1?oo00000ooooooo<`3ooc<0o`02oc<0o`Wo
oooo1Ooo0003ooooo`?o<`3o0ol0000<ooooo`Goo`002Oooool6oc<0oj;ooooo00?o0000ooC5W?od
aI`02?odaI`00ol0003on<^JooS;VP0:ooS;VPWoo<nC1ooodHL5ooo>LPGon<=C00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Wooooo0ol0000Jooooo`00
5oooool00ol0003oooooooooo`0Wooooo`03o`000?o`[hKol:n602?ol:n600?o0000ooooooooool0
<Oooool2oc<0o`Kooooo0_lc0?l01?oo003oooooooooooooool2ool000;ooooo0_lc0?l2ool000Go
oooo0olc0?l00ooooooo<`3ooc<0o`04oc<0o`?oo`001olc0?l3ool000Oo<`3o1?ooool4ool00003
oooooolc0?oo<`3o00;o<`3o2Oooool4ool000?ooooo1Olc0?l3o`0000[ooooo1Ooo0009ooooo`Go
<`3oZOooool00ol0003om<FLooC5W007ooC5W003o`000?ohbi[on<^J00[on<^J2Oolci<7oooAQ`Ko
olib0ooh`e<00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Hooooo`005_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?o`[hKol:n602Col:n600?o0000ooooooooool0;_ooool2oc<0o`03ooooool0003ooooo00;ooooo
0olc0?l01?oo003oooooooooooooool2ool00004oooooolc0?oo<`3ooc<0o`;oo`001?ooool3oc<0
o`;ooooo1?lc0?l4ool000Ko<`3o1?oo0003oc<0o`Oooooo1?oo00000ooooooo<`3ooc<0o`02oc<0
o`Wooooo1?oo0002ooooo`Go<`3o0_ooool3o`0000Oooooo1_oo0008ooooo`Ko<`3o[oooool00ol0
003om<FLooC5W006ooC5W003o`000?ohbi[on<^J00[on<^J2Oolci<7oooAQ`Koolib0ooh`e<00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Hooooo`005_ooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n602Go
l:n600?o0000ooooooooool0:oooool2oc<0o`?ooooo00Go0000oooooolc0?oo<`3oool00003oooo
o`?oo`0000?ooooooc<0oolc0?l00_oo0005ooooo`;o<`3o1?ooool3oc<0o`;oo`001olc0?l3ool0
00?o<`3o1oooool4ool00003oooooolc0?oo<`3o00;o<`3o2?ooool5ool000;ooooo1?lc0?l4oooo
o`?o00001Oooool5ool000Wooooo1Olc0?neooooo`03o`000?odaIcom<FL00Gom<FL00?o0000ooS;
V_ohbiX02oohbiX9ooc?T`Ooom671_oocW83ooS3D`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo1Ol00002oooo
o`?o00002Oooool001Kooooo00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0Uoo2_QP03
o`000?oooooooooo02Wooooo0_lc0?l5ooooo`;o<`3o00Coo`00oooooooooooooooo0_oo00001?oo
oooo<`3ooc<0oolc0?l2ool000Cooooo0olc0?l4ooooo`;o<`3o0_oo0006oc<0o`Coo`000_lc0?l7
ooooo`Coo`0000?ooooooc<0oolc0?l00_lc0?l8ooooo`Coo`000_ooool5oc<0o`Gooooo0ol00003
ooooo`Goo`002?ooool6oc<0ok_ooooo00?o0000ooC5W?odaI`01?odaI`00ol0003on<^JooS;VP0;
ooS;VPWoo<nC1ooodHL6ooo>LP?on<=C00?o0000ooooooooool05oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool01_ooool001Kooooo00?o0000ooooooooool09ooo
ool00ol0003ol:n6oo2_QP0Woo2_QP03o`000?oooooooooo02Kooooo0_lc0?l5ooooo`;o<`3o00?o
o`00ooooooooool00ooo00000ooooooo<`3ooc<0o`02ool000Cooooo0olc0?l5ooooo`03ool00?lc
0?ooo`0000;o<`3o1?ooool3ool000;o<`3o1oooool4ool00003oooooolc0?oo<`3o00;o<`3o1ooo
ool5ool00003oooooolc0?oo<`3o00?o<`3o1oooool3o`000003oooooooo003oo`0000?oo`002?oo
ool5oc<0ol;ooooo00?o0000ooC5W?odaI`00oodaI`00ol0003on<^JooS;VP0:ooS;VP[oo<nC1ooo
dHL6ooo>LP?on<=C00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo000Fooooo`03o`000?oooooooooo02Oooooo00?o0000oo2_Q_o`[hH0:?o`[hH0
0ol0003oooooooooo`0Sooooo`;o<`3o1Oooool2oc<0o`03ool00?oooooo000000;oo`0000Gooooo
oc<0oolc0?oo<`3oool00004ooooo`?o<`3o1Oooool3ool000Gooooo1?oo0002oc<0o`Kooooo1?oo
00000ooooooo<`3ooc<0o`02oc<0o`Oooooo1?oo00000ooooooo<`3ooc<0o`03oc<0o`Sooooo0_l0
0006ool000Oooooo1_lc0?o7ooooo`03o`000?odaIcom<FL00?om<FL00?o0000ooS;V_ohbiX02_oh
biX:ooc?T`Ooom671_oocW82ooS3D`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`005_ooool00ol0003oooooooooo`0Wooooo`03o`000?o`[hKo
l:n602Wol:n600?o0000ooooooooool08?ooool2oc<0o`Cooooo0olc0?l3ooooo`;oo`0000?ooooo
oc<0oolc0?l00_oo0003ooooo`03ool00?lc0?oo<`3o00Gooooo0ooo0005ooooo`?oo`000_lc0?l7
ooooo`?oo`001Olc0?l6ooooo`Goo`0000?ooooooc<0oolc0?l00_lc0?l:ooooo`Goo`001oooool6
oc<0olkooooo00Go0000ooC5W?odaIcom<FLo`00000=ooS;VP[oo<nC1ooodHL6ooo>LP;on<=C00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01?ooool01_l0003ooooooooooooooooo0000ooooo`Co00002Oooool001Kooooo
00?o0000ooooooooool09oooool00ol0003ol:n6oo2_QP0Yoo2_QP03o`000?oooooooooo01kooooo
0_lc0?l4ooooo`;o<`3o00?oo`00ooooooooool00ooo00001?l0003o<`3ooc<0oooo0003ooooo`04
ool00?lc0?oo<`3ooc<0o`Cooooo0ooo0005ooooo`?oo`000_lc0?l6ooooo`Coo`000olc0?l7oooo
o`Coo`0000?ooooooc<0oolc0?l00olc0?l9ooooo`Goo`001oooool5oc<0omGooooo00Co0000ooC5
W?odaIco00003OohbiX:ooc?T`Ooom671_oocW82ooS3D`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00Oo0000
ooooooooooooooooo`000?oooooo000000cooooo000Fooooo`03o`000?oooooooooo02Oooooo00?o
0000oo2_Q_o`[hH0:_o`[hH00ol0003oooooooooo`0Kooooo`;o<`3o1?ooool2oc<0o`03ool00?oo
oooooooo00;oo`0000Gooooooc<0oolc0?oo<`3oool00003ooooo`?o<`3o1?ooool3ool000Cooooo
1?oo00000olc0?ooooooooooo`04ooooo`Coo`000olc0?l6ooooo`Goo`001Olc0?l9ooooo`Goo`00
0_l00004ooooo`Ko<`3of_ooool01?l0003om<FLooC5W?l0000=ooS;VPWoo<nC2?oodHL6ooo>LP;o
n<=C00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wo
oooo0ol00007ooooo`?o00000_ooool5o`0000Sooooo000Fooooo`03o`000?oooooooooo02Oooooo
00?o0000oo2_Q_o`[hH0:oo`[hH00ol0003oooooooooo`0Hooooo`;o<`3o1?ooool2oc<0o`03ool0
0?ooooooo`0000;oo`0000Oooooooc<0oolc0?ooo`00ooooool0003ooooo00?o<`3o0oooool4ool0
00Cooooo0ooo0002oc<0o`Gooooo1?oo0003oc<0o`Kooooo1?oo00000ooooooo<`3ooc<0o`02oc<0
o`Sooooo1_oo00001?oooooo0000o`000?l00002ooooo`Go<`3ohOooool2o`0000kon<^J2Oolci<8
oooAQ`Ooolib00?on<=Co`000?ooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Oooooo0_l00002ooooo`03o`000?oooooooooo01Oooooo000Eooooo`03o`000?oooooooooo
02Sooooo00?o0000oo2_Q_o`[hH0:oo`[hH00ol0003oooooooooo`0Fooooo`;o<`3o0oooool3oc<0
o`;ooooo0_oo00001?oooooo<`3ooc<0oolc0?l3ooooo`03ool00?lc0?oo<`3o00?ooooo0ooo0004
ooooo`Coo`0000?o<`3oooooooooool00oooool4ool000?o<`3o1Oooool5ool000Go<`3o1oooool5
ool000Cooooo0ol00005oc<0onOooooo0_l0000=ooS;VPWoo<nC2?oodHL7ooo>LP03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Oooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000oo2_Q_o`[hH0;?o`[hH00ol0
003oooooooooo`0Cooooo`;o<`3o0oooool2oc<0o`03ool00?ooooooo`0000;oo`0000Cooooooc<0
oolc0?ooo`000_ooool01_oo003o<`3ooc<0oolc0?oo0000ooooo`?oo`001?ooool3ool000;o<`3o
1?ooool4ool000?o<`3o1Oooool4ool000Go<`3o1oooool5ool000Gooooo1?l00002oc<0onoooooo
00?o0000ooS;V_ohbiX02_ohbiX9ooc?T`Soom671ooocW800ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`005Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n602col:n600?o0000ooooooooool04Ooo
ool2oc<0o`?ooooo0_lc0?l01Ooo003oooooool00?oo003ooooo00?o<`3o0_ooool01?oo003o<`3o
oc<0oolc0?l2ooooo`?oo`000oooool4ool00003oc<0oooooooooooo00;ooooo1?oo0003oc<0o`Co
oooo1Ooo0004oc<0o`Oooooo1Ooo0005ooooo`;o<`3o0ol000000olc0?ooooooooooo`3cooooo`03
o`000?ohbi[on<^J00Son<^J2_olci<8oooAQ`Ooolib00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool001Gooooo
00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0]oo2_QP03o`000?oooooooooo00kooooo
0_lc0?l3ooooo`;o<`3o00Goo`00oooooooo003oo`00ooooo`02oc<0o`03ool00?ooooooo`0000?o
<`3o0_ooool3ool00003ooooool0003ooooo00?oo`0000?o<`3oooooooooool00_ooool4ool000?o
<`3o1?ooool4ool000Co<`3o1_ooool6ool000Gooooo1?lc0?l3o`000?[ooooo00?o0000ooS;V_oh
biX01oohbiX:ooc?T`Soom671ooocW800ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`005Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?o`[hKol:n602gol:n600?o0000ooooooooool03?ooool2oc<0o`?ooooo
0_lc0?l01?ooooooo`00ool00?oo0003oc<0o`;ooooo00?oo`00oc<0oolc0?l00_ooool3ool000;o
oooo1?oo00001?lc0?ooooooooooooooool4ool000?o<`3o0oooool5ool000Co<`3o1Oooool5ool0
00Gooooo1_lc0?l01?oooooo0000o`000?l0003nooooo`03o`000?ohbi[on<^J00Kon<^J2_olci<9
oooAQ`Goolib00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool05oooool001Gooooo00?o0000ooooooooool0:?ooool00ol0
003ol:n6oo2_QP0^oo2_QP03o`000?oooooooooo00Wooooo0_lc0?l2ooooo`?o<`3o00Coooooool0
0?oo003ooooo0_lc0?l2ooooo`05ool00?lc0?oo<`3ooc<0ooooool00ooo0002ooooo`?oo`0000Co
<`3oooooool0003ooooo1?oo0003oc<0o`?ooooo1?oo0004oc<0o`Gooooo1Ooo0005ooooo`Go<`3o
1?ooool3o`000?oooooo0oooool00ol0003on<^JooS;VP05ooS;VP[oo<nC2OoodHL4ooo>LP03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Kooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000oo2_Q_o`[hH0;_o`
[hH00ol0003oooooooooo`07ooooo`;o<`3o0_ooool2oc<0o`Coo`000olc0?l00oooooooo`00oc<0
o`02oc<0o`04oooooooo003oo`00ool000;ooooo0ooo00001?lc0?ooooooooooooooool3ool000?o
<`3o0_ooool5ool000?o<`3o1Oooool5ool000Cooooo1_lc0?l6ooooo`?o0000ooooool7ooooo`03
o`000?ohbi[on<^J00Con<^J2_olci<9oooAQ`Coolib00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool001Gooooo
00?o0000ooooooooool0:?ooool00ol0003ol:n6oo2_QP0^oo2_QP03o`000?oooooooooo00Gooooo
0_lc0?l2ooooo`;o<`3o0ooo00001Ooooooo<`3ooc<0ooooooooo`0000?o<`3o1?oo00000ooooooo
o`00ool00002ool000?ooooo1?oo00001?lc0?oo0000ooooooooool4ool000?o<`3o1?ooool6ool0
00Cooooo1Olc0?l8ooooo`Co0000ooooool;ooooo`03o`000?ohbi[on<^J00?on<^J2_olci<9oooA
Q`?oolib00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00[ooooo0_l0000Hooooo`005Oooool00ol0003oooooooooo`0Xooooo`03o`000?o`[hKol:n602oo
l:n600?o0000ooooooooool00_ooool2oc<0o`;ooooo0_lc0?l01?ooooooo`00ool00?oo0002oc<0
o`;oo`000_lc0?l3ool000;ooooo0ooo00000olc0?ooooooooooo`04ool00003oc<0oooooooooooo
00Goo`000olc0?l3ooooo`Goo`001?ooool6oc<0o`[ooooo0ol0003ooooooa3ooooo00?o0000ooS;
V_ohbiX00_ohbiX:ooc?T`Woom670ooocW800ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000Hooooo`005?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?o`[hKol:n602ool:n600?o0000ooooooooool00_lc0?l2ooooo`;o
<`3o0ooo0003oc<0o`03ool00?lc0?oo<`3o00?oo`0000?oooooool00?oo00000_oo0002ooooo`Co
o`0000?o<`3oooooooooool01?oo0003oc<0o`?ooooo1Ooo0004ooooo`Go<`3o3Oooool3o`000?oo
oooo5?ooool01?l0003on<^JooS;V_ohbiX:ooc?T`Woom670_oocW800ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Foooo
o`005?ooool00ol0003oooooooooo`0Yooooo`03o`000?o`[hKol:n6033ol:n60_lc0?l01?oooooo
<`3ooc<0oolc0?l3ool000;o<`3o00?oo`00oc<0oolc0?l00ooo00001_ooooooo`00ool00?oo003o
<`3oooooo`Coo`0000?o<`3ooooooooo00001?oo0002oc<0o`;ooooo1_oo0003ooooo`Ko<`3o3ooo
ool3o`000?oooooo6?ooool00ol0003on<^Jooc?T`0:ooc?T`Woom6700?oolibo`000?ooool0;?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_oo
ool001Cooooo00?o0000ooooooooool0:Oooool00ol0003ol:n6oo2_QP0^oo2_QP;o<`3o00?o0000
oc<0oolc0?l00ooo0003oc<0o`03ool00?lc0?ooo`0000Koo`0000?oooooool00?oo00000_oo0000
0olc0?ooooooool00003ool000;o<`3o0_ooool5ool000;ooooo00?o0000oooooolc0?l01?lc0?lB
ooooo`?o0000oooooolLooooo`03o`000?olci?oo<nC00Woo<nC2OoodHL00ooocW;o0000ooooo`0/
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`005?ooool00ol0003oooooooooo`0Zooooo`03o`000?o`[hKol:n602_ol:n60_lc0?l00oo`
[hKo<`3ooc<0o`03ool000;o<`3o00?oo`00oc<0oooo00001Ooo00000oooooooo`00ool00002ool0
0003oc<0ooooooooo`0000?oo`000_lc0?l00oooooooo`00ool00003ool000?ooooo1_lc0?lDoooo
o`?o0000oooooolPooooo`;o00002Oolci<8oooAQ`;o0000;oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool001Cooooo00?o0000oooooooo
ool0:_ooool00ol0003ol:n6oo2_QP0Yoo2_QP;o<`3o00?ol:n6oc<0oolc0?l00_oo0004oc<0o`[o
o`0000?o<`3oool00?oo00000ooo00000olc0?ooooooool00004ool000?ooooo1Olc0?l4ooooo`03
o`000?oooooooooo013ooooo0ol0003oooooobGooooo0ol00006ooc?T`Koom670_l0000booooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Eooooo`00
5?ooool00ol0003oooooooooo`0Zooooo`03o`000?o`[hKol:n602Ool:n60_lc0?l00oo`[hKo<`3o
oc<0o`02ool000;o<`3o2_oo00000olc0?ooo`00ool00002ool00003oc<0oooo003oo`0000Coo`00
0_ooool6oc<0o`Sooooo00?o0000ooooooooool03Oooool4o`000?oooooo:oooool3o`0000?oo<nC
0ooodHL3o`0003Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Gooooo000Dooooo`03o`000?oooooooooo02[ooooo00?o0000oo2_Q_o`[hH09Oo`
[hH5oc<0o`04ool00?lc0?oo<`3ooc<0oa;oo`000_ooool6oc<0o`kooooo00?o0000ooooooooool0
2_ooool3o`000?oooooo<_ooool3o`000003oooAQol0003o000003Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo000Dooooo`03o`000?oo
oooooooo02[ooooo00?o0000oo2_Q_o`[hH08oo`[hH4oc<0o`;oo`000_lc0?l@ool000;ooooo1Olc
0?lDooooo`03o`000?oooooooooo00Oooooo0ol0003oooooocSooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo0_l0000Gooooo`004oooool0
0ol0003oooooooooo`0[ooooo`03o`000?o`[hKol:n6027ol:n61?lc0?l01?oo003o<`3ooc<0oolc
0?l=ool00003oooooolc0?oo<`3o00Co<`3o6Oooool00ol0003oooooooooo`04ooooo`?o0000oooo
oomhooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
000Gooooo`004oooool00ol0003oooooooooo`0[ooooo`03o`000?o`[hKol:n601ool:n61?lc0?l0
0ooo003o<`3ooc<0o`0;ool00003o`000?lc0?oo<`3o00?o<`3o7oooool01?l0003ooooooooooooo
ool3o`000?ooooooO?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05Oooool001?ooooo00?o0000ooooooooool0;?ooool00ol0003ol:n6oo2_QP0L
oo2_QPCo<`3o00?oo`00oc<0oolc0?l01ooo00000oo`[hKo<`3ooc<0o`04oc<0obCooooo1?l0003o
ooooogoooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Gooooo000Cooooo`03o`000?oooooooooo02cooooo00?o0000oo2_Q_o`[hH06_o`[hH7oc<0
o`Coo`0000?ol:n6oc<0oolc0?l00olc0?l5oo2_QP03o`000?oooooooooo01oooooo1?l0003ooooo
oh?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Gooooo000Cooooo`03o`000?oooooooooo02cooooo00?o0000oo2_Q_o`[hH05_o`[hH2o`0000?o
<`3o00?oo`00oc<0oolc0?l00_oo0006oc<0o`[ol:n600?o0000ooooooooool07?ooool3o`0000?o
oooo00?o0000ooooooooool0oooooon2ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Dooooo`004oooool00ol0003oooooooooo`0/ooooo`03o`00
0?o`[hKol:n601Kol:n600?o0000oc<0oolc0?l01olc0?lAoo2_QP03o`000?oooooooooo01Sooooo
0ol00006ooooo`03o`000?oooooooooo0?ooooooPoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05?ooool001?ooooo00?o0000ooooooooool0;?oo
ool00ol0003ol:n6oo2_QP0Goo2_QP04o`000?lc0?oo<`3ooc<0oaKol:n600?o0000ooooooooool0
5Oooool3o`0000Wooooo00?o0000ooooooooool0oooooon3ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`004oooool00ol0003ooooooooo
o`0/ooooo`03o`000?o`[hKol:n6037ol:n600?o0000ooooooooool04_ooool3o`0000cooooo00?o
0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Dooooo`004oooool00ol0003oooooooooo`0]ooooo`03o`000?o`[hKo
l:n6033ol:n600?o0000ooooooooool03oooool3o`0000oooooo00?o0000ooooooooool0oooooon5
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool2o`0001Kooooo000Boooo
o`03o`000?oooooooooo02kooooo00?o0000oo2_Q_o`[hH0<?o`[hH00ol0003oooooooooo`0;oooo
o`Co00004_ooool00ol0003oooooooooo`3oooooohKooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooo000001Kooooo000Booooo`03o`000?oooooooooo02ko
oooo00?o0000oo2_Q_o`[hH0<Oo`[hH00ol0003oooooooooo`07ooooo`?o00005_ooool00ol0003o
ooooooooo`3oooooohKooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Cooooo000Booooo`03o`000?oooooooooo02kooooo00?o0000oo2_Q_o`[hH0
<Oo`[hH00ol0003oooooooooo`04ooooo`?o00006Oooool00ol0003oooooooooo`3oooooohOooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo
000Booooo`03o`000?oooooooooo02oooooo00?o0000oo2_Q_o`[hH0<?o`[hH01?l0003ooooooooo
ooooool3o`0001cooooo00?o0000ooooooooool0oooooon8ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`004_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?o`[hKol:n6033ol:n61?l0000Nooooo`03o`000?oooooooooo0?ooooooR_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04ooo
ool001;ooooo00?o0000ooooooooool0;oooool00ol0003ol:n6oo2_QP0^oo2_QP?o00008Oooool0
0ol0003oooooooooo`3ooooooh[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo000Booooo`03o`000?oooooooooo02oooooo00?o0000oo2_
Q_o`[hH0:_o`[hH4o`0000;ol:n600?o0000ooooooooool07oooool00ol0003oooooooooo`3ooooo
oh_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01?ooooo000Booooo`03o`000?oooooooooo02oooooo00?o0000oo2_Q_o`[hH09oo`[hH3o`0000Oo
l:n600?o0000ooooooooool07_ooool00ol0003oooooooooo`3oooooohcooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo000Booooo`03o`00
0?oooooooooo033ooooo00?o0000oo2_Q_o`[hH08oo`[hH3o`0000[ol:n600?o0000ooooooooool0
7_ooool00ol0003oooooooooo`3oooooohgooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo000Aooooo`03o`000?oooooooooo037ooooo00?o
0000oo2_Q_o`[hH08?o`[hH3o`0000gol:n600?o0000ooooooooool07_ooool00ol0003ooooooooo
o`3oooooohgooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`?o00005Ooo
ool0017ooooo00?o0000ooooooooool0<Oooool00ol0003ol:n6oo2_QP0Moo2_QP?o00004?o`[hH0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?ooooooS_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool0017ooooo00?o0000oooo
ooooool0<_ooool00ol0003ol:n6oo2_QP0Ioo2_QP?o00004oo`[hH00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0?ooooooSoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool04oooool0017ooooo00?o0000ooooooooool0<_ooool00ol0003o
l:n6oo2_QP0Foo2_QP?o00005_o`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oo
ooooT?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool3o`0000Cooooo0_l00004ooooo`004Oooool00ol0003oooooooooo`0cooooo`03o`00
0?o`[hKol:n6017ol:n61?l0000Ioo2_QP03o`000?oooooooooo01kooooo00?o0000ooooooooool0
oooooon@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003oooo
o`004Oooool00ol0003oooooooooo`0cooooo`03o`000?o`[hKol:n600kol:n60ol0000Moo2_QP03
o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooonAooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00Oooool0017ooooo00?o0000ooooooooool0=?ooool00ol0003o
l:n6oo2_QP0:oo2_QP?o00008?o`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oo
ooooT_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo007ooooo000Aooooo`03
o`000?oooooooooo03Cooooo00?o0000oo2_Q_o`[hH01oo`[hH3o`0002Col:n600?o0000oooooooo
ool07Oooool00ol0003oooooooooo`3ooooooi?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo1?l00003ooooo`04o`000?ooooooooooo`00
00?ooooo000@ooooo`03o`000?oooooooooo03Kooooo00?o0000oo2_Q_o`[hH00oo`[hH3o`0002Oo
l:n600?o0000ooooooooool07Oooool00ol0003oooooooooo`3ooooooi?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00003ooooo`004?ooool00ol0003oooooooooo`0fooooo`03
o`000?o`[hKol:n600?o0000:_o`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0?oo
ooooU?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo0_l00006ooooo`Go
00000oooool2o`0000Cooooo000@ooooo`03o`000?oooooooooo03Gooooo1?l0000]oo2_QP03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0oooooonEooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool2o`000003ooooool0003ooooo01?ooooo000@ooooo`03o`000?oo
oooooooo03;ooooo0ol00002ooooo`03o`000?o`[hKol:n602col:n600?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`3ooooooiKooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo017ooooo000@ooooo`03o`000?oooooooooo02oooooo0ol00006
ooooo`03o`000?o`[hKol:n602_ol:n600?o0000ooooooooool07?ooool00ol0003oooooooooo`3o
oooooiOooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo017ooooo000@ooooo`03o`000?oooooooooo02cooooo0ol00009ooooo`03o`000?o`[hKol:n6
02_ol:n600?o0000ooooooooool07?ooool00ol0003oooooooooo`3ooooooiSooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo017ooooo000@ooooo`03o`000?oooooooooo
02Wooooo0ol0000=ooooo`03o`000?o`[hKol:n602[ol:n600?o0000ooooooooool07?ooool00ol0
003oooooooooo`3ooooooiWooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0A
ooooo`004?ooool00ol0003oooooooooo`0Vooooo`?o00004Oooool00ol0003ol:n6oo2_QP0Xoo2_
QP03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooonJooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool04Oooool0013ooooo00?o0000ooooooooool08_ooool4o`0001Co
oooo00?o0000oo2_Q_o`[hH0:?o`[hH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0?oo
ooooV_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo017ooooo000?ooooo`03
o`000?oooooooooo023ooooo0ol0000Iooooo`03o`000?o`[hKol:n602Ool:n600?o0000oooooooo
ool07Oooool00ol0003oooooooooo`3ooooooi_ooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`0Aooooo`003oooool00ol0003oooooooooo`0Mooooo`?o00007Oooool00ol0003ol:n6
oo2_QP0Voo2_QP03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooonLooooo`;o0000
3?ooool2o`0001;ooooo000?ooooo`03o`000?oooooooooo01[ooooo0ol0000Qooooo`03o`000?o`
[hKol:n602Gol:n600?o0000ooooooooool07Oooool00ol0003oooooooooo`3ooooooi_ooooo0ol0
000:ooooo`?o00004oooool000oooooo00?o0000ooooooooool05oooool3o`0002Cooooo00?o0000
oo2_Q_o`[hH09?o`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?ooooooV?ooool3
o`00013ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000ooooooooool05?ooool3o`00
02Sooooo00?o0000oo2_Q_o`[hH08oo`[hH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
0?ooooooU?ooool4o`0001?ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000oooooooo
ool04Oooool3o`0002cooooo00?o0000oo2_Q_o`[hH08_o`[hH00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo0?ooooooT?ooool4o`0001Oooooo00?o0000ooooooooool04?ooool000oooooo
00?o0000ooooooooool03Oooool4o`0002oooooo00?o0000oo2_Q_o`[hH08_o`[hH00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo0?ooooooSOooool3o`0001_ooooo00?o0000ooooooooool0
4?ooool000oooooo00?o0000ooooooooool02_ooool3o`0003Cooooo00?o0000oo2_Q_o`[hH08?o`
[hH00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?ooooooROooool4o`00037ooooo000?
ooooo`03o`000?oooooooooo00Oooooo0ol0000hooooo`03o`000?o`[hKol:n601ool:n600?o0000
ooooooooool07oooool00ol0003oooooooooo`3oooooohGooooo1?l0000eooooo`003_ooool00ol0
003oooooooooo`05ooooo`?o0000??ooool00ol0003ol:n6oo2_QP0Moo2_QP03o`000?oooooooooo
023ooooo00?o0000ooooooooool0oooooon2ooooo`?o0000>Oooool000kooooo00?o0000oooooooo
ool00_ooool3o`00043ooooo00?o0000oo2_Q_o`[hH07?o`[hH00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0?ooooooO_ooool4o`0003cooooo000>ooooo`03o`000?oooooo000000;o0000
A?ooool00ol0003ol:n6oo2_QP0Joo2_QP03o`000?oooooooooo023ooooo00?o0000ooooooooool0
oooooomkooooo`Co0000@?ooool000kooooo0_l00018ooooo`03o`000?o`[hKol:n601Wol:n600?o
0000ooooooooool08?ooool00ol0003oooooooooo`3oooooogSooooo0ol00014ooooo`004?ooool0
0ol0003oooooooooo`16ooooo`;o00006?o`[hH00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo0?ooooooM?ooool4o`0004Oooooo000Aooooo`03o`000?oooooooooo04Oooooo00?o0000oo2_
Q_o`[hH05?o`[hH00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0?ooooooLOooool3o`00
04_ooooo000Booooo`03o`000?oooooooooo04Oooooo0_l0000Coo2_QP03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0oooooom]ooooo`Co0000C_ooool001?ooooo0_l00019ooooo`;o0000
4?o`[hH00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?ooooooJOooool4o`0005;ooooo
000Eooooo`03o`000?oooooooooo04Sooooo00?o0000oo2_Q_o`[hH03?o`[hH00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo0?ooooooI_ooool3o`0005Kooooo000Fooooo`03o`000?oooooo
oooo04Sooooo0ol00009oo2_QP;o0000:?ooool00ol0003oooooooooo`3oooooof;ooooo1?l0001I
ooooo`005oooool00ol0003oooooooooo`1:ooooo`?o00000oo`[hH3o`0002[ooooo00?o0000oooo
ooooool0oooooomNooooo`Co0000GOooool001Sooooo0_l0001=ooooo`?o0000;Oooool00ol0003o
ooooooooo`3ooooooe_ooooo0ol0001Qooooo`006_ooool00ol0003oooooooooo`1jooooo`03o`00
0?oooooooooo0?ooooooEoooool4o`0006Cooooo000Kooooo`03o`000?oooooooooo07Wooooo00?o
0000ooooooooool0oooooomCooooo`Co0000J?ooool001cooooo00?o0000ooooooooool0N?ooool0
0ol0003oooooooooo`3ooooooe3ooooo0ol0001/ooooo`007Oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooooooo0?ooooooC?ooool4o`0006oooooo000Nooooo`;o0000Moooool00ol0003o
ooooooooo`3oooooodWooooo0ol0001cooooo`008?ooool00ol0003oooooooooo`1dooooo`03o`00
0?oooooooooo0?ooooooAOooool4o`0007Kooooo000Qooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool0oooooom1ooooo`Co0000N_ooool002;ooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`3oooooocoooooo0ol0001nooooo`008oooool2o`00077ooooo00?o0000oooo
ooooool0oooooolkooooo`Co0000POooool002Gooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`3oooooocOooooo1?l00025ooooo`009_ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo0?oooooo=?ooool3o`0008Wooooo000Wooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool0ooooool`ooooo`Co0000S?ooool002Sooooo0_l0001/ooooo`03o`000?oooooo
oooo0?oooooo;?ooool4o`00093ooooo000Zooooo`03o`000?oooooooooo06Wooooo00?o0000oooo
ooooool0oooooolYooooo`?o0000U?ooool002_ooooo00?o0000ooooooooool0J?ooool00ol0003o
ooooooooo`3oooooobGooooo1?l0002Gooooo`00;?ooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo0?oooooo8Oooool4o`0009_ooooo000]ooooo`;o0000Ioooool00ol0003ooooooooo
o`3ooooooakooooo0ol0002Oooooo`00;oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo0?oooooo6_ooool4o`000:;ooooo000`ooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool0oooooolGooooo`?o0000Y_ooool0037ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`3ooooooa?ooooo1?l0002Yooooo`00<_ooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo0?oooooo3oooool4o`000:gooooo000cooooo`;o0000HOooool00ol0003ooooooooo
o`3oooooo`cooooo0ol0002aooooo`00=Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo0?oooooo2?ooool4o`000;Cooooo000fooooo`03o`000?oooooooooo05gooooo00?o0000oooo
ooooool0ooooool4ooooo`Co0000^?ooool003Oooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`3oooooo`;ooooo0ol0002looooo`00>?ooool2o`0005_ooooo00?o0000ooooooooool0
oOooool4o`000;oooooo000jooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0nOoo
ool4o`000<?ooooo000kooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0m_ooool3
o`000<Oooooo000looooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0l_ooool4o`00
0<[ooooo000mooooo`;o0000E_ooool00ol0003oooooooooo`3_ooooo`?o0000c_ooool003oooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`3[ooooo`Co0000dOooool0043ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`3Wooooo`Co0000eOooool0047ooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`3Tooooo`?o0000fOooool004;ooooo0_l0001Aoooo
o`03o`000?oooooooooo0>3ooooo1?l0003Looooo`00A?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo0=cooooo1?l0003Pooooo`00AOooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo0=Wooooo0ol0003Tooooo`00A_ooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo0=Gooooo1?l0003Wooooo`00Aoooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo0=7ooooo1?l0003[ooooo`00B?ooool2o`0004_ooooo00?o0000ooooooooool0c_ooool3o`00
0>oooooo001:ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0b_ooool4o`000?;o
oooo001;ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0b?ooool3o`000?Kooooo
001<ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0a?ooool4o`000?Wooooo001=
ooooo`;o0000AOooool00ol0003oooooooooo`30ooooo`Co0000oOooool004oooooo00?o0000oooo
ooooool0@_ooool00ol0003oooooooooo`2mooooo`?o0000ooooool2ooooo`00D?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo0;Wooooo1?l0003oooooo`Gooooo001Aooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool0]Oooool4o`000?oooooo2Oooool005;ooooo0_l0
0010ooooo`03o`000?oooooooooo0;;ooooo0ol0003oooooo`gooooo001Dooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0[_ooool4o`000?oooooo4?ooool005Gooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`2Zooooo`Co0000oooooolDooooo`00E_ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0:Oooooo0ol0003ooooooaSooooo001Gooooo`;o0000
>oooool00ol0003oooooooooo`2Sooooo`Co0000oooooolKooooo`00FOooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo0:3ooooo0ol0003ooooooaoooooo001Jooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0W?ooool4o`000?oooooo8_ooool005_ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`2Hooooo`Co0000oooooolVooooo`00G?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo09Gooooo0ol0003oooooob[ooooo001Mooooo`;o0000
=Oooool00ol0003oooooooooo`2Aooooo`Co0000ooooool]ooooo`00Goooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo08gooooo1?l0003ooooooc7ooooo001Pooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0Roooool3o`000?oooooo=Oooool0067ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`27ooooo`Co0000oooooolhooooo`00H_ooool2o`0002oo
oooo00?o0000ooooooooool0Poooool4o`000?oooooo??ooool006Cooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`20ooooo`?o0000oooooom0ooooo`00IOooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo07cooooo1?l0003ooooood?ooooo001Vooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0NOooool3o`000?ooooooAoooool006Oooooo0_l0000Zoooo
o`03o`000?oooooooooo07Gooooo1?l0003ooooood[ooooo001Yooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0LOooool4o`000?ooooooC_ooool006[ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1^ooooo`?o0000oooooomBooooo`00Joooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06[ooooo1?l0003ooooooeGooooo001/ooooo`;o00009Oooool0
0ol0003oooooooooo`1Vooooo`Co0000oooooomIooooo`00K_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo06?ooooo0ol0003ooooooegooooo001_ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0Goooool4o`000?ooooooH?ooool0073ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1Kooooo`Co0000oooooomTooooo`00LOooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo05Sooooo0ol0003oooooofSooooo001booooo`;o00007oooool0
0ol0003oooooooooo`1Dooooo`Co0000oooooom[ooooo`00M?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo057ooooo1?l0003oooooofoooooo001eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0C_ooool3o`000?ooooooLoooool007Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1:ooooo`Co0000oooooomfooooo`00Moooool2o`0001Wooooo00?o
0000ooooooooool0Aoooool3o`000?ooooooN_ooool007Wooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`13ooooo`Co0000oooooommooooo`00N_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo03oooooo1?l0003ooooooh7ooooo001kooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0??ooool3o`000?ooooooQOooool007cooooo0_l0000Dooooo`03o`00
0?oooooooooo03Sooooo1?l0003oooooohSooooo001nooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0=?ooool4o`000?ooooooS?ooool007oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0aooooo`?o0000oooooon@ooooo`00P?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02gooooo1?l0003ooooooi?ooooo0021ooooo`;o00003oooool00ol0003o
ooooooooo`0Yooooo`Co0000oooooonGooooo`00Poooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Kooooo0ol0003ooooooi_ooooo0024ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool08_ooool4o`000?ooooooW_ooool008Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Oooooo`?o0000oooooonRooooo`00Q_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01_ooooo1?l0003oooooojGooooo0027ooooo`;o00002Oooool00ol0003o
ooooooooo`0Gooooo`Co0000oooooonYooooo`00ROooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo0ol0003oooooojgooooo002:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04Oooool4o`000?oooooo/?ooool008_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0=ooooo`Co0000oooooondooooo`00S?ooool2o`0000?ooooo00?o0000oooo
ooooool02_ooool3o`000?oooooo^?ooool008kooooo00Co0000oooooooooooo00002?ooool4o`00
0?oooooo^oooool008oooooo00?o0000ooooool000001?ooool4o`000?oooooo_oooool0093ooooo
0_l000001?oooooo0000o`000?l0003ooooool?ooooo002Aooooo`;o0000ooooooo6ooooo`00oooo
oooooooooe[ooooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[o
oooo003oooooooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003ooooo
ooooooooF_ooool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooooooooooF_oo
ool00?oooooooooooomJooooo`00oooooooooooooe[ooooo003oooooooooooooF_ooool00?oooooo
oooooomJooooo`00oooooooooooooe[ooooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {485.188, 0}} -> {0.00478509, 0.0585825, \
0.00171077, 0.00171077}}]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 742}},
WindowToolbars->"EditBar",
WindowSize->{1016, 708},
WindowMargins->{{63, Automatic}, {Automatic, 0}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 343, 5, 119, "Text"],

Cell[CellGroupData[{
Cell[2122, 60, 60, 1, 27, "Input"],
Cell[2185, 63, 42, 0, 23, "Print"],
Cell[2230, 65, 139, 2, 23, "Print"]
}, Open  ]],
Cell[2384, 70, 826, 14, 206, "Input"],
Cell[3213, 86, 1509, 26, 316, "Input"],
Cell[4725, 114, 1549, 33, 132, "Input"],

Cell[CellGroupData[{
Cell[6299, 151, 38, 0, 27, "Input"],
Cell[6340, 153, 1713, 28, 187, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8090, 186, 378, 6, 75, "Input"],
Cell[8471, 194, 192612, 4340, 495, 53247, 2616, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[201098, 4537, 1583, 33, 132, "Input"],

Cell[CellGroupData[{
Cell[202706, 4574, 402, 7, 75, "Input"],
Cell[203111, 4583, 153919, 3107, 495, 28357, 1554, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357067, 7695, 44, 0, 27, "Input"],
Cell[357114, 7697, 1078, 17, 159, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358229, 7719, 190, 5, 27, "Input"],
Cell[358422, 7726, 320, 5, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358779, 7736, 185, 4, 42, "Input"],
Cell[358967, 7742, 151302, 3080, 495, 28692, 1563, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

